-- Configurem alguns paràmetres
SET FEEDBACK OFF
SET ESCAPE ON
ALTER SESSION SET NLS_DATE_FORMAT='DD/MM/YYYY';



-- Eliminem les taules prèviament creades
DROP TABLE participants CASCADE CONSTRAINTS;
DROP TABLE pelis CASCADE CONSTRAINTS;
DROP TABLE pelis_actors CASCADE CONSTRAINTS;
DROP TABLE titols CASCADE CONSTRAINTS;

-- Definim ara les taules correctament
CREATE TABLE participants (
  codi		NUMBER(10) PRIMARY KEY,
  nom 		VARCHAR2(45) NOT NULL,
  sexe 		CHAR(1) NOT NULL,
  naixement	DATE,
  defuncio	DATE,
  CONSTRAINT participants_sexe_ck CHECK (sexe IN ('H','D')),
  CONSTRAINT participants_defuncio_ck CHECK (defuncio > naixement)
);

CREATE TABLE pelis (
  codi 		NUMBER(10) CONSTRAINT pelis_codi_pk PRIMARY KEY,
  produccio	NUMBER(4),
  color		CHAR(1) DEFAULT 'S',
  director_id	NUMBER(10),
  CONSTRAINT pelis_color_ck CHECK (color IN ('S','N')),
  CONSTRAINT pelis_director_id_fk FOREIGN KEY (director_id) REFERENCES participants(codi)
);

CREATE TABLE pelis_actors (
  codi_peli	NUMBER(10) REFERENCES pelis(codi),
  codi_actor	NUMBER(10) REFERENCES participants(codi)
);

CREATE TABLE titols (
  peli		NUMBER(10) NOT NULL,
  locale	CHAR(6) NOT NULL,
  original	CHAR(1),
  titol		VARCHAR2(150) NOT NULL,
  estrena	DATE,
  CONSTRAINT titols_peli_fk FOREIGN KEY (peli) REFERENCES pelis(codi),
  CONSTRAINT titols_original_ck CHECK (original IN ('S','N')),
  CONSTRAINT titols_locale_ck CHECK (locale = LOWER(SUBSTR(locale, 1, 2)) || '_' || UPPER(SUBSTR(locale, 4, 3)))
);



-- Informació dels actors participants
INSERT INTO participants VALUES (  1, 'Orson Welles',		'H', '06/05/1915', '10/10/1985');
INSERT INTO participants VALUES (  2, 'Joseph Cotten',		'H', '15/05/1905', '06/02/1994');
INSERT INTO participants VALUES (  3, 'Dorothy Comingore',	'D', '24/08/1913', '30/12/1971');
INSERT INTO participants VALUES (  4, 'Humphrey Bogart',	'H', '25/12/1899', '14/01/1957');
INSERT INTO participants VALUES (  5, 'Ingrid Bergman',		'D', '29/08/1915', '29/08/1982');
INSERT INTO participants VALUES (  6, 'Paul Henreid',		'H', '10/01/1908', '29/03/1992');
INSERT INTO participants VALUES (  7, 'Marlon Brando', 		'H', '03/04/1924', '01/07/2004');
INSERT INTO participants VALUES (  8, 'Al Pacino', 		'H', '25/04/1940', NULL);
INSERT INTO participants VALUES (  9, 'James Caan', 		'H', '26/03/1940', NULL);
INSERT INTO participants VALUES ( 10, 'Robert Duvall', 		'H', '05/01/1931', NULL);
INSERT INTO participants VALUES ( 11, 'Diane Keaton', 		'D', '05/01/1946', NULL);
INSERT INTO participants VALUES ( 12, 'Clark Gable', 		'H', '01/02/1901', '16/11/1960');
INSERT INTO participants VALUES ( 13, 'Vivien Leigh', 		'D', '05/11/1913', '07/07/1967');
INSERT INTO participants VALUES ( 14, 'Thomas Mitchell', 	'H', '11/07/1892', '17/12/1962');
INSERT INTO participants VALUES ( 15, 'Keir Dullea', 		'H', '30/05/1936', NULL);
INSERT INTO participants VALUES ( 16, 'Gary Lockwood', 		'H', '21/02/1937', NULL);
INSERT INTO participants VALUES ( 17, 'William Sylvester', 	'H', '31/01/1922', '25/01/1995');
INSERT INTO participants VALUES ( 18, 'Peter O''Toole', 	'H', '02/08/1932', NULL);
INSERT INTO participants VALUES ( 19, 'Alec Guinness', 		'H', '02/04/1914', '05/08/2000');
INSERT INTO participants VALUES ( 20, 'Anthony Quinn', 		'H', '21/04/1915', '03/06/2001');
INSERT INTO participants VALUES ( 21, 'Omar Sharif', 		'H', '10/04/1932', NULL);
INSERT INTO participants VALUES ( 22, 'Judy Garland', 		'D', '10/06/1922', '22/06/1969');
INSERT INTO participants VALUES ( 23, 'Frank Morgan', 		'H', '01/06/1890', '18/09/1949');
INSERT INTO participants VALUES ( 24, 'Ray Bolger', 		'H', '10/01/1904', '15/01/1987');
INSERT INTO participants VALUES ( 25, 'Bert Lahr', 		'H', '13/08/1895', '04/12/1967');
INSERT INTO participants VALUES ( 26, 'Jack Haley', 		'H', '10/08/1898', '06/06/1979');
INSERT INTO participants VALUES ( 27, 'Dustin Hoffman', 	'H', '08/08/1937', NULL);
INSERT INTO participants VALUES ( 28, 'Anne Bancroft', 		'D', '17/09/1931', '06/06/2005');
INSERT INTO participants VALUES ( 29, 'Katharine Ross', 	'D', '29/01/1940', NULL);
INSERT INTO participants VALUES ( 30, 'Karl Malden', 		'H', '22/03/1912', '01/07/2009');
INSERT INTO participants VALUES ( 31, 'Lee J. Cobb', 		'H', '08/12/1911', '11/02/1976');
INSERT INTO participants VALUES ( 32, 'Rod Steiger', 		'H', '14/04/1925', '09/07/2002');
INSERT INTO participants VALUES ( 33, 'Liam Neeson', 		'H', '07/06/1952', NULL);
INSERT INTO participants VALUES ( 34, 'Ralph Fiennes', 		'H', '22/12/1962', NULL);
INSERT INTO participants VALUES ( 35, 'Ben Kingsley', 		'H', '31/12/1943', NULL);
INSERT INTO participants VALUES ( 36, 'Caroline Goodall',	'D', '13/11/1959', NULL);
INSERT INTO participants VALUES ( 37, 'Gene Kelly',		'H', '23/08/1912', '02/02/1996');
INSERT INTO participants VALUES ( 38, 'Donald O''Connor',	'H', '28/08/1925', '27/09/2003');
INSERT INTO participants VALUES ( 39, 'Debbie Reynolds', 	'D', '01/04/1932', NULL);
INSERT INTO participants VALUES ( 40, 'James Stewart', 		'H', '20/05/1908', '02/07/1997');
INSERT INTO participants VALUES ( 41, 'Donna Reed',		'D', '27/01/1921', '14/01/1986');
INSERT INTO participants VALUES ( 42, 'Lionel Barrymore',	'H', '28/04/1878', '15/11/1954');
INSERT INTO participants VALUES ( 43, 'William Holden',		'H', '17/04/1918', '16/11/1981');
INSERT INTO participants VALUES ( 44, 'Gloria Swanson',		'D', '27/03/1899', '04/04/1983');
INSERT INTO participants VALUES ( 45, 'Erich von Stroheim',	'H', '22/09/1885', '12/05/1957');
INSERT INTO participants VALUES ( 46, 'Nancy Olson',		'D', '14/07/1928', NULL);
INSERT INTO participants VALUES ( 47, 'Jack Hawkins',		'H', '14/09/1910', '18/07/1973');
INSERT INTO participants VALUES ( 48, 'Marilyn Monroe',		'D', '01/06/1926', '05/08/1962');
INSERT INTO participants VALUES ( 49, 'Tony Curtis', 		'H', '03/06/1925', '29/09/2010');
INSERT INTO participants VALUES ( 50, 'Jack Lemmon',		'H', '08/02/1925', '27/06/2001');
INSERT INTO participants VALUES ( 51, 'Mark Hamill', 		'H', '25/09/1951', NULL);
INSERT INTO participants VALUES ( 52, 'Harrison Ford',		'H', '13/07/1942', NULL);
INSERT INTO participants VALUES ( 53, 'Carrie Fisher',		'D', '21/10/1956', NULL);
INSERT INTO participants VALUES ( 54, 'Peter Cushing',		'H', '26/05/1913', '11/08/1994');
INSERT INTO participants VALUES ( 55, 'Bette Davis', 		'D', '05/04/1908', '06/10/1989');
INSERT INTO participants VALUES ( 56, 'Anne Baxter', 		'D', '07/05/1923', '12/12/1985');
INSERT INTO participants VALUES ( 57, 'George Sanders',		'H', '03/07/1906', '25/04/1972');
INSERT INTO participants VALUES ( 58, 'Celeste Holms',		'D', '29/04/1917', NULL);
INSERT INTO participants VALUES ( 59, 'Katharine Hepburn', 	'D', '12/05/1907', '29/06/2003');
INSERT INTO participants VALUES ( 60, 'Robert Morley', 		'H', '26/05/1908', '03/06/1992');
INSERT INTO participants VALUES ( 61, 'Anthony Perkins', 	'H', '04/04/1932', '12/09/1992');
INSERT INTO participants VALUES ( 62, 'Vera Miles', 		'D', '23/08/1929', NULL);
INSERT INTO participants VALUES ( 63, 'John Gavin', 		'H', '08/04/1931', NULL);
INSERT INTO participants VALUES ( 64, 'Janet Leigh', 		'D', '06/07/1927', '03/10/2004');
INSERT INTO participants VALUES ( 65, 'Jack Nicholson', 	'H', '22/04/1937', NULL);
INSERT INTO participants VALUES ( 66, 'Faye Dunaway', 		'D', '14/01/1941', NULL);
INSERT INTO participants VALUES ( 67, 'John Huston', 		'H', '05/08/1906', '28/08/1987');
INSERT INTO participants VALUES ( 68, 'Louis Fletcher',		'D', '22/07/1934', NULL);
INSERT INTO participants VALUES ( 69, 'Danny DeVito',		'D', '17/11/1944', NULL);
INSERT INTO participants VALUES ( 70, 'Henry Fonda', 		'H', '16/05/1905', '12/08/1982');
INSERT INTO participants VALUES ( 71, 'Jane Darwell', 		'D', '15/10/1879', '13/08/1967');
INSERT INTO participants VALUES ( 72, 'John Carradine', 	'H', '05/02/1906', '27/11/1988');
INSERT INTO participants VALUES ( 73, 'Mary Astor', 		'D', '03/05/1906', '25/09/1987');
INSERT INTO participants VALUES ( 74, 'Gladys George', 		'D', '13/09/1900', '08/12/1954');
INSERT INTO participants VALUES ( 75, 'Peter Lorre', 		'H', '26/06/1904', '23/03/1964');
INSERT INTO participants VALUES ( 76, 'Robert de Niro', 	'H', '17/08/1943', NULL);
INSERT INTO participants VALUES ( 77, 'Cathy Moriarty', 	'D', '29/11/1960', NULL);
INSERT INTO participants VALUES ( 78, 'Joe Pesci', 		'H', '09/02/1943', NULL);
INSERT INTO participants VALUES ( 79, 'Henry Thomas',		'H', '09/09/1971', NULL);
INSERT INTO participants VALUES ( 80, 'Drew Barrymore',		'D', '22/02/1975', NULL);
INSERT INTO participants VALUES ( 81, 'Peter Coyote',		'H', '10/10/1941', NULL);
INSERT INTO participants VALUES ( 82, 'Dee Wallace',		'D', '14/12/1948', NULL);
INSERT INTO participants VALUES ( 83, 'Peter Sellers',		'H', '08/09/1925', '24/07/1980');
INSERT INTO participants VALUES ( 84, 'George C. Scott',	'H', '18/10/1927', '22/09/1999');
INSERT INTO participants VALUES ( 85, 'Sterling Hayden',	'H', '26/03/1916', '23/05/1986');
INSERT INTO participants VALUES ( 86, 'Warren Beatty',		'H', '30/03/1937', NULL);
INSERT INTO participants VALUES ( 87, 'Michael J. Pollard',	'H', '30/05/1939', NULL);
INSERT INTO participants VALUES ( 88, 'Gene Hackman',		'H', '30/01/1930', NULL);
INSERT INTO participants VALUES ( 89, 'Estelle Parsons',	'D', '20/11/1927', NULL);
INSERT INTO participants VALUES ( 90, 'Martin Sheen',		'H', '03/08/1940', NULL);
INSERT INTO participants VALUES ( 91, 'Frederic Forrest',	'H', '23/12/1936', NULL);
INSERT INTO participants VALUES ( 92, 'Laurence Fishburne',	'H', '30/07/1961', NULL);
INSERT INTO participants VALUES ( 93, 'Dennis Hopper',		'H', '17/05/1936', '29/05/2010');
INSERT INTO participants VALUES ( 94, 'Scott Glenn',		'H', '26/01/1941', NULL);
INSERT INTO participants VALUES ( 95, 'Jean Arthur',		'D', '17/10/1900', '19/06/1991');
INSERT INTO participants VALUES ( 96, 'Claude Rains',		'H', '10/11/1889', '30/05/1967');
INSERT INTO participants VALUES ( 97, 'Walter Huston', 		'H', '06/04/1884', '07/04/1950');
INSERT INTO participants VALUES ( 98, 'Tim Holt',		'H', '05/02/1919', '15/02/1973');
INSERT INTO participants VALUES ( 99, 'Woody Allen', 		'H', '01/12/1935', NULL);
INSERT INTO participants VALUES (100, 'Tony Roberts',		'H', '22/10/1939', NULL);
INSERT INTO participants VALUES (101, 'Christopher Walken',	'H', '31/03/1943', NULL);
INSERT INTO participants VALUES (102, 'Gary Cooper',		'H', '07/05/1901', '13/05/1961');
INSERT INTO participants VALUES (103, 'Grace Kelly',		'D', '12/11/1929', '14/09/1982');
INSERT INTO participants VALUES (104, 'Lloyd Bridges',		'H', '15/01/1913', '10/03/1998');
INSERT INTO participants VALUES (105, 'Gregory Peck',		'H', '05/04/1916', '12/06/2003');
INSERT INTO participants VALUES (106, 'John Megna', 		'H', '09/11/1952', '05/09/1995');
INSERT INTO participants VALUES (107, 'Frank Overton', 		'H', '12/03/1918', '24/04/1967');
INSERT INTO participants VALUES (108, 'Brook Peters', 		'H', '02/07/1927', '23/08/2005');
INSERT INTO participants VALUES (109, 'Claudette Colbert', 	'D', '13/09/1903', '30/07/1996');
INSERT INTO participants VALUES (110, 'Walter Connolly',	'H', '08/04/1887', '28/05/1940');
INSERT INTO participants VALUES (111, 'Jon Voight',		'H', '29/12/1938', NULL);
INSERT INTO participants VALUES (112, 'Sylvia Miles',		'D', '09/09/1932', NULL);
INSERT INTO participants VALUES (113, 'Myrna Loy', 		'D', '02/08/1905', '14/12/1993');
INSERT INTO participants VALUES (114, 'Fredic March', 		'H', '30/08/1897', '14/04/1975');
INSERT INTO participants VALUES (115, 'Dana Andrews', 		'H', '01/01/1909', '17/12/1992');
INSERT INTO participants VALUES (116, 'Teresa Wright',		'D', '27/10/1918', '06/03/2005');
INSERT INTO participants VALUES (117, 'Virginia Mayo', 		'D', '30/11/1920', '17/01/2005');
INSERT INTO participants VALUES (118, 'Fred MacMurray', 	'H', '30/08/1908', '05/11/1991');
INSERT INTO participants VALUES (119, 'Barbara Stanwyck', 	'D', '16/07/1907', '20/01/1990');
INSERT INTO participants VALUES (120, 'Edward G. Robinson', 	'H', '12/12/1893', '26/01/1973');
INSERT INTO participants VALUES (121, 'Julie Christie', 	'D', '14/04/1941', NULL);
INSERT INTO participants VALUES (122, 'Geraldine Chaplin', 	'D', '31/07/1944', NULL);
INSERT INTO participants VALUES (123, 'Tom Courtenay', 		'H', '25/02/1937', NULL);
INSERT INTO participants VALUES (124, 'Cary Grant',		'H', '18/01/1904', '29/11/1986');
INSERT INTO participants VALUES (125, 'Eva Marie Saint',	'D', '04/07/1924', NULL);
INSERT INTO participants VALUES (126, 'James Mason',		'H', '15/05/1909', '27/07/1984');
INSERT INTO participants VALUES (127, 'Martin Landau',		'H', '20/06/1928', NULL);
INSERT INTO participants VALUES (128, 'Natalie Wood', 		'D', '20/06/1938', '29/11/1981');
INSERT INTO participants VALUES (129, 'George Chakiris', 	'H', '16/09/1934', NULL);
INSERT INTO participants VALUES (130, 'Richard Beymer', 	'H', '20/02/1938', NULL);
INSERT INTO participants VALUES (131, 'Wendell Corey',		'H', '20/03/1941', '08/11/1968');
INSERT INTO participants VALUES (132, 'Thelma Ritter', 		'D', '14/02/1905', '05/02/1969');
INSERT INTO participants VALUES (133, 'Fay Wray',		'D', '15/09/1907', '08/08/2004');
INSERT INTO participants VALUES (134, 'Robert Armstrong', 	'H', '20/11/1890', '20/04/1973');
INSERT INTO participants VALUES (135, 'Bruce Cabot',		'H', '20/04/1904', '03/05/1972');
INSERT INTO participants VALUES (136, 'Lillian Gish', 		'D', '14/10/1893', '27/02/1993');
INSERT INTO participants VALUES (137, 'Mae Marsh', 		'D', '09/11/1894', '13/02/1968');
INSERT INTO participants VALUES (138, 'Henry B. Walthall', 	'H', '16/03/1878', '17/06/1936');
INSERT INTO participants VALUES (139, 'Kim Hunter', 		'D', '12/11/1922', '11/09/2002');
INSERT INTO participants VALUES (140, 'Malcolm McDowell',	'H', '13/06/1943', NULL);
INSERT INTO participants VALUES (141, 'Patrick Magee',		'H', '31/03/1922', '14/08/1982');
INSERT INTO participants VALUES (142, 'Michael Bates', 		'H', '04/12/1920', '11/01/1978');
INSERT INTO participants VALUES (143, 'Jodie Foster', 		'D', '19/11/1962', NULL);
INSERT INTO participants VALUES (144, 'Cybill Shepherd', 	'D', '18/02/1950', NULL);
INSERT INTO participants VALUES (145, 'Albert Brooks', 		'H', '22/07/1947', NULL);
INSERT INTO participants VALUES (146, 'Peter Boyle',		'H', '18/10/1935', '12/12/2006');
INSERT INTO participants VALUES (147, 'Roy Scheider', 		'H', '10/11/1932', '10/02/2008');
INSERT INTO participants VALUES (148, 'Robert Shaw', 		'H', '09/08/1927', '28/08/1978');
INSERT INTO participants VALUES (149, 'Richard Dreyfuss', 	'H', '29/10/1947', NULL);
INSERT INTO participants VALUES (150, 'Paul Newman', 		'H', '26/01/1925', '26/09/2008');
INSERT INTO participants VALUES (151, 'Robert Redford', 	'H', '18/08/1936', NULL);
INSERT INTO participants VALUES (152, 'Toshiro Mifune', 	'H', '01/04/1920', '24/12/1997');
INSERT INTO participants VALUES (153, 'Takashi Shimura', 	'H', '12/03/1905', '11/02/1982');
INSERT INTO participants VALUES (154, 'Keiko Tsushima', 	'D', '07/02/1926', NULL);
INSERT INTO participants VALUES (155, 'John Howard', 		'H', '14/04/1913', '19/02/1995');
INSERT INTO participants VALUES (156, 'Burt Lancaster',		'H', '02/11/1913', '20/10/1994');
INSERT INTO participants VALUES (157, 'Montgomery Clift', 	'H', '17/10/1920', '23/07/1966');
INSERT INTO participants VALUES (158, 'Deborah Kerr', 		'D', '30/09/1921', '16/10/2007');
INSERT INTO participants VALUES (159, 'Frank Sinatra', 		'H', '12/12/1915', '14/05/1998');
INSERT INTO participants VALUES (160, 'Ernest Borgnine', 	'H', '24/01/1917', NULL);
INSERT INTO participants VALUES (161, 'Jack Warden', 		'H', '18/09/1920', '19/07/2006');
INSERT INTO participants VALUES (162, 'F. Murray Abraham', 	'H', '24/10/1939', NULL);
INSERT INTO participants VALUES (163, 'Tom Hulce', 		'H', '06/12/1953', NULL);
INSERT INTO participants VALUES (164, 'Elizabeth Berridge', 	'D', '02/05/1962', NULL);
INSERT INTO participants VALUES (165, 'Lew Ayres', 		'H', '28/12/1908', '30/12/1996');
INSERT INTO participants VALUES (166, 'Louis Wolheim', 		'H', '28/03/1880', '18/02/1931');
INSERT INTO participants VALUES (167, 'John Wray', 		'H', '13/02/1887', '05/04/1940');
INSERT INTO participants VALUES (168, 'Julie Andrews', 		'D', '01/10/1935', NULL);
INSERT INTO participants VALUES (169, 'Christopher Plummer',	'H', '13/12/1929', NULL);
INSERT INTO participants VALUES (170, 'Eleanor Parker', 	'D', '26/06/1922', NULL);
INSERT INTO participants VALUES (171, 'Alida Valli', 		'D', '31/05/1921', '22/04/2006');
INSERT INTO participants VALUES (172, 'Trevor Howard', 		'H', '29/09/1913', '07/01/1988');
INSERT INTO participants VALUES (173, 'James Dean', 		'H', '08/02/1931', '30/09/1955');
INSERT INTO participants VALUES (174, 'Sal Mineo', 		'H', '10/01/1939', '12/02/1976');
INSERT INTO participants VALUES (175, 'Karen Allen', 		'D', '05/10/1951', NULL);
INSERT INTO participants VALUES (176, 'Paul Freeman', 		'H', '18/01/1943', NULL);
INSERT INTO participants VALUES (177, 'John Rhys-Davies', 	'H', '05/05/1944', NULL);
INSERT INTO participants VALUES (178, 'Kim Novak', 		'D', '13/02/1933', NULL);
INSERT INTO participants VALUES (179, 'Barbara Bel Geddes', 	'D', '31/10/1922', '08/08/2005');
INSERT INTO participants VALUES (180, 'Jessica Lange', 		'D', '20/04/1949', NULL);
INSERT INTO participants VALUES (181, 'Teri Garr', 		'D', '11/12/1947', NULL);
INSERT INTO participants VALUES (182, 'Dabney Coleman', 	'H', '03/01/1932', NULL);
INSERT INTO participants VALUES (183, 'Bill Murray', 		'H', '21/09/1950', NULL);
INSERT INTO participants VALUES (184, 'Sydney Pollack', 	'H', '01/07/1934', '26/05/2008');
INSERT INTO participants VALUES (185, 'Geena Davis', 		'D', '21/01/1956', NULL);
INSERT INTO participants VALUES (186, 'John Wayne', 		'H', '26/05/1907', '11/06/1979');
INSERT INTO participants VALUES (187, 'Claire Trevor', 		'D', '08/03/1910', '08/04/2000');
INSERT INTO participants VALUES (188, 'Andy Devine', 		'H', '07/10/1905', '18/02/1977');
INSERT INTO participants VALUES (189, 'Francois Truffaut', 	'H', '06/02/1932', '21/10/1984');
INSERT INTO participants VALUES (190, 'Melinda Dillon', 	'D', '13/10/1939', NULL);
INSERT INTO participants VALUES (191, 'Anthony Hopkins',	'H', '31/12/1937', NULL);
INSERT INTO participants VALUES (192, 'Peter Finch', 		'H', '28/09/1916', '14/01/1977');
INSERT INTO participants VALUES (193, 'Denzel Washington', 	'H', '28/12/1954', NULL);
INSERT INTO participants VALUES (194, 'Liev Schreiber', 	'H', '04/10/1967', NULL);
INSERT INTO participants VALUES (195, 'Meryl Streep', 		'D', '22/06/1949', NULL);
INSERT INTO participants VALUES (196, 'Leslie Caron', 		'D', '01/07/1931', NULL);
INSERT INTO participants VALUES (197, 'Oscar Levant', 		'H', '27/12/1906', '14/08/1972');
INSERT INTO participants VALUES (198, 'Alan Ladd', 		'H', '03/09/1913', '29/01/1964');
INSERT INTO participants VALUES (199, 'Van Heflin', 		'H', '13/12/1910', '23/07/1971');
INSERT INTO participants VALUES (200, 'Jack Palance', 		'H', '18/02/1919', '10/11/2006');
INSERT INTO participants VALUES (201, 'Fernando Rey',		'H', '20/09/1917', '09/03/1994');
INSERT INTO participants VALUES (202, 'Tony lo Bianco',		'H', '19/10/1936', NULL);
INSERT INTO participants VALUES (203, 'Tom Hanks', 		'H', '09/07/1956', NULL);
INSERT INTO participants VALUES (204, 'Robin Wright', 		'D', '08/04/1966', NULL);
INSERT INTO participants VALUES (205, 'Gary Sinise', 		'H', '17/03/1955', NULL);
INSERT INTO participants VALUES (206, 'Sally Field', 		'D', '06/11/1946', NULL);
INSERT INTO participants VALUES (207, 'Charlton Heston', 	'H', '04/10/1923', '05/04/2008');
INSERT INTO participants VALUES (208, 'Steven Boyd', 		'H', '04/07/1931', '02/06/1977');
INSERT INTO participants VALUES (209, 'Hugh Griffith', 		'H', '30/05/1912', '14/05/1980');
INSERT INTO participants VALUES (210, 'Laurence Olivier', 	'H', '22/03/1907', '11/07/1989');
INSERT INTO participants VALUES (211, 'Merle Oberon', 		'D', '19/02/1911', '23/11/1979');
INSERT INTO participants VALUES (212, 'David Niven', 		'H', '01/03/1910', '29/07/1983');
INSERT INTO participants VALUES (213, 'Geraldine Fitzgerald', 	'D', '24/11/1913', '17/07/2005');
INSERT INTO participants VALUES (214, 'Charles Chaplin',	'H', '16/04/1889', '25/12/1977');
INSERT INTO participants VALUES (215, 'Mack Swain', 		'H', '16/02/1876', '25/08/1935');
INSERT INTO participants VALUES (216, 'Tom Murray', 		'H', '08/09/1874', '27/08/1935');
INSERT INTO participants VALUES (217, 'Kevin Costner', 		'H', '18/01/1955', NULL);
INSERT INTO participants VALUES (218, 'Mary McDonnell', 	'D', '28/04/1952', NULL);
INSERT INTO participants VALUES (219, 'Graham Greene', 		'H', '22/06/1952', NULL);
INSERT INTO participants VALUES (220, 'Virginia Cherrill', 	'D', '12/04/1908', '14/11/1996');
INSERT INTO participants VALUES (221, 'Florence Lee', 		'D', '12/03/1858', '01/09/1962');
INSERT INTO participants VALUES (222, 'Ron Howard', 		'H', '01/03/1954', NULL);
INSERT INTO participants VALUES (223, 'Paul Le Mat', 		'H', '22/09/1946', NULL);
INSERT INTO participants VALUES (224, 'Charles Martin Smith', 	'H', '30/10/1953', NULL);
INSERT INTO participants VALUES (225, 'Cindy Williams', 	'D', '22/08/1947', NULL);
INSERT INTO participants VALUES (226, 'Candy Clark', 		'D', '20/06/1947', NULL);
INSERT INTO participants VALUES (227, 'Mackenzie Phillips',	'D', '10/11/1959', NULL);
INSERT INTO participants VALUES (228, 'Bo Hopkins', 		'H', '02/02/1942', NULL);
INSERT INTO participants VALUES (229, 'Sylvester Stallone',	'H', '06/07/1946', NULL);
INSERT INTO participants VALUES (230, 'Talia Shire', 		'D', '25/04/1946', NULL);
INSERT INTO participants VALUES (231, 'Burt Young', 		'H', '30/04/1940', NULL);
INSERT INTO participants VALUES (232, 'Carl Weathers', 		'H', '14/01/1948', NULL);
INSERT INTO participants VALUES (233, 'Burgess Meredith', 	'H', '16/11/1907', '09/07/1997');
INSERT INTO participants VALUES (234, 'John Cazale',		'H', '12/08/1935', '12/03/1978');
INSERT INTO participants VALUES (235, 'John Savage', 		'H', '25/08/1949', NULL);
INSERT INTO participants VALUES (236, 'Robert Ryan', 		'H', '11/11/1909', '11/07/1973');
INSERT INTO participants VALUES (237, 'Edmon O''Brien', 	'H', '10/09/1915', '09/05/1985');
INSERT INTO participants VALUES (238, 'Warren Oates', 		'H', '05/07/1928', '03/04/1982');
INSERT INTO participants VALUES (239, 'Paulette Goddard', 	'D', '03/06/1910', '23/04/1990');
INSERT INTO participants VALUES (240, 'Henry Bergman', 		'H', '23/02/1868', '22/10/1946');
INSERT INTO participants VALUES (241, 'Elizabeth Taylor', 	'D', '27/02/1932', '23/03/2011');
INSERT INTO participants VALUES (242, 'Rock Hudson', 		'H', '17/11/1925', '02/10/1985');
INSERT INTO participants VALUES (243, 'Caroll Baker', 		'D', '28/05/1931', NULL);
INSERT INTO participants VALUES (244, 'Jane Withers', 		'D', '12/04/1926', NULL);
INSERT INTO participants VALUES (245, 'Chill Wills', 		'H', '18/07/1902', '15/12/1978');
INSERT INTO participants VALUES (246, 'Mercedes McCambridge', 	'D', '16/03/1916', '02/03/2004');
INSERT INTO participants VALUES (247, 'Rod Taylor', 		'H', '11/01/1930', NULL);
INSERT INTO participants VALUES (248, 'Charlie Sheen', 		'H', '03/09/1965', NULL);
INSERT INTO participants VALUES (249, 'Tom Berenger', 		'H', '31/05/1949', NULL);
INSERT INTO participants VALUES (250, 'Willem Dafoe', 		'H', '22/07/1955', NULL);
INSERT INTO participants VALUES (251, 'Forest Whitaker', 	'H', '15/07/1961', NULL);
INSERT INTO participants VALUES (252, 'Johnny Depp', 		'H', '09/06/1963', NULL);
INSERT INTO participants VALUES (253, 'William H. Macy', 	'H', '13/03/1950', NULL);
INSERT INTO participants VALUES (254, 'Frances McDormand', 	'D', '23/06/1957', NULL);
INSERT INTO participants VALUES (255, 'Steve Buscemi', 		'H', '13/12/1957', NULL);
INSERT INTO participants VALUES (256, 'Peter Stormare', 	'H', '27/08/1953', NULL);
INSERT INTO participants VALUES (257, 'Groucho Marx', 		'H', '02/10/1890', '19/08/1977');
INSERT INTO participants VALUES (258, 'Harpo Marx', 		'H', '23/11/1888', '28/09/1964');
INSERT INTO participants VALUES (259, 'Chico Marx', 		'H', '22/03/1887', '11/10/1961');
INSERT INTO participants VALUES (260, 'Zeppo Marx', 		'H', '25/02/1901', '30/11/1979');
INSERT INTO participants VALUES (261, 'Margaret Dumont', 	'D', '20/10/1882', '06/03/1965');
INSERT INTO participants VALUES (262, 'Charles Middleton', 	'H', '03/10/1874', '22/04/1949');
INSERT INTO participants VALUES (263, 'Joanne Woodward', 	'D', '27/02/1930', NULL);
INSERT INTO participants VALUES (264, 'Jason Robards',		'H', '26/07/1922', '26/12/2000');
INSERT INTO participants VALUES (265, 'Charles Laughton',	'H', '01/07/1899', '15/12/1962');
INSERT INTO participants VALUES (266, 'Franchot Tone', 		'H', '27/02/1905', '18/09/1968');
INSERT INTO participants VALUES (267, 'Colin Clive', 		'H', '20/01/1900', '25/06/1937');
INSERT INTO participants VALUES (268, 'Mae Clarke', 		'D', '16/08/1910', '29/04/1992');
INSERT INTO participants VALUES (269, 'Boris Karloff', 		'H', '23/11/1887', '02/02/1969');
INSERT INTO participants VALUES (270, 'Peter Fonda', 		'H', '23/02/1940', NULL);
INSERT INTO participants VALUES (271, 'Stephen Young', 		'H', '19/05/1931', NULL);
INSERT INTO participants VALUES (272, 'Al Jolson', 		'H', '26/05/1886', '23/10/1950');
INSERT INTO participants VALUES (273, 'May McAvoy', 		'D', '08/09/1899', '26/04/1984');
INSERT INTO participants VALUES (274, 'Warner Oland', 		'H', '03/10/1879', '06/08/1938');
INSERT INTO participants VALUES (275, 'Audrey Hepburn', 	'D', '04/05/1929', '20/01/1993');
INSERT INTO participants VALUES (276, 'Rex Harrison', 		'H', '05/03/1908', '02/06/1990');
INSERT INTO participants VALUES (277, 'Stanley Holloway', 	'H', '01/10/1890', '30/01/1982');
INSERT INTO participants VALUES (278, 'Shelley Winters', 	'D', '18/08/1920', '14/01/2006');
INSERT INTO participants VALUES (279, 'Shirley MacLaine', 	'D', '24/04/1934', NULL);
INSERT INTO participants VALUES (280, 'Ray Walston',		'H', '02/12/1914', '01/01/2001');
INSERT INTO participants VALUES (281, 'Ray Liotta', 		'H', '18/12/1954', NULL);
INSERT INTO participants VALUES (282, 'Paul Sorvino', 		'H', '13/04/1939', NULL);
INSERT INTO participants VALUES (283, 'John Travolta', 		'H', '18/02/1954', NULL);
INSERT INTO participants VALUES (284, 'Uma Thurman', 		'D', '29/04/1970', NULL);
INSERT INTO participants VALUES (285, 'Samuel L. Jackson', 	'H', '21/12/1948', NULL);
INSERT INTO participants VALUES (286, 'Rosanna Arquette', 	'D', '10/08/1959', NULL);
INSERT INTO participants VALUES (287, 'Tim Roth', 		'H', '14/05/1961', NULL);
INSERT INTO participants VALUES (288, 'Amanda Plummer',		'D', '23/03/1957', NULL);
INSERT INTO participants VALUES (289, 'Eric Stoltz', 		'H', '30/09/1961', NULL);
INSERT INTO participants VALUES (290, 'Bruce Willis', 		'H', '19/03/1955', NULL);
INSERT INTO participants VALUES (291, 'Jeffrey Hunter',		'H', '25/11/1926', '27/05/1969');
INSERT INTO participants VALUES (292, 'Ward Bond', 		'H', '09/04/1903', '05/11/1960');
INSERT INTO participants VALUES (293, 'Charles Ruggles', 	'H', '08/02/1886', '23/12/1970');
INSERT INTO participants VALUES (294, 'Clint Eastwood', 	'H', '31/05/1930', NULL);
INSERT INTO participants VALUES (295, 'Morgan Freeman', 	'H', '01/06/1937', NULL);
INSERT INTO participants VALUES (296, 'Richard Harris', 	'H', '01/10/1930', '25/10/2002');
INSERT INTO participants VALUES (297, 'Saul Rubinek', 		'H', '02/07/1948', NULL);
INSERT INTO participants VALUES (298, 'Spencer Tracy', 		'H', '05/04/1900', '10/06/1967');
INSERT INTO participants VALUES (299, 'Sidney Poitier', 	'H', '20/02/1927', NULL);
INSERT INTO participants VALUES (300, 'James Cagney', 		'H', '17/07/1899', '30/03/1986');
INSERT INTO participants VALUES (301, 'Joan Leslie', 		'D', '26/01/1925', NULL);
INSERT INTO participants VALUES (302, 'Susan Sarandon', 	'D', '04/10/1946', NULL);
INSERT INTO participants VALUES (303, 'Harvey Keitel', 		'H', '13/05/1939', NULL);
INSERT INTO participants VALUES (304, 'Michael Madsen',		'H', '25/09/1957', NULL);
INSERT INTO participants VALUES (305, 'Brad Pitt', 		'H', '18/12/1963', NULL);
INSERT INTO participants VALUES (306, 'Shelley Duval', 		'D', '07/07/1949', NULL);
INSERT INTO participants VALUES (307, 'Danny Lloyd', 		'H', '01/01/1973', NULL);
INSERT INTO participants VALUES (308, 'Joe Turkel', 		'H', '15/07/1927', NULL);
INSERT INTO participants VALUES (309, 'Rutger Hauer', 		'H', '23/01/1944', NULL);
INSERT INTO participants VALUES (310, 'Sean Young', 		'D', '20/11/1959', NULL);
INSERT INTO participants VALUES (311, 'Edward James Olmos', 	'H', '24/02/1947', NULL);
INSERT INTO participants VALUES (312, 'M. Emmet Walsh', 	'H', '22/03/1935', NULL);
INSERT INTO participants VALUES (313, 'Daryl Hannah', 		'D', '03/12/1960', NULL);
INSERT INTO participants VALUES (314, 'William Sanderson', 	'H', '10/01/1944', NULL);
INSERT INTO participants VALUES (315, 'Brion James', 		'H', '20/02/1945', '07/08/1999');
INSERT INTO participants VALUES (316, 'Joanna Cassidy', 	'D', '02/08/1945', NULL);
INSERT INTO participants VALUES (317, 'James Hong', 		'H', '22/02/1929', NULL);
INSERT INTO participants VALUES (318, 'Kevin Spacey', 		'H', '26/07/1959', NULL);
INSERT INTO participants VALUES (319, 'Gwyneth Paltrow', 	'D', '27/09/1972', NULL);
INSERT INTO participants VALUES (320, 'R. Lee Ermey', 		'H', '24/03/1944', NULL);
INSERT INTO participants VALUES (321, 'Hilary Swank', 		'D', '30/07/1974', NULL);
INSERT INTO participants VALUES (322, 'Ivana Baquero', 		'D', '11/06/1994', NULL);
INSERT INTO participants VALUES (323, 'Ariadna Gil', 		'D', '23/01/1969', NULL);
INSERT INTO participants VALUES (324, 'Sergi López', 		'H', '22/12/1965', NULL);
INSERT INTO participants VALUES (325, 'Maribel Verdú', 		'D', '02/10/1970', NULL);
INSERT INTO participants VALUES (326, 'Aleksandr Antonov', 	'H', '26/11/1962', NULL);
INSERT INTO participants VALUES (327, 'Vladimir Barsky', 	'H', NULL,         '24/01/1936');
INSERT INTO participants VALUES (328, 'Grigori Aleksandrov', 	'H', '23/01/1903', '16/12/1983');
INSERT INTO participants VALUES (329, 'Gunnar Björnstrand', 	'H', '13/11/1909', '26/05/1986');
INSERT INTO participants VALUES (330, 'Bengt Ekerot',		'H', '08/02/1920', '26/11/1971');
INSERT INTO participants VALUES (331, 'Max von Sydow', 		'H', '10/04/1929', NULL);
INSERT INTO participants VALUES (332, 'Bibi Andersson', 	'D', '11/11/1935', NULL);
INSERT INTO participants VALUES (333, 'Eli Wallach', 		'H', '07/12/1915', NULL);
INSERT INTO participants VALUES (334, 'Lee Van Cleef', 		'H', '09/01/1925', '16/12/1989');
INSERT INTO participants VALUES (335, 'Marcello Mastroianni', 	'H', '28/09/1924', '19/12/1996');
INSERT INTO participants VALUES (336, 'Claudia Cardinale', 	'D', '15/04/1938', NULL);
INSERT INTO participants VALUES (337, 'Anouk Aimée', 		'D', '27/04/1932', NULL);
INSERT INTO participants VALUES (338, 'Candice Bergen', 	'D', '09/05/1946', NULL);
INSERT INTO participants VALUES (339, 'John Gielgud', 		'H', '14/04/1904', '21/05/2000');
INSERT INTO participants VALUES (340, 'John Mills', 		'H', '22/02/1908', '23/04/2005');
INSERT INTO participants VALUES (341, 'Brigitte Helm', 		'D', '17/03/1906', '11/06/1996');
INSERT INTO participants VALUES (342, 'Alfred Abel', 		'H', '12/03/1879', '12/12/1937');
INSERT INTO participants VALUES (343, 'Gustav Fröhlich', 	'H', '21/03/1902', '22/12/1987');
INSERT INTO participants VALUES (344, 'Ellen Widmann', 		'D', '15/12/1894', '22/10/1985');
INSERT INTO participants VALUES (345, 'Inge Landgut', 		'D', '23/11/1922', '28/05/1986');
INSERT INTO participants VALUES (346, 'Arletty', 		'D', '15/05/1898', '23/07/1992');
INSERT INTO participants VALUES (347, 'Jean-Louis Barrault', 	'H', '08/09/1910', '22/01/1994');
INSERT INTO participants VALUES (348, 'Pierre Brasseur', 	'H', '22/12/1905', '14/08/1972');
INSERT INTO participants VALUES (349, 'Jean Reno', 		'H', '30/07/1948', NULL);
INSERT INTO participants VALUES (350, 'Natalie Portman', 	'D', '21/03/1958', NULL);
INSERT INTO participants VALUES (351, 'Gary Oldman', 		'H', '09/06/1981', NULL);
INSERT INTO participants VALUES (352, 'Danny Aiello', 		'H', '20/06/1933', NULL);
INSERT INTO participants VALUES (353, 'Michael Curtiz', 	'H', '24/12/1886', '10/04/1962');
INSERT INTO participants VALUES (354, 'John Ford', 		'H', '01/02/1894', '31/08/1973');
INSERT INTO participants VALUES (355, 'William Cottrell', 	'H', '19/11/1906', '22/12/1995');
INSERT INTO participants VALUES (356, 'Akira Kurosawa', 	'H', '23/03/1910', '06/09/1998');
INSERT INTO participants VALUES (358, 'Leo McCarey', 		'H', '03/10/1896', '05/07/1969');
INSERT INTO participants VALUES (359, 'Frank Lloyd', 		'H', '02/02/1886', '10/08/1960');
INSERT INTO participants VALUES (360, 'Fritz Lang', 		'H', '05/12/1890', '02/08/1976');
INSERT INTO participants VALUES (362, 'Stanley Kubrick', 	'H', '26/07/1928', '07/03/1999');
INSERT INTO participants VALUES (363, 'Alfred Hitchcock', 	'H', '13/08/1899', '29/04/1980');
INSERT INTO participants VALUES (365, 'Fred Zinnemann', 	'H', '29/04/1907', '14/03/1997');
INSERT INTO participants VALUES (366, 'Jerome Robbins', 	'H', '11/10/1918', '29/07/1998');
INSERT INTO participants VALUES (367, 'George Cukor', 		'H', '07/07/1899', '24/01/1983');
INSERT INTO participants VALUES (368, 'James Whale', 		'H', '22/07/1889', '29/05/1957');
INSERT INTO participants VALUES (370, 'Ingmar Bergman', 	'H', '14/07/1918', '30/07/2007');
INSERT INTO participants VALUES (371, 'Sergio Leone', 		'H', '03/01/1929', '30/04/1989');
INSERT INTO participants VALUES (372, 'Billy Wilder', 		'H', '22/06/1906', '27/03/2002');
INSERT INTO participants VALUES (373, 'Joseph L. Mankiewicz',	'H', '11/02/1909', '05/02/1993');
INSERT INTO participants VALUES (374, 'George Roy Hill', 	'H', '20/12/1921', '27/12/2002');
INSERT INTO participants VALUES (375, 'Jonathan Demme', 	'H', '22/02/1944', NULL);
INSERT INTO participants VALUES (376, 'Oliver Stone', 		'H', '15/09/1946', NULL);
INSERT INTO participants VALUES (377, 'Franklin J. Schaffner',	'H', '30/05/1920', '02/07/1989');
INSERT INTO participants VALUES (378, 'Martin Scorsese', 	'H', '17/11/1942', NULL);
INSERT INTO participants VALUES (379, 'Arthur Penn', 		'H', '27/09/1922', '28/09/2010');
INSERT INTO participants VALUES (380, 'Lewis Milestone', 	'H', '30/09/1895', '25/09/1980');
INSERT INTO participants VALUES (381, 'George Stevens', 	'H', '18/12/1904', '08/03/1975');
INSERT INTO participants VALUES (382, 'John G. Avildsen', 	'H', '21/12/1935', NULL);
INSERT INTO participants VALUES (383, 'Sergei M. Eisenstein', 	'H', '23/01/1898', '11/02/1948');
INSERT INTO participants VALUES (384, 'Mike Nichols', 		'H', '06/11/1931', NULL);
INSERT INTO participants VALUES (385, 'Frank Capra', 		'H', '18/05/1897', '03/09/1991');
INSERT INTO participants VALUES (387, 'Roman Polanski', 	'H', '18/08/1933', NULL);
INSERT INTO participants VALUES (388, 'Robert Mulligan', 	'H', '23/08/1925', '20/12/2008');
INSERT INTO participants VALUES (389, 'Merian C. Cooper', 	'H', '24/10/1893', '21/04/1973');
INSERT INTO participants VALUES (390, 'Robert Wise', 		'H', '10/09/1914', '14/09/2005');
INSERT INTO participants VALUES (392, 'Syndey Lumet', 		'H', '25/06/1924', '09/04/2011');
INSERT INTO participants VALUES (393, 'Robert Zemeckis', 	'H', '14/05/1951', NULL);
INSERT INTO participants VALUES (394, 'Michael Cimino', 	'H', '03/02/1939', NULL);
INSERT INTO participants VALUES (395, 'Sam Peckinpah', 		'H', '21/02/1925', '28/12/1984');
INSERT INTO participants VALUES (396, 'Federico Fellini', 	'H', '20/01/1920', '31/10/1993');
INSERT INTO participants VALUES (397, 'Nicholas Ray', 		'H', '07/08/1911', '16/06/1979');
INSERT INTO participants VALUES (398, 'Vincente Minnelli', 	'H', '28/02/1903', '25/07/1986');
INSERT INTO participants VALUES (401, 'Richard Attenborough', 	'H', '29/08/1923', NULL);
INSERT INTO participants VALUES (402, 'Luc Besson', 		'H', '18/03/1959', NULL);
INSERT INTO participants VALUES (403, 'Victor Fleming', 	'H', '23/02/1889', '06/01/1949');
INSERT INTO participants VALUES (404, 'Steven Spielberg', 	'H', '18/12/1946', NULL);
INSERT INTO participants VALUES (405, 'Stanley Donen', 		'H', '13/04/1924', NULL);
INSERT INTO participants VALUES (406, 'John Schlesinger', 	'H', '16/02/1926', '25/07/2003');
INSERT INTO participants VALUES (407, 'Joel Coen', 		'H', '29/11/1954', NULL);
INSERT INTO participants VALUES (408, 'Stankey Kramer', 	'H', '29/09/1913', '19/02/2001');
INSERT INTO participants VALUES (409, 'Ridley Scott', 		'H', '30/11/1937', NULL);
INSERT INTO participants VALUES (410, 'David Fincher', 		'H', '28/08/1962', NULL);
INSERT INTO participants VALUES (411, 'Marcel Carné', 		'H', '18/08/1906', '31/10/1996');
INSERT INTO participants VALUES (412, 'Francis Ford Coppola', 	'H', '07/04/1939', NULL);
INSERT INTO participants VALUES (413, 'David Lean', 		'H', '25/03/1908', '16/04/1991');
INSERT INTO participants VALUES (414, 'Elia Kazan', 		'H', '07/09/1909', '28/09/2003');
INSERT INTO participants VALUES (415, 'George Lucas', 		'H', '14/05/1944', NULL);
INSERT INTO participants VALUES (416, 'Milos Forman', 		'H', '18/02/1932', NULL);
INSERT INTO participants VALUES (417, 'William Wyler', 		'H', '01/07/1902', '27/07/1981');
INSERT INTO participants VALUES (418, 'D.W. Griffith', 		'H', '22/01/1875', '23/07/1948');
INSERT INTO participants VALUES (419, 'Carol Reed', 		'H', '30/12/1906', '25/04/1976');
INSERT INTO participants VALUES (420, 'William Friedkin', 	'H', '29/08/1935', NULL);
INSERT INTO participants VALUES (421, 'Alan Crosland', 		'H', '10/08/1894', '16/07/1936');
INSERT INTO participants VALUES (422, 'Quentin Tarantino', 	'H', '27/03/1963', NULL);
INSERT INTO participants VALUES (423, 'Howard Hawks', 		'H', '30/05/1896', '26/12/1977');
INSERT INTO participants VALUES (424, 'Guillermo del Toro', 	'H', '09/10/1964', NULL);



-- Dades bàsiques de les pel·lícules
INSERT INTO pelis VALUES (  1, 1941, 'N',   1);
INSERT INTO pelis VALUES (  2, 1942, 'N', 353);
INSERT INTO pelis VALUES (  3, 1972, 'S', 412);
INSERT INTO pelis VALUES (  4, 1939, 'S', 403);
INSERT INTO pelis VALUES (  5, 1968, 'S', 362);
INSERT INTO pelis VALUES (  6, 1962, 'S', 413);
INSERT INTO pelis VALUES (  7, 1939, 'S', 403);
INSERT INTO pelis VALUES (  8, 1967, 'S', 384);
INSERT INTO pelis VALUES (  9, 1954, 'N', 414);
INSERT INTO pelis VALUES ( 10, 1993, 'S', 404);
INSERT INTO pelis VALUES ( 11, 1952, 'S', 405);
INSERT INTO pelis VALUES ( 12, 1946, 'N', 385);
INSERT INTO pelis VALUES ( 13, 1950, 'N', 372);
INSERT INTO pelis VALUES ( 14, 1957, 'S', 413);
INSERT INTO pelis VALUES ( 15, 1959, 'S', 372);
INSERT INTO pelis VALUES ( 16, 1977, 'S', 415);
INSERT INTO pelis VALUES ( 17, 1950, 'N', 373);
INSERT INTO pelis VALUES ( 18, 1951, 'S',  67);
INSERT INTO pelis VALUES ( 19, 1960, 'S', 363);
INSERT INTO pelis VALUES ( 20, 1974, 'S', 387);
INSERT INTO pelis VALUES ( 21, 1975, 'S', 416);
INSERT INTO pelis VALUES ( 22, 1940, 'N', 354);
INSERT INTO pelis VALUES ( 23, 1941, 'N',  67);
INSERT INTO pelis VALUES ( 24, 1980, 'S', 378);
INSERT INTO pelis VALUES ( 25, 1982, 'S', 404);
INSERT INTO pelis VALUES ( 26, 1964, 'N', 362);
INSERT INTO pelis VALUES ( 27, 1967, 'S', 379);
INSERT INTO pelis VALUES ( 28, 1979, 'S', 412);
INSERT INTO pelis VALUES ( 29, 1939, 'N', 385);
INSERT INTO pelis VALUES ( 30, 1948, 'N',  67);
INSERT INTO pelis VALUES ( 31, 1977, 'S',  99);
INSERT INTO pelis VALUES ( 32, 1974, 'S', 412);
INSERT INTO pelis VALUES ( 33, 1952, 'N', 365);
INSERT INTO pelis VALUES ( 34, 1962, 'N', 388);
INSERT INTO pelis VALUES ( 35, 1934, 'N', 385);
INSERT INTO pelis VALUES ( 36, 1969, 'S', 406);
INSERT INTO pelis VALUES ( 37, 1946, 'N', 417);
INSERT INTO pelis VALUES ( 38, 1944, 'N', 372);
INSERT INTO pelis VALUES ( 39, 1965, 'S', 413);
INSERT INTO pelis VALUES ( 40, 1959, 'S', 363);
INSERT INTO pelis VALUES ( 41, 1961, 'S', 366);
INSERT INTO pelis VALUES ( 42, 1954, 'S', 363);
INSERT INTO pelis VALUES ( 43, 1933, 'N', 389);
INSERT INTO pelis VALUES ( 44, 1915, 'N', 418);
INSERT INTO pelis VALUES ( 45, 1951, 'N', 414);
INSERT INTO pelis VALUES ( 46, 1971, 'S', 362);
INSERT INTO pelis VALUES ( 47, 1976, 'S', 378);
INSERT INTO pelis VALUES ( 48, 1975, 'S', 404);
INSERT INTO pelis VALUES ( 49, 1937, 'S', 355);
INSERT INTO pelis VALUES ( 50, 1969, 'S', 374);
INSERT INTO pelis VALUES ( 51, 1954, 'N', 356);
INSERT INTO pelis VALUES ( 52, 1940, 'N', 367);
INSERT INTO pelis VALUES ( 53, 1953, 'N', 365);
INSERT INTO pelis VALUES ( 54, 1984, 'S', 416);
INSERT INTO pelis VALUES ( 55, 1930, 'N', 380);
INSERT INTO pelis VALUES ( 56, 1965, 'S', 390);
INSERT INTO pelis VALUES ( 57, 1949, 'N', 419);
INSERT INTO pelis VALUES ( 58, 1940, 'S', NULL);
INSERT INTO pelis VALUES ( 59, 1955, 'S', 397);
INSERT INTO pelis VALUES ( 60, 1981, 'S', 404);
INSERT INTO pelis VALUES ( 61, 1958, 'S', 363);
INSERT INTO pelis VALUES ( 62, 1982, 'S', 184);
INSERT INTO pelis VALUES ( 63, 1939, 'N', 354);
INSERT INTO pelis VALUES ( 64, 1977, 'S', 404);
INSERT INTO pelis VALUES ( 65, 1991, 'S', 375);
INSERT INTO pelis VALUES ( 66, 1976, 'S', 392);
INSERT INTO pelis VALUES ( 67, 1962, 'S', 375);
INSERT INTO pelis VALUES ( 68, 1951, 'S', 398);
INSERT INTO pelis VALUES ( 69, 1953, 'S', 381);
INSERT INTO pelis VALUES ( 70, 1971, 'S', 420);
INSERT INTO pelis VALUES ( 71, 1994, 'S', 393);
INSERT INTO pelis VALUES ( 72, 1959, 'S', 417);
INSERT INTO pelis VALUES ( 73, 1939, 'N', 417);
INSERT INTO pelis VALUES ( 74, 1925, 'N', 214);
INSERT INTO pelis VALUES ( 75, 1990, 'S', 217);
INSERT INTO pelis VALUES ( 76, 1931, 'N', 214);
INSERT INTO pelis VALUES ( 77, 1973, 'S', 415);
INSERT INTO pelis VALUES ( 78, 1976, 'S', 382);
INSERT INTO pelis VALUES ( 79, 1978, 'S', 394);
INSERT INTO pelis VALUES ( 80, 1969, 'S', 395);
INSERT INTO pelis VALUES ( 81, 1936, 'N', 214);
INSERT INTO pelis VALUES ( 82, 1956, 'S', 381);
INSERT INTO pelis VALUES ( 83, 1986, 'S', 376);
INSERT INTO pelis VALUES ( 84, 1996, 'S', 407);
INSERT INTO pelis VALUES ( 85, 1933, 'N', 358);
INSERT INTO pelis VALUES ( 86, 1993, 'S', 375);
INSERT INTO pelis VALUES ( 87, 1935, 'N', 359);
INSERT INTO pelis VALUES ( 88, 1931, 'N', 368);
INSERT INTO pelis VALUES ( 89, 1969, 'S',  93);
INSERT INTO pelis VALUES ( 90, 1970, 'S', 377);
INSERT INTO pelis VALUES ( 91, 1927, 'N', 421);
INSERT INTO pelis VALUES ( 92, 1964, 'S', 367);
INSERT INTO pelis VALUES ( 93, 1951, 'N', 381);
INSERT INTO pelis VALUES ( 94, 1960, 'N', 372);
INSERT INTO pelis VALUES ( 95, 1990, 'S', 378);
INSERT INTO pelis VALUES ( 96, 1994, 'S', 422);
INSERT INTO pelis VALUES ( 97, 1956, 'S', 354);
INSERT INTO pelis VALUES ( 98, 1938, 'N', 423);
INSERT INTO pelis VALUES ( 99, 1992, 'S', 294);
INSERT INTO pelis VALUES (100, 1967, 'S', 408);
INSERT INTO pelis VALUES (101, 1942, 'N', 353);
INSERT INTO pelis VALUES (102, 1991, 'S', 409);
INSERT INTO pelis VALUES (103, 1980, 'S', 362);
INSERT INTO pelis VALUES (104, 1982, 'S', 409);
INSERT INTO pelis VALUES (105, 1995, 'S', 410);
INSERT INTO pelis VALUES (106, 2004, 'S', 294);
INSERT INTO pelis VALUES (107, 2006, 'S', 424);
INSERT INTO pelis VALUES (108, 1925, 'N', 383);
INSERT INTO pelis VALUES (109, 1957, 'N', 370);
INSERT INTO pelis VALUES (110, 1966, 'S', 371);
INSERT INTO pelis VALUES (111, 1963, 'N', 396);
INSERT INTO pelis VALUES (112, 1982, 'S', 401);
INSERT INTO pelis VALUES (113, 1927, 'N', 360);
INSERT INTO pelis VALUES (114, 1931, 'N', 360);
INSERT INTO pelis VALUES (115, 1945, 'N', 411);
INSERT INTO pelis VALUES (116, 1994, 'S', 402);



-- Associació dels actors a les pel·lícules
INSERT INTO pelis_actors VALUES ( 1,  1);
INSERT INTO pelis_actors VALUES ( 1,  2);
INSERT INTO pelis_actors VALUES ( 1,  3);
INSERT INTO pelis_actors VALUES ( 2,  4);
INSERT INTO pelis_actors VALUES ( 2,  5);
INSERT INTO pelis_actors VALUES ( 2,  6);
INSERT INTO pelis_actors VALUES ( 2, 96);
INSERT INTO pelis_actors VALUES ( 3,  7);
INSERT INTO pelis_actors VALUES ( 3,  8);
INSERT INTO pelis_actors VALUES ( 3,  9);
INSERT INTO pelis_actors VALUES ( 3, 10);
INSERT INTO pelis_actors VALUES ( 3, 11);
INSERT INTO pelis_actors VALUES ( 3,230);
INSERT INTO pelis_actors VALUES ( 4, 12);
INSERT INTO pelis_actors VALUES ( 4, 13);
INSERT INTO pelis_actors VALUES ( 4, 14);
INSERT INTO pelis_actors VALUES ( 5, 15);
INSERT INTO pelis_actors VALUES ( 5, 16);
INSERT INTO pelis_actors VALUES ( 5, 17);
INSERT INTO pelis_actors VALUES ( 6, 18);
INSERT INTO pelis_actors VALUES ( 6, 19);
INSERT INTO pelis_actors VALUES ( 6, 20);
INSERT INTO pelis_actors VALUES ( 6, 21);
INSERT INTO pelis_actors VALUES ( 6, 96);
INSERT INTO pelis_actors VALUES ( 7, 22);
INSERT INTO pelis_actors VALUES ( 7, 23);
INSERT INTO pelis_actors VALUES ( 7, 24);
INSERT INTO pelis_actors VALUES ( 7, 25);
INSERT INTO pelis_actors VALUES ( 7, 26);
INSERT INTO pelis_actors VALUES ( 8, 27);
INSERT INTO pelis_actors VALUES ( 8, 28);
INSERT INTO pelis_actors VALUES ( 8, 29);
INSERT INTO pelis_actors VALUES ( 9,  7);
INSERT INTO pelis_actors VALUES ( 9, 30);
INSERT INTO pelis_actors VALUES ( 9, 31);
INSERT INTO pelis_actors VALUES ( 9, 32);
INSERT INTO pelis_actors VALUES (10, 33);
INSERT INTO pelis_actors VALUES (10, 34);
INSERT INTO pelis_actors VALUES (10, 35);
INSERT INTO pelis_actors VALUES (10, 36);
INSERT INTO pelis_actors VALUES (11, 37);
INSERT INTO pelis_actors VALUES (11, 38);
INSERT INTO pelis_actors VALUES (11, 39);
INSERT INTO pelis_actors VALUES (12, 40);
INSERT INTO pelis_actors VALUES (12, 41);
INSERT INTO pelis_actors VALUES (12, 42);
INSERT INTO pelis_actors VALUES (12, 14);
INSERT INTO pelis_actors VALUES (12,292);
INSERT INTO pelis_actors VALUES (13, 43);
INSERT INTO pelis_actors VALUES (13, 44);
INSERT INTO pelis_actors VALUES (13, 45);
INSERT INTO pelis_actors VALUES (13, 46);
INSERT INTO pelis_actors VALUES (14, 43);
INSERT INTO pelis_actors VALUES (14, 19);
INSERT INTO pelis_actors VALUES (14, 47);
INSERT INTO pelis_actors VALUES (15, 48);
INSERT INTO pelis_actors VALUES (15, 49);
INSERT INTO pelis_actors VALUES (15, 50);
INSERT INTO pelis_actors VALUES (16, 51);
INSERT INTO pelis_actors VALUES (16, 52);
INSERT INTO pelis_actors VALUES (16, 53);
INSERT INTO pelis_actors VALUES (16, 54);
INSERT INTO pelis_actors VALUES (16, 19);
INSERT INTO pelis_actors VALUES (17, 55);
INSERT INTO pelis_actors VALUES (17, 56);
INSERT INTO pelis_actors VALUES (17, 57);
INSERT INTO pelis_actors VALUES (17, 58);
INSERT INTO pelis_actors VALUES (17, 48);
INSERT INTO pelis_actors VALUES (18,  4);
INSERT INTO pelis_actors VALUES (18, 59);
INSERT INTO pelis_actors VALUES (18, 60);
INSERT INTO pelis_actors VALUES (19, 61);
INSERT INTO pelis_actors VALUES (19, 62);
INSERT INTO pelis_actors VALUES (19, 63);
INSERT INTO pelis_actors VALUES (19, 64);
INSERT INTO pelis_actors VALUES (20, 65);
INSERT INTO pelis_actors VALUES (20, 66);
INSERT INTO pelis_actors VALUES (20, 67);
INSERT INTO pelis_actors VALUES (21, 65);
INSERT INTO pelis_actors VALUES (21, 68);
INSERT INTO pelis_actors VALUES (21, 69);
INSERT INTO pelis_actors VALUES (22, 70);
INSERT INTO pelis_actors VALUES (22, 71);
INSERT INTO pelis_actors VALUES (22, 72);
INSERT INTO pelis_actors VALUES (22,262);
INSERT INTO pelis_actors VALUES (23,  4);
INSERT INTO pelis_actors VALUES (23, 73);
INSERT INTO pelis_actors VALUES (23, 74);
INSERT INTO pelis_actors VALUES (23, 75);
INSERT INTO pelis_actors VALUES (23,292);
INSERT INTO pelis_actors VALUES (24, 76);
INSERT INTO pelis_actors VALUES (24, 77);
INSERT INTO pelis_actors VALUES (24, 78);
INSERT INTO pelis_actors VALUES (25, 79);
INSERT INTO pelis_actors VALUES (25, 80);
INSERT INTO pelis_actors VALUES (25, 81);
INSERT INTO pelis_actors VALUES (25, 82);
INSERT INTO pelis_actors VALUES (26, 83);
INSERT INTO pelis_actors VALUES (26, 84);
INSERT INTO pelis_actors VALUES (26, 85);
INSERT INTO pelis_actors VALUES (27, 86);
INSERT INTO pelis_actors VALUES (27, 66);
INSERT INTO pelis_actors VALUES (27, 87);
INSERT INTO pelis_actors VALUES (27, 88);
INSERT INTO pelis_actors VALUES (27, 89);
INSERT INTO pelis_actors VALUES (28, 90);
INSERT INTO pelis_actors VALUES (28,  7);
INSERT INTO pelis_actors VALUES (28, 10);
INSERT INTO pelis_actors VALUES (28, 91);
INSERT INTO pelis_actors VALUES (28, 92);
INSERT INTO pelis_actors VALUES (28, 52);
INSERT INTO pelis_actors VALUES (28, 93);
INSERT INTO pelis_actors VALUES (28, 94);
INSERT INTO pelis_actors VALUES (29, 40);
INSERT INTO pelis_actors VALUES (29, 95);
INSERT INTO pelis_actors VALUES (29, 96);
INSERT INTO pelis_actors VALUES (29, 14);
INSERT INTO pelis_actors VALUES (30,  4);
INSERT INTO pelis_actors VALUES (30, 97);
INSERT INTO pelis_actors VALUES (30, 98);
INSERT INTO pelis_actors VALUES (31, 99);
INSERT INTO pelis_actors VALUES (31, 11);
INSERT INTO pelis_actors VALUES (31,100);
INSERT INTO pelis_actors VALUES (31,101);
INSERT INTO pelis_actors VALUES (32,  8);
INSERT INTO pelis_actors VALUES (32, 76);
INSERT INTO pelis_actors VALUES (32, 10);
INSERT INTO pelis_actors VALUES (32, 11);
INSERT INTO pelis_actors VALUES (32,230);
INSERT INTO pelis_actors VALUES (33,102);
INSERT INTO pelis_actors VALUES (33,103);
INSERT INTO pelis_actors VALUES (33, 14);
INSERT INTO pelis_actors VALUES (33,104);
INSERT INTO pelis_actors VALUES (34,105);
INSERT INTO pelis_actors VALUES (34,106);
INSERT INTO pelis_actors VALUES (34,107);
INSERT INTO pelis_actors VALUES (34,108);
INSERT INTO pelis_actors VALUES (34, 10);
INSERT INTO pelis_actors VALUES (35, 12);
INSERT INTO pelis_actors VALUES (35,109);
INSERT INTO pelis_actors VALUES (35,110);
INSERT INTO pelis_actors VALUES (36, 27);
INSERT INTO pelis_actors VALUES (36,111);
INSERT INTO pelis_actors VALUES (36,112);
INSERT INTO pelis_actors VALUES (37,113);
INSERT INTO pelis_actors VALUES (37,114);
INSERT INTO pelis_actors VALUES (37,115);
INSERT INTO pelis_actors VALUES (37,116);
INSERT INTO pelis_actors VALUES (37,117);
INSERT INTO pelis_actors VALUES (38,118);
INSERT INTO pelis_actors VALUES (38,119);
INSERT INTO pelis_actors VALUES (38,120);
INSERT INTO pelis_actors VALUES (39, 21);
INSERT INTO pelis_actors VALUES (39,121);
INSERT INTO pelis_actors VALUES (39,122);
INSERT INTO pelis_actors VALUES (39, 32);
INSERT INTO pelis_actors VALUES (39, 19);
INSERT INTO pelis_actors VALUES (39,123);
INSERT INTO pelis_actors VALUES (40,124);
INSERT INTO pelis_actors VALUES (40,125);
INSERT INTO pelis_actors VALUES (40,126);
INSERT INTO pelis_actors VALUES (40,127);
INSERT INTO pelis_actors VALUES (41,128);
INSERT INTO pelis_actors VALUES (41,129);
INSERT INTO pelis_actors VALUES (41,130);
INSERT INTO pelis_actors VALUES (42, 40);
INSERT INTO pelis_actors VALUES (42,103);
INSERT INTO pelis_actors VALUES (42,131);
INSERT INTO pelis_actors VALUES (42,132);
INSERT INTO pelis_actors VALUES (43,133);
INSERT INTO pelis_actors VALUES (43,134);
INSERT INTO pelis_actors VALUES (43,135);
INSERT INTO pelis_actors VALUES (44,136);
INSERT INTO pelis_actors VALUES (44,137);
INSERT INTO pelis_actors VALUES (44,138);
INSERT INTO pelis_actors VALUES (45,  7);
INSERT INTO pelis_actors VALUES (45, 13);
INSERT INTO pelis_actors VALUES (45,139);
INSERT INTO pelis_actors VALUES (45, 30);
INSERT INTO pelis_actors VALUES (46,140);
INSERT INTO pelis_actors VALUES (46,141);
INSERT INTO pelis_actors VALUES (46,142);
INSERT INTO pelis_actors VALUES (47, 76);
INSERT INTO pelis_actors VALUES (47,143);
INSERT INTO pelis_actors VALUES (47,144);
INSERT INTO pelis_actors VALUES (47,145);
INSERT INTO pelis_actors VALUES (47,146);
INSERT INTO pelis_actors VALUES (48,147);
INSERT INTO pelis_actors VALUES (48,148);
INSERT INTO pelis_actors VALUES (48,149);
INSERT INTO pelis_actors VALUES (50,150);
INSERT INTO pelis_actors VALUES (50,151);
INSERT INTO pelis_actors VALUES (50, 29);
INSERT INTO pelis_actors VALUES (51,152);
INSERT INTO pelis_actors VALUES (51,153);
INSERT INTO pelis_actors VALUES (51,154);
INSERT INTO pelis_actors VALUES (52,124);
INSERT INTO pelis_actors VALUES (52, 59);
INSERT INTO pelis_actors VALUES (52, 40);
INSERT INTO pelis_actors VALUES (52,155);
INSERT INTO pelis_actors VALUES (53,156);
INSERT INTO pelis_actors VALUES (53,157);
INSERT INTO pelis_actors VALUES (53,158);
INSERT INTO pelis_actors VALUES (53, 41);
INSERT INTO pelis_actors VALUES (53,159);
INSERT INTO pelis_actors VALUES (53,160);
INSERT INTO pelis_actors VALUES (53,161);
INSERT INTO pelis_actors VALUES (54,162);
INSERT INTO pelis_actors VALUES (54,163);
INSERT INTO pelis_actors VALUES (54,164);
INSERT INTO pelis_actors VALUES (55,165);
INSERT INTO pelis_actors VALUES (55,166);
INSERT INTO pelis_actors VALUES (55,167);
INSERT INTO pelis_actors VALUES (56,168);
INSERT INTO pelis_actors VALUES (56,169);
INSERT INTO pelis_actors VALUES (56,170);
INSERT INTO pelis_actors VALUES (57,  1);
INSERT INTO pelis_actors VALUES (57,  2);
INSERT INTO pelis_actors VALUES (57,171);
INSERT INTO pelis_actors VALUES (57,172);
INSERT INTO pelis_actors VALUES (59,173);
INSERT INTO pelis_actors VALUES (59,128);
INSERT INTO pelis_actors VALUES (59,174);
INSERT INTO pelis_actors VALUES (59, 93);
INSERT INTO pelis_actors VALUES (60, 52);
INSERT INTO pelis_actors VALUES (60,175);
INSERT INTO pelis_actors VALUES (60,176);
INSERT INTO pelis_actors VALUES (60,177);
INSERT INTO pelis_actors VALUES (61, 40);
INSERT INTO pelis_actors VALUES (61,178);
INSERT INTO pelis_actors VALUES (61,179);
INSERT INTO pelis_actors VALUES (62, 27);
INSERT INTO pelis_actors VALUES (62,180);
INSERT INTO pelis_actors VALUES (62,181);
INSERT INTO pelis_actors VALUES (62,182);
INSERT INTO pelis_actors VALUES (62,183);
INSERT INTO pelis_actors VALUES (62,184);
INSERT INTO pelis_actors VALUES (62,185);
INSERT INTO pelis_actors VALUES (63,186);
INSERT INTO pelis_actors VALUES (63,187);
INSERT INTO pelis_actors VALUES (63,188);
INSERT INTO pelis_actors VALUES (63, 72);
INSERT INTO pelis_actors VALUES (63, 14);
INSERT INTO pelis_actors VALUES (63, 98);
INSERT INTO pelis_actors VALUES (64,149);
INSERT INTO pelis_actors VALUES (64,189);
INSERT INTO pelis_actors VALUES (64,181);
INSERT INTO pelis_actors VALUES (64,190);
INSERT INTO pelis_actors VALUES (65,143);
INSERT INTO pelis_actors VALUES (65,191);
INSERT INTO pelis_actors VALUES (65, 94);
INSERT INTO pelis_actors VALUES (66, 66);
INSERT INTO pelis_actors VALUES (66, 43);
INSERT INTO pelis_actors VALUES (66,192);
INSERT INTO pelis_actors VALUES (66, 10);
INSERT INTO pelis_actors VALUES (67,193);
INSERT INTO pelis_actors VALUES (67,194);
INSERT INTO pelis_actors VALUES (67,195);
INSERT INTO pelis_actors VALUES (68, 37);
INSERT INTO pelis_actors VALUES (68,196);
INSERT INTO pelis_actors VALUES (68,197);
INSERT INTO pelis_actors VALUES (69,198);
INSERT INTO pelis_actors VALUES (69, 95);
INSERT INTO pelis_actors VALUES (69,199);
INSERT INTO pelis_actors VALUES (69,200);
INSERT INTO pelis_actors VALUES (70, 88);
INSERT INTO pelis_actors VALUES (70,147);
INSERT INTO pelis_actors VALUES (70,201);
INSERT INTO pelis_actors VALUES (70,202);
INSERT INTO pelis_actors VALUES (71,203);
INSERT INTO pelis_actors VALUES (71,204);
INSERT INTO pelis_actors VALUES (71,205);
INSERT INTO pelis_actors VALUES (71,206);
INSERT INTO pelis_actors VALUES (72,207);
INSERT INTO pelis_actors VALUES (72, 47);
INSERT INTO pelis_actors VALUES (72,208);
INSERT INTO pelis_actors VALUES (72,209);
INSERT INTO pelis_actors VALUES (73,210);
INSERT INTO pelis_actors VALUES (73,211);
INSERT INTO pelis_actors VALUES (73,212);
INSERT INTO pelis_actors VALUES (73,213);
INSERT INTO pelis_actors VALUES (74,214);
INSERT INTO pelis_actors VALUES (74,215);
INSERT INTO pelis_actors VALUES (74,216);
INSERT INTO pelis_actors VALUES (74,240);
INSERT INTO pelis_actors VALUES (75,217);
INSERT INTO pelis_actors VALUES (75,218);
INSERT INTO pelis_actors VALUES (75,219);
INSERT INTO pelis_actors VALUES (76,214);
INSERT INTO pelis_actors VALUES (76,220);
INSERT INTO pelis_actors VALUES (76,221);
INSERT INTO pelis_actors VALUES (77,149);
INSERT INTO pelis_actors VALUES (77,222);
INSERT INTO pelis_actors VALUES (77,223);
INSERT INTO pelis_actors VALUES (77,224);
INSERT INTO pelis_actors VALUES (77,225);
INSERT INTO pelis_actors VALUES (77,226);
INSERT INTO pelis_actors VALUES (77,227);
INSERT INTO pelis_actors VALUES (77,228);
INSERT INTO pelis_actors VALUES (77, 52);
INSERT INTO pelis_actors VALUES (78,229);
INSERT INTO pelis_actors VALUES (78,230);
INSERT INTO pelis_actors VALUES (78,231);
INSERT INTO pelis_actors VALUES (78,232);
INSERT INTO pelis_actors VALUES (78,233);
INSERT INTO pelis_actors VALUES (79, 76);
INSERT INTO pelis_actors VALUES (79,101);
INSERT INTO pelis_actors VALUES (79,234);
INSERT INTO pelis_actors VALUES (79,195);
INSERT INTO pelis_actors VALUES (79,235);
INSERT INTO pelis_actors VALUES (80, 43);
INSERT INTO pelis_actors VALUES (80,160);
INSERT INTO pelis_actors VALUES (80,236);
INSERT INTO pelis_actors VALUES (80,237);
INSERT INTO pelis_actors VALUES (80,238);
INSERT INTO pelis_actors VALUES (80,228);
INSERT INTO pelis_actors VALUES (81,214);
INSERT INTO pelis_actors VALUES (81,239);
INSERT INTO pelis_actors VALUES (81,240);
INSERT INTO pelis_actors VALUES (82,241);
INSERT INTO pelis_actors VALUES (82,242);
INSERT INTO pelis_actors VALUES (82,173);
INSERT INTO pelis_actors VALUES (82,243);
INSERT INTO pelis_actors VALUES (82,244);
INSERT INTO pelis_actors VALUES (82,245);
INSERT INTO pelis_actors VALUES (82,246);
INSERT INTO pelis_actors VALUES (82,247);
INSERT INTO pelis_actors VALUES (83,248);
INSERT INTO pelis_actors VALUES (83,249);
INSERT INTO pelis_actors VALUES (83,250);
INSERT INTO pelis_actors VALUES (83,251);
INSERT INTO pelis_actors VALUES (83,252);
INSERT INTO pelis_actors VALUES (84,253);
INSERT INTO pelis_actors VALUES (84,254);
INSERT INTO pelis_actors VALUES (84,255);
INSERT INTO pelis_actors VALUES (84,256);
INSERT INTO pelis_actors VALUES (85,257);
INSERT INTO pelis_actors VALUES (85,258);
INSERT INTO pelis_actors VALUES (85,259);
INSERT INTO pelis_actors VALUES (85,260);
INSERT INTO pelis_actors VALUES (85,261);
INSERT INTO pelis_actors VALUES (85,262);
INSERT INTO pelis_actors VALUES (86,203);
INSERT INTO pelis_actors VALUES (86,193);
INSERT INTO pelis_actors VALUES (86,263);
INSERT INTO pelis_actors VALUES (86,264);
INSERT INTO pelis_actors VALUES (87,265);
INSERT INTO pelis_actors VALUES (87, 12);
INSERT INTO pelis_actors VALUES (87,266);
INSERT INTO pelis_actors VALUES (88,267);
INSERT INTO pelis_actors VALUES (88,268);
INSERT INTO pelis_actors VALUES (88,269);
INSERT INTO pelis_actors VALUES (89,270);
INSERT INTO pelis_actors VALUES (89, 93);
INSERT INTO pelis_actors VALUES (89, 65);
INSERT INTO pelis_actors VALUES (90, 84);
INSERT INTO pelis_actors VALUES (90, 30);
INSERT INTO pelis_actors VALUES (90,271);
INSERT INTO pelis_actors VALUES (91,272);
INSERT INTO pelis_actors VALUES (91,273);
INSERT INTO pelis_actors VALUES (91,274);
INSERT INTO pelis_actors VALUES (92,275);
INSERT INTO pelis_actors VALUES (92,276);
INSERT INTO pelis_actors VALUES (92,277);
INSERT INTO pelis_actors VALUES (93,157);
INSERT INTO pelis_actors VALUES (93,241);
INSERT INTO pelis_actors VALUES (93,278);
INSERT INTO pelis_actors VALUES (94, 50);
INSERT INTO pelis_actors VALUES (94,279);
INSERT INTO pelis_actors VALUES (94,118);
INSERT INTO pelis_actors VALUES (94,280);
INSERT INTO pelis_actors VALUES (95, 76);
INSERT INTO pelis_actors VALUES (95,281);
INSERT INTO pelis_actors VALUES (95, 78);
INSERT INTO pelis_actors VALUES (95,282);
INSERT INTO pelis_actors VALUES (96,283);
INSERT INTO pelis_actors VALUES (96,284);
INSERT INTO pelis_actors VALUES (96,285);
INSERT INTO pelis_actors VALUES (96,286);
INSERT INTO pelis_actors VALUES (96,287);
INSERT INTO pelis_actors VALUES (96,288);
INSERT INTO pelis_actors VALUES (96,289);
INSERT INTO pelis_actors VALUES (96,290);
INSERT INTO pelis_actors VALUES (97,186);
INSERT INTO pelis_actors VALUES (97,291);
INSERT INTO pelis_actors VALUES (97, 62);
INSERT INTO pelis_actors VALUES (97,292);
INSERT INTO pelis_actors VALUES (97,128);
INSERT INTO pelis_actors VALUES (98, 59);
INSERT INTO pelis_actors VALUES (98,124);
INSERT INTO pelis_actors VALUES (98,293);
INSERT INTO pelis_actors VALUES (99,294);
INSERT INTO pelis_actors VALUES (99, 88);
INSERT INTO pelis_actors VALUES (99,295);
INSERT INTO pelis_actors VALUES (99,296);
INSERT INTO pelis_actors VALUES (99,297);
INSERT INTO pelis_actors VALUES (100,298);
INSERT INTO pelis_actors VALUES (100,299);
INSERT INTO pelis_actors VALUES (100, 59);
INSERT INTO pelis_actors VALUES (101,300);
INSERT INTO pelis_actors VALUES (101,301);
INSERT INTO pelis_actors VALUES (101, 97);
INSERT INTO pelis_actors VALUES (102,302);
INSERT INTO pelis_actors VALUES (102,185);
INSERT INTO pelis_actors VALUES (102,303);
INSERT INTO pelis_actors VALUES (102,304);
INSERT INTO pelis_actors VALUES (102,305);
INSERT INTO pelis_actors VALUES (103, 65);
INSERT INTO pelis_actors VALUES (103,306);
INSERT INTO pelis_actors VALUES (103,307);
INSERT INTO pelis_actors VALUES (103,308);
INSERT INTO pelis_actors VALUES (104, 52);
INSERT INTO pelis_actors VALUES (104,309);
INSERT INTO pelis_actors VALUES (104,310);
INSERT INTO pelis_actors VALUES (104,311);
INSERT INTO pelis_actors VALUES (104,312);
INSERT INTO pelis_actors VALUES (104,313);
INSERT INTO pelis_actors VALUES (104,314);
INSERT INTO pelis_actors VALUES (104,315);
INSERT INTO pelis_actors VALUES (104,316);
INSERT INTO pelis_actors VALUES (104,317);
INSERT INTO pelis_actors VALUES (105,295);
INSERT INTO pelis_actors VALUES (105,305);
INSERT INTO pelis_actors VALUES (105,318);
INSERT INTO pelis_actors VALUES (105,319);
INSERT INTO pelis_actors VALUES (105,320);
INSERT INTO pelis_actors VALUES (106,321);
INSERT INTO pelis_actors VALUES (106,294);
INSERT INTO pelis_actors VALUES (106,295);
INSERT INTO pelis_actors VALUES (107,322);
INSERT INTO pelis_actors VALUES (107,323);
INSERT INTO pelis_actors VALUES (107,324);
INSERT INTO pelis_actors VALUES (107,325);
INSERT INTO pelis_actors VALUES (108,326);
INSERT INTO pelis_actors VALUES (108,327);
INSERT INTO pelis_actors VALUES (108,328);
INSERT INTO pelis_actors VALUES (109,329);
INSERT INTO pelis_actors VALUES (109,330);
INSERT INTO pelis_actors VALUES (109,331);
INSERT INTO pelis_actors VALUES (109,332);
INSERT INTO pelis_actors VALUES (110,294);
INSERT INTO pelis_actors VALUES (110,333);
INSERT INTO pelis_actors VALUES (110,334);
INSERT INTO pelis_actors VALUES (111,335);
INSERT INTO pelis_actors VALUES (111,336);
INSERT INTO pelis_actors VALUES (111,337);
INSERT INTO pelis_actors VALUES (112, 35);
INSERT INTO pelis_actors VALUES (112,338);
INSERT INTO pelis_actors VALUES (112,339);
INSERT INTO pelis_actors VALUES (112,172);
INSERT INTO pelis_actors VALUES (112,340);
INSERT INTO pelis_actors VALUES (112, 90);
INSERT INTO pelis_actors VALUES (113,341);
INSERT INTO pelis_actors VALUES (113,342);
INSERT INTO pelis_actors VALUES (113,343);
INSERT INTO pelis_actors VALUES (114, 75);
INSERT INTO pelis_actors VALUES (114,344);
INSERT INTO pelis_actors VALUES (114,345);
INSERT INTO pelis_actors VALUES (115,346);
INSERT INTO pelis_actors VALUES (115,347);
INSERT INTO pelis_actors VALUES (115,348);
INSERT INTO pelis_actors VALUES (116,349);
INSERT INTO pelis_actors VALUES (116,350);
INSERT INTO pelis_actors VALUES (116,351);
INSERT INTO pelis_actors VALUES (116,352);



-- Informació de títols, locales i estrenes
INSERT INTO titols VALUES (  1, 'en_US ', 'S', 'Citizen Kane', 				'01/05/1941');
INSERT INTO titols VALUES (  1, 'en_UK ', 'N', 'Citizen Kane', 				'24/01/1942');
INSERT INTO titols VALUES (  1, 'es_ES ', 'N', 'Ciudadano Kane', 			'11/02/1946');
INSERT INTO titols VALUES (  1, 'fr_FR ', 'N', 'Citizen Kane', 				'03/07/1946');
INSERT INTO titols VALUES (  1, 'it_IT ', 'N', 'Quarto potere', 			'14/04/1950');
INSERT INTO titols VALUES (  1, 'de_XWG', 'N', 'Citizen Kane',	 			'29/06/1962');

INSERT INTO titols VALUES (  2, 'en_US ', 'S', 'Casablanca', 				'26/11/1942');
INSERT INTO titols VALUES (  2, 'es_ES ', 'N', 'Casablanca',				'19/12/1946');
INSERT INTO titols VALUES (  2, 'ja_JP ', 'N', 'Casablanca',				'20/06/1946');
INSERT INTO titols VALUES (  2, 'it_IT ', 'N', 'Casablanca',				'04/10/1946');
INSERT INTO titols VALUES (  2, 'fr_FR ', 'N', 'Casablanca',				'23/05/1947');
INSERT INTO titols VALUES (  2, 'de_XWG', 'N', 'Casablanca', 				'29/08/1952');

INSERT INTO titols VALUES (  3, 'en_US ', 'S', 'The Godfather', 			'15/03/1972');
INSERT INTO titols VALUES (  3, 'ja_JP ', 'N', 'Godfather', 				'15/07/1972');
INSERT INTO titols VALUES (  3, 'de_XWG', 'N', 'Der Pate',	 			'24/08/1972');
INSERT INTO titols VALUES (  3, 'it_IT ', 'N', 'Il Padrino',	 			'14/09/1972');
INSERT INTO titols VALUES (  3, 'fr_FR ', 'N', 'Le Parrain',	 			'18/10/1972');
INSERT INTO titols VALUES (  3, 'es_ES ', 'N', 'El Padrino',				'20/10/1972');

INSERT INTO titols VALUES (  4, 'en_US ', 'S', 'Gone with the Wind', 			'15/12/1939');
INSERT INTO titols VALUES (  4, 'fr_FR ', 'N', 'Autant en Emporte Le Vent',		'20/05/1950');
INSERT INTO titols VALUES (  4, 'es_ES ', 'N', 'Lo que el Viento se Llevó',		'17/11/1950');
INSERT INTO titols VALUES (  4, 'it_IT ', 'N', 'Via col Vento',				'03/11/1951');
INSERT INTO titols VALUES (  4, 'ja_JP ', 'N', 'Gone with the Wind',			'10/09/1952');
INSERT INTO titols VALUES (  4, 'de_XWG', 'N', 'Vom Winde Verweht',			'15/01/1953');

INSERT INTO titols VALUES (  5, 'en_US ', 'S', '2001: A Space Odyssey', 		'02/04/1968');
INSERT INTO titols VALUES (  5, 'ja_JP ', 'N', '2001 nen: Uchuu no Tabi',		'11/04/1968');
INSERT INTO titols VALUES (  5, 'de_XWG', 'N', '2001: Odyssee im Weltraum',		'11/09/1968');
INSERT INTO titols VALUES (  5, 'fr_FR ', 'N', '2001, l''Odyssée de l''Espace',		'27/09/1968');
INSERT INTO titols VALUES (  5, 'es_ES ', 'N', '2001: Una Odisea del Espacio',		'17/10/1968');
INSERT INTO titols VALUES (  5, 'it_IT ', 'N', '2001: Odissea nello spazio',		'11/12/1968');

INSERT INTO titols VALUES (  6, 'en_UK ', 'S', 'Lawrence of Arabia', 			'10/12/1962');
INSERT INTO titols VALUES (  6, 'en_US ', 'N', 'Lawrence of Arabia', 			'16/12/1962');
INSERT INTO titols VALUES (  6, 'de_XWG', 'N', 'Lawrence von Arabien',			'15/03/1963');
INSERT INTO titols VALUES (  6, 'fr_FR ', 'N', 'Lawrence d''Arabie',			'15/03/1963');
INSERT INTO titols VALUES (  6, 'it_IT ', 'N', 'Lawrence d''Arabia',			'06/06/1963');
INSERT INTO titols VALUES (  6, 'ja_JP ', 'N', 'Arabia no Rorensu',			'21/12/1963');
INSERT INTO titols VALUES (  6, 'es_ES ', 'N', 'Lawrence de Arabia',			'01/10/1963');

INSERT INTO titols VALUES (  7, 'en_US ', 'S', 'The Wizard of Oz', 			'12/08/1939');
INSERT INTO titols VALUES (  7, 'es_ES ', 'N', 'El Mago de Oz',				'19/03/1945');
INSERT INTO titols VALUES (  7, 'fr_FR ', 'N', 'Le Magicien d''Oz',			'26/06/1946');
INSERT INTO titols VALUES (  7, 'it_IT ', 'N', 'Il Mago di Oz',				'04/12/1947');
INSERT INTO titols VALUES (  7, 'de_XWG', 'N', 'Das Zauberhafte Land',			'19/04/1951');
INSERT INTO titols VALUES (  7, 'ja_JP ', 'N', 'Ozu no Mahôtsukai',			'22/12/1954');

INSERT INTO titols VALUES (  8, 'en_US ', 'S', 'The Graduate', 				'21/12/1967');
INSERT INTO titols VALUES (  8, 'ja_JP ', 'N', 'The Graduate',				'22/06/1968');
INSERT INTO titols VALUES (  8, 'fr_FR ', 'N', 'Le Lauréat',				'04/09/1968');
INSERT INTO titols VALUES (  8, 'de_XWG', 'N', 'Die Reifeprüfung',			'06/09/1968');
INSERT INTO titols VALUES (  8, 'it_IT ', 'N', 'Il Laureato',				'11/09/1968');
INSERT INTO titols VALUES (  8, 'es_ES ', 'N', 'El Graduado',				'21/04/1969');

INSERT INTO titols VALUES (  9, 'ja_JP ', 'N', 'Hatoba',				'24/06/1954');
INSERT INTO titols VALUES (  9, 'en_US ', 'S', 'On the Waterfront', 			'28/06/1954');
INSERT INTO titols VALUES (  9, 'de_XWG', 'N', 'Die Faust im Nacken',			'05/11/1954');
INSERT INTO titols VALUES (  9, 'fr_FR ', 'N', 'Sur les Quais',				'14/01/1955');
INSERT INTO titols VALUES (  9, 'it_IT ', 'N', 'Fronte del Porto',			'28/01/1955');
INSERT INTO titols VALUES (  9, 'es_ES ', 'N', 'La Ley del Silencio',			NULL);

INSERT INTO titols VALUES ( 10, 'en_US ', 'S', 'Schindler''s List', 			'30/11/1993');
INSERT INTO titols VALUES ( 10, 'ja_JP ', 'N', 'Shindorâ no risuto',			'26/02/1994');
INSERT INTO titols VALUES ( 10, 'fr_FR ', 'N', 'La Liste de Schindler',			'02/03/1994');
INSERT INTO titols VALUES ( 10, 'de_DE ', 'N', 'Schindlers Liste',			'03/03/1994');
INSERT INTO titols VALUES ( 10, 'it_IT ', 'N', 'La Lista di Schindler',			'04/03/1994');
INSERT INTO titols VALUES ( 10, 'es_ES ', 'N', 'La Lista de Schindler',			'04/03/1994');

INSERT INTO titols VALUES ( 11, 'en_US ', 'S', 'Singin'' in the Rain', 			'27/03/1952');
INSERT INTO titols VALUES ( 11, 'it_IT ', 'N', 'Cantando sotto la Pioggia',		'07/01/1953');
INSERT INTO titols VALUES ( 11, 'de_XWG', 'N', 'Du Sollst mein Glücksstern Sein',	'30/03/1953');
INSERT INTO titols VALUES ( 11, 'es_ES ', 'N', 'Cantando Bajo la Lluvia',		'04/04/1953');
INSERT INTO titols VALUES ( 11, 'ja_JP ', 'N', 'Ame ni Uta Eba',			'15/04/1953');
INSERT INTO titols VALUES ( 11, 'fr_FR ', 'N', 'Chantons sous la Pluie',		'11/09/1953');

INSERT INTO titols VALUES ( 12, 'en_US ', 'S', 'It''s a Wonderful Life', 		'20/12/1946');
INSERT INTO titols VALUES ( 12, 'es_ES ', 'N', '¡Qué Bello es Vivir!',			'27/03/1948');
INSERT INTO titols VALUES ( 12, 'it_IT ', 'N', 'La Vita è Meravigliosa',		'24/06/1948');
INSERT INTO titols VALUES ( 12, 'fr_FR ', 'N', 'La Vie est Belle',			'28/07/1948');
INSERT INTO titols VALUES ( 12, 'ja_JP ', 'N', 'Subarashiki kana, jinsei!',		'17/02/1954');
INSERT INTO titols VALUES ( 12, 'de_XWG', 'N', 'Ist das Leben nicht Schön?',		'25/12/1962');

INSERT INTO titols VALUES ( 13, 'en_US ', 'S', 'Sunset Blvd.',	 			'10/08/1950');
INSERT INTO titols VALUES ( 13, 'it_IT ', 'N', 'Viale del Tramonto',			'29/03/1951');
INSERT INTO titols VALUES ( 13, 'de_XWG', 'N', 'Boulevard der Dämmerung',		'07/04/1951');
INSERT INTO titols VALUES ( 13, 'fr_FR ', 'N', 'Boulevard du Crépuscule',		'18/04/1951');
INSERT INTO titols VALUES ( 13, 'ja_JP ', 'N', 'Sansetto ôdôri',			'05/10/1951');
INSERT INTO titols VALUES ( 13, 'es_ES ', 'N', 'El Crepúsculo de los Dioses',		NULL);

INSERT INTO titols VALUES ( 14, 'en_UK ', 'S', 'The Bridge on the River Kwai', 		'02/10/1957');
INSERT INTO titols VALUES ( 14, 'en_US ', 'N', 'The Bridge on the River Kwai', 		'14/12/1957');
INSERT INTO titols VALUES ( 14, 'fr_FR ', 'N', 'Le Pont de la Rivière Kwai',		'18/12/1957');
INSERT INTO titols VALUES ( 14, 'ja_JP ', 'N', 'Senjô ni Kakeru Hashi',			'22/12/1957');
INSERT INTO titols VALUES ( 14, 'it_IT ', 'N', 'Il Ponte sul Fiume Kwai',		'30/01/1958');
INSERT INTO titols VALUES ( 14, 'de_XWG', 'N', 'Die Brücke am Kwai',			'07/03/1958');
INSERT INTO titols VALUES ( 14, 'es_ES ', 'N', 'El Puente sobre el Río Kwai',		'13/10/1958');

INSERT INTO titols VALUES ( 15, 'en_US ', 'S', 'Some Like It Hot', 			'29/03/1959');
INSERT INTO titols VALUES ( 15, 'fr_FR ', 'N', 'Certains l''Aiment Chaud',		'09/09/1959');
INSERT INTO titols VALUES ( 15, 'it_IT ', 'N', 'A Qualcuno Piace Ccaldo',		'16/09/1959');
INSERT INTO titols VALUES ( 15, 'ja_JP ', 'N', 'O Atsui no ga o Suki',			'14/04/1959');
INSERT INTO titols VALUES ( 15, 'de_XWG', 'N', 'Manche Mögen''s Heiß',			'17/09/1959');
INSERT INTO titols VALUES ( 15, 'es_ES ', 'N', 'Con Faldas y a lo Loco',		NULL);

INSERT INTO titols VALUES ( 16, 'en_US ', 'S', 'Star Wars', 				'25/05/1977');
INSERT INTO titols VALUES ( 16, 'fr_FR ', 'N', 'La Guerre des Étoiles',			'19/10/1977');
INSERT INTO titols VALUES ( 16, 'it_IT ', 'N', 'Guerre Stellari',			'21/10/1977');
INSERT INTO titols VALUES ( 16, 'es_ES ', 'N', 'La Guerra de las Galaxias',		'07/11/1977');
INSERT INTO titols VALUES ( 16, 'de_XWG', 'N', 'Krieg der Sterne',			'09/02/1978');
INSERT INTO titols VALUES ( 16, 'ja_JP ', 'N', 'Star Wars',				'30/06/1978');

INSERT INTO titols VALUES ( 17, 'en_US ', 'S', 'All About Eve', 			'13/10/1950');
INSERT INTO titols VALUES ( 17, 'fr_FR ', 'N', 'Ève',					'13/10/1950');
INSERT INTO titols VALUES ( 17, 'ja_JP ', 'N', 'Eve no Subete',				'21/09/1951');
INSERT INTO titols VALUES ( 17, 'it_IT ', 'N', 'Eva contro Eva',			'29/10/1951');
INSERT INTO titols VALUES ( 17, 'de_XWG', 'N', 'Alles über Eva',			'29/01/1952');
INSERT INTO titols VALUES ( 17, 'es_ES ', 'N', 'Eva al Desnudo',			'12/04/1952');

INSERT INTO titols VALUES ( 18, 'en_US ', 'S', 'The African Queen', 			'23/12/1951');
INSERT INTO titols VALUES ( 18, 'fr_FR ', 'N', 'La Reine Africaine',			'26/03/1952');
INSERT INTO titols VALUES ( 18, 'ja_JP ', 'N', 'The African Queen',			'23/08/1952');
INSERT INTO titols VALUES ( 18, 'it_IT ', 'N', 'La Regina d''Africa',			'18/12/1952');
INSERT INTO titols VALUES ( 18, 'de_XWG', 'N', 'African Queen',				'19/08/1958');
INSERT INTO titols VALUES ( 18, 'es_ES ', 'N', 'La Reina de Africa',			NULL);

INSERT INTO titols VALUES ( 19, 'en_US ', 'S', 'Psycho', 				'16/06/1960');
INSERT INTO titols VALUES ( 19, 'ja_JP ', 'N', 'Psycho',				'04/09/1960');
INSERT INTO titols VALUES ( 19, 'de_XWG', 'N', 'Psycho',				'07/10/1960');
INSERT INTO titols VALUES ( 19, 'fr_FR ', 'N', 'Psychose',				'02/11/1960');
INSERT INTO titols VALUES ( 19, 'it_IT ', 'N', 'Psyco',					'24/11/1960');
INSERT INTO titols VALUES ( 19, 'es_ES ', 'N', 'Psicosis',				'02/04/1961');

INSERT INTO titols VALUES ( 20, 'en_US ', 'S', 'Chinatown', 				'20/06/1974');
INSERT INTO titols VALUES ( 20, 'es_ES ', 'N', 'Chinatown',				'16/12/1974');
INSERT INTO titols VALUES ( 20, 'fr_FR ', 'N', 'Chinatown',				'18/12/1974');
INSERT INTO titols VALUES ( 20, 'de_XWG', 'N', 'Chinatown',				'19/12/1974');
INSERT INTO titols VALUES ( 20, 'it_IT ', 'N', 'Chinatown',				'17/01/1975');
INSERT INTO titols VALUES ( 20, 'ja_JP ', 'N', 'Chinatown',				'12/04/1975');

INSERT INTO titols VALUES ( 21, 'en_US ', 'S', 'One Flew Over the Cuckoo''s Nest', 	'19/11/1975');
INSERT INTO titols VALUES ( 21, 'fr_FR ', 'N', 'Vol au-dessus d''un Nid de Coucou',	'01/03/1976');
INSERT INTO titols VALUES ( 21, 'it_IT ', 'N', 'Qualcuno Volò sul Nido del Cuculo',	'12/03/1976');
INSERT INTO titols VALUES ( 21, 'de_XWG', 'N', 'Einer Flog über das Kuckucksnest',	'18/03/1976');
INSERT INTO titols VALUES ( 21, 'ja_JP ', 'N', 'Kakkou no su no ue de',			'03/04/1976');
INSERT INTO titols VALUES ( 21, 'es_ES ', 'N', 'Alguien Voló sobre el Nido del Cuco',	'07/10/1976');

INSERT INTO titols VALUES ( 22, 'en_US ', 'S', 'The Grapes of Wrath', 			'24/01/1940');
INSERT INTO titols VALUES ( 22, 'fr_FR ', 'N', 'Les Raisins de la Colère',		'31/12/1947');
INSERT INTO titols VALUES ( 22, 'it_IT ', 'N', 'Furore',				'11/10/1947');
INSERT INTO titols VALUES ( 22, 'de_XWG', 'N', 'Früchte des Zorns',			'27/03/1953');
INSERT INTO titols VALUES ( 22, 'ja_JP ', 'N', 'The Grapes of Wrath',			'12/01/1963');
INSERT INTO titols VALUES ( 22, 'es_ES ', 'N', 'Las Uvas de la Ira',			NULL);

INSERT INTO titols VALUES ( 23, 'en_US ', 'S', 'The Maltesse Falcon', 			'03/10/1941');
INSERT INTO titols VALUES ( 23, 'fr_FR ', 'N', 'Le Faucon Maltais',			'31/07/1946');
INSERT INTO titols VALUES ( 23, 'it_IT ', 'N', 'Il Mistero del Falco',			'05/04/1947');
INSERT INTO titols VALUES ( 23, 'ja_JP ', 'N', 'Maruta no Taka',			'26/01/1951');
INSERT INTO titols VALUES ( 23, 'de_XWG', 'N', 'Der Malteser Falke',			'03/03/1969');
INSERT INTO titols VALUES ( 23, 'es_ES ', 'N', 'El Halcón Maltés',			NULL);

INSERT INTO titols VALUES ( 24, 'en_US ', 'S', 'Raging Bull', 				'14/11/1980');
INSERT INTO titols VALUES ( 24, 'ja_JP ', 'N', 'Raging Bull',				'07/02/1981');
INSERT INTO titols VALUES ( 24, 'it_IT ', 'N', 'Toro Scatenato',			'12/02/1981');
INSERT INTO titols VALUES ( 24, 'fr_FR ', 'N', 'Raging Bull',				'11/03/1981');
INSERT INTO titols VALUES ( 24, 'de_XWG', 'N', 'Wie ein Wilder Stier',			'12/03/1981');
INSERT INTO titols VALUES ( 24, 'es_ES ', 'N', 'Toro Salvaje',				NULL);

INSERT INTO titols VALUES ( 25, 'en_US ', 'S', 'E.T.: The Extra-Terrestrial', 		'11/06/1981');
INSERT INTO titols VALUES ( 25, 'fr_FR ', 'N', 'E.T., l''extra-terrestre',		'01/12/1982');
INSERT INTO titols VALUES ( 25, 'es_ES ', 'N', 'E.T.: El Extraterrestre',		'06/12/1982');
INSERT INTO titols VALUES ( 25, 'it_IT ', 'N', 'E.T. l''extra-terrestre',		'07/12/1982');
INSERT INTO titols VALUES ( 25, 'de_XWG', 'N', 'E.T. - Der Außerirdische',		'09/12/1982');
INSERT INTO titols VALUES ( 25, 'ja_JP ', 'N', 'E.T.',					'05/04/1983');

INSERT INTO titols VALUES ( 26, 'en_US ', 'S', 'Dr. Strangelove', 			'29/01/1964');
INSERT INTO titols VALUES ( 26, 'fr_FR ', 'N', 'Docteur Folamour',			'10/04/1964');
INSERT INTO titols VALUES ( 26, 'de_XWG', 'N', 'Dr. Seltsam, oder wie ich Lernte, die Bombe zu Lieben',	'10/04/1964');
INSERT INTO titols VALUES ( 26, 'it_IT ', 'N', 'Il Dottor Stranamore, ovvero come Imparai a non Preoccuparmi e ad Amare la Momba', '14/05/1964');
INSERT INTO titols VALUES ( 26, 'ja_JP ', 'N', 'Hakase no ijô na aijô: Matawa watashi wa ikani shite shinpai suru no wo yamete suibaku wo aisuru you ni natta ka', '06/10/1964');
INSERT INTO titols VALUES ( 26, 'es_ES ', 'N', 'Teléfono Rojo: Volamos hacia Moscú',	'10/01/1966');

INSERT INTO titols VALUES ( 27, 'en_US ', 'S', 'Bonnie and Clyde', 			'13/08/1967');
INSERT INTO titols VALUES ( 27, 'de_XWG', 'N', 'Bonnie und Clyde',			'19/12/1967');
INSERT INTO titols VALUES ( 27, 'fr_FR ', 'N', 'Bonnie et Clyde',			'24/01/1968');
INSERT INTO titols VALUES ( 27, 'it_IT ', 'N', 'Gangster Story',			'09/02/1968');
INSERT INTO titols VALUES ( 27, 'ja_JP ', 'N', 'Oretachi ni asu wa nai',		'17/02/1968');
INSERT INTO titols VALUES ( 27, 'es_ES ', 'N', 'Bonnie and Clyde',			'26/08/1968');

INSERT INTO titols VALUES ( 28, 'en_US ', 'S', 'Apocalypse Now', 			'15/08/1979');
INSERT INTO titols VALUES ( 28, 'fr_FR ', 'N', 'Apocalypse Now',			'26/09/1979');
INSERT INTO titols VALUES ( 28, 'de_XWG', 'N', 'Apocalypse Now',			'04/10/1979');
INSERT INTO titols VALUES ( 28, 'es_ES ', 'N', 'Apocalypse Now',			'07/11/1979');
INSERT INTO titols VALUES ( 28, 'it_IT ', 'N', 'Apocalypse Now',			'18/12/1979');
INSERT INTO titols VALUES ( 28, 'ja_JP ', 'N', 'Jigoku no Mokushiroku',			'23/02/1980');

INSERT INTO titols VALUES ( 29, 'en_US ', 'S', 'Mr. Smith Goes to Washington', 		'17/10/1939');
INSERT INTO titols VALUES ( 29, 'fr_FR ', 'N', 'Monsieur Smith au Sénat',		'19/01/1940');
INSERT INTO titols VALUES ( 29, 'ja_JP ', 'N', 'Furanku Kyappurâ no Sumisu-san wa Washinton ni Itteimasu', '09/10/1941');
INSERT INTO titols VALUES ( 29, 'it_IT ', 'N', 'Mr. Smith va a Washington',		'04/01/1947');
INSERT INTO titols VALUES ( 29, 'es_ES ', 'N', 'Caballero sin Espada',			'16/04/1949');
INSERT INTO titols VALUES ( 29, 'de_XWG', 'N', 'Mr. Smith Geht nach Washington',	'21/05/1978');

INSERT INTO titols VALUES ( 30, 'en_US ', 'S', 'The Treasure of the Sierra Madre', 	'24/01/1948');
INSERT INTO titols VALUES ( 30, 'es_ES ', 'N', 'El Tesoro de Sierra Madre',		'20/10/1948');
INSERT INTO titols VALUES ( 30, 'it_IT ', 'N', 'Il Tesoro della Sierra Madre',		'15/12/1948');
INSERT INTO titols VALUES ( 30, 'ja_JP ', 'N', 'Ougon',					'07/05/1949');
INSERT INTO titols VALUES ( 30, 'de_XWG', 'N', 'Der Schatz der Sierra Madre',		'14/06/1949');
INSERT INTO titols VALUES ( 30, 'fr_FR ', 'N', 'Le Trésor de la Sierra Madre',		NULL);

INSERT INTO titols VALUES ( 31, 'en_US ', 'S', 'Annie Hall', 				'20/04/1977');
INSERT INTO titols VALUES ( 31, 'de_XWG', 'N', 'Der Stadtneurotiker',			'09/06/1977');
INSERT INTO titols VALUES ( 31, 'it_IT ', 'N', 'Io \& Annie',				'20/08/1977');
INSERT INTO titols VALUES ( 31, 'fr_FR ', 'N', 'Annie Hall',				'07/09/1977');
INSERT INTO titols VALUES ( 31, 'ja_JP ', 'N', 'Annie Hall',				'21/01/1978');
INSERT INTO titols VALUES ( 31, 'es_ES ', 'N', 'Annie Hall',				'22/02/1978');

INSERT INTO titols VALUES ( 32, 'en_US ', 'S', 'The Godfather: Part II', 		'12/12/1974');
INSERT INTO titols VALUES ( 32, 'ja_JP ', 'N', 'Godfather Part II',			'26/04/1975');
INSERT INTO titols VALUES ( 32, 'it_IT ', 'N', 'Il Padrino Parte Seconda',		'20/06/1975');
INSERT INTO titols VALUES ( 32, 'fr_FR ', 'N', 'Le Parrain, 2ème Partie',		'27/08/1975');
INSERT INTO titols VALUES ( 32, 'de_XWG', 'N', 'Der Pate 2',				'25/09/1975');
INSERT INTO titols VALUES ( 32, 'es_ES ', 'N', 'El Padrino: Parte II',			NULL);

INSERT INTO titols VALUES ( 33, 'en_US ', 'S', 'High Noon', 				'24/07/1952');
INSERT INTO titols VALUES ( 33, 'ja_JP ', 'N', 'High Noon',				'17/09/1952');
INSERT INTO titols VALUES ( 33, 'fr_FR ', 'N', 'Le Train Sifflera 3 Fois',		'26/09/1952');
INSERT INTO titols VALUES ( 33, 'de_XWG', 'N', 'Zwölf Uhr Mittags',			'09/01/1953');
INSERT INTO titols VALUES ( 33, 'it_IT ', 'N', 'Mezzogiorno di Fuoco',			'26/02/1953');
INSERT INTO titols VALUES ( 33, 'es_ES ', 'N', 'Solo ante el Peligro',			NULL);

INSERT INTO titols VALUES ( 34, 'en_US ', 'S', 'To Kill a Mockingbird', 		'25/12/1962');
INSERT INTO titols VALUES ( 34, 'fr_FR ', 'N', 'Du Silence et des Ombres',		'29/05/1963');
INSERT INTO titols VALUES ( 34, 'ja_JP ', 'N', 'Arabama Monogatari',			'22/06/1963');
INSERT INTO titols VALUES ( 34, 'de_XWG', 'N', 'Wer die Nachtigall Stört',		'28/06/1963');
INSERT INTO titols VALUES ( 34, 'it_IT ', 'N', 'Il Buio oltre la Siepe',		'19/07/1963');
INSERT INTO titols VALUES ( 34, 'es_ES ', 'N', 'Matar a un Ruiseñor',			NULL);

INSERT INTO titols VALUES ( 35, 'en_US ', 'S', 'It Happened One Night', 		'22/02/1934');
INSERT INTO titols VALUES ( 35, 'es_ES ', 'N', 'Sucedió una Noche',			'16/10/1934');
INSERT INTO titols VALUES ( 35, 'fr_FR ', 'N', 'New York - Miami',			'12/09/1934');
INSERT INTO titols VALUES ( 35, 'it_IT ', 'N', 'Accadde una Notte',			'14/12/1934');
INSERT INTO titols VALUES ( 35, 'ja_JP ', 'N', 'It Happened One Night',			'29/08/1934');
INSERT INTO titols VALUES ( 35, 'de_DE ', 'N', 'Es Geschah in einer Nacht',		'28/03/1935');

INSERT INTO titols VALUES ( 36, 'en_US ', 'S', 'Midnight Cowboy', 			'25/05/1969');
INSERT INTO titols VALUES ( 36, 'de_XWG', 'N', 'Asphalt-Cowboy',			'18/07/1969');
INSERT INTO titols VALUES ( 36, 'fr_FR ', 'N', 'Macadam Cow-boy',			'15/10/1969');
INSERT INTO titols VALUES ( 36, 'ja_JP ', 'N', 'Mayonaka no Kâbôi',			'18/10/1969');
INSERT INTO titols VALUES ( 36, 'it_IT ', 'N', 'Un Uomo da Marciapiede',		'21/10/1969');
INSERT INTO titols VALUES ( 36, 'es_ES ', 'N', 'Cowboy de Medianoche',			NULL);

INSERT INTO titols VALUES ( 37, 'en_US ', 'S', 'The Best Years of Our Lives', 		'21/11/1946');
INSERT INTO titols VALUES ( 37, 'fr_FR ', 'N', 'Les Plus Belles Années de Notre Vie',	'03/10/1947');
INSERT INTO titols VALUES ( 37, 'es_ES ', 'N', 'Los Mejores Años de Nuestra Vida',	'11/12/1947');
INSERT INTO titols VALUES ( 37, 'it_IT ', 'N', 'I Migliori Anni della Nostra Vita',	'28/03/1948');
INSERT INTO titols VALUES ( 37, 'de_DE ', 'N', 'Die Besten Jahre Unseres Lebens',	'01/06/1948');
INSERT INTO titols VALUES ( 37, 'ja_JP ', 'N', 'The Best Years of Our Lives',		'15/06/1948');

INSERT INTO titols VALUES ( 38, 'en_US ', 'S', 'Double Indemnity', 			'24/04/1944');
INSERT INTO titols VALUES ( 38, 'fr_FR ', 'N', 'Assurance sur la Mort',			'31/07/1945');
INSERT INTO titols VALUES ( 38, 'it_IT ', 'N', 'La Fiamma del Peccato',			'09/08/1947');
INSERT INTO titols VALUES ( 38, 'de_XWG', 'N', 'Frau ohne Gewissen',			'06/06/1950');
INSERT INTO titols VALUES ( 38, 'ja_JP ', 'N', 'Shinya no Kokuhaku',			'15/12/1953');
INSERT INTO titols VALUES ( 38, 'es_ES ', 'N', 'Perdición',				NULL);

INSERT INTO titols VALUES ( 39, 'en_US ', 'S', 'Doctor Zhivago', 			'22/12/1965');
INSERT INTO titols VALUES ( 39, 'ja_JP ', 'N', 'Doctor Zhivago',			'18/06/1966');
INSERT INTO titols VALUES ( 39, 'de_XWG', 'N', 'Doktor Schiwago',			'05/10/1966');
INSERT INTO titols VALUES ( 39, 'es_ES ', 'N', 'Doctor Zhivago',			'30/10/1966');
INSERT INTO titols VALUES ( 39, 'fr_FR ', 'N', 'Le Docteur Jivago',			'07/12/1966');
INSERT INTO titols VALUES ( 39, 'it_IT ', 'N', 'Il dottor Zivago',			'10/12/1966');

INSERT INTO titols VALUES ( 40, 'en_US ', 'S', 'North by Northwest', 			'17/07/1959');
INSERT INTO titols VALUES ( 40, 'ja_JP ', 'N', 'Hokuhokusei ni Shinro wo Tore',		'17/09/1959');
INSERT INTO titols VALUES ( 40, 'fr_FR ', 'N', 'La Mort aux Trousses',			'21/10/1959');
INSERT INTO titols VALUES ( 40, 'it_IT ', 'N', 'Intrigo Internazionale',		'27/11/1959');
INSERT INTO titols VALUES ( 40, 'de_XWG', 'N', 'Der Unsichtbare Dritte',		'18/12/1959');
INSERT INTO titols VALUES ( 40, 'es_ES ', 'N', 'Con la Muerte en los Talones',		NULL);

INSERT INTO titols VALUES ( 41, 'en_US ', 'S', 'West Side Story', 			'18/10/1961');
INSERT INTO titols VALUES ( 41, 'ja_JP ', 'N', 'West Side Monogatari',			'23/12/1961');
INSERT INTO titols VALUES ( 41, 'it_IT ', 'N', 'West Side Story',			'23/02/1962');
INSERT INTO titols VALUES ( 41, 'fr_FR ', 'N', 'West Side Story',			'03/03/1962');
INSERT INTO titols VALUES ( 41, 'de_XWG', 'N', 'West Side Story',			'13/09/1962');
INSERT INTO titols VALUES ( 41, 'es_ES ', 'N', 'West Side Story',			'28/02/1963');

INSERT INTO titols VALUES ( 42, 'en_US ', 'S', 'Rear Window', 				'01/08/1954');
INSERT INTO titols VALUES ( 42, 'ja_JP ', 'N', 'Uramado',				'14/01/1955');
INSERT INTO titols VALUES ( 42, 'fr_FR ', 'N', 'Fenêtre sur Cour',			'01/04/1955');
INSERT INTO titols VALUES ( 42, 'de_XWG', 'N', 'Das Fenster zum Hof',			'08/04/1955');
INSERT INTO titols VALUES ( 42, 'it_IT ', 'N', 'La Finestra sul Cortile',		'14/04/1955');
INSERT INTO titols VALUES ( 42, 'es_ES ', 'N', 'La Ventana Indiscreta',			NULL);

INSERT INTO titols VALUES ( 43, 'en_US ', 'S', 'King Kong', 				'07/03/1933');
INSERT INTO titols VALUES ( 43, 'ja_JP ', 'N', 'King Kong',				'14/09/1933');
INSERT INTO titols VALUES ( 43, 'fr_FR ', 'N', 'King Kong', 				'29/09/1933');
INSERT INTO titols VALUES ( 43, 'it_IT ', 'N', 'King Kong',				'13/10/1933');
INSERT INTO titols VALUES ( 43, 'de_DE ', 'N', 'Die Fabel von King Kong - Ein Amerikanischer Trick- und Sensationsfilm', '01/12/1933');
INSERT INTO titols VALUES ( 43, 'es_ES ', 'N', 'King Kong',				NULL);

INSERT INTO titols VALUES ( 44, 'en_US ', 'S', 'The Birth of a Nation', 		'08/02/1915');
INSERT INTO titols VALUES ( 44, 'fr_FR ', 'N', 'Naissance d''une Nation',		'22/10/1920');
INSERT INTO titols VALUES ( 44, 'es_ES ', 'N', 'El Nacimiento de una Nación',		'13/10/1921');
INSERT INTO titols VALUES ( 44, 'ja_JP ', 'N', 'Kokumin no Sôsei',			'25/04/1924');
INSERT INTO titols VALUES ( 44, 'it_IT ', 'N', 'La Nascita di una Nazione',		NULL);
INSERT INTO titols VALUES ( 44, 'de_XWG', 'N', 'Die Geburt einer Nation',		NULL);

INSERT INTO titols VALUES ( 45, 'en_US ', 'S', 'A Streetcar Named Desire', 		'18/09/1951');
INSERT INTO titols VALUES ( 45, 'de_XWG', 'N', 'Endstation Sehnsucht',			'01/12/1951');
INSERT INTO titols VALUES ( 45, 'it_IT ', 'N', 'Un Tram che si Chiama Desiderio',	'18/01/1952');
INSERT INTO titols VALUES ( 45, 'fr_FR ', 'N', 'Un Tramway Nommé Désir',		'28/03/1952');
INSERT INTO titols VALUES ( 45, 'ja_JP ', 'N', 'Yokubô Toiu na no Densha',		'10/05/1952');
INSERT INTO titols VALUES ( 45, 'es_ES ', 'N', 'Un Tranvía Llamado Deseo',		NULL);

INSERT INTO titols VALUES ( 46, 'en_US ', 'S', 'A Clockwork Orange', 			'19/12/1971');
INSERT INTO titols VALUES ( 46, 'de_XWG', 'N', 'Uhrwerk Orange',			'23/03/1972');
INSERT INTO titols VALUES ( 46, 'fr_FR ', 'N', 'Orange Mécanique',			'01/04/1972');
INSERT INTO titols VALUES ( 46, 'ja_JP ', 'N', 'Tokei Jikake no Orenji',		'29/04/1972');
INSERT INTO titols VALUES ( 46, 'it_IT ', 'N', 'Arancia Meccanica',			'07/09/1972');
INSERT INTO titols VALUES ( 46, 'es_ES ', 'N', 'La Naranja Mecánica',			'16/06/1975');

INSERT INTO titols VALUES ( 47, 'en_US ', 'S', 'Taxi Driver', 				'08/02/1976');
INSERT INTO titols VALUES ( 47, 'fr_FR ', 'N', 'Taxi Driver',				'02/06/1976');
INSERT INTO titols VALUES ( 47, 'it_IT ', 'N', 'Taxi Driver',				'27/08/1976');
INSERT INTO titols VALUES ( 47, 'ja_JP ', 'N', 'Taxi Driver',				'18/09/1976');
INSERT INTO titols VALUES ( 47, 'de_XWG', 'N', 'Taxi Driver',				'07/10/1976');
INSERT INTO titols VALUES ( 47, 'es_ES ', 'N', 'Taxi Driver',				'10/03/1977');

INSERT INTO titols VALUES ( 48, 'en_US ', 'S', 'Jaws', 					'20/06/1975');
INSERT INTO titols VALUES ( 48, 'ja_JP ', 'N', 'Jaws',					'13/12/1975');
INSERT INTO titols VALUES ( 48, 'de_XWG', 'N', 'Der Weiße Hai',				'18/12/1975');
INSERT INTO titols VALUES ( 48, 'it_IT ', 'N', 'Lo Squalo',				'27/12/1975');
INSERT INTO titols VALUES ( 48, 'fr_FR ', 'N', 'Les Dents de la Mer',			'01/01/1976');
INSERT INTO titols VALUES ( 48, 'es_ES ', 'N', 'Tiburón',				NULL);

INSERT INTO titols VALUES ( 49, 'en_US ', 'S', 'Snow White and the Seven Dwarfs', 	'21/12/1937');
INSERT INTO titols VALUES ( 49, 'fr_FR ', 'N', 'Blanche Neige et les Sept Nains',	'04/05/1938');
INSERT INTO titols VALUES ( 49, 'it_IT ', 'N', 'Biancaneve e i Sette Nani',		'08/08/1938');
INSERT INTO titols VALUES ( 49, 'es_ES ', 'N', 'Blancanieves y los Siete Enanitos',	'06/10/1941');
INSERT INTO titols VALUES ( 49, 'ja_JP ', 'N', 'Shirayuki Hime',			'26/09/1950');
INSERT INTO titols VALUES ( 49, 'de_XWG', 'N', 'Schneewittchen und die Sieben Zwerge',	'24/02/1950');

INSERT INTO titols VALUES ( 50, 'en_US ', 'S', 'Butch Cassidy and the Sundance Kid', 	'24/09/1969');
INSERT INTO titols VALUES ( 50, 'de_XWG', 'N', 'Butch Cassidy und Sundance Kid',	'10/10/1969');
INSERT INTO titols VALUES ( 50, 'ja_JP ', 'N', 'Asu ni Mukatte ute!',			'07/11/1969');
INSERT INTO titols VALUES ( 50, 'fr_FR ', 'N', 'Butch Cassidy et le Kid',		'06/02/1970');
INSERT INTO titols VALUES ( 50, 'it_IT ', 'N', 'Butch Cassidy',				'07/02/1970');
INSERT INTO titols VALUES ( 50, 'es_ES ', 'N', 'Dos Hombres y un Destino',		NULL);

INSERT INTO titols VALUES ( 51, 'ja_JP ', 'S', 'Shichinin no samurai', 			'26/04/1954');
INSERT INTO titols VALUES ( 51, 'fr_FR ', 'N', 'Les Sept Samouraïs',			'30/11/1955');
INSERT INTO titols VALUES ( 51, 'en_US ', 'N', 'Seven Samurai',				'19/11/1956');
INSERT INTO titols VALUES ( 51, 'de_XWG', 'N', 'Die Sieben Samurai',			'13/07/1962');
INSERT INTO titols VALUES ( 51, 'es_ES ', 'N', 'Los Siete Samuráis',			NULL);
INSERT INTO titols VALUES ( 51, 'it_IT ', 'N', 'I Sette Samurai',			NULL);

INSERT INTO titols VALUES ( 52, 'en_US ', 'S', 'The Philadelphia Story', 		'26/12/1940');
INSERT INTO titols VALUES ( 52, 'it_IT ', 'N', 'Scandalo a Filadelfia',			'10/01/1946');
INSERT INTO titols VALUES ( 52, 'de_XWG', 'N', 'Die Nacht vor der Hochzeit',		'07/02/1950');
INSERT INTO titols VALUES ( 52, 'ja_JP ', 'N', 'The Philadelphia Story',		'24/02/1948');
INSERT INTO titols VALUES ( 52, 'fr_FR ', 'N', 'Indiscrétions',				'02/04/1947');
INSERT INTO titols VALUES ( 52, 'es_ES ', 'N', 'Historias De Philadelphia',		NULL);

INSERT INTO titols VALUES ( 53, 'en_US ', 'S', 'From Here to Eternity', 		'05/08/1953');
INSERT INTO titols VALUES ( 53, 'ja_JP ', 'N', 'From Here to Eternity',			'10/11/1953');
INSERT INTO titols VALUES ( 53, 'de_XWG', 'N', 'Verdammt in alle Ewigkeit',		'06/02/1954');
INSERT INTO titols VALUES ( 53, 'it_IT ', 'N', 'Da qui all''Eternità',			'05/03/1954');
INSERT INTO titols VALUES ( 53, 'fr_FR ', 'N', 'Tant qu''il y Aura des Hommes',		'25/03/1954');
INSERT INTO titols VALUES ( 53, 'es_ES ', 'N', 'De Aquí a la Eternidad',		NULL);

INSERT INTO titols VALUES ( 54, 'en_US ', 'S', 'Amadeus', 				'06/09/1984');
INSERT INTO titols VALUES ( 54, 'de_XWG', 'N', 'Amadeus',				'26/10/1984');
INSERT INTO titols VALUES ( 54, 'fr_FR ', 'N', 'Amadeus',				'31/10/1984');
INSERT INTO titols VALUES ( 54, 'it_IT ', 'N', 'Amadeus',				'21/12/1984');
INSERT INTO titols VALUES ( 54, 'ja_JP ', 'N', 'Amadeus',				'16/02/1985');
INSERT INTO titols VALUES ( 54, 'es_ES ', 'N', 'Amadeus',				'01/03/1985');

INSERT INTO titols VALUES ( 55, 'en_US ', 'S', 'All Quiet on the Western Front', 	'21/04/1930');
INSERT INTO titols VALUES ( 55, 'ja_JP ', 'N', 'All Quiet on the Western Front',	'24/10/1930');
INSERT INTO titols VALUES ( 55, 'fr_FR ', 'N', 'À l''Ouest Rien de Nouveau',		'03/12/1930');
INSERT INTO titols VALUES ( 55, 'de_DE ', 'N', 'Im Westen Nichts Neues',		'04/12/1930');
INSERT INTO titols VALUES ( 55, 'it_IT ', 'N', 'All''Ovest Niente di Nuovo',		'16/01/1931');
INSERT INTO titols VALUES ( 55, 'es_ES ', 'N', 'Sin Novedad en el Frente',		NULL);

INSERT INTO titols VALUES ( 56, 'en_US ', 'S', 'The Sound of Music', 			'02/03/1965');
INSERT INTO titols VALUES ( 56, 'ja_JP ', 'N', 'The Sound of Music',			'19/06/1965');
INSERT INTO titols VALUES ( 56, 'de_XWG', 'N', 'Meine Lieder, meine Träume',		'25/12/1965');
INSERT INTO titols VALUES ( 56, 'it_IT ', 'N', 'Tutti Insieme Appassionatamente',	'30/12/1965');
INSERT INTO titols VALUES ( 56, 'fr_FR ', 'N', 'La Mélodie du Bonheur',			'17/02/1966');
INSERT INTO titols VALUES ( 56, 'es_ES ', 'N', 'Sonrisas y Lágrimas',			NULL);

INSERT INTO titols VALUES ( 57, 'en_UK ', 'S', 'The Third Man', 			'31/08/1949');
INSERT INTO titols VALUES ( 57, 'fr_FR ', 'N', 'Le Toisième Homme',			'12/10/1949');
INSERT INTO titols VALUES ( 57, 'de_XWG', 'N', 'Der Dritte Mann',			'06/01/1950');
INSERT INTO titols VALUES ( 57, 'it_IT ', 'N', 'Il Terzo Uomo',				'19/01/1950');
INSERT INTO titols VALUES ( 57, 'en_US ', 'N', 'The Third Man', 			'02/02/1950');
INSERT INTO titols VALUES ( 57, 'es_ES ', 'N', 'El Tercer Hombre',			'08/04/1950');
INSERT INTO titols VALUES ( 57, 'ja_JP ', 'N', 'Daisan no Otoko',			'03/09/1952');

INSERT INTO titols VALUES ( 58, 'en_US ', 'S', 'Fantasia', 				'13/11/1940');
INSERT INTO titols VALUES ( 58, 'es_ES ', 'N', 'Fantasia',				'23/03/1946');
INSERT INTO titols VALUES ( 58, 'it_IT ', 'N', 'Fantasia',				'12/04/1946');
INSERT INTO titols VALUES ( 58, 'fr_FR ', 'N', 'Fantasia',				'01/11/1946');
INSERT INTO titols VALUES ( 58, 'de_XWG', 'N', 'Fantasia',				'10/10/1952');
INSERT INTO titols VALUES ( 58, 'ja_JP ', 'N', 'Fantajia',				'23/09/1955');

INSERT INTO titols VALUES ( 59, 'en_US ', 'S', 'Rebel without a Cause', 		'27/10/1955');
INSERT INTO titols VALUES ( 59, 'fr_FR ', 'N', 'La Fureur de Vivre',			'28/03/1956');
INSERT INTO titols VALUES ( 59, 'de_XWG', 'N', '...denn sie wissen nicht, was sie tun',	'30/03/1956');
INSERT INTO titols VALUES ( 59, 'ja_JP ', 'N', 'Rebel Without a Cause',			'18/04/1956');
INSERT INTO titols VALUES ( 59, 'it_IT ', 'N', 'Gioventù Bruciata',			'27/04/1956');
INSERT INTO titols VALUES ( 59, 'es_ES ', 'N', 'Rebelde sin Causa',			'20/02/1964');

INSERT INTO titols VALUES ( 60, 'en_US ', 'S', 'Raiders of the Lost Ark', 		'12/06/1981');
INSERT INTO titols VALUES ( 60, 'fr_FR ', 'N', 'Les Aventuriers de l''Arche Perdue',	'16/09/1981');
INSERT INTO titols VALUES ( 60, 'it_IT ', 'N', 'I Predatori dell''Arca Perduta',	'22/10/1981');
INSERT INTO titols VALUES ( 60, 'de_XWG', 'N', 'Jäger des Verlorenen Schatzes',		'29/10/1981');
INSERT INTO titols VALUES ( 60, 'ja_JP ', 'N', 'Reidâzu/ushina wareta âku',		'19/12/1981');
INSERT INTO titols VALUES ( 60, 'es_ES ', 'N', 'En Busca del Arca Perdida',		NULL);

INSERT INTO titols VALUES ( 61, 'en_US ', 'S', 'Vertigo', 				'09/05/1958');
INSERT INTO titols VALUES ( 61, 'ja_JP ', 'N', 'Memai',					'07/10/1958');
INSERT INTO titols VALUES ( 61, 'fr_FR ', 'N', 'Sueurs Froides',			'12/12/1958');
INSERT INTO titols VALUES ( 61, 'it_IT ', 'N', 'La Donna che Visse due Volte',		'22/01/1959');
INSERT INTO titols VALUES ( 61, 'de_XWG', 'N', 'Vertigo - Aus dem Reich der Toten',	'03/02/1959');
INSERT INTO titols VALUES ( 61, 'es_ES ', 'N', 'Vértigo (de entre los Muertos)',	NULL);

INSERT INTO titols VALUES ( 62, 'en_US ', 'S', 'Tootsie', 				'01/12/1982');
INSERT INTO titols VALUES ( 62, 'fr_FR ', 'N', 'Tootsie',				'02/03/1983');
INSERT INTO titols VALUES ( 62, 'it_IT ', 'N', 'Tootsie',				'17/03/1983');
INSERT INTO titols VALUES ( 62, 'de_XWG', 'N', 'Tootsie',				'25/03/1983');
INSERT INTO titols VALUES ( 62, 'ja_JP ', 'N', 'Tootsie',				'16/04/1983');
INSERT INTO titols VALUES ( 62, 'es_ES ', 'N', 'Tootsie',				NULL);

INSERT INTO titols VALUES ( 63, 'en_US ', 'S', 'Stagecoach', 				'15/02/1939');
INSERT INTO titols VALUES ( 63, 'fr_FR ', 'N', 'La Chevauchée Fantastique',		'24/03/1939');
INSERT INTO titols VALUES ( 63, 'it_IT ', 'N', 'Ombre Rosse',				'05/01/1940');
INSERT INTO titols VALUES ( 63, 'ja_JP ', 'N', 'Stagecoach',				'19/06/1940');
INSERT INTO titols VALUES ( 63, 'de_XWG', 'N', 'Höllenfahrt nach Santa Fé',		'13/10/1950');
INSERT INTO titols VALUES ( 63, 'es_ES ', 'N', 'La Diligencia',				NULL);

INSERT INTO titols VALUES ( 64, 'en_US ', 'S', 'Close Encounters of the Third Kind', 	'15/11/1977');
INSERT INTO titols VALUES ( 64, 'fr_FR ', 'N', 'Rencontres du Troisième Type',		'24/02/1978');
INSERT INTO titols VALUES ( 64, 'it_IT ', 'N', 'Incontri Ravvicinati del Terzo Tipo',	'24/02/1978');
INSERT INTO titols VALUES ( 64, 'ja_JP ', 'N', 'Michi Tono Sôgû',			'25/02/1978');
INSERT INTO titols VALUES ( 64, 'de_XWG', 'N', 'Unheimliche Begegnung der Dritten Art', '06/03/1978');
INSERT INTO titols VALUES ( 64, 'es_ES ', 'N', 'Encuentros en la Tercera Fase',		'17/03/1978');

INSERT INTO titols VALUES ( 65, 'en_US ', 'S', 'The Silence of the Lambs', 		'30/01/1991');
INSERT INTO titols VALUES ( 65, 'de_DE ', 'N', 'Das Schweigen der Lämmer',		'15/02/1991');
INSERT INTO titols VALUES ( 65, 'fr_FR ', 'N', 'Le Silence des Agneaux',		'10/04/1991');
INSERT INTO titols VALUES ( 65, 'it_IT ', 'N', 'Il Silenzio degli Innocenti',		'12/04/1991');
INSERT INTO titols VALUES ( 65, 'ja_JP ', 'N', 'Hitsujitachi no Chinmoku',		'22/06/1991');
INSERT INTO titols VALUES ( 65, 'es_ES ', 'N', 'El Silencio de los Corderos',		'06/09/1991');

INSERT INTO titols VALUES ( 66, 'en_US ', 'S', 'Network', 				'14/11/1976');
INSERT INTO titols VALUES ( 66, 'ja_JP ', 'N', 'Network',				'29/01/1977');
INSERT INTO titols VALUES ( 66, 'de_XWG', 'N', 'Network',				'10/03/1977');
INSERT INTO titols VALUES ( 66, 'fr_FR ', 'N', 'Network, main basse sur la T.V.',	'16/03/1977');
INSERT INTO titols VALUES ( 66, 'es_ES ', 'N', 'Network (un Mundo Implacable)',		'16/05/1977');
INSERT INTO titols VALUES ( 66, 'it_IT ', 'N', 'Quinto Potere',				'04/11/1977');

INSERT INTO titols VALUES ( 67, 'en_US ', 'S', 'The Manchurian Candidate', 		'24/10/1962');
INSERT INTO titols VALUES ( 67, 'fr_FR ', 'N', 'Un Crime dans la Tête',			'23/11/1962');
INSERT INTO titols VALUES ( 67, 'ja_JP ', 'N', 'Kagenaki Sogekisha',			'09/02/1963');
INSERT INTO titols VALUES ( 67, 'de_XWG', 'N', 'Botschafter der Angst',			'01/03/1963');
INSERT INTO titols VALUES ( 67, 'it_IT ', 'N', 'Va'' e Uccidi',				'14/03/1964');
INSERT INTO titols VALUES ( 67, 'es_ES ', 'N', 'El Mensajero del Miedo',		NULL);

INSERT INTO titols VALUES ( 68, 'en_US ', 'S', 'An American in Paris', 			'04/10/1951');
INSERT INTO titols VALUES ( 68, 'ja_JP ', 'N', 'An American in Paris',			'17/05/1952');
INSERT INTO titols VALUES ( 68, 'fr_FR ', 'N', 'Un Américain à Paris',			'30/07/1952');
INSERT INTO titols VALUES ( 68, 'it_IT ', 'N', 'Un Americano a Parigi',			'06/09/1952');
INSERT INTO titols VALUES ( 68, 'de_XWG', 'N', 'Ein Amerikaner in Paris',		'24/12/1952');
INSERT INTO titols VALUES ( 68, 'es_ES ', 'N', 'Un Americano en Paris',			NULL);

INSERT INTO titols VALUES ( 69, 'en_US ', 'S', 'Shane', 				'23/04/1953');
INSERT INTO titols VALUES ( 69, 'it_IT ', 'N', 'Il Cavaliere della Valle Solitaria',	'24/09/1953');
INSERT INTO titols VALUES ( 69, 'fr_FR ', 'N', 'L''homme des Vallées Perdues',		'15/10/1953');
INSERT INTO titols VALUES ( 69, 'ja_JP ', 'N', 'Shane',					'20/10/1953');
INSERT INTO titols VALUES ( 69, 'de_XWG', 'N', 'Mein grosser Freund Shane',		'23/10/1953');
INSERT INTO titols VALUES ( 69, 'es_ES ', 'N', 'Raíces Profundas',			'12/07/1954');

INSERT INTO titols VALUES ( 70, 'en_US ', 'S', 'The French Connection', 		'07/10/1971');
INSERT INTO titols VALUES ( 70, 'fr_FR ', 'N', 'French Connection',			'14/01/1972');
INSERT INTO titols VALUES ( 70, 'de_XWG', 'N', 'French Connection - Brennpunkt Brooklyn', '14/01/1972');
INSERT INTO titols VALUES ( 70, 'ja_JP ', 'N', 'French Connection',			'12/02/1972');
INSERT INTO titols VALUES ( 70, 'it_IT ', 'N', 'Il Braccio Violento della Legge',	'03/03/1972');
INSERT INTO titols VALUES ( 70, 'es_ES ', 'N', 'Contra el Imperio de la Droga',		NULL);

INSERT INTO titols VALUES ( 71, 'en_US ', 'S', 'Forrest Gump', 				'23/06/1994');
INSERT INTO titols VALUES ( 71, 'es_ES ', 'N', 'Forrest Gump',				'23/09/1994');
INSERT INTO titols VALUES ( 71, 'fr_FR ', 'N', 'Forrest Gump',				'05/10/1994');
INSERT INTO titols VALUES ( 71, 'it_IT ', 'N', 'Forrest Gump',				'06/10/1994');
INSERT INTO titols VALUES ( 71, 'de_DE ', 'N', 'Forrest Gump',				'13/10/1994');
INSERT INTO titols VALUES ( 71, 'ja_JP ', 'N', 'Forrest Gump',				'18/02/1995');

INSERT INTO titols VALUES ( 72, 'en_US ', 'S', 'Ben-Hur', 				'18/11/1959');
INSERT INTO titols VALUES ( 72, 'ja_JP ', 'N', 'Ben-Hur',				'30/03/1960');
INSERT INTO titols VALUES ( 72, 'fr_FR ', 'N', 'Ben-Hur',				'07/10/1960');
INSERT INTO titols VALUES ( 72, 'de_XWG', 'N', 'Ben Hur',				'14/10/1960');
INSERT INTO titols VALUES ( 72, 'it_IT ', 'N', 'Ben-Hur',				'21/10/1960');
INSERT INTO titols VALUES ( 72, 'es_ES ', 'N', 'Ben-Hur',				NULL);

INSERT INTO titols VALUES ( 73, 'en_US ', 'S', 'Wuthering Heights', 			'24/03/1939');
INSERT INTO titols VALUES ( 73, 'fr_FR ', 'N', 'Les Hauts de Hurlevent',		'03/05/1939');
INSERT INTO titols VALUES ( 73, 'it_IT ', 'N', 'Cime Tempestose',			'22/12/1945');
INSERT INTO titols VALUES ( 73, 'de_XWG', 'N', 'Stürmische Höhen',			'28/07/1950');
INSERT INTO titols VALUES ( 73, 'ja_JP ', 'N', 'Wuthering Heights',			'09/12/1950');
INSERT INTO titols VALUES ( 73, 'es_ES ', 'N', 'Cumbres Borrascosas',			NULL);

INSERT INTO titols VALUES ( 74, 'en_US ', 'S', 'The Gold Rush', 			'26/06/1925');
INSERT INTO titols VALUES ( 74, 'es_ES ', 'N', 'La Quimera del Oro',			'08/02/1926');
INSERT INTO titols VALUES ( 74, 'fr_FR ', 'N', 'La Ruée vers l''Or',			'09/10/1925');
INSERT INTO titols VALUES ( 74, 'it_IT ', 'N', 'La Febbre dell''Oro',			'23/10/1925');
INSERT INTO titols VALUES ( 74, 'ja_JP ', 'N', 'The Gold Rush',				'17/12/1925');
INSERT INTO titols VALUES ( 74, 'de_DE ', 'N', 'Goldrausch',				'28/09/1925');

INSERT INTO titols VALUES ( 75, 'en_US ', 'S', 'Dances with Wolves', 			'19/10/1990');
INSERT INTO titols VALUES ( 75, 'it_IT ', 'N', 'Balla coi Lupi',			'14/12/1990');
INSERT INTO titols VALUES ( 75, 'fr_FR ', 'N', 'Danse avec les Loups',			'20/02/1991');
INSERT INTO titols VALUES ( 75, 'de_DE ', 'N', 'Der mit dem Wolf Tanzt',		'21/02/1991');
INSERT INTO titols VALUES ( 75, 'es_ES ', 'N', 'Bailando con Lobos',			'08/03/1991');
INSERT INTO titols VALUES ( 75, 'ja_JP ', 'N', 'Dances with Wolves',			'18/05/1991');

INSERT INTO titols VALUES ( 76, 'en_US ', 'S', 'City Lights', 				'30/01/1931');
INSERT INTO titols VALUES ( 76, 'es_ES ', 'N', 'Luces de Ciudad',			'04/04/1931');
INSERT INTO titols VALUES ( 76, 'fr_FR ', 'N', 'Les Lumières de la Ville',		'07/04/1931');
INSERT INTO titols VALUES ( 76, 'it_IT ', 'N', 'Luci della Città',			'18/09/1931');
INSERT INTO titols VALUES ( 76, 'ja_JP ', 'N', 'Machi no hi',				'20/01/1934');
INSERT INTO titols VALUES ( 76, 'de_XWG', 'N', 'Lichter der Großstadt',			'01/02/1951');

INSERT INTO titols VALUES ( 77, 'en_US ', 'S', 'American Graffiti', 			'01/08/1973');
INSERT INTO titols VALUES ( 77, 'fr_FR ', 'N', 'American Graffiti',			'01/03/1974');
INSERT INTO titols VALUES ( 77, 'it_IT ', 'N', 'American Graffiti',			'25/04/1974');
INSERT INTO titols VALUES ( 77, 'es_ES ', 'N', 'American Graffiti',			'03/06/1974');
INSERT INTO titols VALUES ( 77, 'de_XWG', 'N', 'American Graffiti',			'23/08/1974');
INSERT INTO titols VALUES ( 77, 'ja_JP ', 'N', 'American Graffiti',			'21/12/1974');

INSERT INTO titols VALUES ( 78, 'en_US ', 'S', 'Rocky', 				'21/11/1976');
INSERT INTO titols VALUES ( 78, 'fr_FR ', 'N', 'Rocky',					'25/03/1977');
INSERT INTO titols VALUES ( 78, 'it_IT ', 'N', 'Rocky',					'25/03/1977');
INSERT INTO titols VALUES ( 78, 'de_XWG', 'N', 'Rocky',					'01/04/1977');
INSERT INTO titols VALUES ( 78, 'ja_JP ', 'N', 'Rocky',					'16/04/1977');
INSERT INTO titols VALUES ( 78, 'es_ES ', 'N', 'Rocky',					'03/10/1977');

INSERT INTO titols VALUES ( 79, 'en_US ', 'S', 'The Deer Hunter', 			'08/12/1978');
INSERT INTO titols VALUES ( 79, 'fr_FR ', 'N', 'Voyage au Bout de l''Enfer',		'07/03/1979');
INSERT INTO titols VALUES ( 79, 'de_XWG', 'N', 'Die Durch die Hölle Gehen',		'08/03/1979');
INSERT INTO titols VALUES ( 79, 'it_IT ', 'N', 'Il Cacciatore',				'23/03/1979');
INSERT INTO titols VALUES ( 79, 'ja_JP ', 'N', 'Deer Hunter',				'24/03/1979');
INSERT INTO titols VALUES ( 79, 'es_ES ', 'N', 'El Cazador',				NULL);

INSERT INTO titols VALUES ( 80, 'en_US ', 'S', 'The Wild Bunch', 			'18/06/1969');
INSERT INTO titols VALUES ( 80, 'ja_JP ', 'N', 'The Wild Bunch',			'16/08/1969');
INSERT INTO titols VALUES ( 80, 'it_IT ', 'N', 'Il Mucchio Selvaggio',			'12/09/1969');
INSERT INTO titols VALUES ( 80, 'de_XWG', 'N', 'The Wild Bunch - Sie kannten kein Gesetz', '03/10/1969');
INSERT INTO titols VALUES ( 80, 'fr_FR ', 'N', 'La Horde Sauvage',			'03/12/1969');
INSERT INTO titols VALUES ( 80, 'es_ES ', 'N', 'Grupo Salvaje',				'19/01/1970');

INSERT INTO titols VALUES ( 81, 'en_US ', 'S', 'Modern Times', 				'05/02/1936');
INSERT INTO titols VALUES ( 81, 'fr_FR ', 'N', 'Les Temps Modernes',			'24/09/1936');
INSERT INTO titols VALUES ( 81, 'it_IT ', 'N', 'Tempi Moderni',				'18/12/1936');
INSERT INTO titols VALUES ( 81, 'ja_JP ', 'N', 'Modern Times',				'09/02/1938');
INSERT INTO titols VALUES ( 81, 'de_XWG', 'N', 'Moderne Zeiten',			'31/03/1956');
INSERT INTO titols VALUES ( 81, 'es_ES ', 'N', 'Tiempos Modernos',			NULL);

INSERT INTO titols VALUES ( 82, 'en_US ', 'S', 'Giant', 				'10/10/1956');
INSERT INTO titols VALUES ( 82, 'de_XWG', 'N', 'Giganten',				'12/12/1956');
INSERT INTO titols VALUES ( 82, 'ja_JP ', 'N', 'Giant',					'19/12/1956');
INSERT INTO titols VALUES ( 82, 'fr_FR ', 'N', 'Géant',					'09/01/1957');
INSERT INTO titols VALUES ( 82, 'it_IT ', 'N', 'Il Gigante',				'28/02/1957');
INSERT INTO titols VALUES ( 82, 'es_ES ', 'N', 'Gigante',				'28/03/1959');

INSERT INTO titols VALUES ( 83, 'en_US ', 'S', 'Platoon', 				'19/12/1986');
INSERT INTO titols VALUES ( 83, 'fr_FR ', 'N', 'Platoon',				'25/03/1987');
INSERT INTO titols VALUES ( 83, 'es_ES ', 'N', 'Platoon',				'26/03/1987');
INSERT INTO titols VALUES ( 83, 'it_IT ', 'N', 'Platoon',				'10/04/1987');
INSERT INTO titols VALUES ( 83, 'ja_JP ', 'N', 'Puratôn',				'29/04/1987');
INSERT INTO titols VALUES ( 83, 'de_XWG', 'N', 'Platoon',				'30/04/1987');

INSERT INTO titols VALUES ( 84, 'en_US ', 'S', 'Fargo', 				'08/03/1996');
INSERT INTO titols VALUES ( 84, 'it_IT ', 'N', 'Fargo',					'20/05/1996');
INSERT INTO titols VALUES ( 84, 'es_ES ', 'N', 'Fargo',					'20/06/1996');
INSERT INTO titols VALUES ( 84, 'fr_FR ', 'N', 'Fargo',					'04/09/1996');
INSERT INTO titols VALUES ( 84, 'ja_JP ', 'N', 'Fâgo',					'09/11/1996');
INSERT INTO titols VALUES ( 84, 'de_DE ', 'N', 'Fargo - Blutiger Schnee',		'14/11/1996');

INSERT INTO titols VALUES ( 85, 'en_US ', 'S', 'Duck Soup', 				'17/11/1933');
INSERT INTO titols VALUES ( 85, 'ja_JP ', 'N', 'Duck Soup',				'27/01/1934');
INSERT INTO titols VALUES ( 85, 'fr_FR ', 'N', 'La Soupe au Canard',			'09/04/1934');
INSERT INTO titols VALUES ( 85, 'it_IT ', 'N', 'La Guerra Lampo dei Fratelli Marx',	'11/10/1934');
INSERT INTO titols VALUES ( 85, 'es_ES ', 'N', 'Sopa de Ganso',				'01/03/1939');
INSERT INTO titols VALUES ( 85, 'de_XWG', 'N', 'Die Marx Brothers im Krieg',		'15/07/1949');

INSERT INTO titols VALUES ( 86, 'en_US ', 'S', 'Philadelphia', 				'23/12/1993');
INSERT INTO titols VALUES ( 86, 'de_DE ', 'N', 'Philadelphia',				'24/02/1994');
INSERT INTO titols VALUES ( 86, 'fr_FR ', 'N', 'Philadelphia',				'09/03/1994');
INSERT INTO titols VALUES ( 86, 'es_ES ', 'N', 'Philadelphia',				'11/03/1994');
INSERT INTO titols VALUES ( 86, 'it_IT ', 'N', 'Philadelphia',				NULL);
INSERT INTO titols VALUES ( 86, 'ja_JP ', 'N', 'Philadelphia',				NULL);

INSERT INTO titols VALUES ( 87, 'en_US ', 'S', 'Mutiny on the Bounty', 			'08/11/1935');
INSERT INTO titols VALUES ( 87, 'de_DE ', 'N', 'Meuterei auf der Bounty',		'12/08/1936');
INSERT INTO titols VALUES ( 87, 'it_IT ', 'N', 'Gli Ammutinati del Bounty',		'08/01/1937');
INSERT INTO titols VALUES ( 87, 'ja_JP ', 'N', 'Mutiny on the Bounty',			'19/05/1938');
INSERT INTO titols VALUES ( 87, 'es_ES ', 'N', 'Motín a Bordo',				NULL);
INSERT INTO titols VALUES ( 87, 'fr_FR ', 'N', 'Les Révoltés du Bounty',		NULL);

INSERT INTO titols VALUES ( 88, 'en_US ', 'S', 'Frankenstein', 				'21/11/1931');
INSERT INTO titols VALUES ( 88, 'fr_FR ', 'N', 'Frankenstein',				'17/03/1932');
INSERT INTO titols VALUES ( 88, 'ja_JP ', 'N', 'Frankenstein',				'15/04/1932');
INSERT INTO titols VALUES ( 88, 'de_XWG', 'N', 'Frankenstein',				'18/05/1932');
INSERT INTO titols VALUES ( 88, 'it_IT ', 'N', 'Frankenstein',				'16/09/1932');
INSERT INTO titols VALUES ( 88, 'es_ES ', 'N', 'El Doctor Frankenstein',		NULL);

INSERT INTO titols VALUES ( 89, 'fr_FR ', 'N', 'Easy Rider',				'08/05/1969');
INSERT INTO titols VALUES ( 89, 'en_US ', 'S', 'Easy Rider', 				'14/07/1969');
INSERT INTO titols VALUES ( 89, 'it_IT ', 'N', 'Easy Rider',				'09/10/1969');
INSERT INTO titols VALUES ( 89, 'ja_JP ', 'N', 'Easy Rider',				'31/01/1970');
INSERT INTO titols VALUES ( 89, 'es_ES ', 'N', 'Buscando mi Destino',			'28/11/1974');
INSERT INTO titols VALUES ( 89, 'de_XWG', 'N', 'Easy Rider',				'19/12/1969');

INSERT INTO titols VALUES ( 90, 'en_US ', 'S', 'Patton', 				'04/02/1970');
INSERT INTO titols VALUES ( 90, 'de_XWG', 'N', 'Patton - Rebell in Uniform',		'26/03/1970');
INSERT INTO titols VALUES ( 90, 'it_IT ', 'N', 'Patton Generale d''Acciaio',		'23/04/1970');
INSERT INTO titols VALUES ( 90, 'fr_FR ', 'N', 'Patton',				'24/04/1970');
INSERT INTO titols VALUES ( 90, 'ja_JP ', 'N', 'Patton',				'27/06/1970');
INSERT INTO titols VALUES ( 90, 'es_ES ', 'N', 'Patton',				NULL);

INSERT INTO titols VALUES ( 91, 'en_US ', 'S', 'The Jazz Singer', 			'06/10/1927');
INSERT INTO titols VALUES ( 91, 'fr_FR ', 'N', 'Le Chanteur de Jazz',			'04/10/1929');
INSERT INTO titols VALUES ( 91, 'de_DE ', 'N', 'Der Jazzsinger',			'26/11/1929');
INSERT INTO titols VALUES ( 91, 'ja_JP ', 'N', 'The Jazz Singer',			'21/08/1930');
INSERT INTO titols VALUES ( 91, 'es_ES ', 'N', 'El Cantor de Jazz',			NULL);
INSERT INTO titols VALUES ( 91, 'it_IT ', 'N', 'Il Cantante di Jazz',			NULL);

INSERT INTO titols VALUES ( 92, 'en_US ', 'S', 'My Fair Lady', 				'21/10/1964');
INSERT INTO titols VALUES ( 92, 'es_ES ', 'N', 'My Fair Lady',				'23/12/1964');
INSERT INTO titols VALUES ( 92, 'fr_FR ', 'N', 'My Fair Lady',				'23/12/1964');
INSERT INTO titols VALUES ( 92, 'it_IT ', 'N', 'My Fair Lady',				'23/12/1964');
INSERT INTO titols VALUES ( 92, 'de_XWG', 'N', 'My Fair Lady',				'23/12/1964');
INSERT INTO titols VALUES ( 92, 'ja_JP ', 'N', 'My Fair Lady',				'26/12/1964');

INSERT INTO titols VALUES ( 93, 'en_US ', 'S', 'A Place in the Sun', 			'14/08/1951');
INSERT INTO titols VALUES ( 93, 'fr_FR ', 'N', 'Une Place au Soleil',			'11/10/1951');
INSERT INTO titols VALUES ( 93, 'de_XWG', 'N', 'Ein Platz an der Sonne',		'25/01/1952');
INSERT INTO titols VALUES ( 93, 'ja_JP ', 'N', 'A Place in the Sun',			'24/09/1952');
INSERT INTO titols VALUES ( 93, 'it_IT ', 'N', 'Un Posto al Sole',			NULL);
INSERT INTO titols VALUES ( 93, 'es_ES ', 'N', 'Un Lugar en el Sol',			NULL);

INSERT INTO titols VALUES ( 94, 'en_US ', 'S', 'The Apartment', 			'15/06/1960');
INSERT INTO titols VALUES ( 94, 'fr_FR ', 'N', 'La Garçonnière',			'16/09/1960');
INSERT INTO titols VALUES ( 94, 'de_XWG', 'N', 'Das Appartement',			'16/09/1960');
INSERT INTO titols VALUES ( 94, 'ja_JP ', 'N', 'Apâto no Kagikashimasu',		'08/10/1960');
INSERT INTO titols VALUES ( 94, 'it_IT ', 'N', 'L''Appartamento',			'09/12/1960');
INSERT INTO titols VALUES ( 94, 'es_ES ', 'N', 'El Apartamento',			'19/12/1962');

INSERT INTO titols VALUES ( 95, 'fr_FR ', 'N', 'Les Affranchis',			'12/09/1990');
INSERT INTO titols VALUES ( 95, 'en_US ', 'S', 'Goodfellas', 				'18/09/1990');
INSERT INTO titols VALUES ( 95, 'it_IT ', 'N', 'Quei Bravi Ragazzi',			'20/09/1990');
INSERT INTO titols VALUES ( 95, 'de_DE ', 'N', 'GoodFellas - Drei Jahrzehnte in der Mafia', '11/10/1990');
INSERT INTO titols VALUES ( 95, 'ja_JP ', 'N', 'Goodfellas',				'13/10/1990');
INSERT INTO titols VALUES ( 95, 'es_ES ', 'N', 'Uno de los Nuestros',			NULL);

INSERT INTO titols VALUES ( 96, 'en_US ', 'S', 'Pulp Fiction', 				'23/09/1994');
INSERT INTO titols VALUES ( 96, 'ja_JP ', 'N', 'Pulp Fiction',				'24/09/1994');
INSERT INTO titols VALUES ( 96, 'fr_FR ', 'N', 'Pulp Fiction',				'26/10/1994');
INSERT INTO titols VALUES ( 96, 'de_XWG', 'N', 'Pulp Fiction',				'03/11/1994');
INSERT INTO titols VALUES ( 96, 'it_IT ', 'N', 'Pulp Fiction',				'16/12/1994');
INSERT INTO titols VALUES ( 96, 'es_ES ', 'N', 'Pulp Fiction',				'13/01/1995');

INSERT INTO titols VALUES ( 97, 'en_US ', 'S', 'The Searchers', 			'13/03/1956');
INSERT INTO titols VALUES ( 97, 'fr_FR ', 'N', 'La Prisonnière du Désert',		'08/08/1956');
INSERT INTO titols VALUES ( 97, 'ja_JP ', 'N', 'The Searchers',				'22/08/1956');
INSERT INTO titols VALUES ( 97, 'it_IT ', 'N', 'Sentieri Selvaggi',			'16/09/1956');
INSERT INTO titols VALUES ( 97, 'de_XWG', 'N', 'Der Schwarze Falke',			'05/10/1956');
INSERT INTO titols VALUES ( 97, 'es_ES ', 'N', 'Centauros del Desierto',		NULL);

INSERT INTO titols VALUES ( 98, 'en_US ', 'S', 'Bringing Up Baby', 			'16/02/1938');
INSERT INTO titols VALUES ( 98, 'fr_FR ', 'N', 'L''Impossible Monsieur Bébé',		'18/03/1938');
INSERT INTO titols VALUES ( 98, 'ja_JP ', 'N', 'Bringing Up Baby',			'17/08/1939');
INSERT INTO titols VALUES ( 98, 'es_ES ', 'N', 'La Fiera de mi Niña',			'13/01/1941');
INSERT INTO titols VALUES ( 98, 'it_IT ', 'N', 'Susanna',				'28/09/1949');
INSERT INTO titols VALUES ( 98, 'de_XWG', 'N', 'Leoparden Küßt Man Nicht',		'18/03/1966');

INSERT INTO titols VALUES ( 99, 'en_US ', 'S', 'Unforgiven', 				'03/08/1992');
INSERT INTO titols VALUES ( 99, 'fr_FR ', 'N', 'Impitoyable',				'09/09/1992');
INSERT INTO titols VALUES ( 99, 'de_DE ', 'N', 'Erbarmungslos',				'24/09/1992');
INSERT INTO titols VALUES ( 99, 'es_ES ', 'N', 'Sin Perdón',				'25/09/1992');
INSERT INTO titols VALUES ( 99, 'it_IT ', 'N', 'Gli Spietati',				'18/12/1992');
INSERT INTO titols VALUES ( 99, 'ja_JP ', 'N', 'Yurusarezaru Mono',			'24/04/1993');

INSERT INTO titols VALUES (100, 'en_US ', 'S', 'Guess Who''s Coming to Dinner', 	'11/12/1967');
INSERT INTO titols VALUES (100, 'fr_FR ', 'N', 'Devine qui vient dîner?',		'20/03/1968');
INSERT INTO titols VALUES (100, 'de_XWG', 'N', 'Rat mal, wer zum Essen Kommt',		'21/03/1968');
INSERT INTO titols VALUES (100, 'it_IT ', 'N', 'Indovina chi Viene a Cena?',		'03/04/1968');
INSERT INTO titols VALUES (100, 'ja_JP ', 'N', 'Guess Who''s Coming to Dinner',		'06/04/1968');
INSERT INTO titols VALUES (100, 'es_ES ', 'N', 'Adivina Quién Viene Esta Noche',	NULL);

INSERT INTO titols VALUES (101, 'en_US ', 'S', 'Yankee Doodle Dandy', 			'29/05/1942');
INSERT INTO titols VALUES (101, 'fr_FR ', 'N', 'La Glorieuse Parade',			'25/09/1946');
INSERT INTO titols VALUES (101, 'it_IT ', 'N', 'Ribalta di Gloria',			'10/01/1948');
INSERT INTO titols VALUES (101, 'ja_JP ', 'N', 'Yankee Doodle Dandy',			'06/12/1986');
INSERT INTO titols VALUES (101, 'es_ES ', 'N', 'Yanqui Dandy',				NULL);
INSERT INTO titols VALUES (101, 'de_XWG', 'N', 'Yankee Doodle Dandy',			NULL);

INSERT INTO titols VALUES (102, 'en_US ', 'S', 'Thelma \& Louise', 			'24/05/1991');
INSERT INTO titols VALUES (102, 'fr_FR ', 'N', 'Thelma \& Louise',			'29/05/1991');
INSERT INTO titols VALUES (102, 'ja_JP ', 'N', 'Thelma \& Louise',			'10/10/1991');
INSERT INTO titols VALUES (102, 'de_DE ', 'N', 'Thelma \& Louise',			'24/10/1991');
INSERT INTO titols VALUES (102, 'es_ES ', 'N', 'Thelma y Louise',			'22/11/1991');
INSERT INTO titols VALUES (102, 'it_IT ', 'N', 'Thelma \& Louise',			NULL);

INSERT INTO titols VALUES (103, 'en_US ', 'S', 'The Shining', 				'23/05/1980');
INSERT INTO titols VALUES (103, 'fr_FR ', 'N', 'Shining',				'16/10/1980');
INSERT INTO titols VALUES (103, 'de_XWG', 'N', 'Shining',				'16/10/1980');
INSERT INTO titols VALUES (103, 'ja_JP ', 'N', 'Shining',				'13/12/1980');
INSERT INTO titols VALUES (103, 'it_IT ', 'N', 'Shining',				'22/12/1980');
INSERT INTO titols VALUES (103, 'es_ES ', 'N', 'El Resplandor',				NULL);

INSERT INTO titols VALUES (104, 'en_US ', 'S', 'Blade Runner', 				'25/06/1982');
INSERT INTO titols VALUES (104, 'ja_JP ', 'N', 'Blade Runner',				'03/07/1982');
INSERT INTO titols VALUES (104, 'es_ES ', 'N', 'Blade Runner',				'21/08/1982');
INSERT INTO titols VALUES (104, 'fr_FR ', 'N', 'Blade Runner',				'15/09/1982');
INSERT INTO titols VALUES (104, 'it_IT ', 'N', 'Blade Runner',				'14/10/1982');
INSERT INTO titols VALUES (104, 'de_XWG', 'N', 'Der Blade Runner',			'14/10/1982');

INSERT INTO titols VALUES (105, 'en_US ', 'S', 'Se7en', 				'22/09/1995');
INSERT INTO titols VALUES (105, 'de_DE ', 'N', 'Sieben',				'23/11/1995');
INSERT INTO titols VALUES (105, 'it_IT ', 'N', 'Seven',					'15/12/1995');
INSERT INTO titols VALUES (105, 'es_ES ', 'N', 'Seven',					'10/01/1996');
INSERT INTO titols VALUES (105, 'ja_JP ', 'N', 'Sebun',					'27/01/1996');
INSERT INTO titols VALUES (105, 'fr_FR ', 'N', 'Seven',					'31/01/1996');

INSERT INTO titols VALUES (106, 'en_US ', 'S', 'Million Dollar Baby', 			'15/12/2004');
INSERT INTO titols VALUES (106, 'es_ES ', 'N', 'Million Dollar Baby',			'04/02/2005');
INSERT INTO titols VALUES (106, 'it_IT ', 'N', 'Million Dollar Baby',			'18/02/2005');
INSERT INTO titols VALUES (106, 'fr_FR ', 'N', 'Million Dollar Baby',			'23/03/2005');
INSERT INTO titols VALUES (106, 'de_DE ', 'N', 'Million Dollar Baby',			'24/03/2005');
INSERT INTO titols VALUES (106, 'ja_JP ', 'N', 'Million Dollar Baby',			'28/05/2005');

INSERT INTO titols VALUES (107, 'es_ES ', 'S', 'El Laberinto del Fauno', 		'11/10/2006');
INSERT INTO titols VALUES (107, 'en_US ', 'N', 'Pan''s Labyrinth',			'15/10/2006');
INSERT INTO titols VALUES (107, 'fr_FR ', 'N', 'Le Labyrinthe de Pan',			'01/11/2006');
INSERT INTO titols VALUES (107, 'it_IT ', 'N', 'Il Labirinto del Fauno',		'24/11/2006');
INSERT INTO titols VALUES (107, 'de_DE ', 'N', 'Pans Labyrinth',			'22/02/2007');
INSERT INTO titols VALUES (107, 'ja_JP ', 'N', 'Pan''s Labyrinth',			'06/10/2007');

INSERT INTO titols VALUES (108, 'ru_XSU', 'S', 'Bronenosets Potyomkin', 		'24/12/1925');
INSERT INTO titols VALUES (108, 'fr_FR ', 'N', 'Le Cuirassé Potemkine',			'12/11/1926');
INSERT INTO titols VALUES (108, 'en_US ', 'N', 'Battleship Potemkin',			'05/12/1926');
INSERT INTO titols VALUES (108, 'de_DE ', 'N', 'Panzerkreuzer Potemkin',		'12/08/1930');
INSERT INTO titols VALUES (108, 'ja_JP ', 'N', 'Battleship Potemkin',			'04/10/1967');
INSERT INTO titols VALUES (108, 'it_IT ', 'N', 'La Corazzata Potemkin',			NULL);
INSERT INTO titols VALUES (108, 'es_ES ', 'N', 'El Acorazado Potemkin',			NULL);

INSERT INTO titols VALUES (109, 'sv_SE ', 'S', 'Det Sjunde Inseglet', 			'16/02/1957');
INSERT INTO titols VALUES (109, 'de_XWG', 'N', 'Das Siebente Siegel',			'24/08/1957');
INSERT INTO titols VALUES (109, 'fr_FR ', 'N', 'Le Septième Sceau',			'11/12/1957');
INSERT INTO titols VALUES (109, 'it_IT ', 'N', 'Il Settimo Sigillo',			'06/08/1958');
INSERT INTO titols VALUES (109, 'en_US ', 'N', 'The Seventh Seal',			'13/10/1958');
INSERT INTO titols VALUES (109, 'ja_JP ', 'N', 'The Seventh Seal',			'09/11/1963');
INSERT INTO titols VALUES (109, 'es_ES ', 'N', 'El Séptimo Sello',			NULL);

INSERT INTO titols VALUES (110, 'it_IT ', 'S', 'Il buono, il brutto, il cattivo', 	'23/12/1966');
INSERT INTO titols VALUES (110, 'de_XWG', 'N', 'Zwei Glorreiche Halunken',		'15/12/1967');
INSERT INTO titols VALUES (110, 'en_US ', 'N', 'The Good, the Bad and the Ugly',	'29/12/1967');
INSERT INTO titols VALUES (110, 'ja_JP ', 'N', 'Zoku Yuuhi no Ganman',			'30/12/1967');
INSERT INTO titols VALUES (110, 'fr_FR ', 'N', 'Le Bon, la Brute et le Truand',		'08/03/1968');
INSERT INTO titols VALUES (110, 'es_ES ', 'N', 'El Bueno, el Feo y el Malo',		NULL);

INSERT INTO titols VALUES (111, 'it_IT ', 'S', '8 1/2', 				'14/02/1963');
INSERT INTO titols VALUES (111, 'de_XWG', 'N', 'Achteinhalb',				'23/05/1963');
INSERT INTO titols VALUES (111, 'fr_FR ', 'N', 'Huit et Demi',				'29/05/1963');
INSERT INTO titols VALUES (111, 'en_US ', 'N', '8 1/2',					'25/06/1963');
INSERT INTO titols VALUES (111, 'ja_JP ', 'N', '8 1/2',					'26/09/1965');
INSERT INTO titols VALUES (111, 'es_ES ', 'N', 'Fellini 8 1/2',				'13/05/1967');

INSERT INTO titols VALUES (112, 'en_IN ', 'S', 'Gandhi', 				'30/11/1982');
INSERT INTO titols VALUES (112, 'de_XWG', 'N', 'Gandhi',				'18/02/1983');
INSERT INTO titols VALUES (112, 'fr_FR ', 'N', 'Gandhi',				'23/03/1983');
INSERT INTO titols VALUES (112, 'it_IT ', 'N', 'Gandhi',				NULL);
INSERT INTO titols VALUES (112, 'ja_JP ', 'N', 'Gandhi',				NULL);
INSERT INTO titols VALUES (112, 'es_ES ', 'N', 'Gandhi',				NULL);

INSERT INTO titols VALUES (113, 'de_DE ', 'S', 'Metropolis', 				'10/01/1927');
INSERT INTO titols VALUES (113, 'en_US ', 'N', 'Metropolis',				'06/03/1927');
INSERT INTO titols VALUES (113, 'es_ES ', 'N', 'Metrópolis',				'23/01/1928');
INSERT INTO titols VALUES (113, 'ja_JP ', 'N', 'Metoroporisu',				'03/04/1929');
INSERT INTO titols VALUES (113, 'fr_FR ', 'N', 'Metropolis',				NULL);
INSERT INTO titols VALUES (113, 'it_IT ', 'N', 'Metropolis',				NULL);

INSERT INTO titols VALUES (114, 'de_DE ', 'S', 'M', 					'11/05/1931');
INSERT INTO titols VALUES (114, 'fr_FR ', 'N', 'M le maudit',				'08/04/1932');
INSERT INTO titols VALUES (114, 'en_US ', 'N', 'M',					'31/03/1933');
INSERT INTO titols VALUES (114, 'it_IT ', 'N', 'M, il mostro di Dusseldorf',		NULL);
INSERT INTO titols VALUES (114, 'es_ES ', 'N', 'M, el Vampiro de Düsseldorf',		NULL);
INSERT INTO titols VALUES (114, 'ja_JP ', 'N', 'm',					NULL);

INSERT INTO titols VALUES (115, 'fr_FR ', 'S', 'Les Enfants du Paradis', 		'09/03/1945');
INSERT INTO titols VALUES (115, 'it_IT ', 'N', 'Amanti Perduti',			'27/03/1946');
INSERT INTO titols VALUES (115, 'en_US ', 'N', 'Children of Paradise',			'15/11/1946');
INSERT INTO titols VALUES (115, 'ja_JP ', 'N', 'Les Enfants du Paradis',		'20/02/1952');
INSERT INTO titols VALUES (115, 'de_DE ', 'N', 'Kinder des Olymp',			'28/02/1947');
INSERT INTO titols VALUES (115, 'es_ES ', 'N', 'Los Niños del Paraíso',			NULL);

INSERT INTO titols VALUES (116, 'fr_FR ', 'S', 'León', 					'14/09/1994');
INSERT INTO titols VALUES (116, 'en_US ', 'N', 'Leon: The Professional',		'18/11/1994');
INSERT INTO titols VALUES (116, 'de_DE ', 'N', 'Leon - Der Profi',			'19/01/1995');
INSERT INTO titols VALUES (116, 'ja_JP ', 'N', 'Leon',					'25/03/1995');
INSERT INTO titols VALUES (116, 'es_ES ', 'N', 'El Profesional (León)',			'06/04/1995');
INSERT INTO titols VALUES (116, 'it_IT ', 'N', 'Leon',					NULL);



-- Comentaris de les taules i columnes
COMMENT ON TABLE participants IS 'Aquí s''indiquen actors i directors amb la informació personal corresponent';
COMMENT ON COLUMN participants.codi IS 'Codi identificador de la persona';
COMMENT ON COLUMN participants.nom IS 'Nom complet de la persona';
COMMENT ON COLUMN participants.sexe IS 'Una lletra D vol dir dona, mentre que una lletra H vol dir home';
COMMENT ON COLUMN participants.naixement IS 'Data exacta de naixement de la persona';
COMMENT ON COLUMN participants.defuncio IS 'Data exacta de defunció de la persona o valor NULL si encara és viva';

COMMENT ON TABLE pelis IS 'Informació central de les pel·lícules. Cal consultar la informació detallada unint amb altres taules';
COMMENT ON COLUMN pelis.codi IS 'Codi identificador de la pel·lícula';
COMMENT ON COLUMN pelis.produccio IS 'Any de producció de la pel·lícula. Per a les dates d''estrena, consulti la taula titols';
COMMENT ON COLUMN pelis.color IS 'Una lletra S vol dir que és en color, mentre que una N vol dir en blanc i negre';
COMMENT ON COLUMN pelis.director_id IS 'Codi identificador del director de la pel·lícula. Cal consultar la taula participants';

COMMENT ON TABLE pelis_actors IS 'Taula que relaciona pel·lícules (de la taula pelis) amb actors (de la taula participants)';
COMMENT ON COLUMN pelis_actors.codi_peli IS 'Codi de la pel·lícula, a consultar a la taula pelis';
COMMENT ON COLUMN pelis_actors.codi_actor IS 'Codi de l''actor, a consultar a la taula participants';

COMMENT ON TABLE titols IS 'Taula amb els títols, localitzacions i dates d''estrena de les diferents pel·lícules';
COMMENT ON COLUMN titols.peli IS 'Codi identificador de la pel·lícula, a consultar a la taula pelis';
COMMENT ON COLUMN titols.locale IS 'Locale del titol: idioma amb dues lletres i ubicació amb 2 o 3 lletres';
COMMENT ON COLUMN titols.original IS 'Una lletra S si és el títol original (idioma original) o una N en cas contrari';
COMMENT ON COLUMN titols.titol IS 'Títol associat al locale indicat (idioma i localització)';
COMMENT ON COLUMN titols.estrena IS 'Data d''estrena d''aquella versió en el locale indicat';




-- Part corresponent als usuaris de la base de dades
DROP TABLE colors CASCADE CONSTRAINTS;
DROP TABLE poblacions CASCADE CONSTRAINTS;
DROP TABLE usuaris CASCADE CONSTRAINTS;
DROP TABLE valoracions CASCADE CONSTRAINTS;
DROP TABLE favorites CASCADE CONSTRAINTS;

CREATE TABLE colors (
  codi			NUMBER,
  nom 			VARCHAR2(15)
);

CREATE TABLE poblacions (
  codpos		NUMBER(5) NOT NULL,
  poblacio		VARCHAR2(100) NOT NULL
);

CREATE TABLE usuaris (
  id 			NUMBER(11),
  nom 			VARCHAR2(20) NOT NULL,
  cognoms 		VARCHAR2(30),
  sexe 			CHAR(1),
  adreca 		VARCHAR2(35) NOT NULL,
  codpos 		NUMBER(5) NOT NULL,
  email 		VARCHAR2(50) NOT NULL,
  naixement 		DATE,
  numeropreferit 	NUMBER,
  colorpreferit 	NUMBER(5)
);

CREATE TABLE valoracions (
  usuari		NUMBER(10) NOT NULL,
  peli			NUMBER(10) NOT NULL,
  data			DATE NOT NULL,
  nota			NUMBER(2) NOT NULL
);

CREATE TABLE favorites (
  usuari		NUMBER(10) NOT NULL,
  peli			NUMBER(10) NOT NULL,
  ranquing		NUMBER(5) NOT NULL
);

--
--CREATE TABLE poblacions (
--  id 			NUMBER,
--  codpos		NUMBER(5) CONSTRAINT poblacions_codpos_nn NOT NULL,
--  poblacio		VARCHAR2(100) CONSTRAINT poblacions_poblacio_nn NOT NULL,
--  CONSTRAINT poblacions_codpos_ck CHECK (codpos BETWEEN 00000 AND 99999)
--);

--CREATE TABLE usuaris (
--  id 			NUMBER(11) CONSTRAINT usuaris_id_pk PRIMARY KEY,
--  nom 			VARCHAR2(20) CONSTRAINT usuaris_nom_nn NOT NULL,
--  cognoms 		VARCHAR2(35) CONSTRAINT usuaris_cognoms_nn NOT NULL,
--  sexe 			CHAR(1),
--  adreca 		VARCHAR2(100),
--  poblacio 		NUMBER(5),
--  email 		VARCHAR2(100) CONSTRAINT usuaris_email_nn NOT NULL,
--  naixement 		DATE,
--  numeropreferit 	NUMBER,
--  colorpreferit 	NUMBER(5),
--  CONSTRAINT usuari_sexe_ck CHECK (sexe IN ('H', 'D')),
--  CONSTRAINT usuari_email_ck CHECK ( (INSTR(email,'@')<>0) AND (INSTR(email,'.',INSTR(email,'@'))<>0) ),
--  CONSTRAINT usuari_poblacio_fk FOREIGN KEY (poblacio) REFERENCES poblacions(id),
--  CONSTRAINT usuari_colorpreferit_fk FOREIGN KEY (colorpreferit) REFERENCES colors(codi)
--);

--CREATE TABLE valoracions (
--  usuari		NUMBER(10) CONSTRAINT valoracions_usuari_nn NOT NULL,
--  peli			NUMBER(10) CONSTRAINT valoracions_peli_nn NOT NULL,
--  data			DATE CONSTRAINT valoracions_data_nn NOT NULL,
--  nota			NUMBER(2) CONSTRAINT valoracions_nota_nn NOT NULL,
--  CONSTRAINT valoracions_usuari_fk FOREIGN KEY (usuari) REFERENCES usuaris(id),
--  CONSTRAINT valoracions_peli_fk FOREIGN KEY (peli) REFERENCES pelis(codi),
--  CONSTRAINT valoracions_nota_ck CHECK ( nota BETWEEN 0 AND 10 )
--);

--CREATE TABLE favorites (
--  usuari		NUMBER(10) CONSTRAINT favorites_usuari_nn NOT NULL,
--  peli			NUMBER(10) CONSTRAINT favorites_peli_nn NOT NULL,
--  ranquing		NUMBER(5) CONSTRAINT favorites_ranquing_nn NOT NULL,
--  CONSTRAINT favorites_usuari_fk FOREIGN KEY (usuari) REFERENCES usuaris(id),
--  CONSTRAINT favorites_peli_fk FOREIGN KEY (peli) REFERENCES pelis(codi),
--  CONSTRAINT favorites_ranquing_ck CHECK ( ranquing > 0 )
--);


COMMENT ON TABLE favorites IS 'Taula que conté la llista de pel·lícules marcades com a favorites dels diferents usuaris de la base de dades';
COMMENT ON COLUMN favorites.usuari IS 'Codi identificador de l''usuari per saber de qui és aquesta entrada de llista de favorites';
COMMENT ON COLUMN favorites.peli IS 'Codi identificador de la pel·lícula per saber quina pel·lícula és la que estem afegit a la llista de favorites';
COMMENT ON COLUMN favorites.ranquing IS 'Número que indica la posició dins del rànquing de pel·lícules favorites per a l''usuari i la pel·lícula indicats';



INSERT INTO colors VALUES ( 1, 'Vermell');
INSERT INTO colors VALUES ( 2, 'Verd');
INSERT INTO colors VALUES ( 3, 'Blau');
INSERT INTO colors VALUES ( 4, 'Magenta');
INSERT INTO colors VALUES ( 5, 'Gris');
INSERT INTO colors VALUES ( 6, 'Groc');
INSERT INTO colors VALUES ( 7, 'Taronja');
INSERT INTO colors VALUES ( 8, 'Violeta');
INSERT INTO colors VALUES ( 9, 'Anyil');
INSERT INTO colors VALUES (10, 'Blanc');
INSERT INTO colors VALUES (11, 'Negre');
INSERT INTO colors VALUES (12, 'Verd-blavós');



INSERT INTO poblacions VALUES (1000, 'Vitoria-Gasteiz');
INSERT INTO poblacions VALUES (1117, 'Harana');
INSERT INTO poblacions VALUES (1118, 'Lagrán');
INSERT INTO poblacions VALUES (1138, 'Zigoitia');
INSERT INTO poblacions VALUES (1160, 'Aramaio');
INSERT INTO poblacions VALUES (1170, 'Legutiano');
INSERT INTO poblacions VALUES (1200, 'Salvatierra o Agurain');
INSERT INTO poblacions VALUES (1206, 'Barrundia');
INSERT INTO poblacions VALUES (1208, 'Zalduondo');
INSERT INTO poblacions VALUES (1211, 'Peñacerrada-Urizaharra');
INSERT INTO poblacions VALUES (1212, 'Zambrana');
INSERT INTO poblacions VALUES (1218, 'Berantevilla');
INSERT INTO poblacions VALUES (1220, 'Armiñón');
INSERT INTO poblacions VALUES (1240, 'Alegría-Dulantzi');
INSERT INTO poblacions VALUES (1250, 'Asparrena');
INSERT INTO poblacions VALUES (1300, 'Laguardia');
INSERT INTO poblacions VALUES (1307, 'Leza');
INSERT INTO poblacions VALUES (1311, 'Yécora');
INSERT INTO poblacions VALUES (1314, 'Moreda de Álava');
INSERT INTO poblacions VALUES (1340, 'Elciego');
INSERT INTO poblacions VALUES (1400, 'Llodio');
INSERT INTO poblacions VALUES (1409, 'Okondo');
INSERT INTO poblacions VALUES (1420, 'Ribera Alta');
INSERT INTO poblacions VALUES (1426, 'Valdegovía');
INSERT INTO poblacions VALUES (1427, 'Añana');
INSERT INTO poblacions VALUES (1430, 'Kuartango');
INSERT INTO poblacions VALUES (1470, 'Amurrio');
INSERT INTO poblacions VALUES (1520, 'Arrazua-Ubarrundia');
INSERT INTO poblacions VALUES (2000, 'Albacete');
INSERT INTO poblacions VALUES (2100, 'Tarazona de la Mancha');
INSERT INTO poblacions VALUES (2110, 'La Gineta');
INSERT INTO poblacions VALUES (2120, 'Peñas de San Pedro');
INSERT INTO poblacions VALUES (2124, 'Alcadozo');
INSERT INTO poblacions VALUES (2125, 'Ayna');
INSERT INTO poblacions VALUES (2130, 'Bogarra');
INSERT INTO poblacions VALUES (2141, 'Pozohondo');
INSERT INTO poblacions VALUES (2150, 'Valdeganga');
INSERT INTO poblacions VALUES (2151, 'Casas de Juan Núñez');
INSERT INTO poblacions VALUES (2152, 'Alatoz');
INSERT INTO poblacions VALUES (2153, 'Carcelén');
INSERT INTO poblacions VALUES (2154, 'Pozo-Lorente');
INSERT INTO poblacions VALUES (2154, 'Villavaliente');
INSERT INTO poblacions VALUES (2160, 'Lezuza');
INSERT INTO poblacions VALUES (2162, 'La Herrera');
INSERT INTO poblacions VALUES (2210, 'Alcalá del Júcar');
INSERT INTO poblacions VALUES (2212, 'Casas de Ves');
INSERT INTO poblacions VALUES (2213, 'Villa de Ves');
INSERT INTO poblacions VALUES (2214, 'Balsa de Ves');
INSERT INTO poblacions VALUES (2215, 'Alborea');
INSERT INTO poblacions VALUES (2215, 'Villatoya');
INSERT INTO poblacions VALUES (2220, 'Motilleja');
INSERT INTO poblacions VALUES (2230, 'Madrigueras');
INSERT INTO poblacions VALUES (2240, 'Mahora');
INSERT INTO poblacions VALUES (2246, 'Navas de Jorquera');
INSERT INTO poblacions VALUES (2247, 'Cenizate');
INSERT INTO poblacions VALUES (2249, 'La Recueja');
INSERT INTO poblacions VALUES (2250, 'Abengibre');
INSERT INTO poblacions VALUES (2253, 'Golosalvo');
INSERT INTO poblacions VALUES (2260, 'Fuentealbilla');
INSERT INTO poblacions VALUES (2270, 'Villamalea');
INSERT INTO poblacions VALUES (2300, 'Alcaraz');
INSERT INTO poblacions VALUES (2310, 'Viveros');
INSERT INTO poblacions VALUES (2311, 'Povedilla');
INSERT INTO poblacions VALUES (2314, 'Masegoso');
INSERT INTO poblacions VALUES (2315, 'Vianos');
INSERT INTO poblacions VALUES (2316, 'Salobre');
INSERT INTO poblacions VALUES (2320, 'Balazote');
INSERT INTO poblacions VALUES (2326, 'San Pedro');
INSERT INTO poblacions VALUES (2327, 'Pozuelo');
INSERT INTO poblacions VALUES (2329, 'Casas de Lázaro');
INSERT INTO poblacions VALUES (2340, 'Robledo');
INSERT INTO poblacions VALUES (2400, 'Hellín');
INSERT INTO poblacions VALUES (2410, 'Liétor');
INSERT INTO poblacions VALUES (2434, 'Letur');
INSERT INTO poblacions VALUES (2435, 'Socovos');
INSERT INTO poblacions VALUES (2436, 'Férez');
INSERT INTO poblacions VALUES (2440, 'Molinicos');
INSERT INTO poblacions VALUES (2450, 'Riópar');
INSERT INTO poblacions VALUES (2460, 'Villaverde de Guadalimar');
INSERT INTO poblacions VALUES (2461, 'Cotillas');
INSERT INTO poblacions VALUES (2520, 'Chinchilla de Monte-Aragón');
INSERT INTO poblacions VALUES (2530, 'Nerpio');
INSERT INTO poblacions VALUES (2600, 'Villarrobledo');
INSERT INTO poblacions VALUES (2610, 'El Bonillo');
INSERT INTO poblacions VALUES (2611, 'Ossa de Montiel');
INSERT INTO poblacions VALUES (2614, 'El Ballestero');
INSERT INTO poblacions VALUES (2630, 'La Roda');
INSERT INTO poblacions VALUES (2636, 'Villalgordo del Júcar');
INSERT INTO poblacions VALUES (2637, 'Fuensanta');
INSERT INTO poblacions VALUES (2638, 'Montalvos');
INSERT INTO poblacions VALUES (2639, 'Barrax');
INSERT INTO poblacions VALUES (2640, 'Almansa');
INSERT INTO poblacions VALUES (2650, 'Montealegre del Castillo');
INSERT INTO poblacions VALUES (2651, 'Fuente-Álamo');
INSERT INTO poblacions VALUES (2690, 'Alpera');
INSERT INTO poblacions VALUES (2691, 'Bonete');
INSERT INTO poblacions VALUES (2692, 'Pétrola');
INSERT INTO poblacions VALUES (2694, 'Higueruela');
INSERT INTO poblacions VALUES (3109, 'Tibi');
INSERT INTO poblacions VALUES (3111, 'Busot');
INSERT INTO poblacions VALUES (3130, 'Santa Pola');
INSERT INTO poblacions VALUES (3150, 'Dolores');
INSERT INTO poblacions VALUES (3158, 'Catral');
INSERT INTO poblacions VALUES (3159, 'Daya Nueva');
INSERT INTO poblacions VALUES (3160, 'Almoradí');
INSERT INTO poblacions VALUES (3169, 'Algorfa');
INSERT INTO poblacions VALUES (3170, 'Rojales');
INSERT INTO poblacions VALUES (3179, 'Formentera del Segura');
INSERT INTO poblacions VALUES (3180, 'Torrevieja');
INSERT INTO poblacions VALUES (3187, 'Los Montesinos');
INSERT INTO poblacions VALUES (3190, 'Pilar de la Horadada');
INSERT INTO poblacions VALUES (3193, 'San Miguel de Salinas');
INSERT INTO poblacions VALUES (3310, 'Jacarilla');
INSERT INTO poblacions VALUES (3316, 'Benferri');
INSERT INTO poblacions VALUES (3340, 'Albatera');
INSERT INTO poblacions VALUES (3348, 'Granja de Rocamora');
INSERT INTO poblacions VALUES (3350, 'Cox');
INSERT INTO poblacions VALUES (3350, 'San Isidro');
INSERT INTO poblacions VALUES (3369, 'Rafal');
INSERT INTO poblacions VALUES (3370, 'Redován');
INSERT INTO poblacions VALUES (3380, 'Bigastro');
INSERT INTO poblacions VALUES (3390, 'Benejúzar');
INSERT INTO poblacions VALUES (3400, 'Villena');
INSERT INTO poblacions VALUES (3409, 'Cañada');
INSERT INTO poblacions VALUES (3410, 'Biar');
INSERT INTO poblacions VALUES (3420, 'Castalla');
INSERT INTO poblacions VALUES (3440, 'Ibi');
INSERT INTO poblacions VALUES (3450, 'Banyeres de Mariola');
INSERT INTO poblacions VALUES (3459, 'Alfafara');
INSERT INTO poblacions VALUES (3460, 'Beneixama');
INSERT INTO poblacions VALUES (3500, 'Benidorm');
INSERT INTO poblacions VALUES (3509, 'Finestrat');
INSERT INTO poblacions VALUES (3510, 'Callosa d''En Sarrià');
INSERT INTO poblacions VALUES (3516, 'Benimantell');
INSERT INTO poblacions VALUES (3517, 'Benifato');
INSERT INTO poblacions VALUES (3517, 'Guadalest');
INSERT INTO poblacions VALUES (3518, 'Bolulla');
INSERT INTO poblacions VALUES (3518, 'Tárbena');
INSERT INTO poblacions VALUES (3520, 'Polop');
INSERT INTO poblacions VALUES (3578, 'Relleu');
INSERT INTO poblacions VALUES (3579, 'Orxeta');
INSERT INTO poblacions VALUES (3600, 'Elda');
INSERT INTO poblacions VALUES (3630, 'Sax');
INSERT INTO poblacions VALUES (3638, 'Salinas');
INSERT INTO poblacions VALUES (3660, 'Novelda');
INSERT INTO poblacions VALUES (3668, 'Algueña');
INSERT INTO poblacions VALUES (3670, 'Monforte del Cid');
INSERT INTO poblacions VALUES (3680, 'Aspe');
INSERT INTO poblacions VALUES (3688, 'Hondón de las Nieves');
INSERT INTO poblacions VALUES (3700, 'Dénia');
INSERT INTO poblacions VALUES (3720, 'Benissa');
INSERT INTO poblacions VALUES (3728, 'Alcalalí');
INSERT INTO poblacions VALUES (3729, 'Llíber');
INSERT INTO poblacions VALUES (3729, 'Senija');
INSERT INTO poblacions VALUES (3740, 'Gata de Gorgos');
INSERT INTO poblacions VALUES (3750, 'Pedreguer');
INSERT INTO poblacions VALUES (3759, 'Benidoleig');
INSERT INTO poblacions VALUES (3769, 'Benimeli');
INSERT INTO poblacions VALUES (3769, 'Ráfol de Almunia');
INSERT INTO poblacions VALUES (3769, 'Sanet y Negrals');
INSERT INTO poblacions VALUES (3778, 'Beniarbeig');
INSERT INTO poblacions VALUES (3779, 'els Poblets');
INSERT INTO poblacions VALUES (3780, 'Pego');
INSERT INTO poblacions VALUES (3787, 'Vall de Gallinera');
INSERT INTO poblacions VALUES (3788, 'la Vall d''Alcalà');
INSERT INTO poblacions VALUES (3789, 'Vall de Ebo');
INSERT INTO poblacions VALUES (3790, 'Orba');
INSERT INTO poblacions VALUES (3792, 'Murla');
INSERT INTO poblacions VALUES (3792, 'Parcent');
INSERT INTO poblacions VALUES (3794, 'Benichembla');
INSERT INTO poblacions VALUES (3795, 'Sagra');
INSERT INTO poblacions VALUES (3811, 'Gorga');
INSERT INTO poblacions VALUES (3811, 'Quatretondeta');
INSERT INTO poblacions VALUES (3812, 'Balones');
INSERT INTO poblacions VALUES (3812, 'Benimassot');
INSERT INTO poblacions VALUES (3812, 'Millena');
INSERT INTO poblacions VALUES (3813, 'Facheca');
INSERT INTO poblacions VALUES (3813, 'Famorca');
INSERT INTO poblacions VALUES (3814, 'Alcoleja');
INSERT INTO poblacions VALUES (3814, 'Benasau');
INSERT INTO poblacions VALUES (3816, 'Benifallim');
INSERT INTO poblacions VALUES (3817, 'Confrides');
INSERT INTO poblacions VALUES (3820, 'Cocentaina');
INSERT INTO poblacions VALUES (3828, 'Planes');
INSERT INTO poblacions VALUES (3829, 'l'' Alqueria d''Asnar');
INSERT INTO poblacions VALUES (3840, 'Gaianes');
INSERT INTO poblacions VALUES (3850, 'Beniarrés');
INSERT INTO poblacions VALUES (4140, 'Carboneras');
INSERT INTO poblacions VALUES (4240, 'Viator');
INSERT INTO poblacions VALUES (4250, 'Pechina');
INSERT INTO poblacions VALUES (4260, 'Rioja');
INSERT INTO poblacions VALUES (4271, 'Lubrín');
INSERT INTO poblacions VALUES (4280, 'Los Gallardos');
INSERT INTO poblacions VALUES (4400, 'Alhama de Almería');
INSERT INTO poblacions VALUES (4410, 'Benahadux');
INSERT INTO poblacions VALUES (4470, 'Láujar de Andarax');
INSERT INTO poblacions VALUES (4500, 'Fiñana');
INSERT INTO poblacions VALUES (4510, 'Abla');
INSERT INTO poblacions VALUES (4550, 'Gérgal');
INSERT INTO poblacions VALUES (4560, 'Gádor');
INSERT INTO poblacions VALUES (4600, 'Huércal de Almería');
INSERT INTO poblacions VALUES (4600, 'Huércal-Overa');
INSERT INTO poblacions VALUES (4610, 'Cuevas del Almanzora');
INSERT INTO poblacions VALUES (4630, 'Garrucha');
INSERT INTO poblacions VALUES (4638, 'Mojácar');
INSERT INTO poblacions VALUES (4639, 'Turre');
INSERT INTO poblacions VALUES (4640, 'Pulpí');
INSERT INTO poblacions VALUES (4650, 'Zurgena');
INSERT INTO poblacions VALUES (4660, 'Arboleas');
INSERT INTO poblacions VALUES (4692, 'Taberno');
INSERT INTO poblacions VALUES (4700, 'El Ejido');
INSERT INTO poblacions VALUES (4738, 'Vícar');
INSERT INTO poblacions VALUES (4740, 'Roquetas de Mar');
INSERT INTO poblacions VALUES (4750, 'Dalías');
INSERT INTO poblacions VALUES (4760, 'Berja');
INSERT INTO poblacions VALUES (4770, 'Adra');
INSERT INTO poblacions VALUES (4800, 'Albox');
INSERT INTO poblacions VALUES (4810, 'Oria');
INSERT INTO poblacions VALUES (4825, 'Chirivel');
INSERT INTO poblacions VALUES (4830, 'Vélez-Blanco');
INSERT INTO poblacions VALUES (4838, 'María');
INSERT INTO poblacions VALUES (4850, 'Cantoria');
INSERT INTO poblacions VALUES (4860, 'Olula del Río');
INSERT INTO poblacions VALUES (4870, 'Purchena');
INSERT INTO poblacions VALUES (4880, 'Tíjola');
INSERT INTO poblacions VALUES (4890, 'Serón');
INSERT INTO poblacions VALUES (5000, 'Ávila');
INSERT INTO poblacions VALUES (5100, 'Navaluenga');
INSERT INTO poblacions VALUES (5113, 'Burgohondo');
INSERT INTO poblacions VALUES (5130, 'Solosancho');
INSERT INTO poblacions VALUES (5200, 'Arévalo');
INSERT INTO poblacions VALUES (5216, 'Nava de Arévalo');
INSERT INTO poblacions VALUES (5220, 'Madrigal de las Altas Torres');
INSERT INTO poblacions VALUES (5230, 'Las Navas del Marqués');
INSERT INTO poblacions VALUES (5250, 'El Hoyo de Pinares');
INSERT INTO poblacions VALUES (5260, 'Cebreros');
INSERT INTO poblacions VALUES (5270, 'El Tiemblo');
INSERT INTO poblacions VALUES (5310, 'Fontiveros');
INSERT INTO poblacions VALUES (5410, 'Mombeltrán');
INSERT INTO poblacions VALUES (5416, 'El Arenal');
INSERT INTO poblacions VALUES (5420, 'Sotillo de la Adrada');
INSERT INTO poblacions VALUES (5430, 'La Adrada');
INSERT INTO poblacions VALUES (5440, 'Piedralaves');
INSERT INTO poblacions VALUES (5450, 'Casavieja');
INSERT INTO poblacions VALUES (5600, 'El Barco de Ávila');
INSERT INTO poblacions VALUES (6000, 'Badajoz');
INSERT INTO poblacions VALUES (6100, 'Olivenza');
INSERT INTO poblacions VALUES (6120, 'Oliva de la Frontera');
INSERT INTO poblacions VALUES (6140, 'Talavera la Real');
INSERT INTO poblacions VALUES (6200, 'Almendralejo');
INSERT INTO poblacions VALUES (6230, 'Los Santos de Maimona');
INSERT INTO poblacions VALUES (6300, 'Zafra');
INSERT INTO poblacions VALUES (6340, 'Fregenal de la Sierra');
INSERT INTO poblacions VALUES (6360, 'Fuente del Maestre');
INSERT INTO poblacions VALUES (6380, 'Jerez de los Caballeros');
INSERT INTO poblacions VALUES (6400, 'Don Benito');
INSERT INTO poblacions VALUES (6420, 'Castuera');
INSERT INTO poblacions VALUES (6450, 'Quintana de la Serena');
INSERT INTO poblacions VALUES (6460, 'Campanario');
INSERT INTO poblacions VALUES (6470, 'Guareña');
INSERT INTO poblacions VALUES (6480, 'Montijo');
INSERT INTO poblacions VALUES (6490, 'Puebla de la Calzada');
INSERT INTO poblacions VALUES (6500, 'San Vicente de Alcántara');
INSERT INTO poblacions VALUES (6510, 'Alburquerque');
INSERT INTO poblacions VALUES (6700, 'Villanueva de la Serena');
INSERT INTO poblacions VALUES (6760, 'Navalvillar de Pela');
INSERT INTO poblacions VALUES (6800, 'Mérida');
INSERT INTO poblacions VALUES (6810, 'Calamonte');
INSERT INTO poblacions VALUES (6900, 'Llerena');
INSERT INTO poblacions VALUES (6920, 'Azuaga');
INSERT INTO poblacions VALUES (7000, 'Palma de Mallorca');
INSERT INTO poblacions VALUES (7100, 'Sóller');
INSERT INTO poblacions VALUES (7109, 'Fornalutx');
INSERT INTO poblacions VALUES (7110, 'Bunyola');
INSERT INTO poblacions VALUES (7140, 'Sencelles');
INSERT INTO poblacions VALUES (7142, 'Santa Eugènia');
INSERT INTO poblacions VALUES (7144, 'Costitx');
INSERT INTO poblacions VALUES (7170, 'Valldemosa');
INSERT INTO poblacions VALUES (7179, 'Deyá');
INSERT INTO poblacions VALUES (7190, 'Esporles');
INSERT INTO poblacions VALUES (7192, 'Estellenchs');
INSERT INTO poblacions VALUES (7194, 'Puigpunyent');
INSERT INTO poblacions VALUES (7200, 'Felanitx');
INSERT INTO poblacions VALUES (7210, 'Algaida');
INSERT INTO poblacions VALUES (7240, 'Sant Joan');
INSERT INTO poblacions VALUES (7250, 'Vilafranca de Bonany');
INSERT INTO poblacions VALUES (7260, 'Porreres');
INSERT INTO poblacions VALUES (7300, 'Inca');
INSERT INTO poblacions VALUES (7311, 'Búger');
INSERT INTO poblacions VALUES (7315, 'Escorca');
INSERT INTO poblacions VALUES (7315, 'Mancor de la Vall');
INSERT INTO poblacions VALUES (7320, 'Santa María del Camí');
INSERT INTO poblacions VALUES (7330, 'Consell');
INSERT INTO poblacions VALUES (7350, 'Binissalem');
INSERT INTO poblacions VALUES (7360, 'Lloseta');
INSERT INTO poblacions VALUES (7420, 'Sa Pobla');
INSERT INTO poblacions VALUES (7430, 'Llubí');
INSERT INTO poblacions VALUES (7440, 'Muro');
INSERT INTO poblacions VALUES (7460, 'Pollença');
INSERT INTO poblacions VALUES (7500, 'Manacor');
INSERT INTO poblacions VALUES (7518, 'Lloret de Vista Alegre');
INSERT INTO poblacions VALUES (7519, 'María de la Salud');
INSERT INTO poblacions VALUES (7520, 'Petra');
INSERT INTO poblacions VALUES (7530, 'Sant Llorenç des Cardassar');
INSERT INTO poblacions VALUES (7550, 'Son Servera');
INSERT INTO poblacions VALUES (7570, 'Artà');
INSERT INTO poblacions VALUES (7580, 'Capdepera');
INSERT INTO poblacions VALUES (7620, 'Llucmajor');
INSERT INTO poblacions VALUES (7630, 'Campos');
INSERT INTO poblacions VALUES (7640, 'Ses Salines');
INSERT INTO poblacions VALUES (7700, 'Mahón');
INSERT INTO poblacions VALUES (7720, 'Es Castell');
INSERT INTO poblacions VALUES (7740, 'Es Mercadal');
INSERT INTO poblacions VALUES (7749, 'Es Migjorn Gran');
INSERT INTO poblacions VALUES (7750, 'Ferreries');
INSERT INTO poblacions VALUES (7760, 'Ciutadella de Menorca');
INSERT INTO poblacions VALUES (7800, 'Eivissa');
INSERT INTO poblacions VALUES (7810, 'Sant Joan de Labritja');
INSERT INTO poblacions VALUES (7840, 'Santa Eulalia del Río');
INSERT INTO poblacions VALUES (7860, 'Formentera');
INSERT INTO poblacions VALUES (8000, 'Barcelona');
INSERT INTO poblacions VALUES (8100, 'Mollet del Vallès');
INSERT INTO poblacions VALUES (8110, 'Montcada i Reixac');
INSERT INTO poblacions VALUES (8140, 'Caldes de Montbui');
INSERT INTO poblacions VALUES (8150, 'Parets del Vallès');
INSERT INTO poblacions VALUES (8170, 'Montornès del Vallès');
INSERT INTO poblacions VALUES (8181, 'Sentmenat');
INSERT INTO poblacions VALUES (8186, 'Lliçà d''Amunt');
INSERT INTO poblacions VALUES (8190, 'Sant Cugat del Vallès');
INSERT INTO poblacions VALUES (8192, 'Sant Quirze del Vallès');
INSERT INTO poblacions VALUES (8200, 'Sabadell');
INSERT INTO poblacions VALUES (8210, 'Barberà del Vallès');
INSERT INTO poblacions VALUES (8211, 'Castellar del Vallès');
INSERT INTO poblacions VALUES (8214, 'Badia del Vallès');
INSERT INTO poblacions VALUES (8220, 'Terrassa');
INSERT INTO poblacions VALUES (8230, 'Matadepera');
INSERT INTO poblacions VALUES (8240, 'Manresa');
INSERT INTO poblacions VALUES (8250, 'Sant Joan de Vilatorrada');
INSERT INTO poblacions VALUES (8260, 'Súria');
INSERT INTO poblacions VALUES (8261, 'Cardona');
INSERT INTO poblacions VALUES (8270, 'Navarcles');
INSERT INTO poblacions VALUES (8291, 'Ripollet');
INSERT INTO poblacions VALUES (8292, 'Esparreguera');
INSERT INTO poblacions VALUES (8300, 'Mataró');
INSERT INTO poblacions VALUES (8310, 'Argentona');
INSERT INTO poblacions VALUES (8320, 'El Masnou');
INSERT INTO poblacions VALUES (8330, 'Premià de Mar');
INSERT INTO poblacions VALUES (8338, 'Premià de Dalt');
INSERT INTO poblacions VALUES (8339, 'Vilassar de Dalt');
INSERT INTO poblacions VALUES (8340, 'Vilassar de Mar');
INSERT INTO poblacions VALUES (8350, 'Arenys de Mar');
INSERT INTO poblacions VALUES (8360, 'Canet de Mar');
INSERT INTO poblacions VALUES (8380, 'Malgrat de Mar');
INSERT INTO poblacions VALUES (8390, 'Montgat');
INSERT INTO poblacions VALUES (8391, 'Tiana');
INSERT INTO poblacions VALUES (8392, 'Sant Andreu de Llavaneres');
INSERT INTO poblacions VALUES (8397, 'Pineda de Mar');
INSERT INTO poblacions VALUES (8399, 'Tordera');
INSERT INTO poblacions VALUES (8400, 'Granollers');
INSERT INTO poblacions VALUES (8430, 'La Roca del Vallès');
INSERT INTO poblacions VALUES (8440, 'Cardedeu');
INSERT INTO poblacions VALUES (8450, 'Llinars del Vallès');
INSERT INTO poblacions VALUES (8460, 'Santa Maria de Palautordera');
INSERT INTO poblacions VALUES (8480, 'L'' Ametlla del Vallès');
INSERT INTO poblacions VALUES (8500, 'Vic');
INSERT INTO poblacions VALUES (8520, 'Les Franqueses del Vallès');
INSERT INTO poblacions VALUES (8530, 'La Garriga');
INSERT INTO poblacions VALUES (8540, 'Centelles');
INSERT INTO poblacions VALUES (8560, 'Manlleu');
INSERT INTO poblacions VALUES (8600, 'Berga');
INSERT INTO poblacions VALUES (8630, 'Abrera');
INSERT INTO poblacions VALUES (8640, 'Olesa de Montserrat');
INSERT INTO poblacions VALUES (8680, 'Gironella');
INSERT INTO poblacions VALUES (8700, 'Igualada');
INSERT INTO poblacions VALUES (8710, 'Santa Margarida de Montbui');
INSERT INTO poblacions VALUES (8720, 'Vilafranca del Penedès');
INSERT INTO poblacions VALUES (8750, 'Molins de Rei');
INSERT INTO poblacions VALUES (8757, 'Corbera de Llobregat');
INSERT INTO poblacions VALUES (8758, 'Cervelló');
INSERT INTO poblacions VALUES (8759, 'Vallirana');
INSERT INTO poblacions VALUES (8760, 'Martorell');
INSERT INTO poblacions VALUES (8770, 'Sant Sadurní d''Anoia');
INSERT INTO poblacions VALUES (8780, 'Pallejà');
INSERT INTO poblacions VALUES (8784, 'Piera');
INSERT INTO poblacions VALUES (8800, 'Vilanova i la Geltrú');
INSERT INTO poblacions VALUES (8810, 'Sant Pere de Ribes');
INSERT INTO poblacions VALUES (8820, 'El Prat de Llobregat');
INSERT INTO poblacions VALUES (8830, 'Sant Boi de Llobregat');
INSERT INTO poblacions VALUES (8860, 'Castelldefels');
INSERT INTO poblacions VALUES (8880, 'Cubelles');
INSERT INTO poblacions VALUES (8910, 'Badalona');
INSERT INTO poblacions VALUES (8920, 'Santa Coloma de Gramenet');
INSERT INTO poblacions VALUES (8930, 'Sant Adrià de Besòs');
INSERT INTO poblacions VALUES (8950, 'Esplugues de Llobregat');
INSERT INTO poblacions VALUES (8960, 'Sant Just Desvern');
INSERT INTO poblacions VALUES (8970, 'Sant Joan Despí');
INSERT INTO poblacions VALUES (8980, 'Sant Feliu de Llobregat');
INSERT INTO poblacions VALUES (9000, 'Burgos');
INSERT INTO poblacions VALUES (9110, 'Castrojeriz');
INSERT INTO poblacions VALUES (9123, 'Sasamón');
INSERT INTO poblacions VALUES (9200, 'Miranda de Ebro');
INSERT INTO poblacions VALUES (9210, 'Valle de Tobalina');
INSERT INTO poblacions VALUES (9250, 'Belorado');
INSERT INTO poblacions VALUES (9260, 'Pradoluengo');
INSERT INTO poblacions VALUES (9300, 'Roa');
INSERT INTO poblacions VALUES (9400, 'Aranda de Duero');
INSERT INTO poblacions VALUES (9430, 'Huerta de Rey');
INSERT INTO poblacions VALUES (9500, 'Medina de Pomar');
INSERT INTO poblacions VALUES (9530, 'Oña');
INSERT INTO poblacions VALUES (9540, 'Trespaderne');
INSERT INTO poblacions VALUES (9550, 'Villarcayo de Merindad de Castilla la Vieja');
INSERT INTO poblacions VALUES (9560, 'Espinosa de los Monteros');
INSERT INTO poblacions VALUES (9600, 'Salas de los Infantes');
INSERT INTO poblacions VALUES (9670, 'Quintanar de la Sierra');
INSERT INTO poblacions VALUES (10000, 'Cáceres');
INSERT INTO poblacions VALUES (10200, 'Trujillo');
INSERT INTO poblacions VALUES (10300, 'Navalmoral de la Mata');
INSERT INTO poblacions VALUES (10400, 'Jaraíz de la Vera');
INSERT INTO poblacions VALUES (10500, 'Valencia de Alcántara');
INSERT INTO poblacions VALUES (10840, 'Moraleja');
INSERT INTO poblacions VALUES (10900, 'Arroyo de la Luz');
INSERT INTO poblacions VALUES (11000, 'Cádiz');
INSERT INTO poblacions VALUES (11100, 'San Fernando');
INSERT INTO poblacions VALUES (11130, 'Chiclana de la Frontera');
INSERT INTO poblacions VALUES (11150, 'Vejer de la Frontera');
INSERT INTO poblacions VALUES (11178, 'Paterna de Rivera');
INSERT INTO poblacions VALUES (11180, 'Alcalá de los Gazules');
INSERT INTO poblacions VALUES (11200, 'Algeciras');
INSERT INTO poblacions VALUES (11300, 'La Línea de la Concepción');
INSERT INTO poblacions VALUES (11350, 'Castellar de la Frontera');
INSERT INTO poblacions VALUES (11370, 'Los Barrios');
INSERT INTO poblacions VALUES (11380, 'Tarifa');
INSERT INTO poblacions VALUES (11500, 'El Puerto de Santa María');
INSERT INTO poblacions VALUES (11560, 'Trebujena');
INSERT INTO poblacions VALUES (11600, 'Ubrique');
INSERT INTO poblacions VALUES (11610, 'Grazalema');
INSERT INTO poblacions VALUES (11611, 'Villaluenga del Rosario');
INSERT INTO poblacions VALUES (11612, 'Benaocaz');
INSERT INTO poblacions VALUES (11630, 'Arcos de la Frontera');
INSERT INTO poblacions VALUES (11648, 'Espera');
INSERT INTO poblacions VALUES (11650, 'Villamartín');
INSERT INTO poblacions VALUES (11659, 'Puerto Serrano');
INSERT INTO poblacions VALUES (11660, 'Prado del Rey');
INSERT INTO poblacions VALUES (11670, 'El Bosque');
INSERT INTO poblacions VALUES (11680, 'Algodonales');
INSERT INTO poblacions VALUES (11687, 'El Gastor');
INSERT INTO poblacions VALUES (11688, 'Zahara');
INSERT INTO poblacions VALUES (11690, 'Olvera');
INSERT INTO poblacions VALUES (11691, 'Torre Alháquime');
INSERT INTO poblacions VALUES (11692, 'Setenil de las Bodegas');
INSERT INTO poblacions VALUES (11693, 'Alcalá del Valle');
INSERT INTO poblacions VALUES (12123, 'Castillo de Villamalefa');
INSERT INTO poblacions VALUES (12123, 'Ludiente');
INSERT INTO poblacions VALUES (12124, 'Villahermosa del Río');
INSERT INTO poblacions VALUES (12125, 'Zucaina');
INSERT INTO poblacions VALUES (12127, 'Cortes de Arenoso');
INSERT INTO poblacions VALUES (12130, 'Sant Joan de Moró');
INSERT INTO poblacions VALUES (12132, 'Atzeneta del Maestrat');
INSERT INTO poblacions VALUES (12134, 'Benafigos');
INSERT INTO poblacions VALUES (12135, 'Vistabella del Maestrazgo');
INSERT INTO poblacions VALUES (12140, 'Albocàsser');
INSERT INTO poblacions VALUES (12150, 'Villafranca del Cid');
INSERT INTO poblacions VALUES (12159, 'Castellfort');
INSERT INTO poblacions VALUES (12161, 'la Torre d''En Besora');
INSERT INTO poblacions VALUES (12162, 'Vilar de Canes');
INSERT INTO poblacions VALUES (12163, 'Culla');
INSERT INTO poblacions VALUES (12165, 'Ares del Maestre');
INSERT INTO poblacions VALUES (12170, 'Sant Mateu');
INSERT INTO poblacions VALUES (12180, 'Cabanes');
INSERT INTO poblacions VALUES (12182, 'Sierra Engarcerán');
INSERT INTO poblacions VALUES (12183, 'Vilanova d''Alcolea');
INSERT INTO poblacions VALUES (12184, 'Sarratella');
INSERT INTO poblacions VALUES (12184, 'Torre Endoménech');
INSERT INTO poblacions VALUES (12186, 'la Salzadella');
INSERT INTO poblacions VALUES (12190, 'Borriol');
INSERT INTO poblacions VALUES (12191, 'la Pobla Tornesa');
INSERT INTO poblacions VALUES (12192, 'Vilafamés');
INSERT INTO poblacions VALUES (12194, 'Vall d''Alba');
INSERT INTO poblacions VALUES (12200, 'Onda');
INSERT INTO poblacions VALUES (12210, 'Ribesalbes');
INSERT INTO poblacions VALUES (12221, 'Tales');
INSERT INTO poblacions VALUES (12222, 'Aín');
INSERT INTO poblacions VALUES (12225, 'Fuentes de Ayódar');
INSERT INTO poblacions VALUES (12225, 'Torralba del Pinar');
INSERT INTO poblacions VALUES (12230, 'Argelita');
INSERT INTO poblacions VALUES (12230, 'Espadilla');
INSERT INTO poblacions VALUES (12230, 'Fanzara');
INSERT INTO poblacions VALUES (12230, 'Toga');
INSERT INTO poblacions VALUES (12230, 'Vallat');
INSERT INTO poblacions VALUES (12231, 'Cirat');
INSERT INTO poblacions VALUES (12232, 'Torrechiva');
INSERT INTO poblacions VALUES (12300, 'Morella');
INSERT INTO poblacions VALUES (12310, 'Forcall');
INSERT INTO poblacions VALUES (12311, 'Palanques');
INSERT INTO poblacions VALUES (12311, 'Villores');
INSERT INTO poblacions VALUES (12311, 'Zorita del Maestrazgo');
INSERT INTO poblacions VALUES (12312, 'Olocau del Rey');
INSERT INTO poblacions VALUES (12312, 'Todolella');
INSERT INTO poblacions VALUES (12312, 'la Mata de Morella');
INSERT INTO poblacions VALUES (12315, 'Vallibona');
INSERT INTO poblacions VALUES (12317, 'Herbés');
INSERT INTO poblacions VALUES (12320, 'San Jorge');
INSERT INTO poblacions VALUES (12330, 'Traiguera');
INSERT INTO poblacions VALUES (12340, 'la Jana');
INSERT INTO poblacions VALUES (12350, 'Canet lo Roig');
INSERT INTO poblacions VALUES (12400, 'Segorbe');
INSERT INTO poblacions VALUES (12410, 'Altura');
INSERT INTO poblacions VALUES (12412, 'Geldo');
INSERT INTO poblacions VALUES (12413, 'Almedíjar');
INSERT INTO poblacions VALUES (12413, 'Castellnovo');
INSERT INTO poblacions VALUES (12414, 'Algimia de Almonacid');
INSERT INTO poblacions VALUES (12414, 'Vall de Almonacid');
INSERT INTO poblacions VALUES (12415, 'Gaibiel');
INSERT INTO poblacions VALUES (12415, 'Matet');
INSERT INTO poblacions VALUES (12428, 'Fuente la Reina');
INSERT INTO poblacions VALUES (12428, 'Villanueva de Viver');
INSERT INTO poblacions VALUES (12429, 'El Toro');
INSERT INTO poblacions VALUES (12429, 'Pina de Montalgrao');
INSERT INTO poblacions VALUES (12430, 'Bejís');
INSERT INTO poblacions VALUES (12440, 'Caudiel');
INSERT INTO poblacions VALUES (12447, 'Montán');
INSERT INTO poblacions VALUES (12448, 'Montanejos');
INSERT INTO poblacions VALUES (12449, 'Benafer');
INSERT INTO poblacions VALUES (12449, 'Higueras');
INSERT INTO poblacions VALUES (12450, 'Jérica');
INSERT INTO poblacions VALUES (12460, 'Viver');
INSERT INTO poblacions VALUES (12469, 'Sacañet');
INSERT INTO poblacions VALUES (12469, 'Teresa');
INSERT INTO poblacions VALUES (12470, 'Navajas');
INSERT INTO poblacions VALUES (12480, 'Soneja');
INSERT INTO poblacions VALUES (12499, 'Chóvar');
INSERT INTO poblacions VALUES (12500, 'Vinaròs');
INSERT INTO poblacions VALUES (12510, 'San Rafael del Río');
INSERT INTO poblacions VALUES (12513, 'Catí');
INSERT INTO poblacions VALUES (12520, 'Nules');
INSERT INTO poblacions VALUES (12526, 'Villavieja');
INSERT INTO poblacions VALUES (12527, 'Artana');
INSERT INTO poblacions VALUES (12539, 'Alquerías del Niño Perdido');
INSERT INTO poblacions VALUES (12549, 'Betxí');
INSERT INTO poblacions VALUES (12570, 'Alcalà de Xivert');
INSERT INTO poblacions VALUES (12578, 'Cervera del Maestre');
INSERT INTO poblacions VALUES (12580, 'Benicarló');
INSERT INTO poblacions VALUES (12589, 'Cálig');
INSERT INTO poblacions VALUES (12591, 'la Llosa');
INSERT INTO poblacions VALUES (12592, 'Chilches');
INSERT INTO poblacions VALUES (12593, 'Moncofa');
INSERT INTO poblacions VALUES (12596, 'Torreblanca');
INSERT INTO poblacions VALUES (12598, 'Peñíscola');
INSERT INTO poblacions VALUES (12599, 'la Pobla de Benifassà');
INSERT INTO poblacions VALUES (12600, 'la Vall d''Uixó');
INSERT INTO poblacions VALUES (12609, 'Alfondeguilla');
INSERT INTO poblacions VALUES (13000, 'Ciudad Real');
INSERT INTO poblacions VALUES (13100, 'Piedrabuena');
INSERT INTO poblacions VALUES (13107, 'Alcolea de Calatrava');
INSERT INTO poblacions VALUES (13108, 'Luciana');
INSERT INTO poblacions VALUES (13109, 'Puebla de Don Rodrigo');
INSERT INTO poblacions VALUES (13110, 'Horcajo de los Montes');
INSERT INTO poblacions VALUES (13114, 'El Robledo');
INSERT INTO poblacions VALUES (13116, 'Alcoba');
INSERT INTO poblacions VALUES (13117, 'Anchuras');
INSERT INTO poblacions VALUES (13130, 'Fuencaliente');
INSERT INTO poblacions VALUES (13150, 'Carrión de Calatrava');
INSERT INTO poblacions VALUES (13160, 'Torralba de Calatrava');
INSERT INTO poblacions VALUES (13170, 'Miguelturra');
INSERT INTO poblacions VALUES (13179, 'Pozuelo de Calatrava');
INSERT INTO poblacions VALUES (13190, 'Corral de Calatrava');
INSERT INTO poblacions VALUES (13191, 'Caracuel de Calatrava');
INSERT INTO poblacions VALUES (13192, 'Cabezarados');
INSERT INTO poblacions VALUES (13193, 'Arroba de los Montes');
INSERT INTO poblacions VALUES (13193, 'Fontanarejo');
INSERT INTO poblacions VALUES (13193, 'Navalpino');
INSERT INTO poblacions VALUES (13194, 'Navas de Estena');
INSERT INTO poblacions VALUES (13194, 'Retuerta del Bullaque');
INSERT INTO poblacions VALUES (13195, 'Poblete');
INSERT INTO poblacions VALUES (13200, 'Manzanares');
INSERT INTO poblacions VALUES (13210, 'Villarta de San Juan');
INSERT INTO poblacions VALUES (13248, 'Alhambra');
INSERT INTO poblacions VALUES (13249, 'Ruidera');
INSERT INTO poblacions VALUES (13250, 'Daimiel');
INSERT INTO poblacions VALUES (13260, 'Bolaños de Calatrava');
INSERT INTO poblacions VALUES (13270, 'Almagro');
INSERT INTO poblacions VALUES (13279, 'Valenzuela de Calatrava');
INSERT INTO poblacions VALUES (13300, 'Valdepeñas');
INSERT INTO poblacions VALUES (13320, 'Villanueva de los Infantes');
INSERT INTO poblacions VALUES (13326, 'Montiel');
INSERT INTO poblacions VALUES (13327, 'Santa Cruz de los Cáñamos');
INSERT INTO poblacions VALUES (13328, 'Almedina');
INSERT INTO poblacions VALUES (13329, 'Carrizosa');
INSERT INTO poblacions VALUES (13332, 'Villahermosa');
INSERT INTO poblacions VALUES (13333, 'Fuenllana');
INSERT INTO poblacions VALUES (13340, 'Albaladejo');
INSERT INTO poblacions VALUES (13341, 'Terrinches');
INSERT INTO poblacions VALUES (13342, 'Puebla del Príncipe');
INSERT INTO poblacions VALUES (13343, 'Villamanrique');
INSERT INTO poblacions VALUES (13344, 'Torre de Juan Abad');
INSERT INTO poblacions VALUES (13345, 'Cózar');
INSERT INTO poblacions VALUES (13360, 'Granátula de Calatrava');
INSERT INTO poblacions VALUES (13370, 'Calzada de Calatrava');
INSERT INTO poblacions VALUES (13380, 'Aldea del Rey');
INSERT INTO poblacions VALUES (13391, 'Alcubillas');
INSERT INTO poblacions VALUES (13410, 'Agudo');
INSERT INTO poblacions VALUES (13411, 'Valdemanco del Esteras');
INSERT INTO poblacions VALUES (13412, 'Chillón');
INSERT INTO poblacions VALUES (13413, 'Alamillo');
INSERT INTO poblacions VALUES (13414, 'Saceruela');
INSERT INTO poblacions VALUES (13420, 'Malagón');
INSERT INTO poblacions VALUES (13427, 'Los Cortijos');
INSERT INTO poblacions VALUES (13430, 'Cañada de Calatrava');
INSERT INTO poblacions VALUES (13440, 'Argamasilla de Calatrava');
INSERT INTO poblacions VALUES (13480, 'Almadenejos');
INSERT INTO poblacions VALUES (13500, 'Puertollano');
INSERT INTO poblacions VALUES (13580, 'Almodóvar del Campo');
INSERT INTO poblacions VALUES (13591, 'Cabezarrubias del Puerto');
INSERT INTO poblacions VALUES (13593, 'Solana del Pino');
INSERT INTO poblacions VALUES (13595, 'Villamayor de Calatrava');
INSERT INTO poblacions VALUES (13600, 'Alcázar de San Juan');
INSERT INTO poblacions VALUES (13610, 'Campo de Criptana');
INSERT INTO poblacions VALUES (13620, 'Pedro Muñoz');
INSERT INTO poblacions VALUES (13630, 'Socuéllamos');
INSERT INTO poblacions VALUES (13640, 'Herencia');
INSERT INTO poblacions VALUES (13660, 'Las Labores');
INSERT INTO poblacions VALUES (13670, 'Villarrubia de los Ojos');
INSERT INTO poblacions VALUES (13679, 'Arenas de San Juan');
INSERT INTO poblacions VALUES (13680, 'Fuente el Fresno');
INSERT INTO poblacions VALUES (13700, 'Tomelloso');
INSERT INTO poblacions VALUES (13710, 'Argamasilla de Alba');
INSERT INTO poblacions VALUES (13730, 'Santa Cruz de Mudela');
INSERT INTO poblacions VALUES (13740, 'Torrenueva');
INSERT INTO poblacions VALUES (13750, 'Castellar de Santiago');
INSERT INTO poblacions VALUES (13760, 'Almuradiel');
INSERT INTO poblacions VALUES (13770, 'Viso del Marqués');
INSERT INTO poblacions VALUES (13779, 'San Lorenzo de Calatrava');
INSERT INTO poblacions VALUES (14000, 'Córdoba');
INSERT INTO poblacions VALUES (14100, 'La Carlota');
INSERT INTO poblacions VALUES (14140, 'La Victoria');
INSERT INTO poblacions VALUES (14200, 'Peñarroya-Pueblonuevo');
INSERT INTO poblacions VALUES (14206, 'Valsequillo');
INSERT INTO poblacions VALUES (14207, 'La Granjuela');
INSERT INTO poblacions VALUES (14208, 'Los Blázquez');
INSERT INTO poblacions VALUES (14220, 'Espiel');
INSERT INTO poblacions VALUES (14230, 'Villanueva del Rey');
INSERT INTO poblacions VALUES (14240, 'Belmez');
INSERT INTO poblacions VALUES (14260, 'Fuente la Lancha');
INSERT INTO poblacions VALUES (14270, 'Hinojosa del Duque');
INSERT INTO poblacions VALUES (14280, 'Belalcázar');
INSERT INTO poblacions VALUES (14290, 'Fuente Obejuna');
INSERT INTO poblacions VALUES (14300, 'Villaviciosa de Córdoba');
INSERT INTO poblacions VALUES (14410, 'Torrecampo');
INSERT INTO poblacions VALUES (14412, 'Pedroche');
INSERT INTO poblacions VALUES (14420, 'Villafranca de Córdoba');
INSERT INTO poblacions VALUES (14430, 'Adamuz');
INSERT INTO poblacions VALUES (14448, 'Conquista');
INSERT INTO poblacions VALUES (14450, 'Añora');
INSERT INTO poblacions VALUES (14460, 'Dos Torres');
INSERT INTO poblacions VALUES (14470, 'El Viso');
INSERT INTO poblacions VALUES (14480, 'Alcaracejos');
INSERT INTO poblacions VALUES (14490, 'Villaralto');
INSERT INTO poblacions VALUES (14500, 'Puente Genil');
INSERT INTO poblacions VALUES (14510, 'Moriles');
INSERT INTO poblacions VALUES (14520, 'Fernán-Núñez');
INSERT INTO poblacions VALUES (14530, 'Montemayor');
INSERT INTO poblacions VALUES (14546, 'Santaella');
INSERT INTO poblacions VALUES (14548, 'Montalbán de Córdoba');
INSERT INTO poblacions VALUES (14550, 'Montilla');
INSERT INTO poblacions VALUES (14620, 'El Carpio');
INSERT INTO poblacions VALUES (14630, 'Pedro Abad');
INSERT INTO poblacions VALUES (14700, 'Palma del Río');
INSERT INTO poblacions VALUES (14720, 'Almodóvar del Río');
INSERT INTO poblacions VALUES (14740, 'Hornachuelos');
INSERT INTO poblacions VALUES (14800, 'Priego de Córdoba');
INSERT INTO poblacions VALUES (14810, 'Carcabuey');
INSERT INTO poblacions VALUES (14812, 'Almedinilla');
INSERT INTO poblacions VALUES (14815, 'Fuente-Tójar');
INSERT INTO poblacions VALUES (14830, 'Espejo');
INSERT INTO poblacions VALUES (14840, 'Castro del Río');
INSERT INTO poblacions VALUES (14857, 'Nueva Carteya');
INSERT INTO poblacions VALUES (14870, 'Zuheros');
INSERT INTO poblacions VALUES (14900, 'Lucena');
INSERT INTO poblacions VALUES (14913, 'Encinas Reales');
INSERT INTO poblacions VALUES (14914, 'Palenciana');
INSERT INTO poblacions VALUES (14920, 'Aguilar de la Frontera');
INSERT INTO poblacions VALUES (14930, 'Monturque');
INSERT INTO poblacions VALUES (14960, 'Rute');
INSERT INTO poblacions VALUES (15000, 'A Coruña');
INSERT INTO poblacions VALUES (15110, 'Ponteceso');
INSERT INTO poblacions VALUES (15113, 'Malpica de Bergantiños');
INSERT INTO poblacions VALUES (15115, 'Cabana de Bergantiños');
INSERT INTO poblacions VALUES (15123, 'Camariñas');
INSERT INTO poblacions VALUES (15124, 'Muxía');
INSERT INTO poblacions VALUES (15129, 'Vimianzo');
INSERT INTO poblacions VALUES (15130, 'Corcubión');
INSERT INTO poblacions VALUES (15145, 'Laracha');
INSERT INTO poblacions VALUES (15147, 'Coristanco');
INSERT INTO poblacions VALUES (15165, 'Bergondo');
INSERT INTO poblacions VALUES (15175, 'Carral');
INSERT INTO poblacions VALUES (15185, 'Cerceda');
INSERT INTO poblacions VALUES (15189, 'Culleredo');
INSERT INTO poblacions VALUES (15214, 'Lousame');
INSERT INTO poblacions VALUES (15230, 'Outes');
INSERT INTO poblacions VALUES (15250, 'Muros');
INSERT INTO poblacions VALUES (15256, 'Mazaricos');
INSERT INTO poblacions VALUES (15293, 'Carnota');
INSERT INTO poblacions VALUES (15300, 'Betanzos');
INSERT INTO poblacions VALUES (15312, 'Sobrado');
INSERT INTO poblacions VALUES (15313, 'Irixoa');
INSERT INTO poblacions VALUES (15314, 'Paderne');
INSERT INTO poblacions VALUES (15316, 'Coirós');
INSERT INTO poblacions VALUES (15317, 'Aranga');
INSERT INTO poblacions VALUES (15318, 'Abegondo');
INSERT INTO poblacions VALUES (15337, 'Mañón');
INSERT INTO poblacions VALUES (15350, 'Cedeira');
INSERT INTO poblacions VALUES (15360, 'Cariño');
INSERT INTO poblacions VALUES (15400, 'Ferrol');
INSERT INTO poblacions VALUES (15500, 'Fene');
INSERT INTO poblacions VALUES (15510, 'Neda');
INSERT INTO poblacions VALUES (15552, 'Valdoviño');
INSERT INTO poblacions VALUES (15560, 'San Sadurniño');
INSERT INTO poblacions VALUES (15563, 'Moeche');
INSERT INTO poblacions VALUES (15578, 'Narón');
INSERT INTO poblacions VALUES (15600, 'Pontedeume');
INSERT INTO poblacions VALUES (15619, 'Monfero');
INSERT INTO poblacions VALUES (15620, 'Mugardos');
INSERT INTO poblacions VALUES (15621, 'Cabanas');
INSERT INTO poblacions VALUES (15624, 'Ares');
INSERT INTO poblacions VALUES (15637, 'Vilarmaior');
INSERT INTO poblacions VALUES (15683, 'Tordoia');
INSERT INTO poblacions VALUES (15685, 'Mesía');
INSERT INTO poblacions VALUES (15686, 'Frades');
INSERT INTO poblacions VALUES (15687, 'Trazo');
INSERT INTO poblacions VALUES (15700, 'Santiago de Compostela');
INSERT INTO poblacions VALUES (15800, 'Melide');
INSERT INTO poblacions VALUES (15807, 'Vilasantar');
INSERT INTO poblacions VALUES (15808, 'Santiso');
INSERT INTO poblacions VALUES (15818, 'Boimorto');
INSERT INTO poblacions VALUES (15820, 'Toques');
INSERT INTO poblacions VALUES (15821, 'O Pino');
INSERT INTO poblacions VALUES (15830, 'Negreira');
INSERT INTO poblacions VALUES (15840, 'Santa Comba');
INSERT INTO poblacions VALUES (15864, 'Ames');
INSERT INTO poblacions VALUES (15865, 'Brión');
INSERT INTO poblacions VALUES (15873, 'Val do Dubra');
INSERT INTO poblacions VALUES (15881, 'Boqueixón');
INSERT INTO poblacions VALUES (15884, 'Oroso');
INSERT INTO poblacions VALUES (15885, 'Vedra');
INSERT INTO poblacions VALUES (15900, 'Padrón');
INSERT INTO poblacions VALUES (15911, 'Rois');
INSERT INTO poblacions VALUES (15920, 'Rianxo');
INSERT INTO poblacions VALUES (15930, 'Boiro');
INSERT INTO poblacions VALUES (15940, 'A Pobra do Caramiñal');
INSERT INTO poblacions VALUES (15960, 'Ribeira');
INSERT INTO poblacions VALUES (15970, 'Porto do Son');
INSERT INTO poblacions VALUES (16000, 'Cuenca');
INSERT INTO poblacions VALUES (16220, 'Quintanar del Rey');
INSERT INTO poblacions VALUES (16400, 'Tarancón');
INSERT INTO poblacions VALUES (16600, 'San Clemente');
INSERT INTO poblacions VALUES (16630, 'Mota del Cuervo');
INSERT INTO poblacions VALUES (16660, 'Las Pedroñeras');
INSERT INTO poblacions VALUES (17130, 'L'' Escala');
INSERT INTO poblacions VALUES (17190, 'Salt');
INSERT INTO poblacions VALUES (17200, 'Palafrugell');
INSERT INTO poblacions VALUES (17220, 'Sant Feliu de Guíxols');
INSERT INTO poblacions VALUES (17230, 'Palamós');
INSERT INTO poblacions VALUES (17240, 'Llagostera');
INSERT INTO poblacions VALUES (17244, 'Cassà de la Selva');
INSERT INTO poblacions VALUES (17251, 'Calonge');
INSERT INTO poblacions VALUES (17257, 'Torroella de Montgrí');
INSERT INTO poblacions VALUES (17310, 'Lloret de Mar');
INSERT INTO poblacions VALUES (17480, 'Roses');
INSERT INTO poblacions VALUES (17486, 'Castelló d''Empúries');
INSERT INTO poblacions VALUES (17500, 'Ripoll');
INSERT INTO poblacions VALUES (17520, 'Puigcerdà');
INSERT INTO poblacions VALUES (17800, 'Olot');
INSERT INTO poblacions VALUES (17820, 'Banyoles');
INSERT INTO poblacions VALUES (18000, 'Granada');
INSERT INTO poblacions VALUES (18100, 'Armilla');
INSERT INTO poblacions VALUES (18110, 'Las Gabias');
INSERT INTO poblacions VALUES (18120, 'Alhama de Granada');
INSERT INTO poblacions VALUES (18126, 'Arenas del Rey');
INSERT INTO poblacions VALUES (18127, 'Jayena');
INSERT INTO poblacions VALUES (18127, 'Píñar');
INSERT INTO poblacions VALUES (18128, 'Zafarraya');
INSERT INTO poblacions VALUES (18129, 'Cacín');
INSERT INTO poblacions VALUES (18129, 'Santa Cruz del Comercio');
INSERT INTO poblacions VALUES (18131, 'Ventas de Huelma');
INSERT INTO poblacions VALUES (18132, 'Agrón');
INSERT INTO poblacions VALUES (18140, 'La Zubia');
INSERT INTO poblacions VALUES (18150, 'Gójar');
INSERT INTO poblacions VALUES (18152, 'Dílar');
INSERT INTO poblacions VALUES (18160, 'Güejar Sierra');
INSERT INTO poblacions VALUES (18170, 'Alfacar');
INSERT INTO poblacions VALUES (18170, 'Jun');
INSERT INTO poblacions VALUES (18179, 'Víznar');
INSERT INTO poblacions VALUES (18180, 'Diezma');
INSERT INTO poblacions VALUES (18181, 'Darro');
INSERT INTO poblacions VALUES (18181, 'Huélago');
INSERT INTO poblacions VALUES (18183, 'Huétor de Santillán');
INSERT INTO poblacions VALUES (18184, 'Beas de Granada');
INSERT INTO poblacions VALUES (18190, 'Cenes de la Vega');
INSERT INTO poblacions VALUES (18191, 'Pinos Genil');
INSERT INTO poblacions VALUES (18192, 'Dúdar');
INSERT INTO poblacions VALUES (18193, 'Vegas del Genil');
INSERT INTO poblacions VALUES (18194, 'Churriana de la Vega');
INSERT INTO poblacions VALUES (18194, 'Cúllar Vega');
INSERT INTO poblacions VALUES (18195, 'Los Guajares');
INSERT INTO poblacions VALUES (18197, 'Cogollos de la Vega');
INSERT INTO poblacions VALUES (18197, 'Güevéjar');
INSERT INTO poblacions VALUES (18197, 'Nívar');
INSERT INTO poblacions VALUES (18197, 'Pulianas');
INSERT INTO poblacions VALUES (18200, 'Maracena');
INSERT INTO poblacions VALUES (18210, 'Peligros');
INSERT INTO poblacions VALUES (18220, 'Albolote');
INSERT INTO poblacions VALUES (18230, 'Atarfe');
INSERT INTO poblacions VALUES (18240, 'Pinos Puente');
INSERT INTO poblacions VALUES (18247, 'Moclín');
INSERT INTO poblacions VALUES (18260, 'Illora');
INSERT INTO poblacions VALUES (18280, 'Algarinejo');
INSERT INTO poblacions VALUES (18300, 'Loja');
INSERT INTO poblacions VALUES (18310, 'Salar');
INSERT INTO poblacions VALUES (18311, 'Zagra');
INSERT INTO poblacions VALUES (18320, 'Santa Fe');
INSERT INTO poblacions VALUES (18327, 'Láchar');
INSERT INTO poblacions VALUES (18330, 'Chauchina');
INSERT INTO poblacions VALUES (18339, 'Cijuela');
INSERT INTO poblacions VALUES (18360, 'Huétor Tájar');
INSERT INTO poblacions VALUES (18370, 'Moraleda de Zafayona');
INSERT INTO poblacions VALUES (18400, 'Órgiva');
INSERT INTO poblacions VALUES (18411, 'Pampaneira');
INSERT INTO poblacions VALUES (18413, 'Capileira');
INSERT INTO poblacions VALUES (18414, 'La Taha');
INSERT INTO poblacions VALUES (18416, 'Busquístar');
INSERT INTO poblacions VALUES (18417, 'Trevélez');
INSERT INTO poblacions VALUES (18418, 'Cáñar');
INSERT INTO poblacions VALUES (18420, 'Lanjarón');
INSERT INTO poblacions VALUES (18430, 'Torvizcón');
INSERT INTO poblacions VALUES (18438, 'Almegíjar');
INSERT INTO poblacions VALUES (18439, 'Cástaras');
INSERT INTO poblacions VALUES (18440, 'Cádiar');
INSERT INTO poblacions VALUES (18449, 'Lobras');
INSERT INTO poblacions VALUES (18450, 'Alpujarra de la Sierra');
INSERT INTO poblacions VALUES (18452, 'Juviles');
INSERT INTO poblacions VALUES (18470, 'Válor');
INSERT INTO poblacions VALUES (18480, 'Ugíjar');
INSERT INTO poblacions VALUES (18490, 'Murtas');
INSERT INTO poblacions VALUES (18500, 'Guadix');
INSERT INTO poblacions VALUES (18510, 'Benalúa de Guadix');
INSERT INTO poblacions VALUES (18512, 'Dólar');
INSERT INTO poblacions VALUES (18512, 'La Calahorra');
INSERT INTO poblacions VALUES (18513, 'Ferreira');
INSERT INTO poblacions VALUES (18514, 'Aldeire');
INSERT INTO poblacions VALUES (18516, 'Beas de Guadix');
INSERT INTO poblacions VALUES (18516, 'Lugros');
INSERT INTO poblacions VALUES (18517, 'Cortes y Graena');
INSERT INTO poblacions VALUES (18518, 'Albuñán');
INSERT INTO poblacions VALUES (18518, 'Alquife');
INSERT INTO poblacions VALUES (18518, 'Cogollos de Guadix');
INSERT INTO poblacions VALUES (18518, 'Jerez del Marquesado');
INSERT INTO poblacions VALUES (18518, 'Lanteira');
INSERT INTO poblacions VALUES (18520, 'Alamedilla');
INSERT INTO poblacions VALUES (18530, 'Pedro Martínez');
INSERT INTO poblacions VALUES (18538, 'Alicún de Ortega');
INSERT INTO poblacions VALUES (18538, 'Dehesas de Guadix');
INSERT INTO poblacions VALUES (18539, 'Villanueva de las Torres');
INSERT INTO poblacions VALUES (18540, 'Morelábor');
INSERT INTO poblacions VALUES (18550, 'Iznalloz');
INSERT INTO poblacions VALUES (18560, 'Guadahortuna');
INSERT INTO poblacions VALUES (18563, 'Torre-Cardela');
INSERT INTO poblacions VALUES (18564, 'Benalúa de las Villas');
INSERT INTO poblacions VALUES (18564, 'Colomera');
INSERT INTO poblacions VALUES (18565, 'Campotéjar');
INSERT INTO poblacions VALUES (18566, 'Montillana');
INSERT INTO poblacions VALUES (18570, 'Deifontes');
INSERT INTO poblacions VALUES (18611, 'Molvízar');
INSERT INTO poblacions VALUES (18612, 'Itrabo');
INSERT INTO poblacions VALUES (18614, 'Gualchos');
INSERT INTO poblacions VALUES (18614, 'Lújar');
INSERT INTO poblacions VALUES (18630, 'Otura');
INSERT INTO poblacions VALUES (18640, 'Padul');
INSERT INTO poblacions VALUES (18650, 'Dúrcal');
INSERT INTO poblacions VALUES (18656, 'Lecrín');
INSERT INTO poblacions VALUES (18658, 'El Valle');
INSERT INTO poblacions VALUES (18659, 'Albuñuelas');
INSERT INTO poblacions VALUES (18659, 'Villamena');
INSERT INTO poblacions VALUES (18660, 'El Pinar');
INSERT INTO poblacions VALUES (18670, 'Vélez de Benaudalla');
INSERT INTO poblacions VALUES (18680, 'Salobreña');
INSERT INTO poblacions VALUES (18690, 'Almuñécar');
INSERT INTO poblacions VALUES (18698, 'Otívar');
INSERT INTO poblacions VALUES (18699, 'Jete');
INSERT INTO poblacions VALUES (18699, 'Lentegí');
INSERT INTO poblacions VALUES (18700, 'Albuñol');
INSERT INTO poblacions VALUES (18708, 'Albondón');
INSERT INTO poblacions VALUES (18711, 'Rubite');
INSERT INTO poblacions VALUES (18712, 'Polopos');
INSERT INTO poblacions VALUES (18800, 'Baza');
INSERT INTO poblacions VALUES (18810, 'Caniles');
INSERT INTO poblacions VALUES (18812, 'Freila');
INSERT INTO poblacions VALUES (18814, 'Cortes de Baza');
INSERT INTO poblacions VALUES (18816, 'Castril');
INSERT INTO poblacions VALUES (18817, 'Benamaurel');
INSERT INTO poblacions VALUES (18818, 'Castilléjar');
INSERT INTO poblacions VALUES (18820, 'Puebla de Don Fadrique');
INSERT INTO poblacions VALUES (18830, 'Huéscar');
INSERT INTO poblacions VALUES (18840, 'Galera');
INSERT INTO poblacions VALUES (18858, 'Orce');
INSERT INTO poblacions VALUES (18870, 'Gor');
INSERT INTO poblacions VALUES (19000, 'Guadalajara');
INSERT INTO poblacions VALUES (19200, 'Azuqueca de Henares');
INSERT INTO poblacions VALUES (20000, 'Donostia-San Sebastián');
INSERT INTO poblacions VALUES (20100, 'Lezo');
INSERT INTO poblacions VALUES (20100, 'Rentería');
INSERT INTO poblacions VALUES (20115, 'Astigarraga');
INSERT INTO poblacions VALUES (20120, 'Hernani');
INSERT INTO poblacions VALUES (20130, 'Urnieta');
INSERT INTO poblacions VALUES (20140, 'Andoain');
INSERT INTO poblacions VALUES (20150, 'Aduna');
INSERT INTO poblacions VALUES (20150, 'Villabona');
INSERT INTO poblacions VALUES (20159, 'Asteasu');
INSERT INTO poblacions VALUES (20159, 'Larraul');
INSERT INTO poblacions VALUES (20160, 'Lasarte-Oria');
INSERT INTO poblacions VALUES (20170, 'Usurbil');
INSERT INTO poblacions VALUES (20180, 'Oiartzun');
INSERT INTO poblacions VALUES (20200, 'Beasain');
INSERT INTO poblacions VALUES (20210, 'Lazkao');
INSERT INTO poblacions VALUES (20211, 'Ataun');
INSERT INTO poblacions VALUES (20212, 'Olaberria');
INSERT INTO poblacions VALUES (20213, 'Idiazabal');
INSERT INTO poblacions VALUES (20214, 'Segura');
INSERT INTO poblacions VALUES (20214, 'Zerain');
INSERT INTO poblacions VALUES (20215, 'Zegama');
INSERT INTO poblacions VALUES (20230, 'Legazpi');
INSERT INTO poblacions VALUES (20240, 'Ordizia');
INSERT INTO poblacions VALUES (20248, 'Altzaga');
INSERT INTO poblacions VALUES (20248, 'Arama');
INSERT INTO poblacions VALUES (20248, 'Gaintza');
INSERT INTO poblacions VALUES (20260, 'Alegia');
INSERT INTO poblacions VALUES (20267, 'Ikaztegieta');
INSERT INTO poblacions VALUES (20268, 'Altzo');
INSERT INTO poblacions VALUES (20268, 'Amezketa');
INSERT INTO poblacions VALUES (20269, 'Abaltzisketa');
INSERT INTO poblacions VALUES (20269, 'Orendain');
INSERT INTO poblacions VALUES (20270, 'Anoeta');
INSERT INTO poblacions VALUES (20300, 'Irun');
INSERT INTO poblacions VALUES (20400, 'Ibarra');
INSERT INTO poblacions VALUES (20400, 'Tolosa');
INSERT INTO poblacions VALUES (20490, 'Lizartza');
INSERT INTO poblacions VALUES (20490, 'Orexa');
INSERT INTO poblacions VALUES (20491, 'Belauntza');
INSERT INTO poblacions VALUES (20491, 'Gaztelu');
INSERT INTO poblacions VALUES (20491, 'Leaburu');
INSERT INTO poblacions VALUES (20492, 'Berastegi');
INSERT INTO poblacions VALUES (20493, 'Berrobi');
INSERT INTO poblacions VALUES (20493, 'Elduain');
INSERT INTO poblacions VALUES (20494, 'Hernialde');
INSERT INTO poblacions VALUES (20495, 'Albiztur');
INSERT INTO poblacions VALUES (20496, 'Bidegoyan');
INSERT INTO poblacions VALUES (20530, 'Leintz-Gatzaga');
INSERT INTO poblacions VALUES (20550, 'Aretxabaleta');
INSERT INTO poblacions VALUES (20560, 'Oñati');
INSERT INTO poblacions VALUES (20570, 'Bergara');
INSERT INTO poblacions VALUES (20577, 'Antzuola');
INSERT INTO poblacions VALUES (20700, 'Urretxu');
INSERT INTO poblacions VALUES (20700, 'Zumarraga');
INSERT INTO poblacions VALUES (20720, 'Azkoitia');
INSERT INTO poblacions VALUES (20730, 'Azpeitia');
INSERT INTO poblacions VALUES (20737, 'Errezil');
INSERT INTO poblacions VALUES (20739, 'Beizama');
INSERT INTO poblacions VALUES (20749, 'Aizarnazabal');
INSERT INTO poblacions VALUES (20800, 'Zarautz');
INSERT INTO poblacions VALUES (20808, 'Getaria');
INSERT INTO poblacions VALUES (20809, 'Aia');
INSERT INTO poblacions VALUES (20850, 'Mendaro');
INSERT INTO poblacions VALUES (20870, 'Elgoibar');
INSERT INTO poblacions VALUES (21000, 'Huelva');
INSERT INTO poblacions VALUES (21110, 'Aljaraque');
INSERT INTO poblacions VALUES (21208, 'Cortelazor');
INSERT INTO poblacions VALUES (21209, 'Puerto Moral');
INSERT INTO poblacions VALUES (21210, 'Zufre');
INSERT INTO poblacions VALUES (21220, 'Higuera de la Sierra');
INSERT INTO poblacions VALUES (21230, 'Cortegana');
INSERT INTO poblacions VALUES (21240, 'Aroche');
INSERT INTO poblacions VALUES (21260, 'Santa Olalla del Cala');
INSERT INTO poblacions VALUES (21270, 'Cala');
INSERT INTO poblacions VALUES (21280, 'Arroyomolinos de León');
INSERT INTO poblacions VALUES (21290, 'Jabugo');
INSERT INTO poblacions VALUES (21291, 'Galaroza');
INSERT INTO poblacions VALUES (21291, 'Valdelarco');
INSERT INTO poblacions VALUES (21292, 'Fuenteheridos');
INSERT INTO poblacions VALUES (21293, 'Los Marines');
INSERT INTO poblacions VALUES (21300, 'Calañas');
INSERT INTO poblacions VALUES (21320, 'El Cerro de Andévalo');
INSERT INTO poblacions VALUES (21340, 'Alájar');
INSERT INTO poblacions VALUES (21350, 'Almonaster la Real');
INSERT INTO poblacions VALUES (21359, 'Santa Ana la Real');
INSERT INTO poblacions VALUES (21369, 'Castaño del Robledo');
INSERT INTO poblacions VALUES (21380, 'Cumbres Mayores');
INSERT INTO poblacions VALUES (21386, 'Cumbres de San Bartolomé');
INSERT INTO poblacions VALUES (21387, 'Cumbres de Enmedio');
INSERT INTO poblacions VALUES (21388, 'Cañaveral de León');
INSERT INTO poblacions VALUES (21389, 'Hinojales');
INSERT INTO poblacions VALUES (21390, 'Encinasola');
INSERT INTO poblacions VALUES (21400, 'Ayamonte');
INSERT INTO poblacions VALUES (21410, 'Isla Cristina');
INSERT INTO poblacions VALUES (21440, 'Lepe');
INSERT INTO poblacions VALUES (21450, 'Cartaya');
INSERT INTO poblacions VALUES (21500, 'Gibraleón');
INSERT INTO poblacions VALUES (21510, 'San Bartolomé de la Torre');
INSERT INTO poblacions VALUES (21540, 'Villanueva de los Castillejos');
INSERT INTO poblacions VALUES (21550, 'Puebla de Guzmán');
INSERT INTO poblacions VALUES (21560, 'Paymogo');
INSERT INTO poblacions VALUES (21570, 'Santa Bárbara de Casa');
INSERT INTO poblacions VALUES (21590, 'Villablanca');
INSERT INTO poblacions VALUES (21591, 'San Silvestre de Guzmán');
INSERT INTO poblacions VALUES (21592, 'Villanueva de las Cruces');
INSERT INTO poblacions VALUES (21593, 'El Almendro');
INSERT INTO poblacions VALUES (21594, 'El Granado');
INSERT INTO poblacions VALUES (21595, 'Sanlúcar de Guadiana');
INSERT INTO poblacions VALUES (21600, 'Valverde del Camino');
INSERT INTO poblacions VALUES (21610, 'San Juan del Puerto');
INSERT INTO poblacions VALUES (21620, 'Trigueros');
INSERT INTO poblacions VALUES (21630, 'Beas');
INSERT INTO poblacions VALUES (21640, 'Zalamea la Real');
INSERT INTO poblacions VALUES (21647, 'Berrocal');
INSERT INTO poblacions VALUES (21650, 'El Campillo');
INSERT INTO poblacions VALUES (21660, 'Minas de RiotINTO');
INSERT INTO poblacions VALUES (21668, 'Campofrío');
INSERT INTO poblacions VALUES (21668, 'La Granada de Río-TINTO');
INSERT INTO poblacions VALUES (21700, 'La Palma del Condado');
INSERT INTO poblacions VALUES (21710, 'Bollullos Par del Condado');
INSERT INTO poblacions VALUES (21720, 'Rociana del Condado');
INSERT INTO poblacions VALUES (21730, 'Almonte');
INSERT INTO poblacions VALUES (21740, 'Hinojos');
INSERT INTO poblacions VALUES (21800, 'Moguer');
INSERT INTO poblacions VALUES (21810, 'Palos de la Frontera');
INSERT INTO poblacions VALUES (21820, 'Lucena del Puerto');
INSERT INTO poblacions VALUES (21830, 'Bonares');
INSERT INTO poblacions VALUES (21840, 'Niebla');
INSERT INTO poblacions VALUES (21850, 'Villarrasa');
INSERT INTO poblacions VALUES (21870, 'Escacena del Campo');
INSERT INTO poblacions VALUES (21880, 'Paterna del Campo');
INSERT INTO poblacions VALUES (21890, 'Manzanilla');
INSERT INTO poblacions VALUES (21891, 'Chucena');
INSERT INTO poblacions VALUES (22160, 'La Sotonera');
INSERT INTO poblacions VALUES (22200, 'Sariñena');
INSERT INTO poblacions VALUES (22214, 'Lalueza');
INSERT INTO poblacions VALUES (22234, 'Ballobar');
INSERT INTO poblacions VALUES (22240, 'Tardienta');
INSERT INTO poblacions VALUES (22250, 'Lanaja');
INSERT INTO poblacions VALUES (22270, 'Almudévar');
INSERT INTO poblacions VALUES (22300, 'Barbastro');
INSERT INTO poblacions VALUES (22400, 'Monzón');
INSERT INTO poblacions VALUES (22422, 'Fonz');
INSERT INTO poblacions VALUES (22430, 'Graus');
INSERT INTO poblacions VALUES (22440, 'Benasque');
INSERT INTO poblacions VALUES (22500, 'Binéfar');
INSERT INTO poblacions VALUES (22510, 'Binaced');
INSERT INTO poblacions VALUES (22520, 'Fraga');
INSERT INTO poblacions VALUES (22530, 'Zaidín');
INSERT INTO poblacions VALUES (22533, 'Belver de Cinca');
INSERT INTO poblacions VALUES (22534, 'Albalate de Cinca');
INSERT INTO poblacions VALUES (22550, 'Tamarite de Litera');
INSERT INTO poblacions VALUES (22580, 'Benabarre');
INSERT INTO poblacions VALUES (22590, 'Torrente de Cinca');
INSERT INTO poblacions VALUES (22630, 'Biescas');
INSERT INTO poblacions VALUES (22640, 'Sallent de Gállego');
INSERT INTO poblacions VALUES (22800, 'Ayerbe');
INSERT INTO poblacions VALUES (23000, 'Jaén');
INSERT INTO poblacions VALUES (23100, 'Mancha Real');
INSERT INTO poblacions VALUES (23110, 'Pegalajar');
INSERT INTO poblacions VALUES (23120, 'Cambil');
INSERT INTO poblacions VALUES (23130, 'Campillo de Arenas');
INSERT INTO poblacions VALUES (23140, 'Noalejo');
INSERT INTO poblacions VALUES (23160, 'Los Villares');
INSERT INTO poblacions VALUES (23191, 'Cárcheles');
INSERT INTO poblacions VALUES (23197, 'Escañuela');
INSERT INTO poblacions VALUES (23200, 'La Carolina');
INSERT INTO poblacions VALUES (23210, 'Guarromán');
INSERT INTO poblacions VALUES (23213, 'Santa Elena');
INSERT INTO poblacions VALUES (23215, 'Aldeaquemada');
INSERT INTO poblacions VALUES (23220, 'Vilches');
INSERT INTO poblacions VALUES (23230, 'Arquillos');
INSERT INTO poblacions VALUES (23240, 'Navas de San Juan');
INSERT INTO poblacions VALUES (23250, 'Santisteban del Puerto');
INSERT INTO poblacions VALUES (23260, 'Castellar');
INSERT INTO poblacions VALUES (23264, 'Chiclana de Segura');
INSERT INTO poblacions VALUES (23266, 'Montizón');
INSERT INTO poblacions VALUES (23270, 'Sorihuela del Guadalimar');
INSERT INTO poblacions VALUES (23280, 'Beas de Segura');
INSERT INTO poblacions VALUES (23292, 'Hornos');
INSERT INTO poblacions VALUES (23300, 'Villacarrillo');
INSERT INTO poblacions VALUES (23311, 'Santo Tomé');
INSERT INTO poblacions VALUES (23320, 'Torreperogil');
INSERT INTO poblacions VALUES (23330, 'Villanueva del Arzobispo');
INSERT INTO poblacions VALUES (23370, 'Orcera');
INSERT INTO poblacions VALUES (23390, 'Benatae');
INSERT INTO poblacions VALUES (23392, 'Génave');
INSERT INTO poblacions VALUES (23393, 'Villarrodrigo');
INSERT INTO poblacions VALUES (23410, 'Sabiote');
INSERT INTO poblacions VALUES (23420, 'Canena');
INSERT INTO poblacions VALUES (23440, 'Baeza');
INSERT INTO poblacions VALUES (23450, 'Ibros');
INSERT INTO poblacions VALUES (23460, 'Peal de Becerro');
INSERT INTO poblacions VALUES (23470, 'Cazorla');
INSERT INTO poblacions VALUES (23476, 'La Iruela');
INSERT INTO poblacions VALUES (23477, 'Chilluévar');
INSERT INTO poblacions VALUES (23480, 'Quesada');
INSERT INTO poblacions VALUES (23486, 'Hinojares');
INSERT INTO poblacions VALUES (23487, 'Huesa');
INSERT INTO poblacions VALUES (23500, 'Jódar');
INSERT INTO poblacions VALUES (23510, 'Torreblascopedro');
INSERT INTO poblacions VALUES (23528, 'Lupión');
INSERT INTO poblacions VALUES (23530, 'Jimena');
INSERT INTO poblacions VALUES (23537, 'Bedmar y Garcíez');
INSERT INTO poblacions VALUES (23540, 'Torres');
INSERT INTO poblacions VALUES (23550, 'Cabra del Santo Cristo');
INSERT INTO poblacions VALUES (23560, 'Huelma');
INSERT INTO poblacions VALUES (23568, 'Bélmez de la Moraleda');
INSERT INTO poblacions VALUES (23591, 'Larva');
INSERT INTO poblacions VALUES (23600, 'Martos');
INSERT INTO poblacions VALUES (23610, 'Fuensanta de Martos');
INSERT INTO poblacions VALUES (23611, 'Higuera de Calatrava');
INSERT INTO poblacions VALUES (23620, 'Mengíbar');
INSERT INTO poblacions VALUES (23640, 'Torre del Campo');
INSERT INTO poblacions VALUES (23650, 'Torredonjimeno');
INSERT INTO poblacions VALUES (23659, 'Villardompardo');
INSERT INTO poblacions VALUES (23660, 'Alcaudete');
INSERT INTO poblacions VALUES (23670, 'Castillo de Locubín');
INSERT INTO poblacions VALUES (23700, 'Linares');
INSERT INTO poblacions VALUES (23710, 'Bailén');
INSERT INTO poblacions VALUES (23711, 'Baños de la Encina');
INSERT INTO poblacions VALUES (23712, 'JabalquINTO');
INSERT INTO poblacions VALUES (23730, 'Villanueva de la Reina');
INSERT INTO poblacions VALUES (23740, 'Andújar');
INSERT INTO poblacions VALUES (23746, 'Lahiguera');
INSERT INTO poblacions VALUES (23750, 'Arjonilla');
INSERT INTO poblacions VALUES (23760, 'Arjona');
INSERT INTO poblacions VALUES (23770, 'Marmolejo');
INSERT INTO poblacions VALUES (23780, 'Lopera');
INSERT INTO poblacions VALUES (23790, 'Porcuna');
INSERT INTO poblacions VALUES (24000, 'León');
INSERT INTO poblacions VALUES (24100, 'Villablino');
INSERT INTO poblacions VALUES (24191, 'San Andrés del Rabanedo');
INSERT INTO poblacions VALUES (24193, 'Villaquilambre');
INSERT INTO poblacions VALUES (24300, 'Bembibre');
INSERT INTO poblacions VALUES (24420, 'Fabero');
INSERT INTO poblacions VALUES (24600, 'La Pola de Gordón');
INSERT INTO poblacions VALUES (25000, 'Lleida');
INSERT INTO poblacions VALUES (25100, 'Almacelles');
INSERT INTO poblacions VALUES (25200, 'Cervera');
INSERT INTO poblacions VALUES (25280, 'Solsona');
INSERT INTO poblacions VALUES (25300, 'Tàrrega');
INSERT INTO poblacions VALUES (25400, 'Les Borges Blanques');
INSERT INTO poblacions VALUES (25600, 'Balaguer');
INSERT INTO poblacions VALUES (25620, 'Tremp');
INSERT INTO poblacions VALUES (25700, 'La Seu d''Urgell');
INSERT INTO poblacions VALUES (26000, 'Logroño');
INSERT INTO poblacions VALUES (26100, 'Torrecilla en Cameros');
INSERT INTO poblacions VALUES (26110, 'Nestares');
INSERT INTO poblacions VALUES (26111, 'Almarza de Cameros');
INSERT INTO poblacions VALUES (26111, 'Pinillos');
INSERT INTO poblacions VALUES (26120, 'Albelda de Iregua');
INSERT INTO poblacions VALUES (26121, 'Viguera');
INSERT INTO poblacions VALUES (26122, 'Gallinero de Cameros');
INSERT INTO poblacions VALUES (26122, 'Pradillo');
INSERT INTO poblacions VALUES (26123, 'Villanueva de Cameros');
INSERT INTO poblacions VALUES (26124, 'El Rasillo de Cameros');
INSERT INTO poblacions VALUES (26124, 'Nieva de Cameros');
INSERT INTO poblacions VALUES (26125, 'Villoslada de Cameros');
INSERT INTO poblacions VALUES (26126, 'Lumbreras');
INSERT INTO poblacions VALUES (26130, 'Clavijo');
INSERT INTO poblacions VALUES (26131, 'Lagunilla del Jubera');
INSERT INTO poblacions VALUES (26131, 'Robres del Castillo');
INSERT INTO poblacions VALUES (26131, 'Santa Engracia del Jubera');
INSERT INTO poblacions VALUES (26133, 'Ajamil');
INSERT INTO poblacions VALUES (26133, 'Hornillos de Cameros');
INSERT INTO poblacions VALUES (26133, 'San Román de Cameros');
INSERT INTO poblacions VALUES (26134, 'Jalón de Cameros');
INSERT INTO poblacions VALUES (26134, 'Muro en Cameros');
INSERT INTO poblacions VALUES (26134, 'Torre en Cameros');
INSERT INTO poblacions VALUES (26135, 'Cabezón de Cameros');
INSERT INTO poblacions VALUES (26135, 'Laguna de Cameros');
INSERT INTO poblacions VALUES (26144, 'Galilea');
INSERT INTO poblacions VALUES (26146, 'El Redal');
INSERT INTO poblacions VALUES (26148, 'Ocón');
INSERT INTO poblacions VALUES (26190, 'Nalda');
INSERT INTO poblacions VALUES (26191, 'Sorzano');
INSERT INTO poblacions VALUES (26200, 'Haro');
INSERT INTO poblacions VALUES (26210, 'Cihuri');
INSERT INTO poblacions VALUES (26211, 'Foncea');
INSERT INTO poblacions VALUES (26211, 'Fonzaleche');
INSERT INTO poblacions VALUES (26211, 'Tirgo');
INSERT INTO poblacions VALUES (26212, 'Cellorigo');
INSERT INTO poblacions VALUES (26212, 'Sajazarra');
INSERT INTO poblacions VALUES (26213, 'Herramélluri');
INSERT INTO poblacions VALUES (26213, 'Ochánduri');
INSERT INTO poblacions VALUES (26213, 'Tormantos');
INSERT INTO poblacions VALUES (26214, 'Cuzcurrita de Río Tirón');
INSERT INTO poblacions VALUES (26215, 'Treviana');
INSERT INTO poblacions VALUES (26216, 'San Millán de Yécora');
INSERT INTO poblacions VALUES (26220, 'Ollauri');
INSERT INTO poblacions VALUES (26221, 'Gimileo');
INSERT INTO poblacions VALUES (26222, 'Rodezno');
INSERT INTO poblacions VALUES (26223, 'Hormilla');
INSERT INTO poblacions VALUES (26223, 'Hormilleja');
INSERT INTO poblacions VALUES (26224, 'Alesanco');
INSERT INTO poblacions VALUES (26224, 'Torrecilla sobre Alesanco');
INSERT INTO poblacions VALUES (26225, 'Cañas');
INSERT INTO poblacions VALUES (26225, 'Villar de Torre');
INSERT INTO poblacions VALUES (26225, 'Villarejo');
INSERT INTO poblacions VALUES (26226, 'Pazuengos');
INSERT INTO poblacions VALUES (26226, 'San Millán de la Cogolla');
INSERT INTO poblacions VALUES (26227, 'Berceo');
INSERT INTO poblacions VALUES (26228, 'Estollo');
INSERT INTO poblacions VALUES (26230, 'Casalarreina');
INSERT INTO poblacions VALUES (26240, 'Castañares de Rioja');
INSERT INTO poblacions VALUES (26250, 'Santo Domingo de la Calzada');
INSERT INTO poblacions VALUES (26256, 'Villalobar de Rioja');
INSERT INTO poblacions VALUES (26257, 'Bañares');
INSERT INTO poblacions VALUES (26257, 'Hervías');
INSERT INTO poblacions VALUES (26258, 'Cirueña');
INSERT INTO poblacions VALUES (26258, 'Manzanares de Rioja');
INSERT INTO poblacions VALUES (26259, 'Corporales');
INSERT INTO poblacions VALUES (26259, 'Grañón');
INSERT INTO poblacions VALUES (26259, 'Villarta-Quintana');
INSERT INTO poblacions VALUES (26260, 'Santurde de Rioja');
INSERT INTO poblacions VALUES (26261, 'Santurdejo');
INSERT INTO poblacions VALUES (26270, 'Ojacastro');
INSERT INTO poblacions VALUES (26280, 'Ezcaray');
INSERT INTO poblacions VALUES (26288, 'Valgañón');
INSERT INTO poblacions VALUES (26288, 'Zorraquín');
INSERT INTO poblacions VALUES (26291, 'Cidamón');
INSERT INTO poblacions VALUES (26291, 'San Torcuato');
INSERT INTO poblacions VALUES (26291, 'Zarratón');
INSERT INTO poblacions VALUES (26292, 'Villalba de Rioja');
INSERT INTO poblacions VALUES (26300, 'Nájera');
INSERT INTO poblacions VALUES (26310, 'Badarán');
INSERT INTO poblacions VALUES (26311, 'Arenzana de Abajo');
INSERT INTO poblacions VALUES (26311, 'Camprovín');
INSERT INTO poblacions VALUES (26312, 'Arenzana de Arriba');
INSERT INTO poblacions VALUES (26312, 'Bezares');
INSERT INTO poblacions VALUES (26312, 'Tricio');
INSERT INTO poblacions VALUES (26314, 'Huércanos');
INSERT INTO poblacions VALUES (26315, 'Alesón');
INSERT INTO poblacions VALUES (26315, 'Castroviejo');
INSERT INTO poblacions VALUES (26315, 'Manjarrés');
INSERT INTO poblacions VALUES (26315, 'Santa Coloma');
INSERT INTO poblacions VALUES (26320, 'Baños de Río Tobía');
INSERT INTO poblacions VALUES (26321, 'Bobadilla');
INSERT INTO poblacions VALUES (26321, 'Ledesma de la Cogolla');
INSERT INTO poblacions VALUES (26321, 'Matute');
INSERT INTO poblacions VALUES (26321, 'Pedroso');
INSERT INTO poblacions VALUES (26321, 'Tobía');
INSERT INTO poblacions VALUES (26324, 'Brieva de Cameros');
INSERT INTO poblacions VALUES (26325, 'Viniegra de Abajo');
INSERT INTO poblacions VALUES (26325, 'Viniegra de Arriba');
INSERT INTO poblacions VALUES (26326, 'Canales de la Sierra');
INSERT INTO poblacions VALUES (26329, 'Mansilla de la Sierra');
INSERT INTO poblacions VALUES (26329, 'Villavelayo');
INSERT INTO poblacions VALUES (26330, 'Briones');
INSERT INTO poblacions VALUES (26338, 'San Vicente de la Sonsierra');
INSERT INTO poblacions VALUES (26339, 'Ábalos');
INSERT INTO poblacions VALUES (26340, 'San Asensio');
INSERT INTO poblacions VALUES (26350, 'Cenicero');
INSERT INTO poblacions VALUES (26360, 'Fuenmayor');
INSERT INTO poblacions VALUES (26370, 'Navarrete');
INSERT INTO poblacions VALUES (26371, 'Ventosa');
INSERT INTO poblacions VALUES (26372, 'Hornos de Moncalvillo');
INSERT INTO poblacions VALUES (26374, 'Medrano');
INSERT INTO poblacions VALUES (26375, 'Entrena');
INSERT INTO poblacions VALUES (26376, 'Sojuela');
INSERT INTO poblacions VALUES (26500, 'Calahorra');
INSERT INTO poblacions VALUES (26509, 'Agoncillo');
INSERT INTO poblacions VALUES (26509, 'Arrúbal');
INSERT INTO poblacions VALUES (26511, 'El Villar de Arnedo');
INSERT INTO poblacions VALUES (26512, 'Tudelilla');
INSERT INTO poblacions VALUES (26513, 'Ausejo');
INSERT INTO poblacions VALUES (26520, 'Cervera del Río Alhama');
INSERT INTO poblacions VALUES (26525, 'Igea');
INSERT INTO poblacions VALUES (26526, 'Cornago');
INSERT INTO poblacions VALUES (26530, 'Aguilar del Río Alhama');
INSERT INTO poblacions VALUES (26532, 'Valdemadera');
INSERT INTO poblacions VALUES (26533, 'Navajún');
INSERT INTO poblacions VALUES (26540, 'Alfaro');
INSERT INTO poblacions VALUES (26550, 'Rincón de Soto');
INSERT INTO poblacions VALUES (26559, 'Aldeanueva de Ebro');
INSERT INTO poblacions VALUES (26560, 'Autol');
INSERT INTO poblacions VALUES (26570, 'Quel');
INSERT INTO poblacions VALUES (26580, 'Arnedo');
INSERT INTO poblacions VALUES (26584, 'Herce');
INSERT INTO poblacions VALUES (26586, 'Enciso');
INSERT INTO poblacions VALUES (26586, 'Zarzosa');
INSERT INTO poblacions VALUES (26587, 'Grávalos');
INSERT INTO poblacions VALUES (26587, 'Muro de Aguas');
INSERT INTO poblacions VALUES (26587, 'Villarroya');
INSERT INTO poblacions VALUES (26588, 'Bergasa');
INSERT INTO poblacions VALUES (26588, 'Bergasillas Bajera');
INSERT INTO poblacions VALUES (26589, 'Arnedillo');
INSERT INTO poblacions VALUES (26589, 'Préjano');
INSERT INTO poblacions VALUES (27000, 'Lugo');
INSERT INTO poblacions VALUES (27100, 'A Fonsagrada');
INSERT INTO poblacions VALUES (27113, 'Negueira de Muñiz');
INSERT INTO poblacions VALUES (27120, 'Castroverde');
INSERT INTO poblacions VALUES (27130, 'Baleira');
INSERT INTO poblacions VALUES (27150, 'Outeiro de Rei');
INSERT INTO poblacions VALUES (27170, 'Portomarín');
INSERT INTO poblacions VALUES (27200, 'Palas de Rei');
INSERT INTO poblacions VALUES (27220, 'Friol');
INSERT INTO poblacions VALUES (27240, 'Meira');
INSERT INTO poblacions VALUES (27250, 'Castro de Rei');
INSERT INTO poblacions VALUES (27270, 'Pol');
INSERT INTO poblacions VALUES (27279, 'Barreiros');
INSERT INTO poblacions VALUES (27300, 'Guitiriz');
INSERT INTO poblacions VALUES (27320, 'Quiroga');
INSERT INTO poblacions VALUES (27325, 'Folgoso do Courel');
INSERT INTO poblacions VALUES (27332, 'A Pobra de Brollón');
INSERT INTO poblacions VALUES (27340, 'Bóveda');
INSERT INTO poblacions VALUES (27346, 'O Incio');
INSERT INTO poblacions VALUES (27370, 'Rábade');
INSERT INTO poblacions VALUES (27373, 'Begonte');
INSERT INTO poblacions VALUES (27377, 'Cospeito');
INSERT INTO poblacions VALUES (27400, 'Monforte de Lemos');
INSERT INTO poblacions VALUES (27430, 'Pantón');
INSERT INTO poblacions VALUES (27520, 'Carballedo');
INSERT INTO poblacions VALUES (27560, 'Monterroso');
INSERT INTO poblacions VALUES (27611, 'Paradela');
INSERT INTO poblacions VALUES (27620, 'Samos');
INSERT INTO poblacions VALUES (27630, 'Triacastela');
INSERT INTO poblacions VALUES (27650, 'Navia de Suarna');
INSERT INTO poblacions VALUES (27664, 'Cervantes');
INSERT INTO poblacions VALUES (27670, 'Pedrafita do Cebreiro');
INSERT INTO poblacions VALUES (27720, 'A Pontenova');
INSERT INTO poblacions VALUES (27740, 'Mondoñedo');
INSERT INTO poblacions VALUES (27760, 'Lourenzá');
INSERT INTO poblacions VALUES (27765, 'Trabada');
INSERT INTO poblacions VALUES (27770, 'O Valadouro');
INSERT INTO poblacions VALUES (27773, 'Alfoz');
INSERT INTO poblacions VALUES (27780, 'Foz');
INSERT INTO poblacions VALUES (27836, 'Muras');
INSERT INTO poblacions VALUES (27850, 'Viveiro');
INSERT INTO poblacions VALUES (27860, 'O Vicedo');
INSERT INTO poblacions VALUES (27870, 'Xove');
INSERT INTO poblacions VALUES (27880, 'Burela');
INSERT INTO poblacions VALUES (27891, 'Cervo');
INSERT INTO poblacions VALUES (28000, 'Madrid');
INSERT INTO poblacions VALUES (28023, 'Pozuelo de Alarcón');
INSERT INTO poblacions VALUES (28100, 'Alcobendas');
INSERT INTO poblacions VALUES (28110, 'Algete');
INSERT INTO poblacions VALUES (28130, 'Valdeolmos-Alalpardo');
INSERT INTO poblacions VALUES (28140, 'Fuente el Saz de Jarama');
INSERT INTO poblacions VALUES (28150, 'Valdetorres de Jarama');
INSERT INTO poblacions VALUES (28170, 'Valdepiélagos');
INSERT INTO poblacions VALUES (28189, 'Patones');
INSERT INTO poblacions VALUES (28189, 'Torremocha de Jarama');
INSERT INTO poblacions VALUES (28190, 'Montejo de la Sierra');
INSERT INTO poblacions VALUES (28190, 'Puebla de la Sierra');
INSERT INTO poblacions VALUES (28190, 'Torrelaguna');
INSERT INTO poblacions VALUES (28191, 'Horcajuelo de la Sierra');
INSERT INTO poblacions VALUES (28191, 'La Hiruela');
INSERT INTO poblacions VALUES (28191, 'Prádena del Rincón');
INSERT INTO poblacions VALUES (28192, 'El Berrueco');
INSERT INTO poblacions VALUES (28193, 'Cervera de Buitrago');
INSERT INTO poblacions VALUES (28194, 'Berzosa del Lozoya');
INSERT INTO poblacions VALUES (28194, 'Robledillo de la Jara');
INSERT INTO poblacions VALUES (28200, 'San Lorenzo de El Escorial');
INSERT INTO poblacions VALUES (28212, 'Navalagamella');
INSERT INTO poblacions VALUES (28213, 'Colmenar del Arroyo');
INSERT INTO poblacions VALUES (28214, 'Fresnedillas de la Oliva');
INSERT INTO poblacions VALUES (28230, 'Las Rozas de Madrid');
INSERT INTO poblacions VALUES (28240, 'Hoyo de Manzanares');
INSERT INTO poblacions VALUES (28250, 'Torrelodones');
INSERT INTO poblacions VALUES (28260, 'Galapagar');
INSERT INTO poblacions VALUES (28270, 'Colmenarejo');
INSERT INTO poblacions VALUES (28280, 'El Escorial');
INSERT INTO poblacions VALUES (28293, 'Zarzalejo');
INSERT INTO poblacions VALUES (28294, 'Robledo de Chavela');
INSERT INTO poblacions VALUES (28295, 'Valdemaqueda');
INSERT INTO poblacions VALUES (28296, 'Santa María de la Alameda');
INSERT INTO poblacions VALUES (28320, 'PINTO');
INSERT INTO poblacions VALUES (28330, 'San Martín de la Vega');
INSERT INTO poblacions VALUES (28340, 'Valdemoro');
INSERT INTO poblacions VALUES (28350, 'Ciempozuelos');
INSERT INTO poblacions VALUES (28359, 'Titulcia');
INSERT INTO poblacions VALUES (28370, 'Chinchón');
INSERT INTO poblacions VALUES (28390, 'Belmonte de Tajo');
INSERT INTO poblacions VALUES (28400, 'Collado Villalba');
INSERT INTO poblacions VALUES (28410, 'Manzanares el Real');
INSERT INTO poblacions VALUES (28411, 'Moralzarzal');
INSERT INTO poblacions VALUES (28413, 'El Boalo');
INSERT INTO poblacions VALUES (28430, 'Alpedrete');
INSERT INTO poblacions VALUES (28440, 'Guadarrama');
INSERT INTO poblacions VALUES (28450, 'Collado Mediano');
INSERT INTO poblacions VALUES (28460, 'Los Molinos');
INSERT INTO poblacions VALUES (28470, 'Cercedilla');
INSERT INTO poblacions VALUES (28491, 'Navacerrada');
INSERT INTO poblacions VALUES (28510, 'Campo Real');
INSERT INTO poblacions VALUES (28511, 'Valdilecha');
INSERT INTO poblacions VALUES (28515, 'Olmeda de las Fuentes');
INSERT INTO poblacions VALUES (28529, 'Rivas-Vaciamadrid');
INSERT INTO poblacions VALUES (28530, 'Morata de Tajuña');
INSERT INTO poblacions VALUES (28550, 'Tielmes');
INSERT INTO poblacions VALUES (28560, 'Carabaña');
INSERT INTO poblacions VALUES (28570, 'Orusco de Tajuña');
INSERT INTO poblacions VALUES (28580, 'Ambite');
INSERT INTO poblacions VALUES (28594, 'Valdaracete');
INSERT INTO poblacions VALUES (28595, 'Estremera');
INSERT INTO poblacions VALUES (28596, 'Brea de Tajo');
INSERT INTO poblacions VALUES (28597, 'Fuentidueña de Tajo');
INSERT INTO poblacions VALUES (28598, 'Villamanrique de Tajo');
INSERT INTO poblacions VALUES (28607, 'El Álamo');
INSERT INTO poblacions VALUES (28609, 'Sevilla la Nueva');
INSERT INTO poblacions VALUES (28609, 'Villamantilla');
INSERT INTO poblacions VALUES (28609, 'Villanueva de Perales');
INSERT INTO poblacions VALUES (28610, 'Villamanta');
INSERT INTO poblacions VALUES (28630, 'Villa del Prado');
INSERT INTO poblacions VALUES (28640, 'Cadalso de los Vidrios');
INSERT INTO poblacions VALUES (28649, 'Rozas de Puerto Real');
INSERT INTO poblacions VALUES (28650, 'Cenicientos');
INSERT INTO poblacions VALUES (28660, 'Boadilla del Monte');
INSERT INTO poblacions VALUES (28670, 'Villaviciosa de Odón');
INSERT INTO poblacions VALUES (28680, 'San Martín de Valdeiglesias');
INSERT INTO poblacions VALUES (28691, 'Villanueva de la Cañada');
INSERT INTO poblacions VALUES (28693, 'Quijorna');
INSERT INTO poblacions VALUES (28694, 'Chapinería');
INSERT INTO poblacions VALUES (28696, 'Pelayos de la Presa');
INSERT INTO poblacions VALUES (28710, 'El Molar');
INSERT INTO poblacions VALUES (28720, 'Bustarviejo');
INSERT INTO poblacions VALUES (28721, 'Redueña');
INSERT INTO poblacions VALUES (28723, 'Pedrezuela');
INSERT INTO poblacions VALUES (28729, 'Navalafuente');
INSERT INTO poblacions VALUES (28729, 'Valdemanco');
INSERT INTO poblacions VALUES (28729, 'Venturada');
INSERT INTO poblacions VALUES (28730, 'Buitrago del Lozoya');
INSERT INTO poblacions VALUES (28737, 'Braojos');
INSERT INTO poblacions VALUES (28737, 'Gascones');
INSERT INTO poblacions VALUES (28737, 'La Serna del Monte');
INSERT INTO poblacions VALUES (28738, 'Horcajo de la Sierra');
INSERT INTO poblacions VALUES (28738, 'Madarcos');
INSERT INTO poblacions VALUES (28738, 'Piñuécar');
INSERT INTO poblacions VALUES (28739, 'Gargantilla del Lozoya');
INSERT INTO poblacions VALUES (28740, 'Rascafría');
INSERT INTO poblacions VALUES (28742, 'Lozoya');
INSERT INTO poblacions VALUES (28749, 'Alameda del Valle');
INSERT INTO poblacions VALUES (28749, 'Garganta de los Montes');
INSERT INTO poblacions VALUES (28750, 'San Agustín de Guadalix');
INSERT INTO poblacions VALUES (28751, 'La Cabrera');
INSERT INTO poblacions VALUES (28752, 'Lozoyuela-Navas-Sieteiglesias');
INSERT INTO poblacions VALUES (28754, 'Puentes Viejas');
INSERT INTO poblacions VALUES (28755, 'La Acebeda');
INSERT INTO poblacions VALUES (28755, 'Robregordo');
INSERT INTO poblacions VALUES (28760, 'Tres Cantos');
INSERT INTO poblacions VALUES (28770, 'Colmenar Viejo');
INSERT INTO poblacions VALUES (28792, 'Miraflores de la Sierra');
INSERT INTO poblacions VALUES (28794, 'Guadalix de la Sierra');
INSERT INTO poblacions VALUES (28800, 'Alcalá de Henares');
INSERT INTO poblacions VALUES (28810, 'Villalbilla');
INSERT INTO poblacions VALUES (28811, 'Corpa');
INSERT INTO poblacions VALUES (28812, 'Pezuela de las Torres');
INSERT INTO poblacions VALUES (28813, 'Pozuelo del Rey');
INSERT INTO poblacions VALUES (28813, 'Torres de la Alameda');
INSERT INTO poblacions VALUES (28814, 'Daganzo de Arriba');
INSERT INTO poblacions VALUES (28815, 'Fresno de Torote');
INSERT INTO poblacions VALUES (28815, 'Ribatejada');
INSERT INTO poblacions VALUES (28816, 'Camarma de Esteruelas');
INSERT INTO poblacions VALUES (28816, 'Valdeavero');
INSERT INTO poblacions VALUES (28817, 'Los Santos de la Humosa');
INSERT INTO poblacions VALUES (28818, 'Anchuelo');
INSERT INTO poblacions VALUES (28818, 'Santorcaz');
INSERT INTO poblacions VALUES (28820, 'Coslada');
INSERT INTO poblacions VALUES (28830, 'San Fernando de Henares');
INSERT INTO poblacions VALUES (28864, 'Ajalvir');
INSERT INTO poblacions VALUES (28890, 'Loeches');
INSERT INTO poblacions VALUES (28900, 'Getafe');
INSERT INTO poblacions VALUES (28910, 'Leganés');
INSERT INTO poblacions VALUES (28930, 'Móstoles');
INSERT INTO poblacions VALUES (28940, 'Fuenlabrada');
INSERT INTO poblacions VALUES (28950, 'Moraleja de Enmedio');
INSERT INTO poblacions VALUES (28960, 'Humanes de Madrid');
INSERT INTO poblacions VALUES (28970, 'Griñón');
INSERT INTO poblacions VALUES (28978, 'Casarrubuelos');
INSERT INTO poblacions VALUES (28979, 'Batres');
INSERT INTO poblacions VALUES (28979, 'Serranillos del Valle');
INSERT INTO poblacions VALUES (28980, 'Parla');
INSERT INTO poblacions VALUES (28990, 'Torrejón de Velasco');
INSERT INTO poblacions VALUES (28991, 'Torrejón de la Calzada');
INSERT INTO poblacions VALUES (29100, 'Coín');
INSERT INTO poblacions VALUES (29108, 'Guaro');
INSERT INTO poblacions VALUES (29109, 'Tolox');
INSERT INTO poblacions VALUES (29150, 'Almogía');
INSERT INTO poblacions VALUES (29160, 'Casabermeja');
INSERT INTO poblacions VALUES (29170, 'Colmenar');
INSERT INTO poblacions VALUES (29180, 'Riogordo');
INSERT INTO poblacions VALUES (29194, 'Alfarnate');
INSERT INTO poblacions VALUES (29194, 'Alfarnatejo');
INSERT INTO poblacions VALUES (29195, 'Comares');
INSERT INTO poblacions VALUES (29197, 'Totalán');
INSERT INTO poblacions VALUES (29200, 'Antequera');
INSERT INTO poblacions VALUES (29210, 'Cuevas de San Marcos');
INSERT INTO poblacions VALUES (29240, 'Valle de Abdalajís');
INSERT INTO poblacions VALUES (29300, 'Archidona');
INSERT INTO poblacions VALUES (29312, 'Villanueva del Rosario');
INSERT INTO poblacions VALUES (29313, 'Villanueva del Trabuco');
INSERT INTO poblacions VALUES (29320, 'Campillos');
INSERT INTO poblacions VALUES (29327, 'Teba');
INSERT INTO poblacions VALUES (29328, 'Sierra de Yeguas');
INSERT INTO poblacions VALUES (29330, 'Almargen');
INSERT INTO poblacions VALUES (29340, 'Cañete la Real');
INSERT INTO poblacions VALUES (29350, 'Arriate');
INSERT INTO poblacions VALUES (29360, 'Montejaque');
INSERT INTO poblacions VALUES (29370, 'Benaoján');
INSERT INTO poblacions VALUES (29380, 'Cortes de la Frontera');
INSERT INTO poblacions VALUES (29410, 'Yunquera');
INSERT INTO poblacions VALUES (29420, 'El Burgo');
INSERT INTO poblacions VALUES (29440, 'Igualeja');
INSERT INTO poblacions VALUES (29450, 'Pujerra');
INSERT INTO poblacions VALUES (29451, 'Parauta');
INSERT INTO poblacions VALUES (29460, 'Alpandeire');
INSERT INTO poblacions VALUES (29461, 'Faraján');
INSERT INTO poblacions VALUES (29470, 'Cuevas del Becerro');
INSERT INTO poblacions VALUES (29491, 'Algatocín');
INSERT INTO poblacions VALUES (29491, 'Benalauría');
INSERT INTO poblacions VALUES (29492, 'Genalguacil');
INSERT INTO poblacions VALUES (29492, 'Jubrique');
INSERT INTO poblacions VALUES (29493, 'Benadalid');
INSERT INTO poblacions VALUES (29494, 'Atajate');
INSERT INTO poblacions VALUES (29500, 'Álora');
INSERT INTO poblacions VALUES (29532, 'Mollina');
INSERT INTO poblacions VALUES (29550, 'Ardales');
INSERT INTO poblacions VALUES (29551, 'Carratraca');
INSERT INTO poblacions VALUES (29560, 'Pizarra');
INSERT INTO poblacions VALUES (29566, 'Casarabonela');
INSERT INTO poblacions VALUES (29567, 'Alozaina');
INSERT INTO poblacions VALUES (29570, 'Cártama');
INSERT INTO poblacions VALUES (29610, 'Ojén');
INSERT INTO poblacions VALUES (29611, 'Istán');
INSERT INTO poblacions VALUES (29620, 'Torremolinos');
INSERT INTO poblacions VALUES (29639, 'Benalmádena');
INSERT INTO poblacions VALUES (29650, 'Mijas');
INSERT INTO poblacions VALUES (29679, 'Benahavís');
INSERT INTO poblacions VALUES (29680, 'Estepona');
INSERT INTO poblacions VALUES (29690, 'Casares');
INSERT INTO poblacions VALUES (29691, 'Manilva');
INSERT INTO poblacions VALUES (29700, 'Vélez-Málaga');
INSERT INTO poblacions VALUES (29710, 'Periana');
INSERT INTO poblacions VALUES (29711, 'Alcaucín');
INSERT INTO poblacions VALUES (29712, 'Viñuela');
INSERT INTO poblacions VALUES (29714, 'Salares');
INSERT INTO poblacions VALUES (29715, 'Sedella');
INSERT INTO poblacions VALUES (29717, 'Arenas');
INSERT INTO poblacions VALUES (29718, 'Almáchar');
INSERT INTO poblacions VALUES (29718, 'Cútar');
INSERT INTO poblacions VALUES (29718, 'El Borge');
INSERT INTO poblacions VALUES (29719, 'Benamocarra');
INSERT INTO poblacions VALUES (29719, 'Iznate');
INSERT INTO poblacions VALUES (29738, 'Moclinejo');
INSERT INTO poblacions VALUES (29750, 'Algarrobo');
INSERT INTO poblacions VALUES (29752, 'Sayalonga');
INSERT INTO poblacions VALUES (29753, 'Árchez');
INSERT INTO poblacions VALUES (29754, 'Cómpeta');
INSERT INTO poblacions VALUES (29755, 'Canillas de Albaida');
INSERT INTO poblacions VALUES (29770, 'Torrox');
INSERT INTO poblacions VALUES (29780, 'Nerja');
INSERT INTO poblacions VALUES (29788, 'Frigiliana');
INSERT INTO poblacions VALUES (29791, 'Macharaviaya');
INSERT INTO poblacions VALUES (30140, 'Santomera');
INSERT INTO poblacions VALUES (30170, 'Mula');
INSERT INTO poblacions VALUES (30180, 'Bullas');
INSERT INTO poblacions VALUES (30190, 'Albudeite');
INSERT INTO poblacions VALUES (30191, 'Campos del Río');
INSERT INTO poblacions VALUES (30320, 'Fuente Álamo de Murcia');
INSERT INTO poblacions VALUES (30360, 'La Unión');
INSERT INTO poblacions VALUES (30420, 'Calasparra');
INSERT INTO poblacions VALUES (30430, 'Cehegín');
INSERT INTO poblacions VALUES (30500, 'Molina de Segura');
INSERT INTO poblacions VALUES (30510, 'Yecla');
INSERT INTO poblacions VALUES (30520, 'Jumilla');
INSERT INTO poblacions VALUES (30530, 'Cieza');
INSERT INTO poblacions VALUES (30540, 'Blanca');
INSERT INTO poblacions VALUES (30550, 'Abarán');
INSERT INTO poblacions VALUES (30560, 'Alguazas');
INSERT INTO poblacions VALUES (30562, 'Ceutí');
INSERT INTO poblacions VALUES (30564, 'Lorquí');
INSERT INTO poblacions VALUES (30565, 'Las Torres de Cotillas');
INSERT INTO poblacions VALUES (30600, 'Archena');
INSERT INTO poblacions VALUES (30611, 'Ojós');
INSERT INTO poblacions VALUES (30612, 'Ulea');
INSERT INTO poblacions VALUES (30613, 'Villanueva del Río Segura');
INSERT INTO poblacions VALUES (30620, 'Fortuna');
INSERT INTO poblacions VALUES (30640, 'Abanilla');
INSERT INTO poblacions VALUES (30730, 'San Javier');
INSERT INTO poblacions VALUES (30740, 'San Pedro del Pinatar');
INSERT INTO poblacions VALUES (30820, 'Alcantarilla');
INSERT INTO poblacions VALUES (30840, 'Alhama de Murcia');
INSERT INTO poblacions VALUES (30850, 'Totana');
INSERT INTO poblacions VALUES (30859, 'Aledo');
INSERT INTO poblacions VALUES (30870, 'Mazarrón');
INSERT INTO poblacions VALUES (30880, 'Águilas');
INSERT INTO poblacions VALUES (30890, 'Puerto Lumbreras');
INSERT INTO poblacions VALUES (31110, 'Valle de Elorz Noáin');
INSERT INTO poblacions VALUES (31140, 'Artajona');
INSERT INTO poblacions VALUES (31160, 'Orcoyen');
INSERT INTO poblacions VALUES (31171, 'Olza');
INSERT INTO poblacions VALUES (31177, 'Yerri');
INSERT INTO poblacions VALUES (31190, 'Cizur');
INSERT INTO poblacions VALUES (31192, 'Aranguren');
INSERT INTO poblacions VALUES (31194, 'Ezcabarte');
INSERT INTO poblacions VALUES (31195, 'Berrioplano');
INSERT INTO poblacions VALUES (31210, 'Los Arcos');
INSERT INTO poblacions VALUES (31230, 'Viana');
INSERT INTO poblacions VALUES (31243, 'Arróniz');
INSERT INTO poblacions VALUES (31251, 'Larraga');
INSERT INTO poblacions VALUES (31261, 'Andosilla');
INSERT INTO poblacions VALUES (31300, 'Tafalla');
INSERT INTO poblacions VALUES (31310, 'Carcastillo');
INSERT INTO poblacions VALUES (31320, 'Milagro');
INSERT INTO poblacions VALUES (31340, 'Marcilla');
INSERT INTO poblacions VALUES (31360, 'Funes');
INSERT INTO poblacions VALUES (31370, 'Falces');
INSERT INTO poblacions VALUES (31380, 'Caparroso');
INSERT INTO poblacions VALUES (31390, 'Olite');
INSERT INTO poblacions VALUES (31400, 'Sangüesa');
INSERT INTO poblacions VALUES (31440, 'Lumbier');
INSERT INTO poblacions VALUES (31490, 'Cáseda');
INSERT INTO poblacions VALUES (31500, 'Tudela');
INSERT INTO poblacions VALUES (31511, 'Cabanillas');
INSERT INTO poblacions VALUES (31513, 'Arguedas');
INSERT INTO poblacions VALUES (31520, 'Cascante');
INSERT INTO poblacions VALUES (31520, 'Monteagudo');
INSERT INTO poblacions VALUES (31523, 'Ablitas');
INSERT INTO poblacions VALUES (31540, 'Buñuel');
INSERT INTO poblacions VALUES (31550, 'Ribaforada');
INSERT INTO poblacions VALUES (31560, 'Azagra');
INSERT INTO poblacions VALUES (31570, 'San Adrián');
INSERT INTO poblacions VALUES (31587, 'Mendavia');
INSERT INTO poblacions VALUES (31590, 'Castejón');
INSERT INTO poblacions VALUES (31591, 'Corella');
INSERT INTO poblacions VALUES (31600, 'Burlada');
INSERT INTO poblacions VALUES (31630, 'Esteribar');
INSERT INTO poblacions VALUES (31700, 'Baztan');
INSERT INTO poblacions VALUES (31797, 'Ultzama');
INSERT INTO poblacions VALUES (31820, 'Etxarri-Aranatz');
INSERT INTO poblacions VALUES (31830, 'Lakuntza');
INSERT INTO poblacions VALUES (31860, 'Irurtzun');
INSERT INTO poblacions VALUES (32000, 'Ourense');
INSERT INTO poblacions VALUES (32110, 'Paderne de Allariz');
INSERT INTO poblacions VALUES (32137, 'Piñor');
INSERT INTO poblacions VALUES (32150, 'A Peroxa');
INSERT INTO poblacions VALUES (32152, 'Coles');
INSERT INTO poblacions VALUES (32170, 'Amoeiro');
INSERT INTO poblacions VALUES (32200, 'Cortegada');
INSERT INTO poblacions VALUES (32212, 'Gomesende');
INSERT INTO poblacions VALUES (32226, 'Padrenda');
INSERT INTO poblacions VALUES (32232, 'Castrelo de Miño');
INSERT INTO poblacions VALUES (32234, 'A Arnoia');
INSERT INTO poblacions VALUES (32235, 'Pontedeva');
INSERT INTO poblacions VALUES (32300, 'O Barco de Valdeorras');
INSERT INTO poblacions VALUES (32310, 'Rubiá');
INSERT INTO poblacions VALUES (32340, 'Vilamartín de Valdeorras');
INSERT INTO poblacions VALUES (32350, 'A Rúa');
INSERT INTO poblacions VALUES (32356, 'Petín');
INSERT INTO poblacions VALUES (32358, 'Larouco');
INSERT INTO poblacions VALUES (32360, 'A Veiga');
INSERT INTO poblacions VALUES (32411, 'Melón');
INSERT INTO poblacions VALUES (32420, 'Leiro');
INSERT INTO poblacions VALUES (32430, 'Beariz');
INSERT INTO poblacions VALUES (32431, 'Beade');
INSERT INTO poblacions VALUES (32454, 'Cenlle');
INSERT INTO poblacions VALUES (32455, 'San Amaro');
INSERT INTO poblacions VALUES (32456, 'Punxín');
INSERT INTO poblacions VALUES (32500, 'O Carballiño');
INSERT INTO poblacions VALUES (32514, 'Boborás');
INSERT INTO poblacions VALUES (32530, 'O Irixo');
INSERT INTO poblacions VALUES (32540, 'A Gudiña');
INSERT INTO poblacions VALUES (32549, 'A Mezquita');
INSERT INTO poblacions VALUES (32557, 'Vilariño de Conso');
INSERT INTO poblacions VALUES (32570, 'Maside');
INSERT INTO poblacions VALUES (32600, 'Verín');
INSERT INTO poblacions VALUES (32613, 'Oímbra');
INSERT INTO poblacions VALUES (32616, 'Vilardevós');
INSERT INTO poblacions VALUES (32618, 'Monterrei');
INSERT INTO poblacions VALUES (32620, 'Laza');
INSERT INTO poblacions VALUES (32625, 'Castrelo do Val');
INSERT INTO poblacions VALUES (32630, 'Xinzo de Limia');
INSERT INTO poblacions VALUES (32634, 'Os Blancos');
INSERT INTO poblacions VALUES (32644, 'Calvos de Randín');
INSERT INTO poblacions VALUES (32650, 'Vilar de Santos');
INSERT INTO poblacions VALUES (32689, 'Cualedro');
INSERT INTO poblacions VALUES (32690, 'Taboadela');
INSERT INTO poblacions VALUES (32692, 'Sandiás');
INSERT INTO poblacions VALUES (32695, 'Trasmiras');
INSERT INTO poblacions VALUES (32700, 'Maceda');
INSERT INTO poblacions VALUES (32701, 'Baños de Molgas');
INSERT INTO poblacions VALUES (32702, 'Vilar de Barrio');
INSERT INTO poblacions VALUES (32710, 'O Pereiro de Aguiar');
INSERT INTO poblacions VALUES (32730, 'Xunqueira de Espadanedo');
INSERT INTO poblacions VALUES (32740, 'Parada de Sil');
INSERT INTO poblacions VALUES (32750, 'Montederramo');
INSERT INTO poblacions VALUES (32760, 'Castro Caldelas');
INSERT INTO poblacions VALUES (32765, 'A Teixeira');
INSERT INTO poblacions VALUES (32780, 'A Pobra de Trives');
INSERT INTO poblacions VALUES (32786, 'Chandrexa de Queixa');
INSERT INTO poblacions VALUES (32800, 'Celanova');
INSERT INTO poblacions VALUES (32812, 'A Bola');
INSERT INTO poblacions VALUES (32814, 'Quintela de Leirado');
INSERT INTO poblacions VALUES (32824, 'Cartelle');
INSERT INTO poblacions VALUES (32840, 'Bande');
INSERT INTO poblacions VALUES (32850, 'Lobeira');
INSERT INTO poblacions VALUES (32860, 'Entrimo');
INSERT INTO poblacions VALUES (32870, 'Lobios');
INSERT INTO poblacions VALUES (32911, 'San Cibrao das Viñas');
INSERT INTO poblacions VALUES (33000, 'Oviedo');
INSERT INTO poblacions VALUES (33110, 'Teverga');
INSERT INTO poblacions VALUES (33114, 'Proaza');
INSERT INTO poblacions VALUES (33117, 'Quirós');
INSERT INTO poblacions VALUES (33120, 'Pravia');
INSERT INTO poblacions VALUES (33126, 'Soto del Barco');
INSERT INTO poblacions VALUES (33138, 'Muros de Nalón');
INSERT INTO poblacions VALUES (33150, 'Cudillero');
INSERT INTO poblacions VALUES (33160, 'Riosa');
INSERT INTO poblacions VALUES (33172, 'Ribera de Arriba');
INSERT INTO poblacions VALUES (33180, 'Noreña');
INSERT INTO poblacions VALUES (33200, 'Gijón');
INSERT INTO poblacions VALUES (33300, 'Villaviciosa');
INSERT INTO poblacions VALUES (33344, 'Caravia');
INSERT INTO poblacions VALUES (33400, 'Avilés');
INSERT INTO poblacions VALUES (33411, 'Illas');
INSERT INTO poblacions VALUES (33424, 'Llanera');
INSERT INTO poblacions VALUES (33430, 'Carreño');
INSERT INTO poblacions VALUES (33440, 'Gozón');
INSERT INTO poblacions VALUES (33450, 'Castrillón');
INSERT INTO poblacions VALUES (33500, 'Llanes');
INSERT INTO poblacions VALUES (33510, 'Siero');
INSERT INTO poblacions VALUES (33518, 'Sariego');
INSERT INTO poblacions VALUES (33520, 'Nava');
INSERT INTO poblacions VALUES (33527, 'Bimenes');
INSERT INTO poblacions VALUES (33535, 'Cabranes');
INSERT INTO poblacions VALUES (33550, 'Cangas de Onís');
INSERT INTO poblacions VALUES (33554, 'Cabrales');
INSERT INTO poblacions VALUES (33556, 'Onís');
INSERT INTO poblacions VALUES (33558, 'Amieva');
INSERT INTO poblacions VALUES (33560, 'Ribadesella');
INSERT INTO poblacions VALUES (33570, 'Peñamellera Baja');
INSERT INTO poblacions VALUES (33578, 'Peñamellera Alta');
INSERT INTO poblacions VALUES (33590, 'Ribadedeva');
INSERT INTO poblacions VALUES (33600, 'Mieres');
INSERT INTO poblacions VALUES (33630, 'Lena');
INSERT INTO poblacions VALUES (33686, 'Aller');
INSERT INTO poblacions VALUES (33700, 'Valdés');
INSERT INTO poblacions VALUES (33717, 'Villayón');
INSERT INTO poblacions VALUES (33720, 'Boal');
INSERT INTO poblacions VALUES (33735, 'Pesoz');
INSERT INTO poblacions VALUES (33740, 'Tapia de Casariego');
INSERT INTO poblacions VALUES (33746, 'El Franco');
INSERT INTO poblacions VALUES (33760, 'Castropol');
INSERT INTO poblacions VALUES (33770, 'Vegadeo');
INSERT INTO poblacions VALUES (33774, 'San Tirso de Abres');
INSERT INTO poblacions VALUES (33776, 'Santa Eulalia de Oscos');
INSERT INTO poblacions VALUES (33777, 'San Martín de Oscos');
INSERT INTO poblacions VALUES (33795, 'Coaña');
INSERT INTO poblacions VALUES (33800, 'Cangas del Narcea');
INSERT INTO poblacions VALUES (33810, 'Ibias');
INSERT INTO poblacions VALUES (33820, 'Grado');
INSERT INTO poblacions VALUES (33826, 'Yernes y Tameza');
INSERT INTO poblacions VALUES (33829, 'Candamo');
INSERT INTO poblacions VALUES (33830, 'Belmonte de Miranda');
INSERT INTO poblacions VALUES (33840, 'Somiedo');
INSERT INTO poblacions VALUES (33860, 'Salas');
INSERT INTO poblacions VALUES (33870, 'Tineo');
INSERT INTO poblacions VALUES (33880, 'Allande');
INSERT INTO poblacions VALUES (33900, 'Langreo');
INSERT INTO poblacions VALUES (33950, 'San Martín del Rey Aurelio');
INSERT INTO poblacions VALUES (33980, 'Laviana');
INSERT INTO poblacions VALUES (33990, 'Caso');
INSERT INTO poblacions VALUES (33993, 'Sobrescobio');
INSERT INTO poblacions VALUES (34000, 'Palencia');
INSERT INTO poblacions VALUES (34140, 'Villarramiel');
INSERT INTO poblacions VALUES (34190, 'Villamuriel de Cerrato');
INSERT INTO poblacions VALUES (34210, 'Dueñas');
INSERT INTO poblacions VALUES (34230, 'Torquemada');
INSERT INTO poblacions VALUES (34300, 'Paredes de Nava');
INSERT INTO poblacions VALUES (34310, 'Becerril de Campos');
INSERT INTO poblacions VALUES (34340, 'Villada');
INSERT INTO poblacions VALUES (34400, 'Herrera de Pisuerga');
INSERT INTO poblacions VALUES (34440, 'Frómista');
INSERT INTO poblacions VALUES (34480, 'Alar del Rey');
INSERT INTO poblacions VALUES (34800, 'Aguilar de Campoo');
INSERT INTO poblacions VALUES (34820, 'Barruelo de Santullán');
INSERT INTO poblacions VALUES (34840, 'Cervera de Pisuerga');
INSERT INTO poblacions VALUES (34870, 'Santibáñez de la Peña');
INSERT INTO poblacions VALUES (34880, 'Guardo');
INSERT INTO poblacions VALUES (34886, 'Velilla del Río Carrión');
INSERT INTO poblacions VALUES (35140, 'Mogán');
INSERT INTO poblacions VALUES (35217, 'Valsequillo de Gran Canaria');
INSERT INTO poblacions VALUES (35260, 'Agüimes');
INSERT INTO poblacions VALUES (35280, 'Ingenio');
INSERT INTO poblacions VALUES (35280, 'Santa Lucía de Tirajana');
INSERT INTO poblacions VALUES (35290, 'San Bartolomé de Tirajana');
INSERT INTO poblacions VALUES (35300, 'Santa Brígida');
INSERT INTO poblacions VALUES (35330, 'Teror');
INSERT INTO poblacions VALUES (35340, 'Valleseco');
INSERT INTO poblacions VALUES (35350, 'Artenara');
INSERT INTO poblacions VALUES (35360, 'Tejeda');
INSERT INTO poblacions VALUES (35400, 'Arucas');
INSERT INTO poblacions VALUES (35430, 'Firgas');
INSERT INTO poblacions VALUES (35450, 'Santa María de Guía de Gran Canaria');
INSERT INTO poblacions VALUES (35460, 'Gáldar');
INSERT INTO poblacions VALUES (35470, 'San Nicolás de Tolentino');
INSERT INTO poblacions VALUES (35500, 'Arrecife');
INSERT INTO poblacions VALUES (35530, 'Teguise');
INSERT INTO poblacions VALUES (35550, 'San Bartolomé');
INSERT INTO poblacions VALUES (35570, 'Yaiza');
INSERT INTO poblacions VALUES (35572, 'Tías');
INSERT INTO poblacions VALUES (35600, 'Puerto del Rosario');
INSERT INTO poblacions VALUES (35628, 'Pájara');
INSERT INTO poblacions VALUES (35628, 'Tuineje');
INSERT INTO poblacions VALUES (35630, 'Antigua');
INSERT INTO poblacions VALUES (35637, 'Betancuria');
INSERT INTO poblacions VALUES (35640, 'La Oliva');
INSERT INTO poblacions VALUES (35820, 'Ponte-Caldelas');
INSERT INTO poblacions VALUES (36000, 'Pontevedra');
INSERT INTO poblacions VALUES (36110, 'Campo Lameiro');
INSERT INTO poblacions VALUES (36130, 'Cerdedo');
INSERT INTO poblacions VALUES (36140, 'Vilaboa');
INSERT INTO poblacions VALUES (36194, 'Barro');
INSERT INTO poblacions VALUES (36200, 'Vigo');
INSERT INTO poblacions VALUES (36300, 'Baiona');
INSERT INTO poblacions VALUES (36380, 'Gondomar');
INSERT INTO poblacions VALUES (36390, 'Oia');
INSERT INTO poblacions VALUES (36416, 'Mos');
INSERT INTO poblacions VALUES (36420, 'Crecente');
INSERT INTO poblacions VALUES (36430, 'Arbo');
INSERT INTO poblacions VALUES (36440, 'As Neves');
INSERT INTO poblacions VALUES (36450, 'Salvaterra de Miño');
INSERT INTO poblacions VALUES (36470, 'Salceda de Caselas');
INSERT INTO poblacions VALUES (36500, 'Lalín');
INSERT INTO poblacions VALUES (36518, 'Dozón');
INSERT INTO poblacions VALUES (36530, 'Rodeiro');
INSERT INTO poblacions VALUES (36540, 'Silleda');
INSERT INTO poblacions VALUES (36550, 'Forcarei');
INSERT INTO poblacions VALUES (36590, 'Vila de Cruces');
INSERT INTO poblacions VALUES (36600, 'Vilagarcía de Arousa');
INSERT INTO poblacions VALUES (36612, 'Catoira');
INSERT INTO poblacions VALUES (36620, 'Vilanova de Arousa');
INSERT INTO poblacions VALUES (36626, 'A Illa de Arousa');
INSERT INTO poblacions VALUES (36636, 'Ribadumia');
INSERT INTO poblacions VALUES (36637, 'Meis');
INSERT INTO poblacions VALUES (36640, 'Pontecesures');
INSERT INTO poblacions VALUES (36645, 'Valga');
INSERT INTO poblacions VALUES (36658, 'Portas');
INSERT INTO poblacions VALUES (36660, 'Moraña');
INSERT INTO poblacions VALUES (36670, 'Cuntis');
INSERT INTO poblacions VALUES (36680, 'A Estrada');
INSERT INTO poblacions VALUES (36740, 'Tomiño');
INSERT INTO poblacions VALUES (36770, 'O Rosal');
INSERT INTO poblacions VALUES (36780, 'A Guarda');
INSERT INTO poblacions VALUES (36800, 'Redondela');
INSERT INTO poblacions VALUES (36830, 'A Lama');
INSERT INTO poblacions VALUES (36841, 'Pazos de Borbén');
INSERT INTO poblacions VALUES (36847, 'Fornelos de Montes');
INSERT INTO poblacions VALUES (36856, 'Cotobade');
INSERT INTO poblacions VALUES (36860, 'Ponteareas');
INSERT INTO poblacions VALUES (36870, 'Mondariz');
INSERT INTO poblacions VALUES (36872, 'O Covelo');
INSERT INTO poblacions VALUES (36880, 'A Cañiza');
INSERT INTO poblacions VALUES (36890, 'Mondariz-Balneario');
INSERT INTO poblacions VALUES (36900, 'Marín');
INSERT INTO poblacions VALUES (36930, 'Bueu');
INSERT INTO poblacions VALUES (36940, 'Cangas');
INSERT INTO poblacions VALUES (36950, 'Moaña');
INSERT INTO poblacions VALUES (36960, 'Sanxenxo');
INSERT INTO poblacions VALUES (36968, 'Meaño');
INSERT INTO poblacions VALUES (36980, 'O Grove');
INSERT INTO poblacions VALUES (36994, 'Poio');
INSERT INTO poblacions VALUES (37000, 'Salamanca');
INSERT INTO poblacions VALUES (37100, 'Ledesma');
INSERT INTO poblacions VALUES (37110, 'Santiz');
INSERT INTO poblacions VALUES (37111, 'Añover de Tormes');
INSERT INTO poblacions VALUES (37111, 'Palacios del Arzobispo');
INSERT INTO poblacions VALUES (37114, 'Encina de San Silvestre');
INSERT INTO poblacions VALUES (37114, 'Villaseco de los Gamitos');
INSERT INTO poblacions VALUES (37115, 'Almenara de Tormes');
INSERT INTO poblacions VALUES (37120, 'Doñinos de Salamanca');
INSERT INTO poblacions VALUES (37129, 'Carrascal de Barregas');
INSERT INTO poblacions VALUES (37129, 'Florida de Liébana');
INSERT INTO poblacions VALUES (37129, 'Parada de Arriba');
INSERT INTO poblacions VALUES (37139, 'Doñinos de Ledesma');
INSERT INTO poblacions VALUES (37147, 'Villar de Peralonso');
INSERT INTO poblacions VALUES (37148, 'Espadaña');
INSERT INTO poblacions VALUES (37148, 'Tremedal de Tormes');
INSERT INTO poblacions VALUES (37150, 'Villaseco de los Reyes');
INSERT INTO poblacions VALUES (37160, 'Villarino de los Aires');
INSERT INTO poblacions VALUES (37170, 'El Pino de Tormes');
INSERT INTO poblacions VALUES (37170, 'San Pedro del Valle');
INSERT INTO poblacions VALUES (37170, 'Vega de Tirados');
INSERT INTO poblacions VALUES (37170, 'Zarapicos');
INSERT INTO poblacions VALUES (37171, 'El Manzano');
INSERT INTO poblacions VALUES (37171, 'Monleras');
INSERT INTO poblacions VALUES (37173, 'Ahigal de Villarino');
INSERT INTO poblacions VALUES (37173, 'Trabanca');
INSERT INTO poblacions VALUES (37175, 'Pereña de la Ribera');
INSERT INTO poblacions VALUES (37176, 'Almendra');
INSERT INTO poblacions VALUES (37180, 'Machacón');
INSERT INTO poblacions VALUES (37181, 'Calvarrasa de Abajo');
INSERT INTO poblacions VALUES (37181, 'Pelabravo');
INSERT INTO poblacions VALUES (37182, 'Encinas de Abajo');
INSERT INTO poblacions VALUES (37183, 'Morille');
INSERT INTO poblacions VALUES (37183, 'Mozárbez');
INSERT INTO poblacions VALUES (37183, 'San Pedro de Rozados');
INSERT INTO poblacions VALUES (37184, 'Monterrubio de Armuña');
INSERT INTO poblacions VALUES (37184, 'Villares de la Reina');
INSERT INTO poblacions VALUES (37185, 'Valverdón');
INSERT INTO poblacions VALUES (37185, 'Villamayor');
INSERT INTO poblacions VALUES (37187, 'Aldeatejada');
INSERT INTO poblacions VALUES (37187, 'Miranda de Azán');
INSERT INTO poblacions VALUES (37188, 'Carbajosa de la Sagrada');
INSERT INTO poblacions VALUES (37191, 'Calvarrasa de Arriba');
INSERT INTO poblacions VALUES (37193, 'Cabrerizos');
INSERT INTO poblacions VALUES (37208, 'San Muñoz');
INSERT INTO poblacions VALUES (37209, 'Buenamadre');
INSERT INTO poblacions VALUES (37209, 'Pelarrodríguez');
INSERT INTO poblacions VALUES (37210, 'Vitigudino');
INSERT INTO poblacions VALUES (37213, 'Valsalabroso');
INSERT INTO poblacions VALUES (37214, 'Cabeza del Caballo');
INSERT INTO poblacions VALUES (37214, 'La Peña');
INSERT INTO poblacions VALUES (37215, 'Barceo');
INSERT INTO poblacions VALUES (37216, 'Peralejos de Arriba');
INSERT INTO poblacions VALUES (37217, 'Brincones');
INSERT INTO poblacions VALUES (37217, 'Iruelos');
INSERT INTO poblacions VALUES (37217, 'Villarmuerto');
INSERT INTO poblacions VALUES (37218, 'Sanchón de la Ribera');
INSERT INTO poblacions VALUES (37219, 'Encinasola de los Comendadores');
INSERT INTO poblacions VALUES (37219, 'Moronta');
INSERT INTO poblacions VALUES (37219, 'Valderrodrigo');
INSERT INTO poblacions VALUES (37246, 'Sobradillo');
INSERT INTO poblacions VALUES (37247, 'La Redonda');
INSERT INTO poblacions VALUES (37248, 'Ahigal de los Aceiteros');
INSERT INTO poblacions VALUES (37249, 'Bermellar');
INSERT INTO poblacions VALUES (37250, 'Aldeadávila de la Ribera');
INSERT INTO poblacions VALUES (37251, 'Masueco');
INSERT INTO poblacions VALUES (37254, 'Mieza');
INSERT INTO poblacions VALUES (37256, 'El Milano');
INSERT INTO poblacions VALUES (37257, 'La Zarza de Pumareda');
INSERT INTO poblacions VALUES (37257, 'Saucelle');
INSERT INTO poblacions VALUES (37258, 'Vilvestre');
INSERT INTO poblacions VALUES (37259, 'Saldeana');
INSERT INTO poblacions VALUES (37267, 'Villares de Yeltes');
INSERT INTO poblacions VALUES (37271, 'Bañobárez');
INSERT INTO poblacions VALUES (37272, 'Fuenteliante');
INSERT INTO poblacions VALUES (37281, 'El Cubo de Don Sancho');
INSERT INTO poblacions VALUES (37290, 'Boada');
INSERT INTO poblacions VALUES (37291, 'Cerralbo');
INSERT INTO poblacions VALUES (37292, 'Olmedo de Camaces');
INSERT INTO poblacions VALUES (37310, 'Macotera');
INSERT INTO poblacions VALUES (37312, 'Alaraz');
INSERT INTO poblacions VALUES (37316, 'Bóveda del Río Almar');
INSERT INTO poblacions VALUES (37317, 'Aldeaseca de la Frontera');
INSERT INTO poblacions VALUES (37317, 'El Campo de Peñaranda');
INSERT INTO poblacions VALUES (37318, 'Paradinas de San Juan');
INSERT INTO poblacions VALUES (37318, 'Rágama');
INSERT INTO poblacions VALUES (37319, 'Cantaracillo');
INSERT INTO poblacions VALUES (37320, 'Villar de Gallimazo');
INSERT INTO poblacions VALUES (37329, 'Alconada');
INSERT INTO poblacions VALUES (37329, 'Ventosa del Río Almar');
INSERT INTO poblacions VALUES (37330, 'Babilafuente');
INSERT INTO poblacions VALUES (37337, 'Cordovilla');
INSERT INTO poblacions VALUES (37337, 'Moríñigo');
INSERT INTO poblacions VALUES (37338, 'Huerta');
INSERT INTO poblacions VALUES (37339, 'Villoria');
INSERT INTO poblacions VALUES (37339, 'Villoruela');
INSERT INTO poblacions VALUES (37340, 'San Morales');
INSERT INTO poblacions VALUES (37350, 'Aldealengua');
INSERT INTO poblacions VALUES (37400, 'Cantalapiedra');
INSERT INTO poblacions VALUES (37405, 'Cantalpino');
INSERT INTO poblacions VALUES (37406, 'Poveda de las Cintas');
INSERT INTO poblacions VALUES (37406, 'Villaflores');
INSERT INTO poblacions VALUES (37407, 'Palaciosrubios');
INSERT INTO poblacions VALUES (37408, 'Zorita de la Frontera');
INSERT INTO poblacions VALUES (37409, 'Tarazona de Guareña');
INSERT INTO poblacions VALUES (37410, 'El Pedroso de la Armuña');
INSERT INTO poblacions VALUES (37418, 'Arabayona de Mógica');
INSERT INTO poblacions VALUES (37419, 'Espino de la Orbada');
INSERT INTO poblacions VALUES (37419, 'Parada de Rubiales');
INSERT INTO poblacions VALUES (37420, 'Gomecello');
INSERT INTO poblacions VALUES (37427, 'La Vellés');
INSERT INTO poblacions VALUES (37427, 'Pedrosillo el Ralo');
INSERT INTO poblacions VALUES (37428, 'La Orbada');
INSERT INTO poblacions VALUES (37428, 'Pajares de la Laguna');
INSERT INTO poblacions VALUES (37429, 'Aldeanueva de Figueroa');
INSERT INTO poblacions VALUES (37429, 'Arcediano');
INSERT INTO poblacions VALUES (37430, 'Moriscos');
INSERT INTO poblacions VALUES (37439, 'Castellanos de Moriscos');
INSERT INTO poblacions VALUES (37439, 'Negrilla de Palencia');
INSERT INTO poblacions VALUES (37440, 'Barbadillo');
INSERT INTO poblacions VALUES (37440, 'El Tejado');
INSERT INTO poblacions VALUES (37447, 'Rollán');
INSERT INTO poblacions VALUES (37448, 'Calzada de Don Diego');
INSERT INTO poblacions VALUES (37448, 'Canillas de Abajo');
INSERT INTO poblacions VALUES (37449, 'Galindo y Perahuy');
INSERT INTO poblacions VALUES (37450, 'Matilla de los Caños del Río');
INSERT INTO poblacions VALUES (37451, 'Villalba de los Llanos');
INSERT INTO poblacions VALUES (37452, 'Vecinos');
INSERT INTO poblacions VALUES (37454, 'Las Veguillas');
INSERT INTO poblacions VALUES (37455, 'Barbalos');
INSERT INTO poblacions VALUES (37455, 'Narros de Matalayegua');
INSERT INTO poblacions VALUES (37456, 'Membribe de la Sierra');
INSERT INTO poblacions VALUES (37460, 'Aldehuela de la Bóveda');
INSERT INTO poblacions VALUES (37465, 'La Sagrada');
INSERT INTO poblacions VALUES (37468, 'Sando');
INSERT INTO poblacions VALUES (37468, 'Santa María de Sando');
INSERT INTO poblacions VALUES (37468, 'Villasdardo');
INSERT INTO poblacions VALUES (37469, 'Garcirrey');
INSERT INTO poblacions VALUES (37470, 'Sancti-Spíritus');
INSERT INTO poblacions VALUES (37480, 'Fuentes de Oñoro');
INSERT INTO poblacions VALUES (37482, 'La Alameda de Gardón');
INSERT INTO poblacions VALUES (37483, 'Villar de Argañán');
INSERT INTO poblacions VALUES (37484, 'Gallegos de Argañán');
INSERT INTO poblacions VALUES (37485, 'Villar de la Yegua');
INSERT INTO poblacions VALUES (37486, 'Villar de Ciervo');
INSERT INTO poblacions VALUES (37487, 'La Bouza');
INSERT INTO poblacions VALUES (37487, 'Puerto Seguro');
INSERT INTO poblacions VALUES (37490, 'Pitiegua');
INSERT INTO poblacions VALUES (37491, 'Robliza de Cojos');
INSERT INTO poblacions VALUES (37491, 'Tabera de Abajo');
INSERT INTO poblacions VALUES (37494, 'Castraz');
INSERT INTO poblacions VALUES (37494, 'Martín de Yeltes');
INSERT INTO poblacions VALUES (37495, 'Retortillo');
INSERT INTO poblacions VALUES (37497, 'Espeja');
INSERT INTO poblacions VALUES (37500, 'Ciudad Rodrigo');
INSERT INTO poblacions VALUES (37510, 'Martiago');
INSERT INTO poblacions VALUES (37511, 'Agallas');
INSERT INTO poblacions VALUES (37512, 'Pastores');
INSERT INTO poblacions VALUES (37514, 'El Sahugo');
INSERT INTO poblacions VALUES (37515, 'La Encina');
INSERT INTO poblacions VALUES (37516, 'Herguijuela de Ciudad Rodrigo');
INSERT INTO poblacions VALUES (37520, 'El Bodón');
INSERT INTO poblacions VALUES (37521, 'Robleda');
INSERT INTO poblacions VALUES (37522, 'Villasrubias');
INSERT INTO poblacions VALUES (37523, 'Peñaparda');
INSERT INTO poblacions VALUES (37524, 'El Payo');
INSERT INTO poblacions VALUES (37530, 'Serradilla del Llano');
INSERT INTO poblacions VALUES (37531, 'Serradilla del Arroyo');
INSERT INTO poblacions VALUES (37541, 'Casillas de Flores');
INSERT INTO poblacions VALUES (37542, 'Navasfrías');
INSERT INTO poblacions VALUES (37550, 'Campillo de Azaba');
INSERT INTO poblacions VALUES (37554, 'La Alamedilla');
INSERT INTO poblacions VALUES (37555, 'La Alberguería de Argañán');
INSERT INTO poblacions VALUES (37590, 'Morasverdes');
INSERT INTO poblacions VALUES (37590, 'Tenebrón');
INSERT INTO poblacions VALUES (37591, 'Zamarra');
INSERT INTO poblacions VALUES (37592, 'Castillejo de Martín Viejo');
INSERT INTO poblacions VALUES (37592, 'Saelices el Chico');
INSERT INTO poblacions VALUES (37600, 'Tamames');
INSERT INTO poblacions VALUES (37607, 'La Rinconada de la Sierra');
INSERT INTO poblacions VALUES (37607, 'Navarredonda de la Rinconada');
INSERT INTO poblacions VALUES (37608, 'Tejeda y Segoyuela');
INSERT INTO poblacions VALUES (37610, 'Mogarraz');
INSERT INTO poblacions VALUES (37619, 'Herguijuela de la Sierra');
INSERT INTO poblacions VALUES (37619, 'Madroñal');
INSERT INTO poblacions VALUES (37620, 'El Cabaco');
INSERT INTO poblacions VALUES (37621, 'El Maíllo');
INSERT INTO poblacions VALUES (37623, 'Nava de Francia');
INSERT INTO poblacions VALUES (37624, 'La Alberca');
INSERT INTO poblacions VALUES (37630, 'Cabrillas');
INSERT INTO poblacions VALUES (37638, 'Sepulcro-Hilario');
INSERT INTO poblacions VALUES (37640, 'Abusejo');
INSERT INTO poblacions VALUES (37650, 'Sequeros');
INSERT INTO poblacions VALUES (37656, 'Cepeda');
INSERT INTO poblacions VALUES (37657, 'Sotoserrano');
INSERT INTO poblacions VALUES (37658, 'Villanueva del Conde');
INSERT INTO poblacions VALUES (37659, 'Las Casas del Conde');
INSERT INTO poblacions VALUES (37660, 'Miranda del Castañar');
INSERT INTO poblacions VALUES (37670, 'Santibáñez de la Sierra');
INSERT INTO poblacions VALUES (37671, 'San Esteban de la Sierra');
INSERT INTO poblacions VALUES (37683, 'Molinillo');
INSERT INTO poblacions VALUES (37684, 'Cristóbal');
INSERT INTO poblacions VALUES (37691, 'Aldeanueva de la Sierra');
INSERT INTO poblacions VALUES (37692, 'La Bastida');
INSERT INTO poblacions VALUES (37693, 'Cereceda de la Sierra');
INSERT INTO poblacions VALUES (37694, 'San Miguel del Robledo');
INSERT INTO poblacions VALUES (37710, 'Candelario');
INSERT INTO poblacions VALUES (37712, 'Horcajo de Montemayor');
INSERT INTO poblacions VALUES (37714, 'La Calzada de Béjar');
INSERT INTO poblacions VALUES (37716, 'La Hoya');
INSERT INTO poblacions VALUES (37718, 'Aldeacipreste');
INSERT INTO poblacions VALUES (37720, 'Puerto de Béjar');
INSERT INTO poblacions VALUES (37724, 'Lagunilla');
INSERT INTO poblacions VALUES (37725, 'Valdelageve');
INSERT INTO poblacions VALUES (37727, 'Montemayor del Río');
INSERT INTO poblacions VALUES (37730, 'Ledrada');
INSERT INTO poblacions VALUES (37749, 'Navamorales');
INSERT INTO poblacions VALUES (37750, 'Cespedosa de Tormes');
INSERT INTO poblacions VALUES (37751, 'Gallegos de Solmirón');
INSERT INTO poblacions VALUES (37755, 'Armenteros');
INSERT INTO poblacions VALUES (37760, 'Linares de Riofrío');
INSERT INTO poblacions VALUES (37762, 'Escurial de la Sierra');
INSERT INTO poblacions VALUES (37762, 'Herguijuela del Campo');
INSERT INTO poblacions VALUES (37762, 'La Sierpe');
INSERT INTO poblacions VALUES (37764, 'Valero');
INSERT INTO poblacions VALUES (37765, 'Monleón');
INSERT INTO poblacions VALUES (37766, 'Endrinal');
INSERT INTO poblacions VALUES (37767, 'Casafranca');
INSERT INTO poblacions VALUES (37768, 'Fuenterroble de Salvatierra');
INSERT INTO poblacions VALUES (37768, 'Los Santos');
INSERT INTO poblacions VALUES (37770, 'Guijuelo');
INSERT INTO poblacions VALUES (37774, 'Guijo de Ávila');
INSERT INTO poblacions VALUES (37775, 'Fresnedoso');
INSERT INTO poblacions VALUES (37776, 'Nava de Béjar');
INSERT INTO poblacions VALUES (37777, 'La Cabeza de Béjar');
INSERT INTO poblacions VALUES (37777, 'Sorihuela');
INSERT INTO poblacions VALUES (37779, 'Aldeavieja de Tormes');
INSERT INTO poblacions VALUES (37779, 'Salvatierra de Tormes');
INSERT INTO poblacions VALUES (37780, 'La Maya');
INSERT INTO poblacions VALUES (37785, 'Galinduste');
INSERT INTO poblacions VALUES (37788, 'Monterrubio de la Sierra');
INSERT INTO poblacions VALUES (37788, 'Pedrosillo de los Aires');
INSERT INTO poblacions VALUES (37789, 'Beleña');
INSERT INTO poblacions VALUES (37789, 'Buenavista');
INSERT INTO poblacions VALUES (37789, 'Fresno Alhándiga');
INSERT INTO poblacions VALUES (37791, 'Peromingo');
INSERT INTO poblacions VALUES (37791, 'Puebla de San Medel');
INSERT INTO poblacions VALUES (37791, 'Valdelacasa');
INSERT INTO poblacions VALUES (37791, 'Valverde de Valdelacasa');
INSERT INTO poblacions VALUES (37792, 'Cantagallo');
INSERT INTO poblacions VALUES (37793, 'Navalmoral de Béjar');
INSERT INTO poblacions VALUES (37794, 'Sanchotello');
INSERT INTO poblacions VALUES (37795, 'Montejo');
INSERT INTO poblacions VALUES (37795, 'Pizarral');
INSERT INTO poblacions VALUES (37796, 'Arapiles');
INSERT INTO poblacions VALUES (37797, 'Aldearrodrigo');
INSERT INTO poblacions VALUES (37797, 'El Arco');
INSERT INTO poblacions VALUES (37797, 'Forfoleda');
INSERT INTO poblacions VALUES (37797, 'San Pelayo de Guareña');
INSERT INTO poblacions VALUES (37797, 'Torresmenudas');
INSERT INTO poblacions VALUES (37798, 'Castellanos de Villiquera');
INSERT INTO poblacions VALUES (37799, 'Topas');
INSERT INTO poblacions VALUES (37800, 'Alba de Tormes');
INSERT INTO poblacions VALUES (37810, 'Garcihernández');
INSERT INTO poblacions VALUES (37820, 'Peñarandilla');
INSERT INTO poblacions VALUES (37830, 'Coca de Alba');
INSERT INTO poblacions VALUES (37840, 'Tordillos');
INSERT INTO poblacions VALUES (37850, 'Nava de Sotrobal');
INSERT INTO poblacions VALUES (37860, 'Horcajo Medianero');
INSERT INTO poblacions VALUES (37863, 'Anaya de Alba');
INSERT INTO poblacions VALUES (37865, 'Larrodrigo');
INSERT INTO poblacions VALUES (37870, 'Aldeaseca de Alba');
INSERT INTO poblacions VALUES (37871, 'Pedrosillo de Alba');
INSERT INTO poblacions VALUES (37874, 'Gajates');
INSERT INTO poblacions VALUES (37880, 'Navales');
INSERT INTO poblacions VALUES (37882, 'Pedraza de Alba');
INSERT INTO poblacions VALUES (37891, 'Ejeme');
INSERT INTO poblacions VALUES (37891, 'Galisancho');
INSERT INTO poblacions VALUES (37892, 'Encinas de Arriba');
INSERT INTO poblacions VALUES (37892, 'Sieteiglesias de Tormes');
INSERT INTO poblacions VALUES (37893, 'Martinamor');
INSERT INTO poblacions VALUES (37893, 'Valdemierque');
INSERT INTO poblacions VALUES (37893, 'Villagonzalo de Tormes');
INSERT INTO poblacions VALUES (37900, 'Santa Marta de Tormes');
INSERT INTO poblacions VALUES (38000, 'Santa Cruz de Tenerife');
INSERT INTO poblacions VALUES (38200, 'San Cristóbal de La Laguna');
INSERT INTO poblacions VALUES (38260, 'Arico');
INSERT INTO poblacions VALUES (38280, 'Tegueste');
INSERT INTO poblacions VALUES (38290, 'El Rosario');
INSERT INTO poblacions VALUES (38300, 'La Orotava');
INSERT INTO poblacions VALUES (38350, 'Tacoronte');
INSERT INTO poblacions VALUES (38360, 'El Sauzal');
INSERT INTO poblacions VALUES (38370, 'La Matanza de Acentejo');
INSERT INTO poblacions VALUES (38380, 'La Victoria de Acentejo');
INSERT INTO poblacions VALUES (38400, 'Puerto de la Cruz');
INSERT INTO poblacions VALUES (38420, 'San Juan de la Rambla');
INSERT INTO poblacions VALUES (38430, 'Icod de los Vinos');
INSERT INTO poblacions VALUES (38435, 'El Tanque');
INSERT INTO poblacions VALUES (38436, 'Santiago del Teide');
INSERT INTO poblacions VALUES (38440, 'La Guancha');
INSERT INTO poblacions VALUES (38450, 'Garachico');
INSERT INTO poblacions VALUES (38470, 'Los Silos');
INSERT INTO poblacions VALUES (38480, 'Buenavista del Norte');
INSERT INTO poblacions VALUES (38500, 'Güímar');
INSERT INTO poblacions VALUES (38530, 'Candelaria');
INSERT INTO poblacions VALUES (38550, 'Arafo');
INSERT INTO poblacions VALUES (38600, 'Granadilla de Abona');
INSERT INTO poblacions VALUES (38620, 'San Miguel de Abona');
INSERT INTO poblacions VALUES (38640, 'Arona');
INSERT INTO poblacions VALUES (38680, 'Guía de Isora');
INSERT INTO poblacions VALUES (38700, 'Santa Cruz de la Palma');
INSERT INTO poblacions VALUES (38710, 'Breña Alta');
INSERT INTO poblacions VALUES (38712, 'Breña Baja');
INSERT INTO poblacions VALUES (38715, 'Puntallana');
INSERT INTO poblacions VALUES (38720, 'San Andrés y Sauces');
INSERT INTO poblacions VALUES (38726, 'Barlovento');
INSERT INTO poblacions VALUES (38730, 'Villa de Mazo');
INSERT INTO poblacions VALUES (38750, 'El Paso');
INSERT INTO poblacions VALUES (38760, 'Los Llanos de Aridane');
INSERT INTO poblacions VALUES (38770, 'Tazacorte');
INSERT INTO poblacions VALUES (38780, 'Tijarafe');
INSERT INTO poblacions VALUES (38789, 'Puntagorda');
INSERT INTO poblacions VALUES (38820, 'Hermigua');
INSERT INTO poblacions VALUES (38830, 'Agulo');
INSERT INTO poblacions VALUES (38840, 'Vallehermoso');
INSERT INTO poblacions VALUES (38870, 'Valle Gran Rey');
INSERT INTO poblacions VALUES (38900, 'Valverde');
INSERT INTO poblacions VALUES (38911, 'Frontera');
INSERT INTO poblacions VALUES (39000, 'Santander');
INSERT INTO poblacions VALUES (39200, 'Reinosa');
INSERT INTO poblacions VALUES (39300, 'Torrelavega');
INSERT INTO poblacions VALUES (39400, 'Los Corrales de Buelna');
INSERT INTO poblacions VALUES (39470, 'Piélagos');
INSERT INTO poblacions VALUES (39500, 'Cabezón de la Sal');
INSERT INTO poblacions VALUES (39509, 'Camargo');
INSERT INTO poblacions VALUES (39538, 'Reocín');
INSERT INTO poblacions VALUES (39577, 'Vega de Liébana');
INSERT INTO poblacions VALUES (39610, 'El Astillero');
INSERT INTO poblacions VALUES (39619, 'Medio Cudeyo');
INSERT INTO poblacions VALUES (39694, 'Santa María de Cayón');
INSERT INTO poblacions VALUES (39700, 'Castro-Urdiales');
INSERT INTO poblacions VALUES (39738, 'Solórzano');
INSERT INTO poblacions VALUES (39740, 'Santoña');
INSERT INTO poblacions VALUES (39770, 'Laredo');
INSERT INTO poblacions VALUES (40000, 'Segovia');
INSERT INTO poblacions VALUES (40150, 'Villacastín');
INSERT INTO poblacions VALUES (40194, 'Palazuelos de Eresma');
INSERT INTO poblacions VALUES (40196, 'La Lastrilla');
INSERT INTO poblacions VALUES (40200, 'Cuéllar');
INSERT INTO poblacions VALUES (40250, 'Mozoncillo');
INSERT INTO poblacions VALUES (40360, 'Cantimpalos');
INSERT INTO poblacions VALUES (40370, 'Turégano');
INSERT INTO poblacions VALUES (40400, 'El Espinar');
INSERT INTO poblacions VALUES (40470, 'Navas de Oro');
INSERT INTO poblacions VALUES (40480, 'Coca');
INSERT INTO poblacions VALUES (40520, 'Ayllón');
INSERT INTO poblacions VALUES (41100, 'Coria del Río');
INSERT INTO poblacions VALUES (41110, 'Bollullos de la Mitación');
INSERT INTO poblacions VALUES (41111, 'Almensilla');
INSERT INTO poblacions VALUES (41130, 'La Puebla del Río');
INSERT INTO poblacions VALUES (41140, 'Villafranco del Guadalquivir');
INSERT INTO poblacions VALUES (41210, 'Guillena');
INSERT INTO poblacions VALUES (41220, 'Burguillos');
INSERT INTO poblacions VALUES (41240, 'Almadén de la Plata');
INSERT INTO poblacions VALUES (41250, 'El Real de la Jara');
INSERT INTO poblacions VALUES (41309, 'La Rinconada');
INSERT INTO poblacions VALUES (41310, 'Brenes');
INSERT INTO poblacions VALUES (41318, 'Villaverde del Río');
INSERT INTO poblacions VALUES (41320, 'Cantillana');
INSERT INTO poblacions VALUES (41340, 'Tocina');
INSERT INTO poblacions VALUES (41360, 'El Pedroso');
INSERT INTO poblacions VALUES (41370, 'Cazalla de la Sierra');
INSERT INTO poblacions VALUES (41380, 'Alanís');
INSERT INTO poblacions VALUES (41388, 'San Nicolás del Puerto');
INSERT INTO poblacions VALUES (41390, 'Guadalcanal');
INSERT INTO poblacions VALUES (41400, 'Écija');
INSERT INTO poblacions VALUES (41420, 'Fuentes de Andalucía');
INSERT INTO poblacions VALUES (41429, 'La Campana');
INSERT INTO poblacions VALUES (41430, 'La Luisiana');
INSERT INTO poblacions VALUES (41440, 'Lora del Río');
INSERT INTO poblacions VALUES (41449, 'Alcolea del Río');
INSERT INTO poblacions VALUES (41450, 'Constantina');
INSERT INTO poblacions VALUES (41470, 'Peñaflor');
INSERT INTO poblacions VALUES (41479, 'La Puebla de los Infantes');
INSERT INTO poblacions VALUES (41500, 'Alcalá de Guadaira');
INSERT INTO poblacions VALUES (41510, 'Mairena del Alcor');
INSERT INTO poblacions VALUES (41520, 'El Viso del Alcor');
INSERT INTO poblacions VALUES (41530, 'Morón de la Frontera');
INSERT INTO poblacions VALUES (41540, 'La Puebla de Cazalla');
INSERT INTO poblacions VALUES (41550, 'Aguadulce');
INSERT INTO poblacions VALUES (41560, 'Estepa');
INSERT INTO poblacions VALUES (41564, 'Lora de Estepa');
INSERT INTO poblacions VALUES (41566, 'Pedrera');
INSERT INTO poblacions VALUES (41567, 'Herrera');
INSERT INTO poblacions VALUES (41568, 'El Rubio');
INSERT INTO poblacions VALUES (41569, 'Marinaleda');
INSERT INTO poblacions VALUES (41570, 'Badolatosa');
INSERT INTO poblacions VALUES (41580, 'Casariche');
INSERT INTO poblacions VALUES (41600, 'Arahal');
INSERT INTO poblacions VALUES (41610, 'Paradas');
INSERT INTO poblacions VALUES (41620, 'Marchena');
INSERT INTO poblacions VALUES (41630, 'La Lantejuela');
INSERT INTO poblacions VALUES (41650, 'El Saucejo');
INSERT INTO poblacions VALUES (41657, 'Los Corrales');
INSERT INTO poblacions VALUES (41660, 'Villanueva de San Juan');
INSERT INTO poblacions VALUES (41670, 'Pruna');
INSERT INTO poblacions VALUES (41700, 'Dos Hermanas');
INSERT INTO poblacions VALUES (41710, 'Utrera');
INSERT INTO poblacions VALUES (41749, 'El Cuervo de Sevilla');
INSERT INTO poblacions VALUES (41750, 'Los Molares');
INSERT INTO poblacions VALUES (41760, 'El Coronil');
INSERT INTO poblacions VALUES (41780, 'Coripe');
INSERT INTO poblacions VALUES (41800, 'Sanlúcar la Mayor');
INSERT INTO poblacions VALUES (41804, 'Olivares');
INSERT INTO poblacions VALUES (41805, 'Benacazón');
INSERT INTO poblacions VALUES (41807, 'Espartinas');
INSERT INTO poblacions VALUES (41808, 'Villanueva del Ariscal');
INSERT INTO poblacions VALUES (41809, 'Albaida del Aljarafe');
INSERT INTO poblacions VALUES (41810, 'Castilleja del Campo');
INSERT INTO poblacions VALUES (41820, 'Carrión de los Céspedes');
INSERT INTO poblacions VALUES (41830, 'Huévar');
INSERT INTO poblacions VALUES (41850, 'Villamanrique de la Condesa');
INSERT INTO poblacions VALUES (41880, 'El Ronquillo');
INSERT INTO poblacions VALUES (41888, 'El Garrobo');
INSERT INTO poblacions VALUES (41890, 'El Castillo de las Guardas');
INSERT INTO poblacions VALUES (41897, 'El Madroño');
INSERT INTO poblacions VALUES (41900, 'Camas');
INSERT INTO poblacions VALUES (41908, 'Castilleja de Guzmán');
INSERT INTO poblacions VALUES (41920, 'San Juan de Aznalfarache');
INSERT INTO poblacions VALUES (41927, 'Mairena del Aljarafe');
INSERT INTO poblacions VALUES (41930, 'Bormujos');
INSERT INTO poblacions VALUES (41940, 'Tomares');
INSERT INTO poblacions VALUES (41960, 'Gines');
INSERT INTO poblacions VALUES (41970, 'Santiponce');
INSERT INTO poblacions VALUES (41980, 'La Algaba');
INSERT INTO poblacions VALUES (42000, 'Soria');
INSERT INTO poblacions VALUES (42100, 'Ágreda');
INSERT INTO poblacions VALUES (42110, 'Ólvega');
INSERT INTO poblacions VALUES (42140, 'San Leonardo de Yagüe');
INSERT INTO poblacions VALUES (42157, 'Covaleda');
INSERT INTO poblacions VALUES (42200, 'Almazán');
INSERT INTO poblacions VALUES (42250, 'Arcos de Jalón');
INSERT INTO poblacions VALUES (42300, 'Burgo de Osma-Ciudad de Osma');
INSERT INTO poblacions VALUES (42330, 'San Esteban de Gormaz');
INSERT INTO poblacions VALUES (42360, 'Berlanga de Duero');
INSERT INTO poblacions VALUES (43000, 'Tarragona');
INSERT INTO poblacions VALUES (43120, 'Constantí');
INSERT INTO poblacions VALUES (43140, 'La Pobla de Mafumet');
INSERT INTO poblacions VALUES (43144, 'Vallmoll');
INSERT INTO poblacions VALUES (43151, 'Els Pallaresos');
INSERT INTO poblacions VALUES (43200, 'Reus');
INSERT INTO poblacions VALUES (43300, 'Mont-roig del Camp');
INSERT INTO poblacions VALUES (43340, 'Montbrió del Camp');
INSERT INTO poblacions VALUES (43350, 'Les Borges del Camp');
INSERT INTO poblacions VALUES (43390, 'Riudecols');
INSERT INTO poblacions VALUES (43392, 'Castellvell del Camp');
INSERT INTO poblacions VALUES (43400, 'Montblanc');
INSERT INTO poblacions VALUES (43420, 'Santa Coloma de Queralt');
INSERT INTO poblacions VALUES (43424, 'Sarral');
INSERT INTO poblacions VALUES (43430, 'Vimbodí');
INSERT INTO poblacions VALUES (43460, 'Alcover');
INSERT INTO poblacions VALUES (43470, 'La Selva del Camp');
INSERT INTO poblacions VALUES (43480, 'Vila-seca');
INSERT INTO poblacions VALUES (43500, 'Tortosa');
INSERT INTO poblacions VALUES (43519, 'El Perelló');
INSERT INTO poblacions VALUES (43520, 'Roquetes');
INSERT INTO poblacions VALUES (43530, 'Alcanar');
INSERT INTO poblacions VALUES (43540, 'Sant Carles de la Ràpita');
INSERT INTO poblacions VALUES (43550, 'Ulldecona');
INSERT INTO poblacions VALUES (43560, 'La Sénia');
INSERT INTO poblacions VALUES (43570, 'Santa Bàrbara');
INSERT INTO poblacions VALUES (43580, 'Deltebre');
INSERT INTO poblacions VALUES (43596, 'Horta de Sant Joan');
INSERT INTO poblacions VALUES (43700, 'El Vendrell');
INSERT INTO poblacions VALUES (43710, 'Santa Oliva');
INSERT INTO poblacions VALUES (43711, 'Banyeres del Penedès');
INSERT INTO poblacions VALUES (43712, 'Llorenç del Penedès');
INSERT INTO poblacions VALUES (43713, 'Sant Jaume dels Domenys');
INSERT INTO poblacions VALUES (43716, 'Albinyana');
INSERT INTO poblacions VALUES (43719, 'Bellvei');
INSERT INTO poblacions VALUES (43720, 'L'' Arboç');
INSERT INTO poblacions VALUES (43730, 'Falset');
INSERT INTO poblacions VALUES (43740, 'Móra d''Ebre');
INSERT INTO poblacions VALUES (43746, 'Tivissa');
INSERT INTO poblacions VALUES (43747, 'Benissanet');
INSERT INTO poblacions VALUES (43765, 'La Secuita');
INSERT INTO poblacions VALUES (43770, 'Móra la Nova');
INSERT INTO poblacions VALUES (43780, 'Gandesa');
INSERT INTO poblacions VALUES (43781, 'La Fatarella');
INSERT INTO poblacions VALUES (43784, 'Corbera d''Ebre');
INSERT INTO poblacions VALUES (43786, 'Batea');
INSERT INTO poblacions VALUES (43790, 'Riba-roja d''Ebre');
INSERT INTO poblacions VALUES (43791, 'Ascó');
INSERT INTO poblacions VALUES (43814, 'Vila-rodona');
INSERT INTO poblacions VALUES (43820, 'Calafell');
INSERT INTO poblacions VALUES (43830, 'Torredembarra');
INSERT INTO poblacions VALUES (43838, 'Creixell');
INSERT INTO poblacions VALUES (43840, 'Salou');
INSERT INTO poblacions VALUES (43850, 'Cambrils');
INSERT INTO poblacions VALUES (43881, 'Cunit');
INSERT INTO poblacions VALUES (43883, 'Roda de Barà');
INSERT INTO poblacions VALUES (43890, 'Vandellòs i l''Hospitalet de l''Infant');
INSERT INTO poblacions VALUES (43894, 'Camarles');
INSERT INTO poblacions VALUES (43895, 'L'' Ampolla');
INSERT INTO poblacions VALUES (43896, 'L'' Aldea');
INSERT INTO poblacions VALUES (44100, 'Albarracín');
INSERT INTO poblacions VALUES (44200, 'Calamocha');
INSERT INTO poblacions VALUES (44300, 'Monreal del Campo');
INSERT INTO poblacions VALUES (44360, 'Santa Eulalia');
INSERT INTO poblacions VALUES (44370, 'Cella');
INSERT INTO poblacions VALUES (44380, 'Villarquemado');
INSERT INTO poblacions VALUES (44400, 'Mora de Rubielos');
INSERT INTO poblacions VALUES (44500, 'Andorra');
INSERT INTO poblacions VALUES (44510, 'La Puebla de Híjar');
INSERT INTO poblacions VALUES (44520, 'Samper de Calanda');
INSERT INTO poblacions VALUES (44530, 'Híjar');
INSERT INTO poblacions VALUES (44540, 'Albalate del Arzobispo');
INSERT INTO poblacions VALUES (44550, 'Alcorisa');
INSERT INTO poblacions VALUES (44600, 'Alcañiz');
INSERT INTO poblacions VALUES (44610, 'Calaceite');
INSERT INTO poblacions VALUES (44700, 'Montalbán');
INSERT INTO poblacions VALUES (44760, 'Utrillas');
INSERT INTO poblacions VALUES (44770, 'Escucha');
INSERT INTO poblacions VALUES (45000, 'Toledo');
INSERT INTO poblacions VALUES (45100, 'Sonseca');
INSERT INTO poblacions VALUES (45300, 'Ocaña');
INSERT INTO poblacions VALUES (45470, 'Los Yébenes');
INSERT INTO poblacions VALUES (45500, 'Torrijos');
INSERT INTO poblacions VALUES (45510, 'Fuensalida');
INSERT INTO poblacions VALUES (45516, 'La Puebla de Montalbán');
INSERT INTO poblacions VALUES (45593, 'Bargas');
INSERT INTO poblacions VALUES (45600, 'Talavera de la Reina');
INSERT INTO poblacions VALUES (45700, 'Consuegra');
INSERT INTO poblacions VALUES (45710, 'Madridejos');
INSERT INTO poblacions VALUES (45730, 'Villafranca de los Caballeros');
INSERT INTO poblacions VALUES (45800, 'Quintanar de la Orden');
INSERT INTO poblacions VALUES (45840, 'La Puebla de Almoradiel');
INSERT INTO poblacions VALUES (45860, 'Villacañas');
INSERT INTO poblacions VALUES (45880, 'Corral de Almaguer');
INSERT INTO poblacions VALUES (46000, 'Valencia');
INSERT INTO poblacions VALUES (46110, 'Godella');
INSERT INTO poblacions VALUES (46117, 'Bétera');
INSERT INTO poblacions VALUES (46120, 'Alboraya');
INSERT INTO poblacions VALUES (46132, 'Almàssera');
INSERT INTO poblacions VALUES (46133, 'Meliana');
INSERT INTO poblacions VALUES (46134, 'Foios');
INSERT INTO poblacions VALUES (46137, 'la Pobla de Farnals');
INSERT INTO poblacions VALUES (46160, 'Llíria');
INSERT INTO poblacions VALUES (46180, 'Benaguasil');
INSERT INTO poblacions VALUES (46185, 'la Pobla de Vallbona');
INSERT INTO poblacions VALUES (46191, 'Vilamarxant');
INSERT INTO poblacions VALUES (46200, 'Paiporta');
INSERT INTO poblacions VALUES (46210, 'Picanya');
INSERT INTO poblacions VALUES (46230, 'Alginet');
INSERT INTO poblacions VALUES (46240, 'Carlet');
INSERT INTO poblacions VALUES (46250, 'l'' Alcúdia');
INSERT INTO poblacions VALUES (46260, 'Alberic');
INSERT INTO poblacions VALUES (46270, 'Castelló de la Ribera');
INSERT INTO poblacions VALUES (46290, 'Alcácer');
INSERT INTO poblacions VALUES (46300, 'Utiel');
INSERT INTO poblacions VALUES (46340, 'Requena');
INSERT INTO poblacions VALUES (46360, 'Buñol');
INSERT INTO poblacions VALUES (46370, 'Chiva');
INSERT INTO poblacions VALUES (46380, 'Cheste');
INSERT INTO poblacions VALUES (46400, 'Cullera');
INSERT INTO poblacions VALUES (46410, 'Sueca');
INSERT INTO poblacions VALUES (46440, 'Almussafes');
INSERT INTO poblacions VALUES (46450, 'Benifaió');
INSERT INTO poblacions VALUES (46460, 'Silla');
INSERT INTO poblacions VALUES (46470, 'Albal');
INSERT INTO poblacions VALUES (46470, 'Catarroja');
INSERT INTO poblacions VALUES (46470, 'Massanassa');
INSERT INTO poblacions VALUES (46530, 'Puçol');
INSERT INTO poblacions VALUES (46540, 'Puig');
INSERT INTO poblacions VALUES (46610, 'Guadassuar');
INSERT INTO poblacions VALUES (46620, 'Ayora');
INSERT INTO poblacions VALUES (46650, 'Canals');
INSERT INTO poblacions VALUES (46700, 'Gandia');
INSERT INTO poblacions VALUES (46740, 'Carcaixent');
INSERT INTO poblacions VALUES (46760, 'Tavernes de la Valldigna');
INSERT INTO poblacions VALUES (46780, 'Oliva');
INSERT INTO poblacions VALUES (46800, 'Xàtiva');
INSERT INTO poblacions VALUES (46830, 'Benigánim');
INSERT INTO poblacions VALUES (46841, 'Castelló de Rugat');
INSERT INTO poblacions VALUES (46850, 'l'' Olleria');
INSERT INTO poblacions VALUES (46860, 'Albaida');
INSERT INTO poblacions VALUES (46900, 'Torrent');
INSERT INTO poblacions VALUES (46910, 'Alfafar');
INSERT INTO poblacions VALUES (46910, 'Benetússer');
INSERT INTO poblacions VALUES (46910, 'Sedaví');
INSERT INTO poblacions VALUES (46920, 'Mislata');
INSERT INTO poblacions VALUES (46930, 'Quart de Poblet');
INSERT INTO poblacions VALUES (46940, 'Manises');
INSERT INTO poblacions VALUES (46960, 'Aldaia');
INSERT INTO poblacions VALUES (46970, 'Alaquàs');
INSERT INTO poblacions VALUES (46980, 'Paterna');
INSERT INTO poblacions VALUES (47100, 'Tordesillas');
INSERT INTO poblacions VALUES (47140, 'Laguna de Duero');
INSERT INTO poblacions VALUES (47150, 'Viana de Cega');
INSERT INTO poblacions VALUES (47151, 'Boecillo');
INSERT INTO poblacions VALUES (47155, 'Santovenia de Pisuerga');
INSERT INTO poblacions VALUES (47162, 'Aldeamayor de San Martín');
INSERT INTO poblacions VALUES (47193, 'Cistérniga');
INSERT INTO poblacions VALUES (47195, 'Arroyo de la Encomienda');
INSERT INTO poblacions VALUES (47196, 'La Pedraja de Portillo');
INSERT INTO poblacions VALUES (47230, 'Matapozuelos');
INSERT INTO poblacions VALUES (47240, 'Valdestillas');
INSERT INTO poblacions VALUES (47250, 'Mojados');
INSERT INTO poblacions VALUES (47260, 'Cabezón de Pisuerga');
INSERT INTO poblacions VALUES (47270, 'Cigales');
INSERT INTO poblacions VALUES (47310, 'Campaspero');
INSERT INTO poblacions VALUES (47320, 'Montemayor de Pililla');
INSERT INTO poblacions VALUES (47320, 'Tudela de Duero');
INSERT INTO poblacions VALUES (47410, 'Olmedo');
INSERT INTO poblacions VALUES (47420, 'Íscar');
INSERT INTO poblacions VALUES (47430, 'Pedrajas de San Esteban');
INSERT INTO poblacions VALUES (47490, 'Rueda');
INSERT INTO poblacions VALUES (47491, 'La Seca');
INSERT INTO poblacions VALUES (47500, 'Nava del Rey');
INSERT INTO poblacions VALUES (47510, 'Alaejos');
INSERT INTO poblacions VALUES (47600, 'Villalón de Campos');
INSERT INTO poblacions VALUES (47610, 'Zaratán');
INSERT INTO poblacions VALUES (47680, 'Mayorga');
INSERT INTO poblacions VALUES (48000, 'Bilbao');
INSERT INTO poblacions VALUES (48100, 'Mungia');
INSERT INTO poblacions VALUES (48111, 'Laukiz');
INSERT INTO poblacions VALUES (48112, 'Maruri-Jatabe');
INSERT INTO poblacions VALUES (48114, 'Arrieta');
INSERT INTO poblacions VALUES (48116, 'Fruiz');
INSERT INTO poblacions VALUES (48120, 'Meñaka');
INSERT INTO poblacions VALUES (48140, 'Arantzazu');
INSERT INTO poblacions VALUES (48140, 'Igorre');
INSERT INTO poblacions VALUES (48141, 'Dima');
INSERT INTO poblacions VALUES (48142, 'Artea');
INSERT INTO poblacions VALUES (48143, 'Areatza');
INSERT INTO poblacions VALUES (48144, 'Zeanuri');
INSERT INTO poblacions VALUES (48145, 'Ubide');
INSERT INTO poblacions VALUES (48150, 'Sondika');
INSERT INTO poblacions VALUES (48160, 'Derio');
INSERT INTO poblacions VALUES (48170, 'Zamudio');
INSERT INTO poblacions VALUES (48190, 'Sopuerta');
INSERT INTO poblacions VALUES (48191, 'Galdames');
INSERT INTO poblacions VALUES (48191, 'Garay');
INSERT INTO poblacions VALUES (48195, 'Larrabetzu');
INSERT INTO poblacions VALUES (48196, 'Lezama');
INSERT INTO poblacions VALUES (48210, 'Otxandio');
INSERT INTO poblacions VALUES (48212, 'Mañaria');
INSERT INTO poblacions VALUES (48213, 'Izurtza');
INSERT INTO poblacions VALUES (48215, 'Iurreta');
INSERT INTO poblacions VALUES (48220, 'Abadiño');
INSERT INTO poblacions VALUES (48230, 'Elorrio');
INSERT INTO poblacions VALUES (48240, 'Berriz');
INSERT INTO poblacions VALUES (48250, 'Zaldibar');
INSERT INTO poblacions VALUES (48260, 'Ermua');
INSERT INTO poblacions VALUES (48269, 'Mallabia');
INSERT INTO poblacions VALUES (48270, 'Markina-Xemein');
INSERT INTO poblacions VALUES (48287, 'Ea');
INSERT INTO poblacions VALUES (48289, 'Guizaburuaga');
INSERT INTO poblacions VALUES (48289, 'Mendexa');
INSERT INTO poblacions VALUES (48292, 'Atxondo');
INSERT INTO poblacions VALUES (48309, 'Errigoiti');
INSERT INTO poblacions VALUES (48310, 'Elantxobe');
INSERT INTO poblacions VALUES (48311, 'Ibarrangelu');
INSERT INTO poblacions VALUES (48313, 'Ereño');
INSERT INTO poblacions VALUES (48314, 'Gautegiz Arteaga');
INSERT INTO poblacions VALUES (48320, 'Ajangiz');
INSERT INTO poblacions VALUES (48330, 'Lemoa');
INSERT INTO poblacions VALUES (48350, 'Busturia');
INSERT INTO poblacions VALUES (48360, 'Mundaka');
INSERT INTO poblacions VALUES (48370, 'Bermeo');
INSERT INTO poblacions VALUES (48381, 'Munitibar-Arbatzegi Gerrikaitz');
INSERT INTO poblacions VALUES (48382, 'Mendata');
INSERT INTO poblacions VALUES (48383, 'Arratzu');
INSERT INTO poblacions VALUES (48390, 'Bedia');
INSERT INTO poblacions VALUES (48392, 'Muxika');
INSERT INTO poblacions VALUES (48395, 'Sukarrieta');
INSERT INTO poblacions VALUES (48480, 'Arrigorriaga');
INSERT INTO poblacions VALUES (48480, 'Zaratamo');
INSERT INTO poblacions VALUES (48498, 'Arakaldo');
INSERT INTO poblacions VALUES (48498, 'Arrankudiaga');
INSERT INTO poblacions VALUES (48508, 'Zierbena');
INSERT INTO poblacions VALUES (48510, 'Valle de Trápaga-Trapagaran');
INSERT INTO poblacions VALUES (48530, 'Ortuella');
INSERT INTO poblacions VALUES (48600, 'Sopelana');
INSERT INTO poblacions VALUES (48610, 'Urduliz');
INSERT INTO poblacions VALUES (48620, 'Lemoiz');
INSERT INTO poblacions VALUES (48620, 'Plentzia');
INSERT INTO poblacions VALUES (48630, 'Gorliz');
INSERT INTO poblacions VALUES (48640, 'Berango');
INSERT INTO poblacions VALUES (48710, 'Berriatua');
INSERT INTO poblacions VALUES (48810, 'Alonsotegi');
INSERT INTO poblacions VALUES (48840, 'Güeñes');
INSERT INTO poblacions VALUES (48879, 'Arcentales');
INSERT INTO poblacions VALUES (48880, 'Trucios-Turtzioz');
INSERT INTO poblacions VALUES (48891, 'Carranza');
INSERT INTO poblacions VALUES (48891, 'Lanestosa');
INSERT INTO poblacions VALUES (48900, 'Barakaldo');
INSERT INTO poblacions VALUES (48910, 'Sestao');
INSERT INTO poblacions VALUES (48920, 'Portugalete');
INSERT INTO poblacions VALUES (48950, 'Erandio');
INSERT INTO poblacions VALUES (48970, 'Basauri');
INSERT INTO poblacions VALUES (48980, 'Santurtzi');
INSERT INTO poblacions VALUES (48990, 'Getxo');
INSERT INTO poblacions VALUES (49000, 'Zamora');
INSERT INTO poblacions VALUES (49100, 'Villanueva del Campo');
INSERT INTO poblacions VALUES (49150, 'Moraleja del Vino');
INSERT INTO poblacions VALUES (49200, 'Bermillo de Sayago');
INSERT INTO poblacions VALUES (49400, 'Fuentesaúco');
INSERT INTO poblacions VALUES (49510, 'Fonfría');
INSERT INTO poblacions VALUES (49530, 'Coreses');
INSERT INTO poblacions VALUES (49591, 'Riofrío de Aliste');
INSERT INTO poblacions VALUES (49600, 'Benavente');
INSERT INTO poblacions VALUES (49610, 'Santibáñez de Vidriales');
INSERT INTO poblacions VALUES (49620, 'Santa Cristina de la Polvorosa');
INSERT INTO poblacions VALUES (49622, 'Quiruelas de Vidriales');
INSERT INTO poblacions VALUES (49690, 'San Cristóbal de Entreviñas');
INSERT INTO poblacions VALUES (49700, 'Corrales');
INSERT INTO poblacions VALUES (49820, 'Villabuena del Puente');
INSERT INTO poblacions VALUES (50000, 'Zaragoza');
INSERT INTO poblacions VALUES (50100, 'La Almunia de Doña Godina');
INSERT INTO poblacions VALUES (50160, 'Leciñena');
INSERT INTO poblacions VALUES (50170, 'Mequinenza');
INSERT INTO poblacions VALUES (50171, 'La Puebla de Alfindén');
INSERT INTO poblacions VALUES (50172, 'Alfajarín');
INSERT INTO poblacions VALUES (50177, 'Bujaraloz');
INSERT INTO poblacions VALUES (50180, 'Utebo');
INSERT INTO poblacions VALUES (50220, 'Ariza');
INSERT INTO poblacions VALUES (50230, 'Alhama de Aragón');
INSERT INTO poblacions VALUES (50246, 'Brea de Aragón');
INSERT INTO poblacions VALUES (50260, 'Morata de Jalón');
INSERT INTO poblacions VALUES (50270, 'Ricla');
INSERT INTO poblacions VALUES (50280, 'Calatorao');
INSERT INTO poblacions VALUES (50290, 'Épila');
INSERT INTO poblacions VALUES (50298, 'Pinseque');
INSERT INTO poblacions VALUES (50300, 'Calatayud');
INSERT INTO poblacions VALUES (50340, 'Maluenda');
INSERT INTO poblacions VALUES (50360, 'Daroca');
INSERT INTO poblacions VALUES (50400, 'Cariñena');
INSERT INTO poblacions VALUES (50410, 'Cuarte de Huerva');
INSERT INTO poblacions VALUES (50420, 'Cadrete');
INSERT INTO poblacions VALUES (50461, 'Alfamén');
INSERT INTO poblacions VALUES (50500, 'Tarazona');
INSERT INTO poblacions VALUES (50520, 'Magallón');
INSERT INTO poblacions VALUES (50540, 'Borja');
INSERT INTO poblacions VALUES (50550, 'Mallén');
INSERT INTO poblacions VALUES (50630, 'Alagón');
INSERT INTO poblacions VALUES (50637, 'Remolinos');
INSERT INTO poblacions VALUES (50640, 'Luceni');
INSERT INTO poblacions VALUES (50641, 'Boquiñeni');
INSERT INTO poblacions VALUES (50650, 'Gallur');
INSERT INTO poblacions VALUES (50670, 'Sádaba');
INSERT INTO poblacions VALUES (50690, 'Pedrola');
INSERT INTO poblacions VALUES (50693, 'Torres de Berrellén');
INSERT INTO poblacions VALUES (50695, 'Biota');
INSERT INTO poblacions VALUES (50710, 'Maella');
INSERT INTO poblacions VALUES (50730, 'El Burgo de Ebro');
INSERT INTO poblacions VALUES (50740, 'Fuentes de Ebro');
INSERT INTO poblacions VALUES (50750, 'Pina de Ebro');
INSERT INTO poblacions VALUES (50770, 'QuINTO');
INSERT INTO poblacions VALUES (50780, 'Sástago');
INSERT INTO poblacions VALUES (50786, 'Gelsa');
INSERT INTO poblacions VALUES (50793, 'Fabara');
INSERT INTO poblacions VALUES (50794, 'Nonaspe');
INSERT INTO poblacions VALUES (50830, 'Villanueva de Gállego');
INSERT INTO poblacions VALUES (50840, 'San Mateo de Gállego');
INSERT INTO poblacions VALUES (52000, 'Melilla');



INSERT INTO usuaris VALUES (1, 'Maya', 'Cotto Brito', 'D', '39 Extramuros', 28491, 'Maya.Cotto.Brito@spambob.com', '02/04/51', 74, 3);
INSERT INTO usuaris VALUES (2, 'Escolástico', 'Barraza Baez', 'H', '48 Ctra. de la Puerta', 27250, 'Escolastico.Barraza.Baez@dodgit.com', '05/11/50', 13, 11);
INSERT INTO usuaris VALUES (3, 'Marcial', 'Ocampo Cordova', 'H', '72 Avda. Rio Nalon', 33535, 'Marcial.Ocampo.Cordova@mailinator.com', '01/10/74', 43, 8);
INSERT INTO usuaris VALUES (4, 'Natalio', 'Galindo Valdivia', 'H', '57 El Roqueo', 17230, 'Natalio.Galindo.Valdivia@pookmail.com', '08/03/84', 24, 6);
INSERT INTO usuaris VALUES (5, 'Sharif', 'Dávila Alaniz', 'H', '56 Plaza Colón', 25700, 'Sharif.Davila.Alaniz@dodgit.com', '13/03/44', 92, 4);
INSERT INTO usuaris VALUES (6, 'Publia', 'Guerrero Aparicio', 'D', '42 C/ Cuevas de Ambrosio', 24100, 'Publia.Guerrero.Aparicio@trashymail.com', '09/08/65', 72, NULL);
INSERT INTO usuaris VALUES (7, 'Cuyén', 'Rosas Díaz', 'H', '8 C/ Angosto', 23440, 'Cuyen.Rosas.Diaz@trashymail.com', '08/05/80', 27, 2);
INSERT INTO usuaris VALUES (8, 'Thalia', 'Romero Ramón', NULL, '2 Boriñaur enparantza', 7430, 'Thalia.Romero.Ramon@dodgit.com', '20/06/43', 55, 1);
INSERT INTO usuaris VALUES (9, 'Selena', 'Vergara Espinal', 'D', '27 C/ Cañada del Rosal', 21668, 'Selena.Vergara.Espinal@spambob.com', '17/02/72', 82, 5);
INSERT INTO usuaris VALUES (10, 'Ruth', 'Muro Quezada', 'D', '85 Outid de Arriba', 43460, 'Ruth.Muro.Quezada@pookmail.com', '16/07/81', 8, 10);
INSERT INTO usuaris VALUES (11, 'Palixena', 'Olivo Cedillo', 'D', '77 Carretera Cádiz-Málaga', 20850, 'Palixena.Olivo.Cedillo@pookmail.com', '10/06/82', 89, NULL);
INSERT INTO usuaris VALUES (12, 'Hamanchay', 'Castro Sierra', 'D', '48 Cañadilla', 21810, 'Hamanchay.Castro.Sierra@trashymail.com', '24/07/60', 22, 7);
INSERT INTO usuaris VALUES (13, 'Doria', 'Herrera Olivera', 'D', '71 C/ Cuevas de Ambrosio', 23740, 'Doria.Herrera.Olivera@pookmail.com', '09/09/73', 58, 12);
INSERT INTO usuaris VALUES (14, 'Julieta', 'Rosario Zepeda', 'D', '29 Rúa do Paseo', 41900, 'Julieta.Rosario.Zepeda@trashymail.com', '02/03/56', 45, 12);
INSERT INTO usuaris VALUES (15, 'Husai', 'Vera Cárdenas', 'H', '98 Enxertos', 37511, 'Husai.Vera.Cardenas@spambob.com', '18/01/84', 95, 11);
INSERT INTO usuaris VALUES (16, 'Kemberley', 'Baca Otero', 'D', '24 Avda. Alameda Sundheim', 22550, 'Kemberley.Baca.Otero@spambob.com', '10/02/43', 16, 7);
INSERT INTO usuaris VALUES (17, 'Leonid', 'Lucio Ozuna', 'H', '85 Cruce Casa de Postas', 18260, 'Leonid.Lucio.Ozuna@pookmail.com', '13/08/63', 22, 12);
INSERT INTO usuaris VALUES (18, 'Verbena', 'Pichardo Narváez', 'D', '78 Camiño Ancho', 37779, 'Verbena.Pichardo.Narvaez@spambob.com', '18/01/40', 56, 8);
INSERT INTO usuaris VALUES (19, 'Deyanira', 'Lugo Rendón', NULL, '33 C/ Fernández de Leceta', 3509, 'Deyanira.Lugo.Rendon@trashymail.com', '17/06/85', 60, 11);
INSERT INTO usuaris VALUES (20, 'Desdémona', 'Alemán Ríos', 'D', '87 Pl. Virgen Blanca', 8630, 'Desdemona.Aleman.Rios@dodgit.com', '01/04/44', 27, 11);
INSERT INTO usuaris VALUES (21, 'Jonas', 'Saldana Apodaca', 'H', '79 Estrela', 39619, 'Jonas.Saldana.Apodaca@spambob.com', '25/04/63', 16, 1);
INSERT INTO usuaris VALUES (22, 'Sunta', 'Contreras Curiel', 'D', '25 Cádiz', 18450, 'Sunta.Contreras.Curiel@mailinator.com', '21/09/55', 49, 8);
INSERT INTO usuaris VALUES (23, 'Ireneo', 'Romero Polanco', 'H', '72 C/ Los Herrán', 6490, 'Ireneo.Romero.Polanco@mailinator.com', '11/05/80', 43, 8);
INSERT INTO usuaris VALUES (24, 'Rauel', 'Montero Godoy', 'H', '78 Plaza Colón', 25280, 'Rauel.Montero.Godoy@mailinator.com', '24/12/67', 70, 8);
INSERT INTO usuaris VALUES (25, 'Indalecia', 'Villanueva Garay', 'D', '70 Avda. Enrique Peinador', 37170, 'Indalecia.Villanueva.Garay@mailinator.com', '11/08/53', 5, 5);
INSERT INTO usuaris VALUES (26, 'Mia', 'Tejada Zarate', 'D', '82 Rio Segura', 31500, 'Mia.Tejada.Zarate@mailinator.com', '04/08/54', 37, 4);
INSERT INTO usuaris VALUES (27, 'Cleodora', 'Hinojosa Velázquez', 'D', '64 Avda. Rio Nalon', 33500, 'Cleodora.Hinojosa.Velazquez@mailinator.com', '14/05/69', 55, 2);
INSERT INTO usuaris VALUES (28, 'Madison', 'Briones Guzmán', 'H', '55 C/ Angosto', 23528, 'Madison.Briones.Guzman@dodgit.com', '01/11/63', 39, 10);
INSERT INTO usuaris VALUES (29, 'Elvisa', 'Rentería Mascarenas', 'D', '92 C/ Pablo Iglesias', 26330, 'Elvisa.Renteria.Mascarenas@mailinator.com', '18/06/83', 53, 5);
INSERT INTO usuaris VALUES (30, 'Grato', 'Perales Matías', 'H', '64 C/ Eras', 28752, 'Grato.Perales.Matias@trashymail.com', '18/07/78', 4, 12);
INSERT INTO usuaris VALUES (31, 'Eugen', 'Garay Alva', 'H', '56 Reyes Católicos', 9260, 'Eugen.Garay.Alva@dodgit.com', '13/06/85', 10, 4);
INSERT INTO usuaris VALUES (32, 'Petrus', 'Avilés Duran', 'H', '22 Urzáiz', 44610, 'Petrus.Aviles.Duran@dodgit.com', '01/01/53', 35, 10);
INSERT INTO usuaris VALUES (33, 'Cosimus', 'Madera Colunga', 'H', '86 Avda. de Andalucía', 29340, 'Cosimus.Madera.Colunga@trashymail.com', '23/07/60', 70, 7);
INSERT INTO usuaris VALUES (34, 'Deolinda', 'Quiñónez Varela', 'D', '94 Paseo Junquera', 12450, 'Deolinda.Quinonez.Varela@trashymail.com', '24/03/77', 76, 4);
INSERT INTO usuaris VALUES (35, 'Errolán', 'Herrera Muñiz', 'H', '96 Apartado de Correos', 37429, 'Errolan.Herrera.Muniz@dodgit.com', '10/08/73', 28, 4);
INSERT INTO usuaris VALUES (36, 'Ascensión', 'Ojeda Morales', 'D', '24 Ventanilla de Beas', 28140, 'Ascension.Ojeda.Morales@spambob.com', '30/05/85', 35, 3);
INSERT INTO usuaris VALUES (37, 'Eleonora', 'Gurule Arredondo', 'D', '55 Avda. Rio Nalon', 33440, 'Eleonora.Gurule.Arredondo@spambob.com', '17/09/82', 60, NULL);
INSERT INTO usuaris VALUES (38, 'Thelma', 'Calderón Portillo', 'D', '36 Calle Carril de la Fuente', 13250, 'Thelma.Calderon.Portillo@mailinator.com', '01/03/76', 71, 8);
INSERT INTO usuaris VALUES (39, 'Clarabella', 'Delgadillo Díaz', 'D', '37 Boriñaur enparantza', 7580, 'Clarabella.Delgadillo.Diaz@dodgit.com', '23/02/52', 31, 6);
INSERT INTO usuaris VALUES (40, 'Erminia', 'Alemán Casas', 'D', '41 Bouciña', 43830, 'Erminia.Aleman.Casas@dodgit.com', '09/04/48', 55, 10);
INSERT INTO usuaris VALUES (41, 'Obdulio', 'Ledesma Baeza', 'H', '45 C/ Cuevas de Ambrosio', 24193, 'Obdulio.Ledesma.Baeza@trashymail.com', '11/12/57', 19, 3);
INSERT INTO usuaris VALUES (42, 'Ampelio', 'Guerrero Galindo', 'H', '87 Boriñaur enparantza', 7700, 'Ampelio.Guerrero.Galindo@pookmail.com', '19/03/84', 78, 1);
INSERT INTO usuaris VALUES (43, 'Eudoxia', 'Duarte Olmos', 'D', '63 Carretera', 14857, 'Eudoxia.Duarte.Olmos@pookmail.com', '25/01/58', 32, 1);
INSERT INTO usuaris VALUES (44, 'Gabino', 'Espinosa Arévalo', 'H', '86 Calle Proc. San Sebastián', 13100, 'Gabino.Espinosa.Arevalo@mailinator.com', '04/09/77', 26, NULL);
INSERT INTO usuaris VALUES (45, 'Aladino', 'Pizarro Vasquez', 'H', '81 Avda. Enrique Peinador', 37175, 'Aladino.Pizarro.Vasquez@dodgit.com', '07/03/53', 36, 1);
INSERT INTO usuaris VALUES (46, 'Fedro', 'Valenzuela Miranda', 'H', '87 Avda. Enrique Peinador', 37184, 'Fedro.Valenzuela.Miranda@mailinator.com', '11/12/61', 80, 8);
INSERT INTO usuaris VALUES (47, 'Ludwiq', 'Domínquez Tamayo', 'H', '75 Boriñaur enparantza', 7550, 'Ludwiq.Dominquez.Tamayo@mailinator.com', '28/10/63', 11, 3);
INSERT INTO usuaris VALUES (48, 'Querían', 'Pichardo Gil', 'H', '31 Cañadilla', 22300, 'Querian.Pichardo.Gil@dodgit.com', '27/05/68', 35, 1);
INSERT INTO usuaris VALUES (49, 'Cloe', 'Muñoz Granado', 'D', '1 Enxertos', 37512, 'Cloe.Munoz.Granado@pookmail.com', '29/11/79', 95, NULL);
INSERT INTO usuaris VALUES (50, 'Jana', 'Palomo Laboy', 'D', '16 C/ Cañada del Rosal', 21550, 'Jana.Palomo.Laboy@pookmail.com', '16/06/59', 17, 1);
INSERT INTO usuaris VALUES (51, 'Dionisia', 'Collado Magana', 'D', '76 C/ Canarias', 20100, 'Dionisia.Collado.Magana@pookmail.com', '18/06/68', 90, 1);
INSERT INTO usuaris VALUES (52, 'Saba', 'Zapata Cedillo', 'D', '18 Enxertos', 37524, 'Saba.Zapata.Cedillo@mailinator.com', '12/11/50', 68, 3);
INSERT INTO usuaris VALUES (53, 'Kyra', 'Sauceda Corrales', 'D', '27 San Andrés', 37271, 'Kyra.Sauceda.Corrales@pookmail.com', NULL, 64, 3);
INSERT INTO usuaris VALUES (54, 'Donna', 'Ávila Aguirre', 'D', '15 Rio Segura', 31390, 'Donna.Avila.Aguirre@trashymail.com', '04/05/71', 84, 9);
INSERT INTO usuaris VALUES (55, 'Isabelle', 'Orellana Urías', 'D', '67 Puerto Lugar', 29717, 'Isabelle.Orellana.Urias@pookmail.com', '16/12/46', 13, 1);
INSERT INTO usuaris VALUES (56, 'Jacqueline', 'Venegas Luján', NULL, '63 Carretera', 14550, 'Jacqueline.Venegas.Lujan@spambob.com', '05/12/40', 66, 8);
INSERT INTO usuaris VALUES (57, 'Elvisa', 'Alva Villa', 'D', '40 C/ Los Herrán', 6460, 'Elvisa.Alva.Villa@dodgit.com', '27/07/82', 15, 7);
INSERT INTO usuaris VALUES (58, 'Zaida', 'Badillo Montano', 'D', '13 Avda. de la Estación', 28660, 'Zaida.Badillo.Montano@dodgit.com', '24/11/61', 71, 2);
INSERT INTO usuaris VALUES (59, 'Querubina', 'Cepeda Mata', 'D', '42 Ourense', 43392, 'Querubina.Cepeda.Mata@spambob.com', '07/05/84', 76, 10);
INSERT INTO usuaris VALUES (60, 'Catrin', 'Centeno Maya', 'D', '22 Puerta Nueva', 36000, 'Catrin.Centeno.Maya@trashymail.com', '11/09/46', 63, 9);
INSERT INTO usuaris VALUES (61, 'Dorina', 'Carrión Saenz', 'D', '59 Eusebio Dávila', 41550, 'Dorina.Carrion.Saenz@pookmail.com', '28/11/76', 17, 12);
INSERT INTO usuaris VALUES (62, 'Joscio', 'Carranza Apodaca', 'H', '43 C/ Rosa de los Vientos', 11630, 'Joscio.Carranza.Apodaca@pookmail.com', '15/09/75', 24, 1);
INSERT INTO usuaris VALUES (63, 'Ulrico', 'Padrón Llarnas', 'H', '14 Ctra. Villena', 33900, 'Ulrico.Padron.Llarnas@spambob.com', '24/01/85', 89, 4);
INSERT INTO usuaris VALUES (64, 'Leylen', 'Mota Menchaca', 'D', '35 Comandante Izarduy', 8920, 'Leylen.Mota.Menchaca@dodgit.com', '14/05/72', 66, 4);
INSERT INTO usuaris VALUES (65, 'Osmundo', 'Covas Carranza', 'H', '76 C/ Cuevas de Ambrosio', 23670, 'Osmundo.Covas.Carranza@pookmail.com', '10/05/75', 50, 7);
INSERT INTO usuaris VALUES (66, 'Raynaldo', 'Viera Navarro', 'H', '24 Caño', 32911, 'Raynaldo.Viera.Navarro@pookmail.com', '14/12/48', 25, 7);
INSERT INTO usuaris VALUES (67, 'Amelio', 'Soto Solís', 'H', '19 Constitución', 36968, 'Amelio.Soto.Solis@mailinator.com', '19/03/45', 52, 7);
INSERT INTO usuaris VALUES (68, 'Alueche', 'Hidalgo Samaniego', 'D', '21 C/ Amoladera', 28816, 'Alueche.Hidalgo.Samaniego@trashymail.com', '04/01/49', 33, 1);
INSERT INTO usuaris VALUES (69, 'Calixta', 'Sandoval Loera', 'D', '7 Ventanilla de Beas', 28140, 'Calixta.Sandoval.Loera@dodgit.com', '16/07/75', 93, 7);
INSERT INTO usuaris VALUES (70, 'Clemencia', 'Candelaria Luna', 'D', '33 Ctra. de Siles', 27670, 'Clemencia.Candelaria.Luna@trashymail.com', '20/05/79', 96, 2);
INSERT INTO usuaris VALUES (71, 'Huilen', 'Concepción Leiva', 'D', '63 Calvo Sotelo', 47420, 'Huilen.Concepcion.Leiva@mailinator.com', NULL, 99, 5);
INSERT INTO usuaris VALUES (72, 'Sora', 'Otero Ríos', 'D', '38 C/ Los Herrán', 6360, 'Sora.Otero.Rios@pookmail.com', '20/11/67', 9, 12);
INSERT INTO usuaris VALUES (73, 'Raymi', 'Cedillo Munguia', 'H', '83 Ctra. de la Puerta', 26586, 'Raymi.Cedillo.Munguia@pookmail.com', '30/12/81', 11, 3);
INSERT INTO usuaris VALUES (74, 'Mijal', 'Ochoa Rentería', 'D', '10 C/ Libertad', 4880, 'Mijal.Ochoa.Renteria@trashymail.com', '15/07/65', 63, 7);
INSERT INTO usuaris VALUES (75, 'Betania', 'Cordero Ybarra', 'D', '26 Calle Carril de la Fuente', 13190, 'Betania.Cordero.Ybarra@trashymail.com', '04/12/42', 13, 7);
INSERT INTO usuaris VALUES (76, 'Arcángela', 'Lebrón Tovar', 'D', '68 Celso Emilio Ferreiro', 50400, 'Arcangela.Lebron.Tovar@mailinator.com', '22/02/55', 18, 10);
INSERT INTO usuaris VALUES (77, 'Ordoño', 'Figueroa Varela', 'H', '47 Carretera', 14740, 'Ordono.Figueroa.Varela@pookmail.com', '01/08/80', 11, 8);
INSERT INTO usuaris VALUES (78, 'Wenzel', 'Jaramillo Lara', 'H', '29 Enxertos', 37542, 'Wenzel.Jaramillo.Lara@dodgit.com', '26/04/45', 52, 12);
INSERT INTO usuaris VALUES (79, 'Daila', 'Mayonga Gaona', 'D', '18 José matía', 2130, 'Daila.Mayonga.Gaona@trashymail.com', '04/05/71', 78, 4);
INSERT INTO usuaris VALUES (80, 'Deidamia', 'Amaya Figueroa', 'D', '19 Socampo', 37623, 'Deidamia.Amaya.Figueroa@dodgit.com', '17/01/46', 36, 6);
INSERT INTO usuaris VALUES (81, 'Giorgio', 'Nevarez Negrete', 'H', '88 Camiño Real', 48508, 'Giorgio.Nevarez.Negrete@dodgit.com', '26/05/70', 0, 8);
INSERT INTO usuaris VALUES (82, 'Libia', 'Peres Grijalva', 'D', '61 Outid de Arriba', 43424, 'Libia.Peres.Grijalva@pookmail.com', '28/12/47', 56, 9);
INSERT INTO usuaris VALUES (83, 'Pelagio', 'Bonilla Vasquez', 'H', '17 Eusebio Dávila', 41310, 'Pelagio.Bonilla.Vasquez@spambob.com', '15/03/76', 24, 4);
INSERT INTO usuaris VALUES (84, 'Harry', 'Yáñez Laboy', 'H', '19 Ourense', 42000, 'Harry.Yanez.Laboy@trashymail.com', '03/07/73', 55, NULL);
INSERT INTO usuaris VALUES (85, 'Aglae', 'Vergara Carreón', NULL, '56 Cruce Casa de Postas', 18400, 'Aglae.Vergara.Carreon@trashymail.com', '02/02/83', 12, NULL);
INSERT INTO usuaris VALUES (86, 'Malva', 'Cortés Alanis', 'D', '7 Boriñaur enparantza', 7460, 'Malva.Cortes.Alanis@spambob.com', '07/03/79', 99, 11);
INSERT INTO usuaris VALUES (87, 'Velasco', 'Jiménez Urrútia', 'H', '98 Padre Caro', 13679, 'Velasco.Jimenez.Urrutia@trashymail.com', '15/04/84', 13, 4);
INSERT INTO usuaris VALUES (88, 'Bartolomé', 'Gurule Flórez', 'H', '20 Plazuela do Porto', 38400, 'Bartolome.Gurule.Florez@dodgit.com', '24/02/77', 81, 9);
INSERT INTO usuaris VALUES (89, 'Fucsia', 'Villalpando Ferrer', 'D', '71 Apartado de Correos', 37439, 'Fucsia.Villalpando.Ferrer@trashymail.com', '30/04/63', 94, 7);
INSERT INTO usuaris VALUES (90, 'Florida', 'Arreola Carmona', 'D', '77 Rúa do Paseo', 41850, 'Florida.Arreola.Carmona@trashymail.com', '08/03/78', 90, 9);
INSERT INTO usuaris VALUES (91, 'Licinio', 'Reyes Mateo', 'H', '21 Ctra. Beas-Cortijos Nuevos', 26511, 'Licinio.Reyes.Mateo@spambob.com', '22/02/62', 36, 2);
INSERT INTO usuaris VALUES (92, 'Cyrille', 'Escalante Arriaga', 'H', '3 Avda. Alameda Sundheim', 22530, 'Cyrille.Escalante.Arriaga@pookmail.com', '10/09/80', 8, 11);
INSERT INTO usuaris VALUES (93, 'Diva', 'Flores Collado', 'D', '48 Rúa do Paseo', 41807, 'Diva.Flores.Collado@trashymail.com', '08/11/55', 81, 6);
INSERT INTO usuaris VALUES (94, 'Christian', 'Ramón Cadena', 'H', '10 Estrela', 38820, 'Christian.Ramon.Cadena@dodgit.com', '11/02/51', 59, 2);
INSERT INTO usuaris VALUES (95, 'Eduarda', 'Casas Abrego', 'D', '3 C/ Pablo Iglesias', 26315, 'Eduarda.Casas.Abrego@pookmail.com', '04/07/71', 4, 8);
INSERT INTO usuaris VALUES (96, 'Henrey', 'Vega Salcido', 'H', '76 Extramuros', 28430, 'Henrey.Vega.Salcido@spambob.com', '08/01/78', 52, 12);
INSERT INTO usuaris VALUES (97, 'Adaluz', 'Holguín Lerma', 'D', '31 Ctra. Bailén-Motril', 23200, 'Adaluz.Holguin.Lerma@spambob.com', '26/10/43', 26, 7);
INSERT INTO usuaris VALUES (98, 'Gerald', 'Alanis Rael', 'H', '21 Boriñaur enparantza', 7440, 'Gerald.Alanis.Rael@spambob.com', '09/07/43', 39, 4);
INSERT INTO usuaris VALUES (99, 'Mildreda', 'Abrego Casárez', 'D', '34 Avda. de Andalucía', 29300, 'Mildreda.Abrego.Casarez@trashymail.com', '10/07/82', 29, 3);
INSERT INTO usuaris VALUES (100, 'Alvina', 'Armenta Ruiz', 'D', '60 Rúa do Paseo', 41940, 'Alvina.Armenta.Ruiz@trashymail.com', '07/08/58', 17, 7);
INSERT INTO usuaris VALUES (101, 'Iva', 'Flórez Sanabria', 'D', '70 C/ Amoladera', 28890, 'Iva.Florez.Sanabria@mailinator.com', '16/02/45', 27, 2);
INSERT INTO usuaris VALUES (102, 'Ammia', 'Núñez Barajas', 'D', '4 Avda. Enrique Peinador', 37183, 'Ammia.Nunez.Barajas@spambob.com', '03/08/48', 64, 5);
INSERT INTO usuaris VALUES (103, 'Prudenciano', 'Sevilla Toro', 'H', '69 José matía', 2120, 'Prudenciano.Sevilla.Toro@pookmail.com', '03/10/59', 77, 10);
INSERT INTO usuaris VALUES (104, 'Androcles', 'Serna Flores', 'H', '9 Atamaria', 36636, 'Androcles.Serna.Flores@pookmail.com', '02/11/82', 52, 2);
INSERT INTO usuaris VALUES (105, 'Absalón', 'Armenta Montalvo', 'H', '9 Pza. Fuensanta', 32431, 'Absalon.Armenta.Montalvo@trashymail.com', '14/02/67', 8, 1);
INSERT INTO usuaris VALUES (106, 'Doménica', 'Trejo Robles', 'D', '38 Fuente del Gallo', 15113, 'Domenica.Trejo.Robles@trashymail.com', '11/03/67', 34, 4);
INSERT INTO usuaris VALUES (107, 'Adelino', 'Cantú Armas', 'H', '96 Avda. de Andalucía', 29460, 'Adelino.Cantu.Armas@pookmail.com', '16/01/70', 48, 4);
INSERT INTO usuaris VALUES (108, 'Justiniano', 'Orellana Paez', 'H', '32 Castelao', 48900, 'Justiniano.Orellana.Paez@pookmail.com', '20/09/71', 19, 4);
INSERT INTO usuaris VALUES (109, 'Torcuato', 'Ulloa Ramírez', 'H', '65 Avda. Andalucía', 26133, 'Torcuato.Ulloa.Ramirez@mailinator.com', '06/10/79', 36, 11);
INSERT INTO usuaris VALUES (110, 'Folco', 'Rico Murillo', 'H', '9 C/ Amoladera', 28792, 'Folco.Rico.Murillo@spambob.com', '22/09/73', 43, 3);
INSERT INTO usuaris VALUES (111, 'Edilma', 'Espinoza Mata', 'D', '87 Cádiz', 18449, 'Edilma.Espinoza.Mata@trashymail.com', '07/05/47', 98, 1);
INSERT INTO usuaris VALUES (112, 'Remedios', 'Pulido Acevedo', 'D', '22 Cádiz', 18516, 'Remedios.Pulido.Acevedo@dodgit.com', '17/08/58', 35, NULL);
INSERT INTO usuaris VALUES (113, 'Xochilt', 'Gómez Ulibarri', 'D', '56 Alvaro Cunqueiro', 41110, 'Xochilt.Gomez.Ulibarri@trashymail.com', '13/02/68', 57, 9);
INSERT INTO usuaris VALUES (114, 'Laureano', 'Acosta Camacho', 'H', '38 Carretera del Muelle', 12413, 'Laureano.Acosta.Camacho@trashymail.com', '24/10/42', 88, 5);
INSERT INTO usuaris VALUES (115, 'Maximilian', 'Sepúlveda Velez', 'H', '72 Valadouro', 48210, 'Maximilian.Sepulveda.Velez@dodgit.com', '19/07/80', 87, 10);
INSERT INTO usuaris VALUES (116, 'Ermelinda', 'Olivo Lucero', 'D', '26 Ctra. Hornos', 26216, 'Ermelinda.Olivo.Lucero@pookmail.com', '07/09/52', 56, 4);
INSERT INTO usuaris VALUES (117, 'Ignacio', 'González Contreras', 'H', '39 Alvaro Cunqueiro', 41140, 'Ignacio.Gonzalez.Contreras@trashymail.com', '22/05/51', 91, 1);
INSERT INTO usuaris VALUES (118, 'Jemina', 'Raya Mercado', 'D', '15 La Fontanilla', 14240, 'Jemina.Raya.Mercado@dodgit.com', '25/09/60', 38, 9);
INSERT INTO usuaris VALUES (119, 'Severo', 'Murillo Salcedo', 'H', '31 Enxertos', 37511, 'Severo.Murillo.Salcedo@spambob.com', '22/01/78', 43, 12);
INSERT INTO usuaris VALUES (120, 'Shirley', 'Pabón Collazo', 'D', '94 Cercas Bajas', 8170, 'Shirley.Pabon.Collazo@dodgit.com', '22/01/69', 19, 4);
INSERT INTO usuaris VALUES (121, 'Iciar', 'Puente Bernal', 'D', '14 Maestro Puig Valera', 33735, 'Iciar.Puente.Bernal@dodgit.com', '26/08/64', 83, 5);
INSERT INTO usuaris VALUES (122, 'Policarpo', 'Jaimes Domínguez', 'H', '28 Cádiz', 18452, 'Policarpo.Jaimes.Dominguez@dodgit.com', '19/12/50', 34, 12);
INSERT INTO usuaris VALUES (123, 'Caitán', 'Alejandro Alonso', 'H', '56 Carretera del Muelle', 12410, 'Caitan.Alejandro.Alonso@trashymail.com', '01/09/58', 0, 11);
INSERT INTO usuaris VALUES (124, 'Lior', 'Miramontes Domínquez', 'H', '8 Bellavista', 49620, 'Lior.Miramontes.Dominquez@trashymail.com', '27/05/80', 30, 9);
INSERT INTO usuaris VALUES (125, 'Saskia', 'Palacios Medrano', 'D', '10 Cañadilla', 21668, 'Saskia.Palacios.Medrano@trashymail.com', '18/06/74', 98, 4);
INSERT INTO usuaris VALUES (126, 'Virgil', 'Arteaga Cotto', 'H', '8 Puerto Lugar', 29788, 'Virgil.Arteaga.Cotto@mailinator.com', '13/10/63', 47, 8);
INSERT INTO usuaris VALUES (127, 'Honorina', 'Orta Frías', 'D', '66 Pza. Fuensanta', 32234, 'Honorina.Orta.Frias@pookmail.com', '03/11/54', 90, 1);
INSERT INTO usuaris VALUES (128, 'Solón', 'Aguayo Gastelum', NULL, '6 Carretera', 14520, 'Solon.Aguayo.Gastelum@trashymail.com', '07/11/44', 58, 5);
INSERT INTO usuaris VALUES (129, 'Hullen', 'Huerta Atencio', 'H', '8 C/ Fernández de Leceta', 3410, 'Hullen.Huerta.Atencio@dodgit.com', '19/01/67', 97, 10);
INSERT INTO usuaris VALUES (130, 'Athina', 'Espinosa Zambrano', 'D', '79 C/ Benito Guinea', 8400, 'Athina.Espinosa.Zambrano@spambob.com', '03/05/61', 39, 6);
INSERT INTO usuaris VALUES (131, 'Lihuel', 'Aparicio Urbina', 'H', '99 Canónigo Valiño', 46650, 'Lihuel.Aparicio.Urbina@mailinator.com', '17/04/51', 47, 3);
INSERT INTO usuaris VALUES (132, 'Baal', 'Puente Mireles', 'H', '82 Avda. de Andalucía', 29197, 'Baal.Puente.Mireles@spambob.com', '08/08/65', 19, 5);
INSERT INTO usuaris VALUES (133, 'Paine', 'Zarate Contreras', 'D', '92 Rio Segura', 31320, 'Paine.Zarate.Contreras@mailinator.com', '20/02/55', 35, 1);
INSERT INTO usuaris VALUES (134, 'Amaru', 'Godoy Rentería', 'H', '21 Avendaño', 4500, 'Amaru.Godoy.Renteria@pookmail.com', '03/08/53', 66, 5);
INSERT INTO usuaris VALUES (135, 'Cesáreo', 'Duarte Irizarry', 'H', '9 C/ Cuevas de Ambrosio', 23711, 'Cesareo.Duarte.Irizarry@pookmail.com', '15/03/63', 23, 4);
INSERT INTO usuaris VALUES (136, 'Rosenda', 'Gamez Jurado', 'D', '17 Cercas Bajas', 8170, 'Rosenda.Gamez.Jurado@pookmail.com', '13/05/76', 80, 11);
INSERT INTO usuaris VALUES (137, 'Bricio', 'Árias Santana', 'H', '68 Calle Carril de la Fuente', 13193, 'Bricio.Arias.Santana@mailinator.com', '06/05/82', 86, 12);
INSERT INTO usuaris VALUES (138, 'Simón', 'Zarate Olmos', 'H', '36 Avda. Generalísimo', 31830, 'Simon.Zarate.Olmos@dodgit.com', '03/11/77', 34, 10);
INSERT INTO usuaris VALUES (139, 'Merlino', 'Romo Castro', 'H', '12 Plaza de España', 15624, 'Merlino.Romo.Castro@spambob.com', '11/08/71', 61, 12);
INSERT INTO usuaris VALUES (140, 'Herodes', 'Brito Badillo', 'H', '3 Crta. Cádiz-Málaga', 12170, 'Herodes.Brito.Badillo@spambob.com', '08/10/85', 41, 10);
INSERT INTO usuaris VALUES (141, 'Emily', 'Jimínez Muñoz', 'D', '82 C/ Eras', 28737, 'Emily.Jiminez.Munoz@pookmail.com', '24/01/46', 57, 7);
INSERT INTO usuaris VALUES (142, 'Edelira', 'Lovato Mares', 'D', '81 El Roqueo', 17220, 'Edelira.Lovato.Mares@trashymail.com', '29/08/69', 99, 8);
INSERT INTO usuaris VALUES (143, 'Nereo', 'Lucio Nevarez', 'H', '48 Celso Emilio Ferreiro', 50340, 'Nereo.Lucio.Nevarez@dodgit.com', '18/03/42', 92, 12);
INSERT INTO usuaris VALUES (144, 'Tabaré', 'Gaytan Longoria', 'H', '84 Rosa de los Vientos', 13333, 'Tabare.Gaytan.Longoria@spambob.com', '09/05/59', 62, NULL);
INSERT INTO usuaris VALUES (145, 'Digna', 'Espinosa Rolón', NULL, '60 Escuadro', 46830, 'Digna.Espinosa.Rolon@pookmail.com', '05/02/78', NULL, 1);
INSERT INTO usuaris VALUES (146, 'Seaghdha', 'Miramontes Prado', 'H', '35 Bouciña', 43780, 'Seaghdha.Miramontes.Prado@spambob.com', '20/02/69', 2, 6);
INSERT INTO usuaris VALUES (147, 'Rafa', 'Sotelo Barragán', 'H', '88 La Fontanilla', 14230, 'Rafa.Sotelo.Barragan@pookmail.com', '08/03/74', 70, 1);
INSERT INTO usuaris VALUES (148, 'Fiorella', 'Ávila Callas', 'D', '50 Avda. Rio Nalon', 33550, 'Fiorella.Avila.Callas@mailinator.com', '22/11/41', 52, 9);
INSERT INTO usuaris VALUES (149, 'Wenzel', 'Rivas Lovato', 'H', '18 Pascual Yunquera', 18820, 'Wenzel.Rivas.Lovato@dodgit.com', '25/03/68', 98, 3);
INSERT INTO usuaris VALUES (150, 'Fernán', 'Zamudio Sanabria', 'H', '18 Camiño Ancho', 37770, 'Fernan.Zamudio.Sanabria@mailinator.com', '05/06/73', 89, 2);
INSERT INTO usuaris VALUES (151, 'Verenice', 'Barrera Ceja', 'D', '27 Atamaria', 36530, 'Verenice.Barrera.Ceja@dodgit.com', '09/02/47', 38, 12);
INSERT INTO usuaris VALUES (152, 'Hortensio', 'Peres Roque', 'H', '27 C/ Pablo Iglesias', 26321, 'Hortensio.Peres.Roque@trashymail.com', '18/02/68', 28, 7);
INSERT INTO usuaris VALUES (153, 'Simón', 'Garibay Ortiz', 'H', '72 Pza. Fuensanta', 32170, 'Simon.Garibay.Ortiz@spambob.com', '18/01/64', 43, 6);
INSERT INTO usuaris VALUES (154, 'Orangel', 'Acosta Hidalgo', 'H', '69 Inglaterra', 18563, 'Orangel.Acosta.Hidalgo@spambob.com', '05/05/44', 90, NULL);
INSERT INTO usuaris VALUES (155, 'Sulamita', 'Anaya Alcalá', 'D', '24 Maestro Puig Valera', 33774, 'Sulamita.Anaya.Alcala@pookmail.com', '10/01/68', 29, 8);
INSERT INTO usuaris VALUES (156, 'Demian', 'Canales Caballero', 'H', '11 Rua da Rapina', 37494, 'Demian.Canales.Caballero@mailinator.com', '13/05/40', 92, 9);
INSERT INTO usuaris VALUES (157, 'Donosa', 'Briones Pabón', NULL, '90 Ctra. Beas-Cortijos Nuevos', 26376, 'Donosa.Briones.Pabon@spambob.com', '31/10/70', 36, 12);
INSERT INTO usuaris VALUES (158, 'Kapriel', 'Lozada García', 'D', '44 Plaza Maior', 37215, 'Kapriel.Lozada.Garcia@mailinator.com', '30/10/67', 52, 10);
INSERT INTO usuaris VALUES (159, 'Rosalie', 'Toledo Solano', 'D', '76 Rúa do Paseo', 41809, 'Rosalie.Toledo.Solano@dodgit.com', '13/10/84', 92, 10);
INSERT INTO usuaris VALUES (160, 'Bixintxo', 'Elizondo Rivera', 'H', '86 Antonio Vázquez', 38780, 'Bixintxo.Elizondo.Rivera@pookmail.com', '30/03/65', 92, 6);
INSERT INTO usuaris VALUES (161, 'Hervé', 'Salcedo Peres', 'H', '92 Plaza Maior', 37214, 'Herve.Salcedo.Peres@spambob.com', '14/01/69', NULL, 7);
INSERT INTO usuaris VALUES (162, 'Odina', 'Robledo Roque', 'D', '18 C/ Benito Guinea', 8397, 'Odina.Robledo.Roque@pookmail.com', '31/03/48', 84, 6);
INSERT INTO usuaris VALUES (163, 'Alano', 'Naranjo Sauceda', 'H', '85 Bellavista', 50230, 'Alano.Naranjo.Sauceda@trashymail.com', '20/07/69', 96, NULL);
INSERT INTO usuaris VALUES (164, 'Gilda', 'Valdez Saenz', 'D', '33 Salzillo', 32540, 'Gilda.Valdez.Saenz@trashymail.com', '02/07/60', 50, 9);
INSERT INTO usuaris VALUES (165, 'Elpidio', 'Loera Valdez', 'H', '14 Camiño Real', 48370, 'Elpidio.Loera.Valdez@spambob.com', '19/11/54', 73, 4);
INSERT INTO usuaris VALUES (166, 'Fermina', 'Pabón Olvera', 'D', '85 Alvaro Cunqueiro', 40200, 'Fermina.Pabon.Olvera@trashymail.com', '08/08/74', 39, 1);
INSERT INTO usuaris VALUES (167, 'Lion', 'Cabrera Valverde', 'H', '78 Ctra. Bailén-Motril', 23240, 'Lion.Cabrera.Valverde@dodgit.com', '04/02/59', 6, 3);
INSERT INTO usuaris VALUES (168, 'Claudina', 'Guajardo Samaniego', 'D', '3 Calle Carril de la Fuente', 13195, 'Claudina.Guajardo.Samaniego@trashymail.com', '17/05/64', 39, NULL);
INSERT INTO usuaris VALUES (169, 'Melany', 'Abeyta Madrigal', 'D', '33 Enxertos', 37592, 'Melany.Abeyta.Madrigal@dodgit.com', '29/12/66', 36, 11);
INSERT INTO usuaris VALUES (170, 'Fortunata', 'Ceja Casárez', 'D', '42 Zumalakarregi etorbidea', 7200, 'Fortunata.Ceja.Casarez@spambob.com', '12/01/45', 36, 4);
INSERT INTO usuaris VALUES (171, 'Agnes', 'Tamayo Jáquez', 'D', '47 El Roqueo', 16660, 'Agnes.Tamayo.Jaquez@pookmail.com', '10/07/53', 85, 6);
INSERT INTO usuaris VALUES (172, 'Paulo', 'Aguilar Mascarenas', 'H', '6 José matía', 2154, 'Paulo.Aguilar.Mascarenas@spambob.com', '11/05/72', 48, 11);
INSERT INTO usuaris VALUES (173, 'Argenis', 'Aguilar Aranda', 'H', '63 Avda. Explanada Barnuevo', 35280, 'Argenis.Aguilar.Aranda@spambob.com', '15/06/80', 90, 6);
INSERT INTO usuaris VALUES (174, 'Fabricia', 'Aragón Alcaraz', 'D', '60 Avda. Generalísimo', 31820, 'Fabricia.Aragon.Alcaraz@pookmail.com', '02/12/59', 72, 6);
INSERT INTO usuaris VALUES (175, 'Xalome', 'Rivero Cotto', 'D', '53 Avda. Enrique Peinador', 37183, 'Xalome.Rivero.Cotto@dodgit.com', '13/04/46', 80, 1);
INSERT INTO usuaris VALUES (176, 'Colomba', 'Fernández Figueroa', 'D', '79 Reiseñor', 45860, 'Colomba.Fernandez.Figueroa@pookmail.com', '05/04/69', 78, NULL);
INSERT INTO usuaris VALUES (177, 'Aleydis', 'Menéndez Quintero', 'H', '33 Ctra. de Fuentenueva', 28214, 'Aleydis.Menendez.Quintero@dodgit.com', '02/12/46', 45, NULL);
INSERT INTO usuaris VALUES (178, 'Mariela', 'Munguia Peralta', 'D', '27 Puerta Nueva', 36416, 'Mariela.Munguia.Peralta@spambob.com', '10/10/58', 80, 4);
INSERT INTO usuaris VALUES (179, 'Benon', 'Jasso Cortés', 'H', '22 Avda. de Andalucía', 29327, 'Benon.Jasso.Cortes@mailinator.com', '13/06/48', 69, 6);
INSERT INTO usuaris VALUES (180, 'Ruth', 'Bernal Saenz', 'D', '34 Crta. Cádiz-Málaga', 12182, 'Ruth.Bernal.Saenz@trashymail.com', '01/07/53', 64, 10);
INSERT INTO usuaris VALUES (181, 'Llanos', 'Domínguez Curiel', 'H', '74 Avda. Enrique Peinador', 37170, 'Llanos.Dominguez.Curiel@spambob.com', '10/03/58', 84, 11);
INSERT INTO usuaris VALUES (182, 'Kussi', 'Villa Ortega', 'H', '71 Cádiz', 18500, 'Kussi.Villa.Ortega@trashymail.com', '30/10/66', 24, 6);
INSERT INTO usuaris VALUES (183, 'Alejandrina', 'Caraballo Castaneda', 'D', '56 Cartagena', 30565, 'Alejandrina.Caraballo.Castaneda@dodgit.com', '29/05/42', 89, 7);
INSERT INTO usuaris VALUES (184, 'Armida', 'Sarabia Collazo', 'D', '75 Avendaño', 4250, 'Armida.Sarabia.Collazo@spambob.com', '11/08/84', 39, 4);
INSERT INTO usuaris VALUES (185, 'Laban', 'Fierro Patino', 'H', '97 Valadouro', 48144, 'Laban.Fierro.Patino@dodgit.com', '26/06/65', 58, 1);
INSERT INTO usuaris VALUES (186, 'Atilio', 'Toledo Segovia', 'H', '18 Calle Carril de la Fuente', 13193, 'Atilio.Toledo.Segovia@dodgit.com', '05/02/52', 72, NULL);
INSERT INTO usuaris VALUES (187, 'Electra', 'Velez Ayala', 'D', '38 Ourense', 43140, 'Electra.Velez.Ayala@pookmail.com', '14/09/49', 89, 3);
INSERT INTO usuaris VALUES (188, 'Bab', 'Segura Godínez', 'D', '32 Rúa Olmos', 37406, 'Bab.Segura.Godinez@dodgit.com', '15/05/51', 63, 7);
INSERT INTO usuaris VALUES (189, 'Vincent', 'Villanueva Olivo', 'H', '90 Paseo Junquera', 12448, 'Vincent.Villanueva.Olivo@trashymail.com', '10/05/70', 45, 2);
INSERT INTO usuaris VALUES (190, 'Pánfilo', 'Santana Lovato', 'H', '60 Escuadro', 46910, 'Panfilo.Santana.Lovato@mailinator.com', '24/07/61', 40, 3);
INSERT INTO usuaris VALUES (191, 'Concordia', 'Ortiz Serrato', 'D', '81 Maestro Puig Valera', 33578, 'Concordia.Ortiz.Serrato@mailinator.com', '24/04/77', 59, 10);
INSERT INTO usuaris VALUES (192, 'Anna', 'Benavides Carrero', 'D', '55 Ctra. Bailén-Motril', 23300, 'Anna.Benavides.Carrero@dodgit.com', '29/12/69', 14, 5);
INSERT INTO usuaris VALUES (193, 'Lope', 'Galvez Gamboa', 'H', '6 Pascual Yunquera', 18690, 'Lope.Galvez.Gamboa@pookmail.com', '11/02/83', 71, 4);
INSERT INTO usuaris VALUES (194, 'Atala', 'Collazo Iglesias', 'D', '3 Plaza Colón', 26120, 'Atala.Collazo.Iglesias@pookmail.com', '19/09/79', 16, 6);
INSERT INTO usuaris VALUES (195, 'Amantzi', 'Castellanos Leiva', 'H', '92 C/ Fernández de Leceta', 3516, 'Amantzi.Castellanos.Leiva@dodgit.com', '28/08/75', 50, 8);
INSERT INTO usuaris VALUES (196, 'Atilano', 'Cuellar González', 'H', '99 C/ Cuevas de Ambrosio', 23750, 'Atilano.Cuellar.Gonzalez@pookmail.com', '05/02/62', 76, 11);
INSERT INTO usuaris VALUES (197, 'René', 'Ramos García', 'H', '44 Reiseñor', 46137, 'Rene.Ramos.Garcia@dodgit.com', '06/01/79', 35, 7);
INSERT INTO usuaris VALUES (198, 'Tubau', 'Magana Vera', 'H', '10 Rúa de San Pedro', 37797, 'Tubau.Magana.Vera@mailinator.com', '24/08/46', 97, 12);
INSERT INTO usuaris VALUES (199, 'Juliano', 'Sanabria Calderón', 'H', '90 Paseo Junquera', 12500, 'Juliano.Sanabria.Calderon@dodgit.com', '05/06/40', 57, 1);
INSERT INTO usuaris VALUES (200, 'Tzípora', 'Flórez Robles', 'D', '79 Ctra. de la Puerta', 27220, 'Tzipora.Florez.Robles@trashymail.com', '21/01/60', 40, 3);
INSERT INTO usuaris VALUES (201, 'Numeria', 'Perea Perales', 'D', '33 Inglaterra', 18650, 'Numeria.Perea.Perales@spambob.com', '01/06/60', 62, 7);
INSERT INTO usuaris VALUES (202, 'Evelia', 'Banda Vanegas', 'D', '94 C/ Amoladera', 28760, 'Evelia.Banda.Vanegas@mailinator.com', '23/02/72', 91, 1);
INSERT INTO usuaris VALUES (203, 'Bernabela', 'Sandoval Miramontes', 'D', '56 Antonio Vázquez', 38780, 'Bernabela.Sandoval.Miramontes@spambob.com', '31/01/71', 54, 1);
INSERT INTO usuaris VALUES (204, 'Maruja', 'Feliciano Partida', 'D', '19 Ctra. Bailén-Motril', 23260, 'Maruja.Feliciano.Partida@spambob.com', '02/09/83', 1, 4);
INSERT INTO usuaris VALUES (205, 'Aucan', 'Meza Escalante', 'D', '63 C/ Cuesta del  Álamo', 29611, 'Aucan.Meza.Escalante@mailinator.com', '10/12/55', 86, 2);
INSERT INTO usuaris VALUES (206, 'Aparicio', 'Arteaga Fuentes', 'H', '59 Cruce Casa de Postas', 18417, 'Aparicio.Arteaga.Fuentes@spambob.com', '29/11/46', 50, 11);
INSERT INTO usuaris VALUES (207, 'Silvano', 'Varela Alarcón', 'H', '5 Carretera', 14550, 'Silvano.Varela.Alarcon@pookmail.com', '02/12/83', 24, 10);
INSERT INTO usuaris VALUES (208, 'Conrad', 'Alarcón Banda', 'H', '20 Antonio Vázquez', 38789, 'Conrad.Alarcon.Banda@spambob.com', '09/09/41', 80, 4);
INSERT INTO usuaris VALUES (209, 'Clorindo', 'Tórrez Luján', 'H', '98 Extramuros', 28511, 'Clorindo.Torrez.Lujan@mailinator.com', '23/06/59', 15, 1);
INSERT INTO usuaris VALUES (210, 'Hobart', 'Almanza Garza', 'H', '55 Camiño Ancho', 37776, 'Hobart.Almanza.Garza@pookmail.com', '12/10/58', 83, 4);
INSERT INTO usuaris VALUES (211, 'Zofía', 'Velasco Alonzo', 'D', '69 Reyes Católicos', 10000, 'Zofia.Velasco.Alonzo@mailinator.com', '28/02/48', 72, 12);
INSERT INTO usuaris VALUES (212, 'Baldovino', 'Serrato Sanabria', 'H', '24 Zumalakarregi etorbidea', 7320, 'Baldovino.Serrato.Sanabria@spambob.com', '20/01/45', 15, 6);
INSERT INTO usuaris VALUES (213, 'Vito', 'Roque Hinojosa', 'H', '69 Ourense', 43120, 'Vito.Roque.Hinojosa@trashymail.com', '22/05/72', 2, 9);
INSERT INTO usuaris VALUES (214, 'Orquídea', 'Montano Gaitán', NULL, '8 Avendaño', 3829, 'Orquidea.Montano.Gaitan@dodgit.com', '07/12/82', 24, 4);
INSERT INTO usuaris VALUES (215, 'Elena', 'Dueñas Portillo', 'D', '7 Prolongacion San Sebastian', 21260, 'Elena.Duenas.Portillo@mailinator.com', '26/06/81', 67, 5);
INSERT INTO usuaris VALUES (216, 'Manzur', 'Puga Santana', 'H', '47 Reiseñor', 45710, 'Manzur.Puga.Santana@dodgit.com', '29/10/42', 15, 11);
INSERT INTO usuaris VALUES (217, 'Ales', 'Serna Cabán', 'H', '19 Avenida Cervantes', 48250, 'Ales.Serna.Caban@dodgit.com', '30/03/48', 71, 9);
INSERT INTO usuaris VALUES (218, 'Pelegrino', 'Perea Benavides', 'H', '5 Celso Emilio Ferreiro', 50500, 'Pelegrino.Perea.Benavides@spambob.com', '18/03/68', 71, 3);
INSERT INTO usuaris VALUES (219, 'Gatty', 'Salinas Ferrer', 'D', '68 Ctra. Bailén-Motril', 23311, 'Gatty.Salinas.Ferrer@trashymail.com', '26/07/41', 85, 1);
INSERT INTO usuaris VALUES (220, 'Kirios', 'Tafoya Cardona', 'H', '24 Ctra. Bailén-Motril', 23280, 'Kirios.Tafoya.Cardona@dodgit.com', '12/12/42', NULL, 9);
INSERT INTO usuaris VALUES (221, 'Azariel', 'Estévez Benavides', 'H', '71 C/ Eras', 28730, 'Azariel.Estevez.Benavides@pookmail.com', '22/09/65', 24, 4);
INSERT INTO usuaris VALUES (222, 'Martiniana', 'Aparicio Ceja', 'D', '38 Quevedo', 15360, 'Martiniana.Aparicio.Ceja@pookmail.com', '13/07/85', 95, 1);
INSERT INTO usuaris VALUES (223, 'Selim', 'Salazar Nava', 'H', '98 Cádiz', 18517, 'Selim.Salazar.Nava@mailinator.com', '17/01/70', 37, 3);
INSERT INTO usuaris VALUES (224, 'Uberto', 'Tamayo Escobedo', 'H', '95 Ventanilla de Beas', 27773, 'Uberto.Tamayo.Escobedo@pookmail.com', '19/01/73', 32, 9);
INSERT INTO usuaris VALUES (225, 'Nais', 'Tafoya Riojas', 'D', '93 Puerto Lugar', 29711, 'Nais.Tafoya.Riojas@trashymail.com', NULL, 21, 4);
INSERT INTO usuaris VALUES (226, 'Danel', 'Sotelo Tamayo', 'H', '1 C/ Andalucía', 4850, 'Danel.Sotelo.Tamayo@dodgit.com', '29/09/65', 17, 7);
INSERT INTO usuaris VALUES (227, 'Giulia', 'Espino Gómez', 'D', '53 Herrería', 18240, 'Giulia.Espino.Gomez@mailinator.com', '27/02/45', NULL, NULL);
INSERT INTO usuaris VALUES (228, 'Nahuel', 'Barrientos Zavala', 'H', '35 Comandante Izarduy', 9000, 'Nahuel.Barrientos.Zavala@spambob.com', '25/12/70', 38, 1);
INSERT INTO usuaris VALUES (229, 'Lelis', 'Comejo Rico', 'D', '29 Calvo Sotelo', 47320, 'Lelis.Comejo.Rico@mailinator.com', '26/01/57', 43, 8);
INSERT INTO usuaris VALUES (230, 'Sharif', 'Brito Carrera', 'H', '12 Rio Segura', 31523, 'Sharif.Brito.Carrera@mailinator.com', '24/02/81', 4, 3);
INSERT INTO usuaris VALUES (231, 'Orosco', 'Montés Muñoz', 'H', '15 Maestro Puig Valera', 33800, 'Orosco.Montes.Munoz@spambob.com', '29/08/67', 45, 3);
INSERT INTO usuaris VALUES (232, 'Ángela', 'Anguiano Luevano', 'D', '46 C/ Los Herrán', 6140, 'Angela.Anguiano.Luevano@spambob.com', '19/03/51', 95, 8);
INSERT INTO usuaris VALUES (233, 'Peñen', 'Cano Noriega', 'D', '12 Camiño Real', 48370, 'Penen.Cano.Noriega@mailinator.com', '05/04/64', 73, 5);
INSERT INTO usuaris VALUES (234, 'Custodio', 'Cuellar Villareal', 'H', '36 Rúa de San Pedro', 37797, 'Custodio.Cuellar.Villareal@trashymail.com', '23/12/46', 12, 11);
INSERT INTO usuaris VALUES (235, 'Benjamín', 'Galván Camarillo', 'H', '64 Reyes Católicos', 10400, 'Benjamin.Galvan.Camarillo@trashymail.com', '09/05/83', 64, NULL);
INSERT INTO usuaris VALUES (236, 'Favian', 'Carmona Rosado', 'H', '93 Plaza Colón', 25600, 'Favian.Carmona.Rosado@mailinator.com', '06/05/57', 99, 9);
INSERT INTO usuaris VALUES (237, 'Ettiene', 'Cuellar Almaraz', 'H', '93 C/ Pablo Iglesias', 26312, 'Ettiene.Cuellar.Almaraz@mailinator.com', '11/06/69', 39, NULL);
INSERT INTO usuaris VALUES (238, 'Calíope', 'Alemán Cárdenas', 'D', '43 Bellavista', 50000, 'Caliope.Aleman.Cardenas@spambob.com', '10/07/52', 51, 1);
INSERT INTO usuaris VALUES (239, 'Urban', 'Quiroz Roybal', 'H', '81 C/ Andalucía', 4600, 'Urban.Quiroz.Roybal@mailinator.com', '07/06/66', 89, 1);
INSERT INTO usuaris VALUES (240, 'Hermelindo', 'Anguiano Nevarez', 'H', '59 Avenida Cervantes', 48215, 'Hermelindo.Anguiano.Nevarez@pookmail.com', '12/05/74', 88, 2);
INSERT INTO usuaris VALUES (241, 'Coral', 'Vergara Griego', 'D', '37 Prolongacion San Sebastian', 21208, 'Coral.Vergara.Griego@mailinator.com', '03/07/51', 6, 9);
INSERT INTO usuaris VALUES (242, 'Sylvester', 'Viera Domínquez', 'H', '83 Salzillo', 32689, 'Sylvester.Viera.Dominquez@trashymail.com', '15/01/63', 54, 5);
INSERT INTO usuaris VALUES (243, 'Magno', 'Godoy Téllez', 'H', '75 Ventanilla de Beas', 28000, 'Magno.Godoy.Tellez@pookmail.com', '25/02/72', 61, 3);
INSERT INTO usuaris VALUES (244, 'Leticia', 'Almaraz Paz', 'D', '48 Socampo', 37670, 'Leticia.Almaraz.Paz@dodgit.com', '15/05/64', 93, 8);
INSERT INTO usuaris VALUES (245, 'Ageo', 'Ceballos Romo', 'H', '4 Rúa Olmos', 37400, 'Ageo.Ceballos.Romo@spambob.com', '20/03/70', 25, 8);
INSERT INTO usuaris VALUES (246, 'Denis', 'Colunga Anaya', 'D', '19 Paseo del Atlántico', 18000, 'Denis.Colunga.Anaya@mailinator.com', '28/07/67', 29, 3);
INSERT INTO usuaris VALUES (247, 'Galeaso', 'Jiménez Pabón', 'H', '95 Camiño Ancho', 37775, 'Galeaso.Jimenez.Pabon@mailinator.com', '10/03/56', 15, 8);
INSERT INTO usuaris VALUES (248, 'Ascensión', 'Olmos Botello', 'D', '40 Apartado de Correos', 37451, 'Ascension.Olmos.Botello@pookmail.com', '15/11/70', 82, 7);
INSERT INTO usuaris VALUES (249, 'Lala', 'Olivera Posada', 'D', '54 Avda. Generalísimo', 31820, 'Lala.Olivera.Posada@dodgit.com', '15/10/74', 22, 12);
INSERT INTO usuaris VALUES (250, 'Gordon', 'Arteaga Sisneros', 'H', '12 El Roqueo', 16000, 'Gordon.Arteaga.Sisneros@trashymail.com', '25/10/56', 18, 8);
INSERT INTO usuaris VALUES (251, 'Giulianna', 'Barrios Quesada', 'D', '81 Cádiz', 18449, 'Giulianna.Barrios.Quesada@dodgit.com', '01/07/60', 24, 12);
INSERT INTO usuaris VALUES (252, 'Filadelfo', 'Fonseca Covarrubias', 'H', '24 Plaza Maior', 37219, 'Filadelfo.Fonseca.Covarrubias@mailinator.com', '28/05/74', NULL, 10);
INSERT INTO usuaris VALUES (253, 'Karen', 'Enríquez Pabón', NULL, '11 C/ Angosto', 23480, 'Karen.Enriquez.Pabon@dodgit.com', '05/03/77', 74, 9);
INSERT INTO usuaris VALUES (254, 'Britanic', 'Puente Coronado', 'H', '95 C/ Hijuela de Lojo', 20269, 'Britanic.Puente.Coronado@trashymail.com', '03/01/61', 2, 2);
INSERT INTO usuaris VALUES (255, 'Carmín', 'Estrada Castro', 'D', '77 Carretera', 14840, 'Carmin.Estrada.Castro@mailinator.com', '08/02/43', 32, 6);
INSERT INTO usuaris VALUES (256, 'Vanesa', 'Pineda Rendón', NULL, '34 Padre Caro', 13670, 'Vanesa.Pineda.Rendon@pookmail.com', '01/03/85', 75, 4);
INSERT INTO usuaris VALUES (257, 'Clio', 'Cardona Montano', 'H', '28 Calle Proc. San Sebastián', 12600, 'Clio.Cardona.Montano@pookmail.com', '13/03/80', 36, 2);
INSERT INTO usuaris VALUES (258, 'Leneo', 'Otero Ledesma', 'H', '6 Urzáiz', 44100, 'Leneo.Otero.Ledesma@pookmail.com', '29/08/74', 76, 1);
INSERT INTO usuaris VALUES (259, 'Felicity', 'Garza Santacruz', 'D', '82 Inglaterra', 18565, 'Felicity.Garza.Santacruz@trashymail.com', '13/02/79', 8, 7);
INSERT INTO usuaris VALUES (260, 'Amando', 'Matías Solórzano', 'H', '60 Pascual Yunquera', 18698, 'Amando.Matias.Solorzano@trashymail.com', '29/09/57', 66, 5);
INSERT INTO usuaris VALUES (261, 'Moira', 'Reséndez Ocampo', 'D', '62 Plaza de España', 15818, 'Moira.Resendez.Ocampo@mailinator.com', '12/08/43', 24, 6);
INSERT INTO usuaris VALUES (262, 'Joann', 'Santiago Tafoya', 'D', '91 Cercas Bajas', 8200, 'Joann.Santiago.Tafoya@mailinator.com', '09/10/83', 93, 7);
INSERT INTO usuaris VALUES (263, 'Giusto', 'Quintero Osorio', 'H', '95 Camiño Real', 48510, 'Giusto.Quintero.Osorio@spambob.com', '03/02/85', 70, 2);
INSERT INTO usuaris VALUES (264, 'Prudens', 'Lucero Irizarry', 'H', '8 Estrela', 38820, 'Prudens.Lucero.Irizarry@dodgit.com', '30/05/67', 29, 10);
INSERT INTO usuaris VALUES (265, 'Eufemia', 'Saucedo Carbajal', 'D', '57 Avda. de la Estación', 28670, 'Eufemia.Saucedo.Carbajal@spambob.com', '18/03/77', 5, 3);
INSERT INTO usuaris VALUES (266, 'Dimitri', 'Corona Aponte', 'H', '85 Extramuros', 28340, 'Dimitri.Corona.Aponte@spambob.com', '28/07/70', 42, 5);
INSERT INTO usuaris VALUES (267, 'Felisardo', 'Preciado Ceballos', 'H', '74 Extramuros', 28413, 'Felisardo.Preciado.Ceballos@spambob.com', '30/12/60', 86, 9);
INSERT INTO usuaris VALUES (268, 'Esmirna', 'Quiñónez Quiñónez', 'D', '15 Avda. Los llanos', 26259, 'Esmirna.Quinonez.Quinonez@spambob.com', '29/07/61', 10, 1);
INSERT INTO usuaris VALUES (269, 'Kate', 'Paz Perales', 'D', '88 Bellavista', 49690, 'Kate.Paz.Perales@trashymail.com', '30/03/58', 53, 7);
INSERT INTO usuaris VALUES (270, 'Caín', 'Castellanos Cárdenas', 'H', '24 Urzáiz', 44610, 'Cain.Castellanos.Cardenas@spambob.com', '27/12/65', 61, 2);
INSERT INTO usuaris VALUES (271, 'Alaor', 'Orozco Cárdenas', 'H', '57 C/ Señores Curas', 11690, 'Alaor.Orozco.Cardenas@mailinator.com', '05/12/40', 24, 6);
INSERT INTO usuaris VALUES (272, 'Godofredo', 'Betancourt Brito', 'H', '96 C/ Señores Curas', 11659, 'Godofredo.Betancourt.Brito@pookmail.com', '07/10/76', 12, 3);
INSERT INTO usuaris VALUES (273, 'Alexandra', 'Serrano Cotto', 'D', '50 Maestro Puig Valera', 33820, 'Alexandra.Serrano.Cotto@spambob.com', '02/03/84', 11, 11);
INSERT INTO usuaris VALUES (274, 'Próspero', 'Quintero Alicea', 'H', '51 Cañadilla', 22214, 'Prospero.Quintero.Alicea@trashymail.com', '12/07/68', NULL, 11);
INSERT INTO usuaris VALUES (275, 'Karumanta', 'Márquez Lebrón', NULL, '37 C/ Manuel Iradier', 3788, 'Karumanta.Marquez.Lebron@spambob.com', '28/02/58', 7, 10);
INSERT INTO usuaris VALUES (276, 'Laodamia', 'Girón Ortiz', 'D', '59 Carretera del Muelle', 12415, 'Laodamia.Giron.Ortiz@pookmail.com', '19/11/55', 3, 4);
INSERT INTO usuaris VALUES (277, 'Escolástico', 'Vanegas Ybarra', 'H', '88 Pza. Fuensanta', 32350, 'Escolastico.Vanegas.Ybarra@spambob.com', '30/05/63', 67, 4);
INSERT INTO usuaris VALUES (278, 'Cuyén', 'Naranjo Contreras', 'H', '81 Fuente del Gallo', 15115, 'Cuyen.Naranjo.Contreras@mailinator.com', '12/08/49', 7, 2);
INSERT INTO usuaris VALUES (279, 'Franco', 'Miranda Sevilla', 'H', '3 Carretera del Muelle', 12312, 'Franco.Miranda.Sevilla@dodgit.com', '16/11/46', 39, 7);
INSERT INTO usuaris VALUES (280, 'Ferdinand', 'Gonzales Barraza', 'H', '11 Carretera Cádiz-Málaga', 20749, 'Ferdinand.Gonzales.Barraza@dodgit.com', '17/10/73', 64, NULL);
INSERT INTO usuaris VALUES (281, 'Rómula', 'Rolón Quiroz', 'D', '27 La Fontanilla', 14470, 'Romula.Rolon.Quiroz@mailinator.com', '26/10/83', 77, 6);
INSERT INTO usuaris VALUES (282, 'Nino', 'Porras Pelayo', 'H', '53 Constitución', 36980, 'Nino.Porras.Pelayo@spambob.com', '26/06/66', 17, 7);
INSERT INTO usuaris VALUES (283, 'Muredac', 'Feliciano Cervantes', 'H', '46 Maestro Puig Valera', 33717, 'Muredac.Feliciano.Cervantes@dodgit.com', '20/04/65', 91, 2);
INSERT INTO usuaris VALUES (284, 'Jabel', 'Vergara Villareal', 'D', '38 Celso Emilio Ferreiro', 50550, 'Jabel.Vergara.Villareal@pookmail.com', '05/03/60', 90, 5);
INSERT INTO usuaris VALUES (285, 'Renata', 'Montanez Candelaria', 'D', '53 Camiño Ancho', 37789, 'Renata.Montanez.Candelaria@trashymail.com', '21/01/71', 28, NULL);
INSERT INTO usuaris VALUES (286, 'Nydia', 'Huerta Cárdenas', 'D', '93 Cruce Casa de Postas', 18300, 'Nydia.Huerta.Cardenas@spambob.com', '19/10/53', 54, NULL);
INSERT INTO usuaris VALUES (287, 'Nataniel', 'Lara Noriega', 'H', '38 Cartagena', 30191, 'Nataniel.Lara.Noriega@dodgit.com', '17/06/67', 30, 4);
INSERT INTO usuaris VALUES (288, 'Donna', 'Quiñones Urena', 'D', '75 C/ Amoladera', 28810, 'Donna.Quinones.Urena@dodgit.com', '29/06/71', 37, 2);
INSERT INTO usuaris VALUES (289, 'Dinorah', 'Godoy Vergara', 'D', '46 Avda. Alameda Sundheim', 23140, 'Dinorah.Godoy.Vergara@trashymail.com', '01/07/43', 33, 12);
INSERT INTO usuaris VALUES (290, 'Eber', 'Varela Orosco', 'H', '84 Plaza Colón', 26122, 'Eber.Varela.Orosco@dodgit.com', '16/04/70', 93, 4);
INSERT INTO usuaris VALUES (291, 'Abdallah', 'Rentería Díaz', 'H', '4 Constitución', 36940, 'Abdallah.Renteria.Diaz@spambob.com', '18/10/47', 99, 5);
INSERT INTO usuaris VALUES (292, 'Ilve', 'Rincón Curiel', 'D', '41 C/ Los Herrán', 6810, 'Ilve.Rincon.Curiel@trashymail.com', '14/02/82', 64, 10);
INSERT INTO usuaris VALUES (293, 'Orson', 'Navarrete Robles', 'H', '58 C/ Los Herrán', 6510, 'Orson.Navarrete.Robles@pookmail.com', '11/05/65', 92, 9);
INSERT INTO usuaris VALUES (294, 'Rayen', 'Quezada Arellano', 'H', '26 Av. Zumalakarregi', 3150, 'Rayen.Quezada.Arellano@trashymail.com', '03/08/71', 15, 2);
INSERT INTO usuaris VALUES (295, 'Edén', 'Echevarría Melgar', 'D', '54 Rúa Olmos', 37406, 'Eden.Echevarria.Melgar@trashymail.com', '01/01/83', 98, 3);
INSERT INTO usuaris VALUES (296, 'Froilán', 'Beltrán Velasco', 'H', '20 C/ Cañada del Rosal', 21440, 'Froilan.Beltran.Velasco@mailinator.com', '13/11/48', 46, 1);
INSERT INTO usuaris VALUES (297, 'Gibert', 'Macías Hernández', 'H', '86 Pascual Yunquera', 18699, 'Gibert.Macias.Hernandez@dodgit.com', '07/11/40', 87, NULL);
INSERT INTO usuaris VALUES (298, 'Evangelina', 'Lucio Agosto', 'D', '38 Rua da Rapina', 37482, 'Evangelina.Lucio.Agosto@dodgit.com', '19/05/46', 30, 1);
INSERT INTO usuaris VALUES (299, 'Genciana', 'Corrales Mireles', 'D', '75 Ctra. Bailén-Motril', 23230, 'Genciana.Corrales.Mireles@dodgit.com', '28/05/84', 72, NULL);
INSERT INTO usuaris VALUES (300, 'Aleksander', 'Comejo Carrión', 'H', '28 C/ Arana', 2436, 'Aleksander.Comejo.Carrion@trashymail.com', '14/02/56', 88, 6);
INSERT INTO usuaris VALUES (301, 'Peter', 'Uribe Argüello', 'H', '58 Lamas Carbajal', 41567, 'Peter.Uribe.Arguello@dodgit.com', '03/09/81', 17, 7);
INSERT INTO usuaris VALUES (302, 'Liduvina', 'Gamez Hernádez', 'D', '26 C/ Señores Curas', 11650, 'Liduvina.Gamez.Hernadez@spambob.com', '04/07/48', 40, 8);
INSERT INTO usuaris VALUES (303, 'Fulk', 'Vigil Sanches', 'H', '7 C/ Andalucía', 4738, 'Fulk.Vigil.Sanches@mailinator.com', '30/08/46', 12, 3);
INSERT INTO usuaris VALUES (304, 'Encarna', 'Jaime Sosa', 'D', '12 Carretera', 14810, 'Encarna.Jaime.Sosa@spambob.com', '12/05/66', 26, 7);
INSERT INTO usuaris VALUES (305, 'Josefa', 'Armenta Valles', 'D', '17 Valadouro', 48140, 'Josefa.Armenta.Valles@spambob.com', '23/08/66', 51, 5);
INSERT INTO usuaris VALUES (306, 'Xuxa', 'Villanueva Zapata', 'D', '27 Socampo', 37656, 'Xuxa.Villanueva.Zapata@trashymail.com', '16/12/73', 6, 6);
INSERT INTO usuaris VALUES (307, 'Pantaleón', 'Cerda Zayas', 'H', '26 Rúa Olmos', 37316, 'Pantaleon.Cerda.Zayas@dodgit.com', '21/02/53', 45, 12);
INSERT INTO usuaris VALUES (308, 'Seneca', 'Corral Martínez', 'H', '16 Urzáiz', 45000, 'Seneca.Corral.Martinez@pookmail.com', '19/12/41', NULL, 5);
INSERT INTO usuaris VALUES (309, 'Piren', 'León Leal', 'D', '54 C/ Eras', 28740, 'Piren.Leon.Leal@dodgit.com', '02/11/73', 29, 1);
INSERT INTO usuaris VALUES (310, 'Partenia', 'Luna Noriega', 'D', '33 Plazuela do Porto', 38280, 'Partenia.Luna.Noriega@dodgit.com', '14/05/64', 62, 7);
INSERT INTO usuaris VALUES (311, 'Jose', 'Alemán Colón', 'H', '89 Avda. Alameda Sundheim', 23100, 'Jose.Aleman.Colon@trashymail.com', '08/07/74', 77, 8);
INSERT INTO usuaris VALUES (312, 'Pura', 'Castellanos Villaseñor', 'D', '10 Padre Caro', 13500, 'Pura.Castellanos.Villasenor@spambob.com', '07/04/67', 59, 1);
INSERT INTO usuaris VALUES (313, 'Danel', 'Valdez Alarcón', 'H', '67 Lamas Carbajal', 41800, 'Danel.Valdez.Alarcon@dodgit.com', '19/01/79', 96, 7);
INSERT INTO usuaris VALUES (314, 'Ives', 'Vela Baez', 'H', '97 Avda. Explanada Barnuevo', 35470, 'Ives.Vela.Baez@pookmail.com', '02/11/83', 74, 3);
INSERT INTO usuaris VALUES (315, 'Quint', 'Barrera Hernández', 'H', '20 Avda. Enrique Peinador', 37173, 'Quint.Barrera.Hernandez@pookmail.com', '30/01/63', 33, NULL);
INSERT INTO usuaris VALUES (316, 'Heraldo', 'Lomeli Juárez', 'H', '57 C/ Angosto', 23477, 'Heraldo.Lomeli.Juarez@spambob.com', '04/03/60', 86, 11);
INSERT INTO usuaris VALUES (317, 'Desdémona', 'Chapa Gaitán', NULL, '77 C/ Cuevas de Ambrosio', 23746, 'Desdemona.Chapa.Gaitan@mailinator.com', '26/08/75', 4, 7);
INSERT INTO usuaris VALUES (318, 'Fiona', 'Matías Árias', 'D', '37 Rio Segura', 31511, 'Fiona.Matias.Arias@dodgit.com', '24/11/47', 60, 12);
INSERT INTO usuaris VALUES (319, 'Tabita', 'Sandoval Marroquín', NULL, '32 Atamaria', 36856, 'Tabita.Sandoval.Marroquin@mailinator.com', '26/11/66', 43, 8);
INSERT INTO usuaris VALUES (320, 'Nicandro', 'Escamilla Esparza', 'H', '52 C/ Henan Cortes', 29100, 'Nicandro.Escamilla.Esparza@mailinator.com', '14/07/77', 65, 4);
INSERT INTO usuaris VALUES (321, 'Valda', 'Cuellar Jáquez', 'D', '85 Ctra. de Siles', 27664, 'Valda.Cuellar.Jaquez@dodgit.com', '02/07/79', 19, 5);
INSERT INTO usuaris VALUES (322, 'Florian', 'Loya Orellana', 'H', '87 C/ Benito Guinea', 8320, 'Florian.Loya.Orellana@mailinator.com', '05/11/76', 61, 4);
INSERT INTO usuaris VALUES (323, 'Milca', 'Pedraza Esparza', 'D', '90 Pza. Fuensanta', 32340, 'Milca.Pedraza.Esparza@pookmail.com', '11/07/63', 36, 8);
INSERT INTO usuaris VALUES (324, 'Friedrich', 'Díaz Jiménez', 'H', '99 Cercas Bajas', 8210, 'Friedrich.Diaz.Jimenez@pookmail.com', '12/05/54', 67, 11);
INSERT INTO usuaris VALUES (325, 'Astolfo', 'Ornelas Garay', 'H', '71 Avda. Andalucía', 26131, 'Astolfo.Ornelas.Garay@dodgit.com', '28/03/52', 8, 1);
INSERT INTO usuaris VALUES (326, 'Rufino', 'Méndez Magana', 'H', '12 Carretera del Muelle', 12232, 'Rufino.Mendez.Magana@spambob.com', '02/07/54', 41, NULL);
INSERT INTO usuaris VALUES (327, 'Lauren', 'Alba Delgadillo', 'H', '56 Pl. Virgen Blanca', 8640, 'Lauren.Alba.Delgadillo@dodgit.com', '21/04/41', 79, 9);
INSERT INTO usuaris VALUES (328, 'Sintiques', 'Matías Barreto', 'D', '21 C/ Cañada del Rosal', 21647, 'Sintiques.Matias.Barreto@dodgit.com', '02/01/43', 39, 5);
INSERT INTO usuaris VALUES (329, 'Nikole', 'Villagómez Hernádez', 'D', '26 Maestro Puig Valera', 33560, 'Nikole.Villagomez.Hernadez@spambob.com', '14/12/53', 75, NULL);
INSERT INTO usuaris VALUES (330, 'Zoilo', 'Abeyta Vázquez', 'H', '15 Ctra. de Fuentenueva', 28240, 'Zoilo.Abeyta.Vazquez@pookmail.com', '20/02/81', 61, 4);
INSERT INTO usuaris VALUES (331, 'Yago', 'Tello Alicea', 'H', '4 Caño', 32740, 'Yago.Tello.Alicea@pookmail.com', '27/02/56', 14, NULL);
INSERT INTO usuaris VALUES (332, 'Melito', 'Quiñones Rubio', 'H', '5 Herrería', 18200, 'Melito.Quinones.Rubio@pookmail.com', '07/10/84', 73, 2);
INSERT INTO usuaris VALUES (333, 'Ezechiel', 'Espinal Zapata', 'H', '42 Plaza Maior', 37193, 'Ezechiel.Espinal.Zapata@mailinator.com', '27/06/83', 43, 10);
INSERT INTO usuaris VALUES (334, 'Juanita', 'Carvajal Barreto', 'D', '90 Calle Proc. San Sebastián', 12598, 'Juanita.Carvajal.Barreto@spambob.com', '20/03/44', 83, 9);
INSERT INTO usuaris VALUES (335, 'Traful', 'Solórzano Lozada', 'H', '61 C/ Rosa de los Vientos', 11180, 'Traful.Solorzano.Lozada@spambob.com', '26/03/81', 6, 12);
INSERT INTO usuaris VALUES (336, 'Pirra', 'Ulibarri Salcido', 'D', '87 Canónigo Valiño', 46210, 'Pirra.Ulibarri.Salcido@trashymail.com', '04/03/63', 83, 4);
INSERT INTO usuaris VALUES (337, 'Kensel', 'Vigil Fierro', 'H', '83 Reiseñor', 45700, 'Kensel.Vigil.Fierro@spambob.com', '23/03/41', 98, 12);
INSERT INTO usuaris VALUES (338, 'Zelmira', 'Escamilla Burgos', 'D', '59 José matía', 2130, 'Zelmira.Escamilla.Burgos@mailinator.com', '08/12/57', 14, 4);
INSERT INTO usuaris VALUES (339, 'Marion', 'Pineda Alanis', 'D', '77 Pascual Yunquera', 18712, 'Marion.Pineda.Alanis@pookmail.com', '08/06/73', 99, 1);
INSERT INTO usuaris VALUES (340, 'Jannifer', 'Pabón Salas', 'D', '98 Zumalakarregi etorbidea', 7330, 'Jannifer.Pabon.Salas@pookmail.com', '22/02/76', 74, 5);
INSERT INTO usuaris VALUES (341, 'Faustine', 'Bustos Tovar', 'D', '56 C/ Canarias', 20100, 'Faustine.Bustos.Tovar@pookmail.com', '27/09/63', 99, 6);
INSERT INTO usuaris VALUES (342, 'Clea', 'Márquez Leyva', 'D', '16 C/ Hijuela de Lojo', 20260, 'Clea.Marquez.Leyva@mailinator.com', '14/03/66', 40, 5);
INSERT INTO usuaris VALUES (343, 'Eira', 'Colunga Loya', 'D', '14 Alcon Molina', 30850, 'Eira.Colunga.Loya@pookmail.com', '25/10/65', NULL, 6);
INSERT INTO usuaris VALUES (344, 'Nale', 'Estévez Hernandes', 'D', '5 Ctra. Beas-Cortijos Nuevos', 26570, 'Nale.Estevez.Hernandes@trashymail.com', '17/11/43', 25, 8);
INSERT INTO usuaris VALUES (345, 'Braulia', 'Gamez Montemayor', 'D', '56 C/ Domingo Beltrán', 2327, 'Braulia.Gamez.Montemayor@pookmail.com', '14/11/71', 40, 8);
INSERT INTO usuaris VALUES (346, 'Elisea', 'Saucedo Barajas', 'D', '69 C/ Domingo Beltrán', 2260, 'Elisea.Saucedo.Barajas@dodgit.com', '25/03/42', 8, 8);
INSERT INTO usuaris VALUES (347, 'Alvero', 'Cordova Zamora', 'H', '95 Avda. Rio Nalon', 33126, 'Alvero.Cordova.Zamora@dodgit.com', '10/10/81', 94, 4);
INSERT INTO usuaris VALUES (348, 'Randall', 'González Pineda', 'H', '3 C/ Hijuela de Lojo', 20491, 'Randall.Gonzalez.Pineda@dodgit.com', '07/05/44', 71, 6);
INSERT INTO usuaris VALUES (349, 'Antolin', 'Colón Longoria', 'H', '43 Reyes Católicos', 11130, 'Antolin.Colon.Longoria@spambob.com', '29/08/59', 79, 3);
INSERT INTO usuaris VALUES (350, 'Ubaldina', 'Martínez Sanabria', 'D', '87 Ctra. Villena', 34440, 'Ubaldina.Martinez.Sanabria@trashymail.com', '27/10/67', 90, 10);
INSERT INTO usuaris VALUES (351, 'Oswald', 'Garica Martínez', 'H', '11 Ourense', 43340, 'Oswald.Garica.Martinez@mailinator.com', '02/11/77', 36, 4);
INSERT INTO usuaris VALUES (352, 'Dylan', 'Apodaca Pedroza', 'H', '8 Reiseñor', 46000, 'Dylan.Apodaca.Pedroza@dodgit.com', '13/06/59', 86, 6);
INSERT INTO usuaris VALUES (353, 'Joaquina', 'Alemán Valladares', 'D', '32 Celso Emilio Ferreiro', 50540, 'Joaquina.Aleman.Valladares@spambob.com', '08/06/81', 50, 8);
INSERT INTO usuaris VALUES (354, 'Octavia', 'Matos Arriaga', 'D', '9 C/ Eras', 28729, 'Octavia.Matos.Arriaga@dodgit.com', '03/05/50', 86, 10);
INSERT INTO usuaris VALUES (355, 'Ela', 'Valverde Iglesias', 'D', '53 Visitación de la Encina', 37724, 'Ela.Valverde.Iglesias@spambob.com', '16/03/57', 6, 5);
INSERT INTO usuaris VALUES (356, 'Landolf', 'Ulloa Juárez', 'H', '77 Bouciña', 43850, 'Landolf.Ulloa.Juarez@pookmail.com', NULL, 33, 4);
INSERT INTO usuaris VALUES (357, 'Yvette', 'Ojeda Figueroa', 'D', '29 Atamaria', 36800, 'Yvette.Ojeda.Figueroa@dodgit.com', '09/11/72', 26, 1);
INSERT INTO usuaris VALUES (358, 'Maura', 'Caldera Zamudio', 'D', '48 Inglaterra', 18565, 'Maura.Caldera.Zamudio@dodgit.com', '18/07/74', 9, 5);
INSERT INTO usuaris VALUES (359, 'Kathryn', 'Flórez Moreno', 'D', '77 Plaza Maior', 37218, 'Kathryn.Florez.Moreno@pookmail.com', '18/12/46', 84, 12);
INSERT INTO usuaris VALUES (360, 'Otilde', 'Frías Alarcón', NULL, '17 Zumalakarregi etorbidea', 7194, 'Otilde.Frias.Alarcon@dodgit.com', '02/08/61', 20, 6);
INSERT INTO usuaris VALUES (361, 'Jehiel', 'Valle Tórrez', 'H', '85 Avda. Generalísimo', 32110, 'Jehiel.Valle.Torrez@spambob.com', '21/01/45', 60, NULL);
INSERT INTO usuaris VALUES (362, 'Goratze', 'Delgado Villaseñor', 'D', '66 Visitación de la Encina', 37749, 'Goratze.Delgado.Villasenor@mailinator.com', '21/06/56', 69, 6);
INSERT INTO usuaris VALUES (363, 'Iriel', 'Covarrubias Muro', 'D', '18 Avda. de la Estación', 28640, 'Iriel.Covarrubias.Muro@spambob.com', '07/12/45', 82, 6);
INSERT INTO usuaris VALUES (364, 'Wara', 'Espinosa Cordero', 'D', '17 C/ Canarias', 20100, 'Wara.Espinosa.Cordero@pookmail.com', '01/12/65', 79, NULL);
INSERT INTO usuaris VALUES (365, 'Inaxio', 'Ríos Vanegas', 'H', '67 C/ Cañada del Rosal', 21388, 'Inaxio.Rios.Vanegas@dodgit.com', '16/07/54', 72, 12);
INSERT INTO usuaris VALUES (366, 'Lien', 'Trujillo Irizarry', 'D', '9 Avda. Rio Nalon', 33550, 'Lien.Trujillo.Irizarry@pookmail.com', '20/06/50', 38, 5);
INSERT INTO usuaris VALUES (367, 'Didier', 'Galván Abeyta', 'H', '26 Zumalakarregi etorbidea', 7320, 'Didier.Galvan.Abeyta@spambob.com', '29/10/50', 22, 3);
INSERT INTO usuaris VALUES (368, 'Sira', 'Barrientos Canales', 'D', '76 Antonio Vázquez', 38500, 'Sira.Barrientos.Canales@trashymail.com', '05/05/75', 99, 6);
INSERT INTO usuaris VALUES (369, 'Hullen', 'Sauceda Pabón', NULL, '39 Cañadilla', 22250, 'Hullen.Sauceda.Pabon@dodgit.com', '21/06/53', 5, 4);
INSERT INTO usuaris VALUES (370, 'Fortunato', 'Rentería Zayas', 'H', '96 Avda. de la Estación', 28580, 'Fortunato.Renteria.Zayas@dodgit.com', '13/04/42', 47, 11);
INSERT INTO usuaris VALUES (371, 'Pola', 'Cardona Esparza', 'D', '45 Pza. Fuensanta', 32235, 'Pola.Cardona.Esparza@pookmail.com', '30/10/52', 6, 2);
INSERT INTO usuaris VALUES (372, 'Taffy', 'Cazares Montenegro', 'D', '95 Calvo Sotelo', 47240, 'Taffy.Cazares.Montenegro@mailinator.com', '28/01/75', 4, 6);
INSERT INTO usuaris VALUES (373, 'Bautista', 'Saavedra Meza', 'H', '28 Ctra. Hornos', 26212, 'Bautista.Saavedra.Meza@trashymail.com', NULL, 20, 4);
INSERT INTO usuaris VALUES (374, 'Nevio', 'Mares Marroquín', 'H', '76 C/ Andalucía', 4750, 'Nevio.Mares.Marroquin@dodgit.com', '18/01/68', 55, 5);
INSERT INTO usuaris VALUES (375, 'Esther', 'Solórzano Cotto', 'D', '66 Lamas Carbajal', 41780, 'Esther.Solorzano.Cotto@spambob.com', '20/02/69', 39, 11);
INSERT INTO usuaris VALUES (376, 'Anabella', 'Montemayor Quintana', 'D', '40 C/ Andalucía', 4738, 'Anabella.Montemayor.Quintana@pookmail.com', '01/05/45', 53, 6);
INSERT INTO usuaris VALUES (377, 'Florio', 'Tello Montalvo', 'H', '62 Carretera Cádiz-Málaga', 20570, 'Florio.Tello.Montalvo@spambob.com', '17/03/76', 91, 11);
INSERT INTO usuaris VALUES (378, 'Ena', 'Barrera Negrete', 'D', '71 Rúa de San Pedro', 37793, 'Ena.Barrera.Negrete@trashymail.com', '07/06/84', 74, 6);
INSERT INTO usuaris VALUES (379, 'Fanny', 'Pineda Garrido', 'D', '12 Bouciña', 43883, 'Fanny.Pineda.Garrido@mailinator.com', '07/10/74', 97, 3);
INSERT INTO usuaris VALUES (380, 'Rutilda', 'Rodríguez Arriaga', 'D', '65 El Roqueo', 16630, 'Rutilda.Rodriguez.Arriaga@dodgit.com', '16/08/62', 85, 5);
INSERT INTO usuaris VALUES (381, 'Kevin', 'Merino Pérez', 'H', '64 C/ Andalucía', 4639, 'Kevin.Merino.Perez@mailinator.com', '19/01/64', 2, 10);
INSERT INTO usuaris VALUES (382, 'Gad', 'Saldivar Rojo', 'H', '38 Ctra. Bailén-Motril', 23320, 'Gad.Saldivar.Rojo@trashymail.com', '29/05/44', 76, 6);
INSERT INTO usuaris VALUES (383, 'Malva', 'Benavides Hinojosa', 'D', '32 C/ Domingo Beltrán', 2314, 'Malva.Benavides.Hinojosa@pookmail.com', '02/08/49', 25, 12);
INSERT INTO usuaris VALUES (384, 'Triana.', 'Estrada Laboy', 'D', '70 C/ Hijuela de Lojo', 20491, 'Triana.Estrada.Laboy@dodgit.com', '08/06/74', 64, NULL);
INSERT INTO usuaris VALUES (385, 'Lily', 'Gurule Jáquez', 'D', '41 C/ Cuevas de Ambrosio', 24100, 'Lily.Gurule.Jaquez@pookmail.com', '14/01/82', 56, 7);
INSERT INTO usuaris VALUES (386, 'Cañumil', 'Juárez Leiva', 'H', '12 C/ Hijuela de Lojo', 20490, 'Canumil.Juarez.Leiva@trashymail.com', '27/10/45', 8, 1);
INSERT INTO usuaris VALUES (387, 'Daryl', 'Avilés Valdez', 'H', '82 Paseo Junquera', 12428, 'Daryl.Aviles.Valdez@pookmail.com', '30/10/46', 43, 8);
INSERT INTO usuaris VALUES (388, 'Mirko', 'Carmona Trejo', 'H', '9 Padre Caro', 13480, 'Mirko.Carmona.Trejo@dodgit.com', '14/03/66', 78, 8);
INSERT INTO usuaris VALUES (389, 'Alda', 'Hernandes Ulibarri', 'D', '13 Apartado de Correos', 37448, 'Alda.Hernandes.Ulibarri@mailinator.com', '18/08/57', 82, 5);
INSERT INTO usuaris VALUES (390, 'Solana', 'Comejo Díaz', 'D', '78 C/ Hijuela de Lojo', 20248, 'Solana.Comejo.Diaz@pookmail.com', '31/05/80', 74, 9);
INSERT INTO usuaris VALUES (391, 'Domínica', 'Guerrero Jaimes', 'D', '64 Reiseñor', 45800, 'Dominica.Guerrero.Jaimes@trashymail.com', '01/06/47', 84, 8);
INSERT INTO usuaris VALUES (392, 'Elisabeth', 'Salcedo Madrigal', 'D', '42 Ourense', 42200, 'Elisabeth.Salcedo.Madrigal@spambob.com', '08/07/47', 87, 9);
INSERT INTO usuaris VALUES (393, 'Luigi', 'Fuentes Méndez', 'H', '69 Caño', 32760, 'Luigi.Fuentes.Mendez@pookmail.com', '09/07/81', 4, NULL);
INSERT INTO usuaris VALUES (394, 'Yanquiman', 'Ortega Salas', 'H', '55 La Fontanilla', 14460, 'Yanquiman.Ortega.Salas@mailinator.com', '23/03/82', 63, NULL);
INSERT INTO usuaris VALUES (395, 'Meinard', 'Monroy Arteaga', 'H', '76 C/ Eras', 28737, 'Meinard.Monroy.Arteaga@spambob.com', '01/04/70', 28, 5);
INSERT INTO usuaris VALUES (396, 'Arcadio', 'Abreu Galván', 'H', '64 C/ Canarias', 20213, 'Arcadio.Abreu.Galvan@pookmail.com', '23/07/54', 91, 12);
INSERT INTO usuaris VALUES (397, 'Veredigna', 'Cordova Briseño', 'D', '11 Rúa do Paseo', 41830, 'Veredigna.Cordova.Briseno@mailinator.com', '25/06/57', 48, 1);
INSERT INTO usuaris VALUES (398, 'Reynaldo', 'Almonte Tovar', NULL, '79 C/ Pablo Iglesias', 26329, 'Reynaldo.Almonte.Tovar@spambob.com', '29/09/49', 3, 1);
INSERT INTO usuaris VALUES (399, 'Ticiana', 'Fierro Villa', 'D', '12 El Roqueo', 15885, 'Ticiana.Fierro.Villa@mailinator.com', '15/11/77', 21, 2);
INSERT INTO usuaris VALUES (400, 'Amiel', 'Saldivar Esparza', 'H', '64 C/ Cuevas de Ambrosio', 23611, 'Amiel.Saldivar.Esparza@pookmail.com', '02/03/58', 86, 5);
INSERT INTO usuaris VALUES (401, 'Abraham', 'Zambrano Iglesias', 'H', '14 Calvo Sotelo', 48000, 'Abraham.Zambrano.Iglesias@mailinator.com', '22/04/42', 23, 4);
INSERT INTO usuaris VALUES (402, 'Guzmán', 'Agosto Estrada', 'H', '63 Celso Emilio Ferreiro', 50640, 'Guzman.Agosto.Estrada@spambob.com', '11/01/41', 35, 3);
INSERT INTO usuaris VALUES (403, 'Didio', 'Castellanos Nazario', 'H', '8 C/ Fernández de Leceta', 3518, 'Didio.Castellanos.Nazario@dodgit.com', '06/08/43', 21, 2);
INSERT INTO usuaris VALUES (404, 'Basa', 'Cedillo Orozco', 'D', '63 Camiño Ancho', 37780, 'Basa.Cedillo.Orozco@mailinator.com', '16/11/54', 51, 6);
INSERT INTO usuaris VALUES (405, 'Omer', 'Guzmán Abrego', 'H', '32 Prolongacion San Sebastian', 21240, 'Omer.Guzman.Abrego@mailinator.com', '09/04/43', 5, 5);
INSERT INTO usuaris VALUES (406, 'Haide', 'Madrigal Velasco', 'D', '80 C/ Angosto', 23460, 'Haide.Madrigal.Velasco@mailinator.com', '28/12/41', 83, 6);
INSERT INTO usuaris VALUES (407, 'Odoacro', 'Aguirre Esquivel', 'H', '64 Avda. de Andalucía', 29440, 'Odoacro.Aguirre.Esquivel@pookmail.com', '07/07/63', 28, 4);
INSERT INTO usuaris VALUES (408, 'Monserrat', 'Domínguez Olivas', 'H', '24 Lamas Carbajal', 41700, 'Monserrat.Dominguez.Olivas@dodgit.com', '18/07/83', 43, 6);
INSERT INTO usuaris VALUES (409, 'Lissa', 'Ramírez Echevarría', 'D', '16 San Andrés', 37291, 'Lissa.Ramirez.Echevarria@trashymail.com', '11/01/72', 73, 9);
INSERT INTO usuaris VALUES (410, 'Alethia', 'Viera Galindo', 'D', '45 Valadouro', 48150, 'Alethia.Viera.Galindo@dodgit.com', '12/10/44', 97, 5);
INSERT INTO usuaris VALUES (411, 'Niceto', 'Tapia Esquibel', 'H', '29 Inglaterra', 18538, 'Niceto.Tapia.Esquibel@spambob.com', '31/12/63', 46, 7);
INSERT INTO usuaris VALUES (412, 'Marín', 'Gaona Salazar', NULL, '84 Crta. Cádiz-Málaga', 12184, 'Marin.Gaona.Salazar@dodgit.com', '23/10/76', 37, 2);
INSERT INTO usuaris VALUES (413, 'Diadema', 'Rubio Sevilla', 'D', '7 Outid de Arriba', 43710, 'Diadema.Rubio.Sevilla@mailinator.com', '26/08/67', 9, 2);
INSERT INTO usuaris VALUES (414, 'Nilton', 'Molina Velasco', 'H', '28 Extramuros', 28470, 'Nilton.Molina.Velasco@dodgit.com', '03/05/42', 17, 4);
INSERT INTO usuaris VALUES (415, 'Baldomero', 'Luna Castaneda', 'H', '52 Calle Proc. San Sebastián', 13150, 'Baldomero.Luna.Castaneda@dodgit.com', '20/04/63', 48, NULL);
INSERT INTO usuaris VALUES (416, 'Remedios', 'Toro Sierra', 'D', '25 Calle Aduana', 1118, 'Remedios.Toro.Sierra@trashymail.com', '31/08/50', 52, 7);
INSERT INTO usuaris VALUES (417, 'Heloísa', 'Carrera Aranda', 'D', '84 Calle Aduana', 1250, 'Heloisa.Carrera.Aranda@mailinator.com', '23/09/59', 1, 2);
INSERT INTO usuaris VALUES (418, 'Irina', 'Chapa Zavala', 'D', '69 Av. Zumalakarregi', 3130, 'Irina.Chapa.Zavala@spambob.com', '18/03/69', 68, 6);
INSERT INTO usuaris VALUES (419, 'Lara', 'Villegas Melgar', 'D', '52 Herrería', 18160, 'Lara.Villegas.Melgar@trashymail.com', '03/12/42', 86, 3);
INSERT INTO usuaris VALUES (420, 'Erardo', 'Suárez Serrano', 'H', '56 Ctra. de Fuentenueva', 28191, 'Erardo.Suarez.Serrano@pookmail.com', '04/11/84', 96, 1);
INSERT INTO usuaris VALUES (421, 'Quinta', 'Tijerina Duarte', 'D', '86 Boriñaur enparantza', 7720, 'Quinta.Tijerina.Duarte@pookmail.com', '29/05/58', 42, 5);
INSERT INTO usuaris VALUES (422, 'Lanin', 'Montés Casas', 'D', '73 C/ Arana', 2639, 'Lanin.Montes.Casas@pookmail.com', '03/08/77', 20, 4);
INSERT INTO usuaris VALUES (423, 'Edith', 'Saldana Collado', 'D', '29 Ourense', 42250, 'Edith.Saldana.Collado@mailinator.com', '28/03/58', 86, 7);
INSERT INTO usuaris VALUES (424, 'Jean', 'Carmona Miranda', 'H', '64 Carretera del Muelle', 12350, 'Jean.Carmona.Miranda@mailinator.com', '26/10/64', 14, 5);
INSERT INTO usuaris VALUES (425, 'Landerico', 'Archuleta Pacheco', 'H', '56 Ctra. de la Puerta', 26587, 'Landerico.Archuleta.Pacheco@pookmail.com', '05/06/68', 10, 4);
INSERT INTO usuaris VALUES (426, 'Líbera', 'Vaca Vergara', 'D', '75 Avendaño', 3840, 'Libera.Vaca.Vergara@pookmail.com', '08/06/47', 85, 1);
INSERT INTO usuaris VALUES (427, 'Virgil', 'García Gaona', 'H', '91 Plaza de España', 15807, 'Virgil.Garcia.Gaona@mailinator.com', '06/02/47', 76, 8);
INSERT INTO usuaris VALUES (428, 'Iair', 'Maya Casares', 'H', '77 Rio Segura', 31360, 'Iair.Maya.Casares@spambob.com', '31/07/78', 27, 3);
INSERT INTO usuaris VALUES (429, 'Eulalia', 'Blanco Escobedo', 'D', '21 C/ Domingo Beltrán', 2230, 'Eulalia.Blanco.Escobedo@spambob.com', '26/02/69', 56, 8);
INSERT INTO usuaris VALUES (430, 'Fortuna', 'Esquivel Rangel', 'D', '54 Caño', 32911, 'Fortuna.Esquivel.Rangel@mailinator.com', '12/04/75', 71, 1);
INSERT INTO usuaris VALUES (431, 'Seraphin', 'Muñiz Rubio', 'H', '43 Salzillo', 32600, 'Seraphin.Muniz.Rubio@mailinator.com', '15/10/44', 8, 3);
INSERT INTO usuaris VALUES (432, 'Palemon', 'Zepeda Pineda', 'H', '44 Avda. de la Estación', 28691, 'Palemon.Zepeda.Pineda@mailinator.com', '16/08/70', 28, 11);
INSERT INTO usuaris VALUES (433, 'Rosina', 'Bañuelos Melgar', 'D', '87 Camiño Ancho', 37762, 'Rosina.Banuelos.Melgar@dodgit.com', '07/01/79', 86, 9);
INSERT INTO usuaris VALUES (434, 'Thina', 'Castellanos Tello', 'D', '22 Herrería', 18194, 'Thina.Castellanos.Tello@spambob.com', '27/02/41', 25, 12);
INSERT INTO usuaris VALUES (435, 'Crisóforo', 'Espinoza Rodrígez', 'H', '97 José matía', 2125, 'Crisoforo.Espinoza.Rodrigez@dodgit.com', '10/10/70', 0, 11);
INSERT INTO usuaris VALUES (436, 'Eawinda', 'Riojas Collazo', 'D', '83 Antonio Vázquez', 38770, 'Eawinda.Riojas.Collazo@dodgit.com', '26/10/80', 51, 4);
INSERT INTO usuaris VALUES (437, 'Ahmend', 'Carvajal Ocampo', 'H', '20 Celso Emilio Ferreiro', 50420, 'Ahmend.Carvajal.Ocampo@spambob.com', '27/05/83', 37, 10);
INSERT INTO usuaris VALUES (438, 'Lorea', 'Juárez Roque', 'D', '55 C/ Cuesta del  Álamo', 29650, 'Lorea.Juarez.Roque@trashymail.com', '21/05/81', 84, 6);
INSERT INTO usuaris VALUES (439, 'Lisandra', 'Dueñas Serna', 'D', '24 Reyes Católicos', 9600, 'Lisandra.Duenas.Serna@spambob.com', '22/06/75', 11, 7);
INSERT INTO usuaris VALUES (440, 'Alcuino', 'Rosario Gonzales', 'H', '54 C/ Eras', 28750, 'Alcuino.Rosario.Gonzales@pookmail.com', '14/02/84', 29, 10);
INSERT INTO usuaris VALUES (441, 'Isabel', 'Montano Aguayo', 'D', '92 Avda. Los llanos', 26310, 'Isabel.Montano.Aguayo@dodgit.com', '01/09/62', 53, 12);
INSERT INTO usuaris VALUES (442, 'Laszlo', 'Tamez Tejada', 'H', '67 Avenida Cervantes', 48270, 'Laszlo.Tamez.Tejada@spambob.com', '10/08/69', 39, 7);
INSERT INTO usuaris VALUES (443, 'Tarsilia', 'Zelaya Perales', 'D', '16 Ventanilla de Beas', 28140, 'Tarsilia.Zelaya.Perales@spambob.com', '29/03/62', 17, 2);
INSERT INTO usuaris VALUES (444, 'Adonis', 'Farías Gallegos', 'H', '43 Zumalakarregi etorbidea', 7311, 'Adonis.Farias.Gallegos@trashymail.com', '29/08/67', 14, 7);
INSERT INTO usuaris VALUES (445, 'Huara', 'Padrón Meza', 'D', '29 Rosa de los Vientos', 13329, 'Huara.Padron.Meza@pookmail.com', '03/10/83', 30, 8);
INSERT INTO usuaris VALUES (446, 'Marvin', 'Bustos Bahena', 'H', '42 Pza. Fuensanta', 32300, 'Marvin.Bustos.Bahena@spambob.com', '03/05/68', 29, NULL);
INSERT INTO usuaris VALUES (447, 'Calixta', 'Ruvalcaba Alfaro', 'D', '39 C/ Andalucía', 4825, 'Calixta.Ruvalcaba.Alfaro@pookmail.com', '20/05/51', 12, 6);
INSERT INTO usuaris VALUES (448, 'Ezekiel', 'Carrillo Yáñez', 'H', '89 C/ Los Herrán', 6470, 'Ezekiel.Carrillo.Yanez@dodgit.com', '31/10/52', 36, 4);
INSERT INTO usuaris VALUES (449, 'Wenceslao', 'Benítez Gómez', 'H', '44 Calle Proc. San Sebastián', 13000, 'Wenceslao.Benitez.Gomez@pookmail.com', '08/03/83', 89, 3);
INSERT INTO usuaris VALUES (450, 'Arcángel', 'Varela Montoya', 'H', '79 El Roqueo', 15970, 'Arcangel.Varela.Montoya@trashymail.com', '23/04/54', 34, 12);
INSERT INTO usuaris VALUES (451, 'Eleonora', 'Saldivar Villanueva', 'D', '27 Comandante Izarduy', 8950, 'Eleonora.Saldivar.Villanueva@pookmail.com', '09/11/50', 84, 11);
INSERT INTO usuaris VALUES (452, 'Constanza', 'Franco Ramírez', 'D', '48 Ctra. de Siles', 27670, 'Constanza.Franco.Ramirez@pookmail.com', '16/12/85', 30, 5);
INSERT INTO usuaris VALUES (453, 'Giancarlo', 'Jimínez Campos', 'H', '56 Maestro Puig Valera', 33735, 'Giancarlo.Jiminez.Campos@dodgit.com', '30/10/40', 9, 2);
INSERT INTO usuaris VALUES (454, 'Peer', 'González Vega', 'H', '19 Fuente del Gallo', 15129, 'Peer.Gonzalez.Vega@pookmail.com', '20/12/42', 28, NULL);
INSERT INTO usuaris VALUES (455, 'Milena', 'Aparicio Villegas', 'D', '22 Paseo del Atlántico', 18131, 'Milena.Aparicio.Villegas@dodgit.com', '13/10/69', 20, 10);
INSERT INTO usuaris VALUES (456, 'Zenadia', 'Acosta Alcalá', 'D', '26 Carretera', 14720, 'Zenadia.Acosta.Alcala@pookmail.com', '29/07/76', 51, 12);
INSERT INTO usuaris VALUES (457, 'Aracely', 'Barragán Ocampo', 'D', '7 Zumalakarregi etorbidea', 7192, 'Aracely.Barragan.Ocampo@spambob.com', '20/06/67', 87, 7);
INSERT INTO usuaris VALUES (458, 'Veda', 'Callas Aranda', 'D', '25 Comandante Izarduy', 8800, 'Veda.Callas.Aranda@spambob.com', '27/11/79', 14, 9);
INSERT INTO usuaris VALUES (459, 'Dinora', 'Ulibarri Flórez', 'D', '62 C/ Hijuela de Lojo', 20493, 'Dinora.Ulibarri.Florez@trashymail.com', '20/03/51', 92, 4);
INSERT INTO usuaris VALUES (460, 'Jimeno', 'Rincón Armendáriz', 'H', '36 Carretera del Muelle', 12412, 'Jimeno.Rincon.Armendariz@pookmail.com', '02/04/41', 17, 4);
INSERT INTO usuaris VALUES (461, 'Menajem', 'Enríquez Carrasquill', 'H', '72 C/ Hijuela de Lojo', 20248, 'Menajem.Enriquez.Carrasquill@spambob.com', '28/07/59', 92, 6);
INSERT INTO usuaris VALUES (462, 'Fabian', 'Farías Yáñez', 'H', '65 Quevedo', 15316, 'Fabian.Farias.Yanez@pookmail.com', '25/08/50', 44, 5);
INSERT INTO usuaris VALUES (463, 'Argimiro', 'Palomo Ulloa', 'H', '5 Socampo', 37683, 'Argimiro.Palomo.Ulloa@trashymail.com', '16/10/57', 2, 2);
INSERT INTO usuaris VALUES (464, 'Oriana', 'Rivero Mora', 'D', '86 Enxertos', 37531, 'Oriana.Rivero.Mora@dodgit.com', '01/07/47', 98, 4);
INSERT INTO usuaris VALUES (465, 'Joana', 'Betancourt Montoya', 'D', '87 Cruce Casa de Postas', 18320, 'Joana.Betancourt.Montoya@pookmail.com', '13/04/51', 78, 12);
INSERT INTO usuaris VALUES (466, 'Othon', 'Malave Correa', 'H', '80 Caño', 32870, 'Othon.Malave.Correa@mailinator.com', '31/08/59', 30, 11);
INSERT INTO usuaris VALUES (467, 'Agape', 'Hernández Acevedo', 'D', '74 Cartagena', 30640, 'Agape.Hernandez.Acevedo@mailinator.com', '20/09/82', 75, 3);
INSERT INTO usuaris VALUES (468, 'Alanis', 'Becerra Fierro', 'H', '39 Outid de Arriba', 43746, 'Alanis.Becerra.Fierro@spambob.com', '06/02/62', 52, 11);
INSERT INTO usuaris VALUES (469, 'Adelmo', 'Carvajal Hernández', 'H', '65 Outid de Arriba', 43710, 'Adelmo.Carvajal.Hernandez@pookmail.com', '25/01/61', 13, 12);
INSERT INTO usuaris VALUES (470, 'Melisa', 'Verdugo Melgar', 'D', '1 Constitución', 36930, 'Melisa.Verdugo.Melgar@spambob.com', '27/09/63', 80, 10);
INSERT INTO usuaris VALUES (471, 'Casdoa', 'Melgar Pena', 'D', '65 Constitución', 37120, 'Casdoa.Melgar.Pena@trashymail.com', '04/06/40', 44, 9);
INSERT INTO usuaris VALUES (472, 'Agar', 'Baez Salcedo', 'H', '51 Avda. Andalucía', 26190, 'Agar.Baez.Salcedo@trashymail.com', '22/04/46', 27, 11);
INSERT INTO usuaris VALUES (473, 'Zuleika', 'Fonseca Frías', 'D', '51 C/ Cuevas de Ambrosio', 23780, 'Zuleika.Fonseca.Frias@mailinator.com', '29/12/58', 56, 6);
INSERT INTO usuaris VALUES (474, 'Eudosia', 'Archuleta Alonzo', 'D', '79 Paseo Junquera', 12513, 'Eudosia.Archuleta.Alonzo@mailinator.com', '17/09/46', 47, 12);
INSERT INTO usuaris VALUES (475, 'Stefan', 'Tafoya Polanco', 'H', '27 Carretera del Muelle', 12312, 'Stefan.Tafoya.Polanco@trashymail.com', '29/01/72', 45, 5);
INSERT INTO usuaris VALUES (476, 'Eduviges', 'Arroyo Baca', 'D', '89 C/ Pablo Iglesias', 26338, 'Eduviges.Arroyo.Baca@spambob.com', '12/09/77', 60, 10);
INSERT INTO usuaris VALUES (477, 'Emerson', 'Paredes Mares', 'H', '86 Lamas Carbajal', 41600, 'Emerson.Paredes.Mares@spambob.com', '11/05/68', 63, 10);
INSERT INTO usuaris VALUES (478, 'Gordon', 'Ocampo Melgar', NULL, '37 Estrela', 39500, 'Gordon.Ocampo.Melgar@trashymail.com', '10/09/56', 9, 5);
INSERT INTO usuaris VALUES (479, 'Alfa', 'Griego Razo', 'D', '77 Caño', 32850, 'Alfa.Griego.Razo@spambob.com', '08/07/76', 52, 7);
INSERT INTO usuaris VALUES (480, 'Etel', 'Padilla Delgadillo', 'D', '68 Avda. Enrique Peinador', 37160, 'Etel.Padilla.Delgadillo@pookmail.com', '30/09/46', 26, 12);
INSERT INTO usuaris VALUES (481, 'Ezechiel', 'Ortega Camacho', 'H', '58 Escuadro', 46940, 'Ezechiel.Ortega.Camacho@pookmail.com', '15/06/65', 84, NULL);
INSERT INTO usuaris VALUES (482, 'Lemuel', 'Veliz Arriaga', 'H', '51 Puerto Lugar', 29754, 'Lemuel.Veliz.Arriaga@pookmail.com', '06/10/45', 78, 9);
INSERT INTO usuaris VALUES (483, 'Kiliano', 'Urbina Tapia', 'H', '16 Apartado de Correos', 37440, 'Kiliano.Urbina.Tapia@pookmail.com', '13/01/84', 17, 11);
INSERT INTO usuaris VALUES (484, 'Edgar', 'Saldana Zavala', 'H', '69 Calle Proc. San Sebastián', 12593, 'Edgar.Saldana.Zavala@trashymail.com', '09/01/58', 27, 1);
INSERT INTO usuaris VALUES (485, 'Cristopher', 'Jaime Arriaga', 'H', '23 Puerta Nueva', 35628, 'Cristopher.Jaime.Arriaga@pookmail.com', '11/09/77', 39, 2);
INSERT INTO usuaris VALUES (486, 'Afrodita', 'Robledo Raya', 'D', '7 C/ Señores Curas', 11650, 'Afrodita.Robledo.Raya@pookmail.com', '22/04/56', 78, 11);
INSERT INTO usuaris VALUES (487, 'Elias', 'Guajardo Guevara', 'H', '12 Valadouro', 48116, 'Elias.Guajardo.Guevara@dodgit.com', '20/01/54', 8, 12);
INSERT INTO usuaris VALUES (488, 'Penny', 'Corral Arellano', 'D', '82 Ctra. Hornos', 26213, 'Penny.Corral.Arellano@dodgit.com', '09/09/63', 61, 2);
INSERT INTO usuaris VALUES (489, 'Kristina', 'Gamez Rico', 'D', '86 Alvaro Cunqueiro', 41309, 'Kristina.Gamez.Rico@mailinator.com', '25/09/56', 92, 12);
INSERT INTO usuaris VALUES (490, 'Aleida', 'Adomo Quintero', 'D', '55 C/ Amoladera', 28830, 'Aleida.Adomo.Quintero@trashymail.com', '24/06/81', 90, 6);
INSERT INTO usuaris VALUES (491, 'Kristina', 'Ontiveros Jáquez', 'D', '44 Avda. Alameda Sundheim', 22533, 'Kristina.Ontiveros.Jaquez@pookmail.com', '06/11/69', 98, 1);
INSERT INTO usuaris VALUES (492, 'Romero', 'Vaca Reyna', 'H', '51 Avda. de Andalucía', 29461, 'Romero.Vaca.Reyna@spambob.com', '12/09/48', 12, 6);
INSERT INTO usuaris VALUES (493, 'Almendra', 'Fuentes Briseño', 'D', '19 Outid de Arriba', 43711, 'Almendra.Fuentes.Briseno@trashymail.com', '18/06/77', 48, 4);
INSERT INTO usuaris VALUES (494, 'Olinda', 'Prado Santillán', NULL, '74 C/ Cuesta del  Álamo', 29679, 'Olinda.Prado.Santillan@dodgit.com', NULL, 35, 11);
INSERT INTO usuaris VALUES (495, 'Casio', 'Alaniz Atencio', 'H', '91 Ctra. de Fuentenueva', 28190, 'Casio.Alaniz.Atencio@mailinator.com', '27/03/52', 88, 6);
INSERT INTO usuaris VALUES (496, 'Etelvina', 'Mares Santana', 'D', '42 Visitación de la Encina', 37755, 'Etelvina.Mares.Santana@pookmail.com', '24/09/51', 80, 11);
INSERT INTO usuaris VALUES (497, 'Adelmo', 'Montoya Cruz', 'H', '6 C/ Libertad', 5260, 'Adelmo.Montoya.Cruz@dodgit.com', '25/05/83', 35, NULL);
INSERT INTO usuaris VALUES (498, 'Osmar', 'Villa Maya', 'H', '27 Rio Segura', 31500, 'Osmar.Villa.Maya@spambob.com', '18/05/40', 43, 3);
INSERT INTO usuaris VALUES (499, 'Cayo', 'Huerta Frías', 'H', '42 Avda. Generalísimo', 32150, 'Cayo.Huerta.Frias@dodgit.com', '16/10/48', 82, 12);
INSERT INTO usuaris VALUES (500, 'Sophie', 'Delgadillo Vega', 'D', '4 Fuente del Gallo', 14920, 'Sophie.Delgadillo.Vega@dodgit.com', '24/04/48', 64, 8);
INSERT INTO usuaris VALUES (501, 'Isaldina', 'Valencia Corona', 'D', '88 C/ Canarias', 20211, 'Isaldina.Valencia.Corona@pookmail.com', '04/01/53', 41, 8);
INSERT INTO usuaris VALUES (502, 'Betty', 'Saldana Sauceda', 'D', '39 Carretera', 14548, 'Betty.Saldana.Sauceda@dodgit.com', '10/08/77', 43, 5);
INSERT INTO usuaris VALUES (503, 'Wilma', 'Cabán Botello', 'D', '27 Boriñaur enparantza', 7440, 'Wilma.Caban.Botello@spambob.com', '08/05/58', 73, 11);
INSERT INTO usuaris VALUES (504, 'Wendi', 'Noriega Collado', 'D', '17 Pl. Virgen Blanca', 8600, 'Wendi.Noriega.Collado@trashymail.com', '16/11/52', 80, 11);
INSERT INTO usuaris VALUES (505, 'Adhemar', 'Farías Guevara', 'H', '15 Valadouro', 48210, 'Adhemar.Farias.Guevara@pookmail.com', '04/03/62', 48, 2);
INSERT INTO usuaris VALUES (506, 'Nuriel', 'Partida Ontiveros', 'D', '76 Reyes Católicos', 11130, 'Nuriel.Partida.Ontiveros@trashymail.com', '31/12/79', 82, 7);
INSERT INTO usuaris VALUES (507, 'Atala', 'Sanabria Gallardo', 'D', '59 Salzillo', 32625, 'Atala.Sanabria.Gallardo@dodgit.com', '11/09/47', 43, 11);
INSERT INTO usuaris VALUES (508, 'Catalina', 'Escobar Moreno', 'D', '6 Camiño Real', 48498, 'Catalina.Escobar.Moreno@spambob.com', '24/04/67', 45, NULL);
INSERT INTO usuaris VALUES (509, 'Cancio', 'Cuellar Jimínez', 'H', '73 Ventanilla de Beas', 28189, 'Cancio.Cuellar.Jiminez@spambob.com', '30/09/47', 23, 10);
INSERT INTO usuaris VALUES (510, 'Carpo', 'Carrero Castellanos', 'H', '25 Apartado de Correos', 37447, 'Carpo.Carrero.Castellanos@spambob.com', '22/07/79', 32, NULL);
INSERT INTO usuaris VALUES (511, 'Tiburcio', 'Correa Guardado', 'H', '31 Salzillo', 32692, 'Tiburcio.Correa.Guardado@mailinator.com', '28/07/61', 13, 9);
INSERT INTO usuaris VALUES (512, 'Lioba', 'Tafoya Merino', 'D', '8 C/ Cañada del Rosal', 21390, 'Lioba.Tafoya.Merino@pookmail.com', '30/07/55', 63, 10);
INSERT INTO usuaris VALUES (513, 'Keren', 'Quiñónez Saenz', 'D', '75 Socampo', 37684, 'Keren.Quinonez.Saenz@trashymail.com', '15/07/52', 32, 8);
INSERT INTO usuaris VALUES (514, 'Yuki', 'Dávila Cervantes', 'D', '39 Comandante Izarduy', 8920, 'Yuki.Davila.Cervantes@dodgit.com', '28/02/63', 61, 11);
INSERT INTO usuaris VALUES (515, 'Leopolda', 'Alfaro Mateo', 'D', '33 Camiño Ancho', 37767, 'Leopolda.Alfaro.Mateo@dodgit.com', '14/02/53', 83, 3);
INSERT INTO usuaris VALUES (516, 'Gisella', 'Saavedra Fierro', 'D', '19 Outid de Arriba', 43713, 'Gisella.Saavedra.Fierro@dodgit.com', '30/01/76', 23, 6);
INSERT INTO usuaris VALUES (517, 'Grato', 'Concepción Nieto', 'H', '84 Avda. Generalísimo', 31820, 'Grato.Concepcion.Nieto@mailinator.com', '28/03/79', 46, 9);
INSERT INTO usuaris VALUES (518, 'Escolástica', 'Calderón Bernal', 'D', '76 Paraguay', 3700, 'Escolastica.Calderon.Bernal@pookmail.com', '14/07/80', 96, 6);
INSERT INTO usuaris VALUES (519, 'Elena', 'Aguayo Menéndez', 'D', '94 Canónigo Valiño', 46620, 'Elena.Aguayo.Menendez@spambob.com', '23/02/40', 4, 8);
INSERT INTO usuaris VALUES (520, 'Lucía', 'Jasso Lugo', 'D', '35 C/ Domingo Beltrán', 2329, 'Lucia.Jasso.Lugo@mailinator.com', '12/04/83', 35, 12);
INSERT INTO usuaris VALUES (521, 'Isidre', 'Argüello Gaona', 'H', '26 Atamaria', 36800, 'Isidre.Arguello.Gaona@trashymail.com', '23/05/60', 45, 10);
INSERT INTO usuaris VALUES (522, 'Hipólito', 'Méndez Jasso', 'H', '86 C/ Los Herrán', 6490, 'Hipolito.Mendez.Jasso@pookmail.com', '18/09/47', 12, 3);
INSERT INTO usuaris VALUES (523, 'Pascualina', 'Duarte Marrero', 'D', '70 Pl. Virgen Blanca', 8630, 'Pascualina.Duarte.Marrero@dodgit.com', '19/03/62', 9, 12);
INSERT INTO usuaris VALUES (524, 'Saba', 'Ruiz Solórzano', 'D', '40 Crta. Cádiz-Málaga', 12225, 'Saba.Ruiz.Solorzano@dodgit.com', '20/04/76', 63, 6);
INSERT INTO usuaris VALUES (525, 'Covadonga', 'Cárdenas Esparza', 'D', '60 Ourense', 43120, 'Covadonga.Cardenas.Esparza@trashymail.com', '18/05/80', 46, 10);
INSERT INTO usuaris VALUES (526, 'Chloe', 'Alcalá Díaz', 'D', '62 José matía', 1400, 'Chloe.Alcala.Diaz@trashymail.com', '15/04/65', 82, 6);
INSERT INTO usuaris VALUES (527, 'Guy', 'Casárez Barreto', 'H', '68 Herrería', 18230, 'Guy.Casarez.Barreto@dodgit.com', '20/09/82', 74, 1);
INSERT INTO usuaris VALUES (528, 'Juvencio', 'Ruiz Cortés', 'H', '74 Cádiz', 18440, 'Juvencio.Ruiz.Cortes@mailinator.com', '18/07/72', 31, 1);
INSERT INTO usuaris VALUES (529, 'Vespasiano', 'Villaseñor Collado', 'H', '6 Reiseñor', 45600, 'Vespasiano.Villasenor.Collado@spambob.com', '09/04/57', 18, NULL);
INSERT INTO usuaris VALUES (530, 'Mixel', 'Treviño Loera', 'H', '63 Comandante Izarduy', 8830, 'Mixel.Trevino.Loera@pookmail.com', '14/04/77', 25, 12);
INSERT INTO usuaris VALUES (531, 'Mateos', 'Briones Acuna', 'H', '63 Avda. Explanada Barnuevo', 35550, 'Mateos.Briones.Acuna@mailinator.com', '02/07/82', 73, 7);
INSERT INTO usuaris VALUES (532, 'Wanda', 'Colón Figueroa', 'D', '22 Rúa do Paseo', 41880, 'Wanda.Colon.Figueroa@pookmail.com', '26/06/50', 32, 4);
INSERT INTO usuaris VALUES (533, 'Nurit', 'Loya Sanabria', 'D', '6 Outid de Arriba', 43719, 'Nurit.Loya.Sanabria@trashymail.com', '21/09/73', 28, NULL);
INSERT INTO usuaris VALUES (534, 'Aglae', 'Muñoz Muro', 'D', '25 Comandante Izarduy', 9200, 'Aglae.Munoz.Muro@dodgit.com', '03/12/42', 42, 9);
INSERT INTO usuaris VALUES (535, 'Liz', 'Alfaro Guerrero', 'D', '34 Eusebio Dávila', 41430, 'Liz.Alfaro.Guerrero@dodgit.com', '28/12/64', 4, 2);
INSERT INTO usuaris VALUES (536, 'Reinaldo', 'Delgado Nava', 'H', '62 Plaza de España', 15840, 'Reinaldo.Delgado.Nava@spambob.com', '13/06/57', 8, 5);
INSERT INTO usuaris VALUES (537, 'Loana', 'Pineda Juárez', 'D', '13 C/ Benito Guinea', 8292, 'Loana.Pineda.Juarez@spambob.com', '08/01/54', 68, 7);
INSERT INTO usuaris VALUES (538, 'Angelines', 'Briones Arellano', 'D', '65 Cercas Bajas', 8192, 'Angelines.Briones.Arellano@pookmail.com', '04/07/66', 83, 7);
INSERT INTO usuaris VALUES (539, 'Querubina', 'Cano Zayas', 'D', '80 C/ Henan Cortes', 29150, 'Querubina.Cano.Zayas@pookmail.com', '10/09/77', 62, 1);
INSERT INTO usuaris VALUES (540, 'Eulogia', 'Najera Sotelo', 'D', '7 Avda. Generalísimo', 31591, 'Eulogia.Najera.Sotelo@pookmail.com', '28/09/73', 47, 12);
INSERT INTO usuaris VALUES (541, 'Pelagio', 'Urrútia Alonzo', 'H', '63 C/ Rosa de los Vientos', 11178, 'Pelagio.Urrutia.Alonzo@pookmail.com', '06/08/83', 11, 12);
INSERT INTO usuaris VALUES (542, 'Helene', 'Escobar Verdugo', 'D', '36 Reiseñor', 46134, 'Helene.Escobar.Verdugo@trashymail.com', '11/05/85', 27, 1);
INSERT INTO usuaris VALUES (543, 'Jennifer', 'Agosto Díaz', 'D', '27 C/ Amoladera', 28813, 'Jennifer.Agosto.Diaz@pookmail.com', '01/09/55', 78, 8);
INSERT INTO usuaris VALUES (544, 'Cesáreo', 'Valle Naranjo', 'H', '95 C/ Rosa de los Vientos', 11300, 'Cesareo.Valle.Naranjo@pookmail.com', '24/09/62', 55, 8);
INSERT INTO usuaris VALUES (545, 'Lair', 'Benítez Farías', 'H', '49 Ctra. Hornos', 26224, 'Lair.Benitez.Farias@mailinator.com', '10/01/80', 98, 10);
INSERT INTO usuaris VALUES (546, 'Melina', 'Sevilla Amador', 'D', '57 Canónigo Valiño', 46540, 'Melina.Sevilla.Amador@spambob.com', '31/12/43', 42, 12);
INSERT INTO usuaris VALUES (547, 'Candelaria', 'Barajas Ordóñez', 'D', '28 San Andrés', 37292, 'Candelaria.Barajas.Ordonez@trashymail.com', '06/10/66', 61, 6);
INSERT INTO usuaris VALUES (548, 'Arandú', 'Castillo Ríos', 'H', '54 C/ Señores Curas', 11693, 'Arandu.Castillo.Rios@mailinator.com', '25/08/51', 32, 6);
INSERT INTO usuaris VALUES (549, 'Melany', 'Sanabria Urbina', 'D', '20 Ctra. de Fuentenueva', 28280, 'Melany.Sanabria.Urbina@trashymail.com', '11/10/53', 27, 12);
INSERT INTO usuaris VALUES (550, 'Timotea', 'Fierro Sánchez', 'D', '34 C/ Cuesta del  Álamo', 29551, 'Timotea.Fierro.Sanchez@dodgit.com', '23/05/67', 34, 4);
INSERT INTO usuaris VALUES (551, 'Mijail', 'Puente Armendáriz', 'H', '25 Herrería', 18195, 'Mijail.Puente.Armendariz@dodgit.com', '11/06/41', 12, 10);
INSERT INTO usuaris VALUES (552, 'Alfio', 'Collazo Berrios', 'H', '87 Bouciña', 43820, 'Alfio.Collazo.Berrios@pookmail.com', '27/02/56', 79, 12);
INSERT INTO usuaris VALUES (553, 'Crispo', 'Vallejo Vaca', 'H', '2 Paseo Junquera', 12449, 'Crispo.Vallejo.Vaca@spambob.com', '07/02/60', 70, NULL);
INSERT INTO usuaris VALUES (554, 'Isaias', 'Sepúlveda Marín', 'H', '80 Avda. Enrique Peinador', 37150, 'Isaias.Sepulveda.Marin@mailinator.com', '26/11/65', 13, 10);
INSERT INTO usuaris VALUES (555, 'Robertino', 'Griego Valles', 'H', '87 Eusebio Dávila', 41564, 'Robertino.Griego.Valles@pookmail.com', '26/01/64', 40, 10);
INSERT INTO usuaris VALUES (556, 'Juancruz', 'Rocha Villegas', 'H', '15 Av. Zumalakarregi', 3170, 'Juancruz.Rocha.Villegas@mailinator.com', '20/09/63', 45, 3);
INSERT INTO usuaris VALUES (557, 'Deidamia', 'Barrios Luján', NULL, '22 Cañadilla', 21891, 'Deidamia.Barrios.Lujan@mailinator.com', '17/04/79', 87, 8);
INSERT INTO usuaris VALUES (558, 'Edipo', 'Montanez Roybal', 'H', '43 Carretera del Muelle', 12320, 'Edipo.Montanez.Roybal@spambob.com', '11/09/54', 50, 6);
INSERT INTO usuaris VALUES (559, 'Joya', 'Ayala Guardado', 'D', '36 Avda. Explanada Barnuevo', 35400, 'Joya.Ayala.Guardado@pookmail.com', '02/03/79', 49, 8);
INSERT INTO usuaris VALUES (560, 'Flaminio', 'Comejo Ávalos', 'H', '21 San Andrés', 37290, 'Flaminio.Comejo.Avalos@trashymail.com', '24/02/64', 57, 2);
INSERT INTO usuaris VALUES (561, 'Centola', 'Longoria Irizarry', 'D', '92 Reyes Católicos', 11000, 'Centola.Longoria.Irizarry@spambob.com', '06/08/74', 64, 6);
INSERT INTO usuaris VALUES (562, 'Katriel', 'Escamilla Badillo', 'D', '48 Rúa Olmos', 37329, 'Katriel.Escamilla.Badillo@pookmail.com', '11/04/80', 14, 6);
INSERT INTO usuaris VALUES (563, 'Agamenón', 'Amador Romo', 'H', '58 Boriñaur enparantza', 7350, 'Agamenon.Amador.Romo@pookmail.com', '18/02/61', 0, 11);
INSERT INTO usuaris VALUES (564, 'Laodamia', 'Borrego Canales', 'D', '3 C/ Eras', 28754, 'Laodamia.Borrego.Canales@trashymail.com', '11/12/81', 28, 6);
INSERT INTO usuaris VALUES (565, 'Arián', 'Olivera Aparicio', 'H', '42 C/ Cuevas de Ambrosio', 23660, 'Arian.Olivera.Aparicio@dodgit.com', '26/06/82', 3, 4);
INSERT INTO usuaris VALUES (566, 'Agesislao', 'Esquivel Llarnas', 'H', '95 Valadouro', 48111, 'Agesislao.Esquivel.Llarnas@mailinator.com', '07/04/59', 27, 5);
INSERT INTO usuaris VALUES (567, 'Naná', 'Barrera Pedroza', 'D', '81 Rúa de San Pedro', 37798, 'Nana.Barrera.Pedroza@mailinator.com', '06/07/51', 72, 2);
INSERT INTO usuaris VALUES (568, 'Elia', 'Gaona Ceballos', 'D', '81 Rua da Rapina', 37468, 'Elia.Gaona.Ceballos@mailinator.com', '20/03/78', 62, 5);
INSERT INTO usuaris VALUES (569, 'Andrónico', 'Santiago Lerma', 'H', '86 Salzillo', 32634, 'Andronico.Santiago.Lerma@trashymail.com', '04/11/77', 60, 4);
INSERT INTO usuaris VALUES (570, 'Fileas', 'Rojas Escamilla', 'H', '67 Reyes Católicos', 9500, 'Fileas.Rojas.Escamilla@dodgit.com', '26/02/70', 7, 2);
INSERT INTO usuaris VALUES (571, 'Nasha', 'Roybal Carreón', NULL, '96 Plaza de España', 15687, 'Nasha.Roybal.Carreon@trashymail.com', '13/01/70', 67, 9);
INSERT INTO usuaris VALUES (572, 'Herbet', 'Segura Garrido', 'H', '44 C/ Fernández de Leceta', 3400, 'Herbet.Segura.Garrido@trashymail.com', '18/08/46', 53, 3);
INSERT INTO usuaris VALUES (573, 'Nikita', 'Zelaya Huerta', 'D', '16 Ctra. de Siles', 27430, 'Nikita.Zelaya.Huerta@spambob.com', '14/11/60', 95, 8);
INSERT INTO usuaris VALUES (574, 'Agripina', 'Quesada Robles', 'D', '55 Cartagena', 30520, 'Agripina.Quesada.Robles@mailinator.com', '11/10/84', 9, 1);
INSERT INTO usuaris VALUES (575, 'Gianira', 'Alvarado Barrera', 'D', '78 Constitución', 37111, 'Gianira.Alvarado.Barrera@spambob.com', '22/11/43', 84, 9);
INSERT INTO usuaris VALUES (576, 'Prudenciana', 'Pacheco Castro', 'D', '17 Avda. Andalucía', 26200, 'Prudenciana.Pacheco.Castro@pookmail.com', '17/12/56', 22, 6);
INSERT INTO usuaris VALUES (577, 'Lelio', 'Jáquez Rentería', 'H', '55 C/ Cuevas de Ambrosio', 23711, 'Lelio.Jaquez.Renteria@mailinator.com', '18/03/62', 84, 2);
INSERT INTO usuaris VALUES (578, 'Yara', 'Hurtado Escalante', 'D', '20 Outid de Arriba', 43550, 'Yara.Hurtado.Escalante@dodgit.com', '19/05/49', 93, 11);
INSERT INTO usuaris VALUES (579, 'Gordon', 'Sedillo Esquivel', 'H', '75 Atamaria', 36540, 'Gordon.Sedillo.Esquivel@dodgit.com', '08/12/56', 26, 3);
INSERT INTO usuaris VALUES (580, 'Saverio', 'Galindo Mascarenas', 'H', '89 Calvo Sotelo', 47250, 'Saverio.Galindo.Mascarenas@mailinator.com', '20/10/59', 24, 4);
INSERT INTO usuaris VALUES (581, 'Zulema', 'Jimínez Cabán', NULL, '36 Puerto Lugar', 29752, 'Zulema.Jiminez.Caban@pookmail.com', '15/08/83', 53, 5);
INSERT INTO usuaris VALUES (582, 'Melba', 'Reyna Zayas', 'D', '23 Inglaterra', 18540, 'Melba.Reyna.Zayas@dodgit.com', '23/09/71', 68, 12);
INSERT INTO usuaris VALUES (583, 'Lydie', 'Mena Jáquez', 'D', '98 Constitución', 36930, 'Lydie.Mena.Jaquez@spambob.com', '04/05/66', 70, 7);
INSERT INTO usuaris VALUES (584, 'Carina', 'Vallejo Solano', 'D', '60 Paseo del Atlántico', 17820, 'Carina.Vallejo.Solano@mailinator.com', '09/06/41', 66, 4);
INSERT INTO usuaris VALUES (585, 'Tara', 'Armijo Laureano', 'D', '34 C/ Pablo Iglesias', 26312, 'Tara.Armijo.Laureano@mailinator.com', '26/12/59', 88, 2);
INSERT INTO usuaris VALUES (586, 'Elaís', 'Gallegos Vega', 'D', '61 Ctra. Beas-Cortijos Nuevos', 26371, 'Elais.Gallegos.Vega@trashymail.com', '03/03/76', 55, 12);
INSERT INTO usuaris VALUES (587, 'Rosicler', 'Sanches Collazo', 'D', '73 Calle Carril de la Fuente', 13249, 'Rosicler.Sanches.Collazo@trashymail.com', '20/08/70', 56, 6);
INSERT INTO usuaris VALUES (588, 'Sam', 'Griego Concepción', 'H', '45 C/ Angosto', 23476, 'Sam.Griego.Concepcion@trashymail.com', '13/08/69', 89, 6);
INSERT INTO usuaris VALUES (589, 'Emilian', 'Márquez Ocampo', 'H', '31 Calle Aduana', 1170, 'Emilian.Marquez.Ocampo@trashymail.com', '19/03/45', 64, 1);
INSERT INTO usuaris VALUES (590, 'Jennifer', 'Amaya Jurado', 'D', '84 Boriñaur enparantza', 7570, 'Jennifer.Amaya.Jurado@spambob.com', '31/01/74', 7, 6);
INSERT INTO usuaris VALUES (591, 'Antenor', 'Valladares Granado', 'H', '8 Avda. Alameda Sundheim', 22510, 'Antenor.Valladares.Granado@pookmail.com', '24/05/40', 58, NULL);
INSERT INTO usuaris VALUES (592, 'Antares', 'Saavedra Ponce', 'H', '69 Paseo del Atlántico', 17251, 'Antares.Saavedra.Ponce@mailinator.com', '05/05/83', 16, 10);
INSERT INTO usuaris VALUES (593, 'Gordon', 'Matías Domínguez', 'H', '11 Carretera', 14630, 'Gordon.Matias.Dominguez@dodgit.com', '04/04/62', 56, 5);
INSERT INTO usuaris VALUES (594, 'Apeles', 'Tello Aparicio', 'H', '43 Constitución', 37111, 'Apeles.Tello.Aparicio@spambob.com', '16/06/74', 4, 3);
INSERT INTO usuaris VALUES (595, 'Cumelén', 'Saldivar Muñoz', 'D', '12 C/ Arana', 2637, 'Cumelen.Saldivar.Munoz@spambob.com', '15/11/41', 94, 2);
INSERT INTO usuaris VALUES (596, 'Audomaro', 'Linares Soria', 'H', '18 Plaza Colón', 24600, 'Audomaro.Linares.Soria@mailinator.com', '12/11/49', 41, 2);
INSERT INTO usuaris VALUES (597, 'Dennis', 'Mena Montanez', 'H', '40 Ctra. Bailén-Motril', 23191, 'Dennis.Mena.Montanez@spambob.com', '09/09/77', 87, 9);
INSERT INTO usuaris VALUES (598, 'Argeo', 'Meraz Ávalos', 'H', '69 Rúa do Paseo', 41970, 'Argeo.Meraz.Avalos@dodgit.com', '29/11/70', 43, 4);
INSERT INTO usuaris VALUES (599, 'Piero', 'Trejo Quiroz', 'H', '28 Plazuela do Porto', 38436, 'Piero.Trejo.Quiroz@spambob.com', '16/10/46', 91, 1);
INSERT INTO usuaris VALUES (600, 'Romildo', 'Mejía Ontiveros', 'H', '84 Plaza de España', 15800, 'Romildo.Mejia.Ontiveros@pookmail.com', '30/06/45', 19, NULL);
INSERT INTO usuaris VALUES (601, 'Salvio', 'Valverde Puente', 'H', '86 Pza. Fuensanta', 32235, 'Salvio.Valverde.Puente@pookmail.com', '04/01/70', 26, 5);
INSERT INTO usuaris VALUES (602, 'Fariol', 'Cordero Narváez', 'H', '28 C/ Rosa de los Vientos', 11178, 'Fariol.Cordero.Narvaez@trashymail.com', '28/01/42', 62, 9);
INSERT INTO usuaris VALUES (603, 'Arapey', 'Segura Valencia', 'H', '49 Pascual Yunquera', 18711, 'Arapey.Segura.Valencia@mailinator.com', '05/08/85', 18, 8);
INSERT INTO usuaris VALUES (604, 'Melusina', 'Guerra Villagómez', 'D', '44 Cruce Casa de Postas', 18414, 'Melusina.Guerra.Villagomez@mailinator.com', '14/03/66', 56, 4);
INSERT INTO usuaris VALUES (605, 'Lelia', 'Rubio Holguín', NULL, '94 C/ Henan Cortes', 29160, 'Lelia.Rubio.Holguin@dodgit.com', '21/12/66', 11, 5);
INSERT INTO usuaris VALUES (606, 'Iole', 'Bañuelos Huerta', 'H', '88 Avenida Cervantes', 48350, 'Iole.Banuelos.Huerta@spambob.com', '26/06/79', 0, 7);
INSERT INTO usuaris VALUES (607, 'Zenobia', 'Ríos Arce', 'D', '81 Ctra. de Fuentenueva', 28190, 'Zenobia.Rios.Arce@mailinator.com', '21/05/82', 83, 4);
INSERT INTO usuaris VALUES (608, 'Valentín', 'Salgado Noriega', 'H', '63 Reiseñor', 46120, 'Valentin.Salgado.Noriega@trashymail.com', '05/04/74', 37, 10);
INSERT INTO usuaris VALUES (609, 'Emigdio', 'Gaitán Meraz', 'H', '36 Ctra. de Siles', 27620, 'Emigdio.Gaitan.Meraz@trashymail.com', '29/05/74', 61, 9);
INSERT INTO usuaris VALUES (610, 'Boreas', 'Amador García', 'H', '27 Ctra. Villena', 34300, 'Boreas.Amador.Garcia@dodgit.com', '07/06/50', 96, 9);
INSERT INTO usuaris VALUES (611, 'Hamlet', 'Acuna Lovato', 'H', '21 Calle Carril de la Fuente', 13327, 'Hamlet.Acuna.Lovato@trashymail.com', '06/04/60', 63, 11);
INSERT INTO usuaris VALUES (612, 'Diadema', 'Zamora Solórzano', 'D', '97 Avda. Explanada Barnuevo', 35217, 'Diadema.Zamora.Solorzano@mailinator.com', '30/11/66', 93, 4);
INSERT INTO usuaris VALUES (613, 'Thomás', 'Rosado Aponte', 'H', '76 C/ Hijuela de Lojo', 20491, 'Thomas.Rosado.Aponte@mailinator.com', '09/01/75', 98, 5);
INSERT INTO usuaris VALUES (614, 'Noel', 'Rodarte Ortega', 'D', '95 Pascual Yunquera', 18800, 'Noel.Rodarte.Ortega@dodgit.com', '15/07/68', 58, 7);
INSERT INTO usuaris VALUES (615, 'Celsa', 'Ferrer Apodaca', 'D', '34 Cádiz', 18438, 'Celsa.Ferrer.Apodaca@pookmail.com', '25/07/59', 55, 9);
INSERT INTO usuaris VALUES (616, 'Eluney', 'Menchaca Merino', 'D', '37 Rúa de San Pedro', 37810, 'Eluney.Menchaca.Merino@pookmail.com', '13/04/62', 43, 5);
INSERT INTO usuaris VALUES (617, 'Agila', 'Parra Curiel', 'H', '7 Avda. de Andalucía', 29240, 'Agila.Parra.Curiel@trashymail.com', '24/05/80', 81, 9);
INSERT INTO usuaris VALUES (618, 'Sam', 'Cervantes Alva', 'H', '98 Atamaria', 36670, 'Sam.Cervantes.Alva@pookmail.com', '14/06/54', 5, 2);
INSERT INTO usuaris VALUES (619, 'Cuyén', 'Castro Loya', 'H', '62 C/ Eras', 28749, 'Cuyen.Castro.Loya@dodgit.com', '21/05/64', 94, NULL);
INSERT INTO usuaris VALUES (620, 'Yexalén', 'Guzmán Paredes', 'D', '83 Ctra. Bailén-Motril', 23250, 'Yexalen.Guzman.Paredes@spambob.com', '08/06/43', 46, 5);
INSERT INTO usuaris VALUES (621, 'Ariane', 'Olmos Duarte', 'D', '56 Ctra. Hornos', 26226, 'Ariane.Olmos.Duarte@dodgit.com', '23/02/48', 2, 5);
INSERT INTO usuaris VALUES (622, 'Tehuel', 'Preciado Lozada', 'H', '56 Bellavista', 50177, 'Tehuel.Preciado.Lozada@dodgit.com', '05/04/41', 33, 11);
INSERT INTO usuaris VALUES (623, 'Kevin', 'Castaneda Guardado', 'H', '87 Alvaro Cunqueiro', 41240, 'Kevin.Castaneda.Guardado@pookmail.com', '31/03/79', 51, 6);
INSERT INTO usuaris VALUES (624, 'Adalgisa', 'Nazario Castellanos', 'D', '59 Carretera del Muelle', 12413, 'Adalgisa.Nazario.Castellanos@trashymail.com', '20/09/60', 39, 3);
INSERT INTO usuaris VALUES (625, 'Jose', 'Gracia Valles', 'H', '27 Canónigo Valiño', 46450, 'Jose.Gracia.Valles@pookmail.com', '06/01/82', 60, 6);
INSERT INTO usuaris VALUES (626, 'Teolinda', 'Carranza Farías', 'D', '93 Camiño Ancho', 37774, 'Teolinda.Carranza.Farias@dodgit.com', '17/02/68', 23, 10);
INSERT INTO usuaris VALUES (627, 'Imperio', 'Cerda Leyva', 'D', '54 Carretera Cádiz-Málaga', 20850, 'Imperio.Cerda.Leyva@spambob.com', '28/10/58', 20, 1);
INSERT INTO usuaris VALUES (628, 'Denise', 'Soliz Solano', 'D', '27 Camiño Real', 48480, 'Denise.Soliz.Solano@mailinator.com', '28/09/50', 90, 7);
INSERT INTO usuaris VALUES (629, 'Damaris', 'Montalvo Olmos', 'D', '47 Avda. de Andalucía', 29328, 'Damaris.Montalvo.Olmos@spambob.com', '18/11/79', 11, 11);
INSERT INTO usuaris VALUES (630, 'Jon', 'Serna Uribe', 'H', '92 Av. Zumalakarregi', 3111, 'Jon.Serna.Uribe@pookmail.com', '11/03/68', 45, 6);
INSERT INTO usuaris VALUES (631, 'Giancarlo', 'Vanegas Escamilla', 'H', '67 Ourense', 42250, 'Giancarlo.Vanegas.Escamilla@pookmail.com', '09/10/47', 31, 1);
INSERT INTO usuaris VALUES (632, 'Jocelyn', 'Ruvalcaba Banda', 'D', '31 C/ Señores Curas', 12135, 'Jocelyn.Ruvalcaba.Banda@trashymail.com', '28/02/55', 95, 1);
INSERT INTO usuaris VALUES (633, 'Bernarda', 'Rico Leal', 'D', '89 Camiño Ancho', 37788, 'Bernarda.Rico.Leal@trashymail.com', '10/08/58', 15, 11);
INSERT INTO usuaris VALUES (634, 'Huilen', 'Ballesteros Garibay', 'D', '38 Canónigo Valiño', 46230, 'Huilen.Ballesteros.Garibay@dodgit.com', '23/11/42', 32, 2);
INSERT INTO usuaris VALUES (635, 'Kistiñe', 'Collado Lemus', 'D', '25 Pl. Virgen Blanca', 8700, 'Kistine.Collado.Lemus@mailinator.com', '28/08/63', 12, 12);
INSERT INTO usuaris VALUES (636, 'Iselda', 'Reynoso Cedillo', 'D', '28 Rúa de San Pedro', 37794, 'Iselda.Reynoso.Cedillo@trashymail.com', '04/03/47', 10, 8);
INSERT INTO usuaris VALUES (637, 'Hossana', 'Figueroa Pantoja', 'D', '82 Pascual Yunquera', 18800, 'Hossana.Figueroa.Pantoja@dodgit.com', '19/01/41', 58, 10);
INSERT INTO usuaris VALUES (638, 'Isberga', 'Jaime Espinal', 'D', '31 Ctra. de la Puerta', 26586, 'Isberga.Jaime.Espinal@spambob.com', '23/04/72', 31, 9);
INSERT INTO usuaris VALUES (639, 'Auda', 'Verdugo Polanco', 'D', '24 Alcon Molina', 30840, 'Auda.Verdugo.Polanco@dodgit.com', '29/05/85', 94, 4);
INSERT INTO usuaris VALUES (640, 'Luján', 'Mota Olivera', 'H', '25 Constitución', 37115, 'Lujan.Mota.Olivera@trashymail.com', '04/10/66', 32, 9);
INSERT INTO usuaris VALUES (641, 'Pampín', 'Valentín Carrión', 'H', '97 Pza. Fuensanta', 32430, 'Pampin.Valentin.Carrion@spambob.com', '17/12/70', 4, 8);
INSERT INTO usuaris VALUES (642, 'Tertulio', 'Sevilla Almaraz', 'H', '18 Paseo del Atlántico', 17820, 'Tertulio.Sevilla.Almaraz@spambob.com', '19/12/54', 58, 3);
INSERT INTO usuaris VALUES (643, 'Utka', 'Serrano Peres', 'H', '47 Plazuela do Porto', 38260, 'Utka.Serrano.Peres@mailinator.com', '29/03/75', 39, 10);
INSERT INTO usuaris VALUES (644, 'Sigfrido', 'Calvillo Escalante', 'H', '28 Camiño Ancho', 37791, 'Sigfrido.Calvillo.Escalante@mailinator.com', '24/06/48', 14, 6);
INSERT INTO usuaris VALUES (645, 'Hersilia', 'Menchaca Collazo', 'D', '6 Ctra. Hornos', 26212, 'Hersilia.Menchaca.Collazo@pookmail.com', '10/05/65', 38, 11);
INSERT INTO usuaris VALUES (646, 'Marc', 'Llarnas Zelaya', 'H', '60 Avda. Explanada Barnuevo', 35360, 'Marc.Llarnas.Zelaya@mailinator.com', '21/08/46', 59, 4);
INSERT INTO usuaris VALUES (647, 'Taffy', 'Soto Espinal', 'D', '11 Ventanilla de Beas', 28150, 'Taffy.Soto.Espinal@pookmail.com', '26/06/75', 15, 6);
INSERT INTO usuaris VALUES (648, 'Evaristo', 'Gurule Bravo', 'H', '93 Calle Carril de la Fuente', 13179, 'Evaristo.Gurule.Bravo@mailinator.com', '02/11/69', 22, 6);
INSERT INTO usuaris VALUES (649, 'Borja', 'Amador Aguilera', 'H', '20 Lamas Carbajal', 41566, 'Borja.Amador.Aguilera@trashymail.com', '04/06/58', 9, 7);
INSERT INTO usuaris VALUES (650, 'Verna', 'Zelaya Elizondo', 'D', '89 Ourense', 42360, 'Verna.Zelaya.Elizondo@mailinator.com', '28/08/61', 3, 1);
INSERT INTO usuaris VALUES (651, 'André', 'Paez Negrete', 'H', '77 C/ Cuevas de Ambrosio', 23640, 'Andre.Paez.Negrete@mailinator.com', '15/05/69', 90, 2);
INSERT INTO usuaris VALUES (652, 'Salvo', 'Porras Serrato', 'H', '42 Comandante Izarduy', 8930, 'Salvo.Porras.Serrato@pookmail.com', '12/09/62', 65, 12);
INSERT INTO usuaris VALUES (653, 'Pilato', 'Lucio Lozada', 'H', '42 Fuente del Gallo', 14870, 'Pilato.Lucio.Lozada@pookmail.com', '20/10/70', 97, 4);
INSERT INTO usuaris VALUES (654, 'Casimira', 'Chacón Sisneros', 'D', '2 Rua da Rapina', 37491, 'Casimira.Chacon.Sisneros@pookmail.com', '21/10/71', 2, 7);
INSERT INTO usuaris VALUES (655, 'Maximilian', 'Aguilar Gracia', 'H', '83 Valadouro', 48191, 'Maximilian.Aguilar.Gracia@mailinator.com', '24/01/85', 54, 5);
INSERT INTO usuaris VALUES (656, 'Itatay', 'Patino Ledesma', 'D', '88 C/ Benito Guinea', 8340, 'Itatay.Patino.Ledesma@trashymail.com', '23/12/61', 71, 1);
INSERT INTO usuaris VALUES (657, 'Teodolinda', 'Leyva Ulibarri', 'D', '27 Avda. de la Estación', 28570, 'Teodolinda.Leyva.Ulibarri@mailinator.com', '07/09/85', 47, 5);
INSERT INTO usuaris VALUES (658, 'Ernestina', 'Valles Cintrón', NULL, '57 Avenida Cervantes', 48320, 'Ernestina.Valles.Cintron@dodgit.com', '01/09/43', 22, 3);
INSERT INTO usuaris VALUES (659, 'Jasón', 'Arenas Osorio', 'H', '79 C/ Manuel Iradier', 3769, 'Jason.Arenas.Osorio@dodgit.com', '10/01/60', 32, NULL);
INSERT INTO usuaris VALUES (660, 'Gregorina', 'Roldán Tamez', 'D', '89 Reyes Católicos', 9530, 'Gregorina.Roldan.Tamez@mailinator.com', '13/04/59', 11, 1);
INSERT INTO usuaris VALUES (661, 'Mafalda', 'Lomeli Núñez', 'D', '33 Prolongacion San Sebastian', 21320, 'Mafalda.Lomeli.Nunez@trashymail.com', '06/03/73', 96, 5);
INSERT INTO usuaris VALUES (662, 'Leonora', 'Leiva Fonseca', 'D', '86 Canónigo Valiño', 46460, 'Leonora.Leiva.Fonseca@mailinator.com', '01/04/82', 47, 4);
INSERT INTO usuaris VALUES (663, 'Adelhard', 'Tejeda Colón', 'H', '41 Antonio Vázquez', 38450, 'Adelhard.Tejeda.Colon@dodgit.com', '24/05/81', 61, 9);
INSERT INTO usuaris VALUES (664, 'Faustina', 'Abrego Castellanos', 'D', '74 Paseo Junquera', 12429, 'Faustina.Abrego.Castellanos@pookmail.com', '18/06/67', 14, 2);
INSERT INTO usuaris VALUES (665, 'Ald', 'Santiago Espinosa', 'H', '32 Ctra. Villena', 34230, 'Ald.Santiago.Espinosa@pookmail.com', '01/11/83', 5, 8);
INSERT INTO usuaris VALUES (666, 'Perceval', 'Mora Jimínez', 'H', '84 Enxertos', 37516, 'Perceval.Mora.Jiminez@mailinator.com', '11/05/42', 23, 4);
INSERT INTO usuaris VALUES (667, 'Luisina', 'Guajardo Ocasio', 'D', '52 C/ Eras', 28755, 'Luisina.Guajardo.Ocasio@dodgit.com', '14/03/75', 35, 3);
INSERT INTO usuaris VALUES (668, 'Teodora', 'Galindo Almaraz', 'D', '38 C/ Canarias', 20100, 'Teodora.Galindo.Almaraz@dodgit.com', '27/07/84', 75, 4);
INSERT INTO usuaris VALUES (669, 'Lautaro', 'Fernández Montemayor', NULL, '32 Camiño Ancho', 37766, 'Lautaro.Fernandez.Montemayor@trashymail.com', '23/08/43', 49, 12);
INSERT INTO usuaris VALUES (670, 'Helia', 'Cazares Rangel', 'D', '33 Paseo Junquera', 12430, 'Helia.Cazares.Rangel@mailinator.com', '22/12/43', 30, 12);
INSERT INTO usuaris VALUES (671, 'Galia', 'Montano Olivárez', 'D', '27 Canónigo Valiño', 46300, 'Galia.Montano.Olivarez@pookmail.com', '28/06/84', 24, 1);
INSERT INTO usuaris VALUES (672, 'Marissa', 'Argüello Quiñones', 'D', '41 C/ Domingo Beltrán', 2246, 'Marissa.Arguello.Quinones@trashymail.com', '17/04/63', 92, 4);
INSERT INTO usuaris VALUES (673, 'Sabine', 'Velázquez Quiñónez', 'D', '87 Fuente del Gallo', 15123, 'Sabine.Velazquez.Quinonez@dodgit.com', '06/11/56', 28, 9);
INSERT INTO usuaris VALUES (674, 'Areb', 'Quiroz Torres', 'H', '91 Plaza Maior', 37214, 'Areb.Quiroz.Torres@pookmail.com', '27/04/64', 40, 11);
INSERT INTO usuaris VALUES (675, 'Balbina', 'Alvarez Linares', 'D', '87 Outid de Arriba', 43460, 'Balbina.Alvarez.Linares@pookmail.com', '28/12/81', 12, 3);
INSERT INTO usuaris VALUES (676, 'Pantaleón', 'Aparicio Nieves', 'H', '70 Boriñaur enparantza', 7620, 'Pantaleon.Aparicio.Nieves@trashymail.com', '06/01/68', 36, 9);
INSERT INTO usuaris VALUES (677, 'Marilyn', 'Pérez Alfaro', 'D', '76 Carretera', 14510, 'Marilyn.Perez.Alfaro@dodgit.com', '31/07/76', 17, 10);
INSERT INTO usuaris VALUES (678, 'Charlotte', 'Hernádez Muñiz', 'D', '11 Paseo Junquera', 12470, 'Charlotte.Hernadez.Muniz@pookmail.com', '05/09/60', 56, 3);
INSERT INTO usuaris VALUES (679, 'Oliana', 'Sepúlveda Cepeda', 'D', '77 Maestro Puig Valera', 33777, 'Oliana.Sepulveda.Cepeda@trashymail.com', '23/08/61', 52, 3);
INSERT INTO usuaris VALUES (680, 'Ornella', 'Atencio Gonzales', 'D', '32 Caño', 32786, 'Ornella.Atencio.Gonzales@dodgit.com', '30/04/80', 21, 6);
INSERT INTO usuaris VALUES (681, 'Itaete', 'Correa Naranjo', 'H', '63 Plaza Colón', 25300, 'Itaete.Correa.Naranjo@mailinator.com', '19/12/45', 80, 6);
INSERT INTO usuaris VALUES (682, 'Vitalicio', 'Jimínez Molina', 'H', '30 Reiseñor', 46160, 'Vitalicio.Jiminez.Molina@pookmail.com', '23/03/84', 18, 2);
INSERT INTO usuaris VALUES (683, 'Raphael', 'Pineda Ocasio', 'H', '16 El Roqueo', 15873, 'Raphael.Pineda.Ocasio@spambob.com', '19/01/75', 8, 2);
INSERT INTO usuaris VALUES (684, 'Nuri', 'Manzanares Montanez', 'H', '68 Eusebio Dávila', 41370, 'Nuri.Manzanares.Montanez@dodgit.com', '26/02/75', NULL, 11);
INSERT INTO usuaris VALUES (685, 'Longinos', 'Ordóñez Sánchez', 'H', '63 Quevedo', 15313, 'Longinos.Ordonez.Sanchez@dodgit.com', '22/06/63', 56, 10);
INSERT INTO usuaris VALUES (686, 'Aleck', 'Salcido Granados', 'H', '8 Alvaro Cunqueiro', 41220, 'Aleck.Salcido.Granados@pookmail.com', '24/01/55', 22, 1);
INSERT INTO usuaris VALUES (687, 'Fiona', 'Martínez Velasco', 'D', '95 Alcon Molina', 31140, 'Fiona.Martinez.Velasco@pookmail.com', '03/06/71', 5, 5);
INSERT INTO usuaris VALUES (688, 'Anais', 'Barela Gallardo', 'D', '18 Avda. Enrique Peinador', 37183, 'Anais.Barela.Gallardo@spambob.com', '11/02/84', 77, 6);
INSERT INTO usuaris VALUES (689, 'Monserrat', 'Arredondo Rojas', 'H', '31 Cercas Bajas', 8214, 'Monserrat.Arredondo.Rojas@trashymail.com', '10/02/69', 68, 1);
INSERT INTO usuaris VALUES (690, 'Giordano', 'Vergara Prado', 'H', '43 Pza. Fuensanta', 32360, 'Giordano.Vergara.Prado@spambob.com', '16/01/67', 90, NULL);
INSERT INTO usuaris VALUES (691, 'Vicenta', 'Tórrez Moreno', 'D', '26 El Roqueo', 16220, 'Vicenta.Torrez.Moreno@mailinator.com', '08/06/64', NULL, 6);
INSERT INTO usuaris VALUES (692, 'Macra', 'Lemus Alva', 'D', '23 Avda. de la Estación', 28609, 'Macra.Lemus.Alva@dodgit.com', '29/12/74', 28, NULL);
INSERT INTO usuaris VALUES (693, 'Alí', 'Tamez Collazo', 'H', '56 Caño', 33114, 'Ali.Tamez.Collazo@dodgit.com', '07/10/65', 99, 10);
INSERT INTO usuaris VALUES (694, 'Anna', 'Hinojosa Meraz', 'D', '94 Plazuela do Porto', 37893, 'Anna.Hinojosa.Meraz@spambob.com', '26/03/53', 73, 8);
INSERT INTO usuaris VALUES (695, 'Henry', 'Carreón Griego', 'H', '5 Antonio Vázquez', 38720, 'Henry.Carreon.Griego@mailinator.com', '09/12/49', 61, 6);
INSERT INTO usuaris VALUES (696, 'Ceumar', 'Caraballo Barela', 'H', '54 Paseo Junquera', 12520, 'Ceumar.Caraballo.Barela@mailinator.com', '16/06/66', 50, NULL);
INSERT INTO usuaris VALUES (697, 'Julia', 'Saldivar Feliciano', 'D', '10 C/ Hijuela de Lojo', 20491, 'Julia.Saldivar.Feliciano@dodgit.com', '22/03/77', 9, 10);
INSERT INTO usuaris VALUES (698, 'Margarita', 'Marroquín Lozada', 'D', '57 Paseo Junquera', 12460, 'Margarita.Marroquin.Lozada@spambob.com', '11/01/85', 85, 4);
INSERT INTO usuaris VALUES (699, 'Tibalt', 'Chapa Abrego', 'H', '27 Caño', 33120, 'Tibalt.Chapa.Abrego@spambob.com', '09/06/73', 43, NULL);
INSERT INTO usuaris VALUES (700, 'Arián', 'Alemán Lomeli', 'H', '16 Pascual Yunquera', 18817, 'Arian.Aleman.Lomeli@trashymail.com', '25/01/82', 12, 2);
INSERT INTO usuaris VALUES (701, 'Curcio', 'Aparicio Godoy', 'H', '12 Puerta Nueva', 35628, 'Curcio.Aparicio.Godoy@dodgit.com', '12/10/65', 69, 3);
INSERT INTO usuaris VALUES (702, 'Vernón', 'Ayala Mejía', 'H', '90 C/ Libertad', 5000, 'Vernon.Ayala.Mejia@dodgit.com', '21/03/50', 79, 6);
INSERT INTO usuaris VALUES (703, 'Adelaide', 'Leyva Guerra', 'D', '59 Prolongacion San Sebastian', 21110, 'Adelaide.Leyva.Guerra@trashymail.com', '26/06/45', 12, 12);
INSERT INTO usuaris VALUES (704, 'Piren', 'Mendoza Dueñas', 'D', '33 Padre Caro', 13480, 'Piren.Mendoza.Duenas@spambob.com', '10/02/41', 1, 3);
INSERT INTO usuaris VALUES (705, 'Koko', 'Tafoya Mercado', 'H', '53 Bellavista', 50000, 'Koko.Tafoya.Mercado@dodgit.com', '02/06/63', 41, 3);
INSERT INTO usuaris VALUES (706, 'Celide', 'Duran Salinas', 'D', '85 Herrería', 18197, 'Celide.Duran.Salinas@mailinator.com', '12/05/59', 63, 7);
INSERT INTO usuaris VALUES (707, 'Ayelén', 'Palomo Escamilla', 'D', '19 Ctra. Beas-Cortijos Nuevos', 26570, 'Ayelen.Palomo.Escamilla@spambob.com', '01/05/48', 62, 12);
INSERT INTO usuaris VALUES (708, 'Aquilesia', 'Feliciano Zayas', 'D', '13 Reyes Católicos', 9260, 'Aquilesia.Feliciano.Zayas@trashymail.com', '02/01/71', 65, NULL);
INSERT INTO usuaris VALUES (709, 'Thiago', 'Cerda Calvillo', 'H', '52 Ctra. Bailén-Motril', 23390, 'Thiago.Cerda.Calvillo@mailinator.com', '26/01/80', 22, 7);
INSERT INTO usuaris VALUES (710, 'Lizbeth', 'Morales Pérez', 'D', '59 Ventanilla de Beas', 28100, 'Lizbeth.Morales.Perez@trashymail.com', '05/07/79', 0, 1);
INSERT INTO usuaris VALUES (711, 'Saskia', 'Ocampo Lugo', 'D', '58 Rosa de los Vientos', 13342, 'Saskia.Ocampo.Lugo@spambob.com', '04/04/40', 76, 5);
INSERT INTO usuaris VALUES (712, 'Miles', 'Ochoa Loya', 'H', '26 C/ Cuevas de Ambrosio', 23670, 'Miles.Ochoa.Loya@dodgit.com', '19/03/83', 41, NULL);
INSERT INTO usuaris VALUES (713, 'Keiko', 'Iglesias Posada', 'D', '22 Calle Carril de la Fuente', 13195, 'Keiko.Iglesias.Posada@trashymail.com', '10/03/45', 16, 12);
INSERT INTO usuaris VALUES (714, 'Absalón', 'Marín Cantú', 'H', '99 Rio Segura', 31511, 'Absalon.Marin.Cantu@pookmail.com', '29/10/73', 54, 8);
INSERT INTO usuaris VALUES (715, 'Edén', 'Armenta Escamilla', 'D', '11 Calle Carril de la Fuente', 13179, 'Eden.Armenta.Escamilla@trashymail.com', '01/01/48', 55, 8);
INSERT INTO usuaris VALUES (716, 'Arminda', 'Robles Regalado', 'D', '81 Plazuela do Porto', 37893, 'Arminda.Robles.Regalado@pookmail.com', '31/03/59', 47, 10);
INSERT INTO usuaris VALUES (717, 'Lizbeth', 'Rico Espino', 'D', '25 Castelao', 48900, 'Lizbeth.Rico.Espino@mailinator.com', '18/08/84', 89, 5);
INSERT INTO usuaris VALUES (718, 'Néstor', 'Castellanos González', 'H', '19 Celso Emilio Ferreiro', 50630, 'Nestor.Castellanos.Gonzalez@trashymail.com', '18/10/82', 98, NULL);
INSERT INTO usuaris VALUES (719, 'Arnaldo', 'Herrera Rojo', 'H', '84 C/ Benito Guinea', 8270, 'Arnaldo.Herrera.Rojo@mailinator.com', '26/01/58', 19, 11);
INSERT INTO usuaris VALUES (720, 'Odina', 'Urena Reyna', 'D', '8 C/ Cuesta del  Álamo', 29566, 'Odina.Urena.Reyna@mailinator.com', '23/06/45', 39, 8);
INSERT INTO usuaris VALUES (721, 'Sigrid', 'Lemus Puente', 'D', '77 Ctra. Bailén-Motril', 23191, 'Sigrid.Lemus.Puente@mailinator.com', '19/07/58', 83, NULL);
INSERT INTO usuaris VALUES (722, 'Melany', 'Hernandes Soto', 'D', '13 Avda. Enrique Peinador', 37182, 'Melany.Hernandes.Soto@spambob.com', '01/11/77', 52, 6);
INSERT INTO usuaris VALUES (723, 'Hilario', 'Guerrero Nevarez', 'H', '65 Cádiz', 18516, 'Hilario.Guerrero.Nevarez@mailinator.com', '19/09/54', 67, 7);
INSERT INTO usuaris VALUES (724, 'Rainero', 'Espinoza Ybarra', 'H', '68 Paseo del Atlántico', 17257, 'Rainero.Espinoza.Ybarra@pookmail.com', '13/10/60', 86, 9);
INSERT INTO usuaris VALUES (725, 'Hygin', 'Santillán Noriega', 'H', '99 Avda. Enrique Peinador', 37183, 'Hygin.Santillan.Noriega@dodgit.com', '18/05/48', 22, 12);
INSERT INTO usuaris VALUES (726, 'Cintia', 'Vallejo Pacheco', 'D', '17 Valadouro', 48212, 'Cintia.Vallejo.Pacheco@dodgit.com', '09/08/63', 27, 12);
INSERT INTO usuaris VALUES (727, 'Dalal', 'Callas Valverde', 'D', '47 Comandante Izarduy', 8980, 'Dalal.Callas.Valverde@spambob.com', '26/02/50', 18, 11);
INSERT INTO usuaris VALUES (728, 'Batilde', 'Morales Paez', 'D', '33 Ventanilla de Beas', 27765, 'Batilde.Morales.Paez@trashymail.com', '24/10/59', 97, 8);
INSERT INTO usuaris VALUES (729, 'Waldino', 'Banda Cordero', 'H', '70 Fuente del Gallo', 15110, 'Waldino.Banda.Cordero@spambob.com', '21/05/63', 15, 6);
INSERT INTO usuaris VALUES (730, 'Naimid', 'Ledesma Laureano', 'D', '78 Avendaño', 3828, 'Naimid.Ledesma.Laureano@mailinator.com', '14/12/73', 25, 3);
INSERT INTO usuaris VALUES (731, 'Lev', 'Nieto Garibay', 'H', '23 C/ Canarias', 20212, 'Lev.Nieto.Garibay@spambob.com', '10/08/80', 87, 8);
INSERT INTO usuaris VALUES (732, 'Araceli', 'Olivera Maestas', 'D', '27 Avda. Los llanos', 26288, 'Araceli.Olivera.Maestas@spambob.com', '23/04/52', 1, 7);
INSERT INTO usuaris VALUES (733, 'Otniel', 'Carrasquill Suárez', 'H', '48 Camiño Ancho', 37764, 'Otniel.Carrasquill.Suarez@pookmail.com', '09/05/79', NULL, 2);
INSERT INTO usuaris VALUES (734, 'Arandú', 'Leal Oquendo', 'H', '80 Comandante Izarduy', 9110, 'Arandu.Leal.Oquendo@spambob.com', '11/02/76', 99, 6);
INSERT INTO usuaris VALUES (735, 'Renán', 'Esquibel Toro', 'H', '21 Ctra. Villena', 33900, 'Renan.Esquibel.Toro@trashymail.com', '01/11/55', 1, 8);
INSERT INTO usuaris VALUES (736, 'Domma', 'Barela Nieves', 'D', '1 Puerta Nueva', 36420, 'Domma.Barela.Nieves@mailinator.com', '13/05/40', 67, 12);
INSERT INTO usuaris VALUES (737, 'Jose', 'Gutiérrez Guzmán', 'H', '50 C/ Cañada del Rosal', 21592, 'Jose.Gutierrez.Guzman@trashymail.com', '23/04/80', 85, 2);
INSERT INTO usuaris VALUES (738, 'Leoncio', 'Aragón Vega', 'H', '55 Reyes Católicos', 9400, 'Leoncio.Aragon.Vega@dodgit.com', '05/05/40', 55, NULL);
INSERT INTO usuaris VALUES (739, 'Asha', 'Reyes Vela', 'D', '98 Boriñaur enparantza', 7640, 'Asha.Reyes.Vela@spambob.com', '19/06/47', 20, 10);
INSERT INTO usuaris VALUES (740, 'Triana.', 'Crespo Mireles', 'D', '47 Pascual Yunquera', 18800, 'Triana.Crespo.Mireles@dodgit.com', '03/06/61', 14, NULL);
INSERT INTO usuaris VALUES (741, 'Kenneth', 'Corral Árias', 'H', '32 Inglaterra', 18614, 'Kenneth.Corral.Arias@trashymail.com', '05/06/46', 42, 4);
INSERT INTO usuaris VALUES (742, 'Kaori', 'Sedillo Luján', 'H', '24 Avenida Cervantes', 48309, 'Kaori.Sedillo.Lujan@trashymail.com', '27/04/44', 9, 2);
INSERT INTO usuaris VALUES (743, 'Ticiano', 'Zarate Villanueva', 'H', '19 Herrería', 18197, 'Ticiano.Zarate.Villanueva@dodgit.com', '18/01/67', 37, NULL);
INSERT INTO usuaris VALUES (744, 'Carissa', 'Ruiz Saenz', 'D', '91 Padre Caro', 13480, 'Carissa.Ruiz.Saenz@trashymail.com', '21/06/65', 53, 8);
INSERT INTO usuaris VALUES (745, 'Plinio', 'Alfaro Muñoz', 'H', '43 Pza. Fuensanta', 32454, 'Plinio.Alfaro.Munoz@spambob.com', '01/06/64', 2, 3);
INSERT INTO usuaris VALUES (746, 'Yaco', 'Cotto Puente', 'H', '74 C/ Benito Guinea', 8250, 'Yaco.Cotto.Puente@pookmail.com', '21/08/53', 29, 7);
INSERT INTO usuaris VALUES (747, 'Mafalda', 'Aponte Cavazos', 'D', '4 Socampo', 37659, 'Mafalda.Aponte.Cavazos@trashymail.com', '11/09/75', 3, 3);
INSERT INTO usuaris VALUES (748, 'Waldo', 'Valle Partida', 'H', '53 Prolongacion San Sebastian', 21290, 'Waldo.Valle.Partida@trashymail.com', '25/04/69', 36, 11);
INSERT INTO usuaris VALUES (749, 'Kristen', 'Árias Negrón', NULL, '1 C/ Eras', 28738, 'Kristen.Arias.Negron@dodgit.com', '24/09/63', 14, 8);
INSERT INTO usuaris VALUES (750, 'Dámaso', 'Viera Cerda', 'H', '61 Eusebio Dávila', 41560, 'Damaso.Viera.Cerda@pookmail.com', '21/12/67', 72, 4);
INSERT INTO usuaris VALUES (751, 'Brunella', 'Limón Gutiérrez', 'D', '30 Cercas Bajas', 8100, 'Brunella.Limon.Gutierrez@mailinator.com', '09/12/85', 70, 9);
INSERT INTO usuaris VALUES (752, 'Adassa', 'Nava Nieves', 'H', '30 Pascual Yunquera', 18670, 'Adassa.Nava.Nieves@dodgit.com', '28/02/51', 74, 4);
INSERT INTO usuaris VALUES (753, 'Yaguatí', 'Urrútia Pichardo', 'H', '26 Alvaro Cunqueiro', 41220, 'Yaguati.Urrutia.Pichardo@dodgit.com', '20/03/68', 74, 7);
INSERT INTO usuaris VALUES (754, 'Filomeno', 'Limón Cavazos', 'H', '50 Av. Zumalakarregi', 3179, 'Filomeno.Limon.Cavazos@pookmail.com', '20/04/52', 0, 6);
INSERT INTO usuaris VALUES (755, 'Inacayal', 'Llarnas Baez', 'H', '68 Zumalakarregi etorbidea', 7330, 'Inacayal.Llarnas.Baez@trashymail.com', '13/04/41', 84, 9);
INSERT INTO usuaris VALUES (756, 'Rina', 'Nino Olvera', 'D', '6 Rosa de los Vientos', 13341, 'Rina.Nino.Olvera@mailinator.com', '22/01/51', 72, NULL);
INSERT INTO usuaris VALUES (757, 'Baco', 'Hernandes Raya', 'H', '51 San Andrés', 37248, 'Baco.Hernandes.Raya@pookmail.com', '09/05/42', 45, 1);
INSERT INTO usuaris VALUES (758, 'Gilberta', 'Arévalo Bahena', 'D', '76 Rúa Olmos', 37317, 'Gilberta.Arevalo.Bahena@pookmail.com', '04/06/83', 78, 1);
INSERT INTO usuaris VALUES (759, 'Zohar', 'Maya Bueno', 'H', '16 Puerta Nueva', 36000, 'Zohar.Maya.Bueno@mailinator.com', '29/12/56', 48, 9);
INSERT INTO usuaris VALUES (760, 'Hermalindo', 'Téllez Marroquín', 'H', '64 Cercas Bajas', 7840, 'Hermalindo.Tellez.Marroquin@trashymail.com', '08/02/84', 23, 10);
INSERT INTO usuaris VALUES (761, 'Matilda', 'Rodarte Escobar', 'D', '93 Enxertos', 37522, 'Matilda.Rodarte.Escobar@dodgit.com', '31/03/63', 0, 11);
INSERT INTO usuaris VALUES (762, 'Lihue', 'Ozuna Ojeda', 'D', '12 C/ Manuel Iradier', 3814, 'Lihue.Ozuna.Ojeda@trashymail.com', '12/07/77', 88, NULL);
INSERT INTO usuaris VALUES (763, 'Anibal', 'Vergara Fonseca', 'H', '86 Ctra. Beas-Cortijos Nuevos', 26526, 'Anibal.Vergara.Fonseca@mailinator.com', '16/09/65', 1, 9);
INSERT INTO usuaris VALUES (764, 'Prudencia', 'Granado Benavidez', 'D', '87 Castelao', 49400, 'Prudencia.Granado.Benavidez@mailinator.com', '01/06/50', 58, 5);
INSERT INTO usuaris VALUES (765, 'Petrus', 'Lira Orozco', 'H', '5 Paseo del Atlántico', 17251, 'Petrus.Lira.Orozco@pookmail.com', '26/01/43', 30, 7);
INSERT INTO usuaris VALUES (766, 'Edgarda', 'Barrios Almanza', 'D', '48 C/ Libertad', 4890, 'Edgarda.Barrios.Almanza@mailinator.com', '11/07/59', 80, 6);
INSERT INTO usuaris VALUES (767, 'Luvencio', 'Maya Saavedra', 'H', '93 Urzáiz', 44770, 'Luvencio.Maya.Saavedra@trashymail.com', '03/07/47', 37, 10);
INSERT INTO usuaris VALUES (768, 'Roberta', 'Cepeda Villareal', 'D', '21 Crta. Cádiz-Málaga', 12182, 'Roberta.Cepeda.Villareal@dodgit.com', '26/04/56', 75, 3);
INSERT INTO usuaris VALUES (769, 'Zoé', 'Ramos Nevarez', 'H', '62 Ventanilla de Beas', 27773, 'Zoe.Ramos.Nevarez@dodgit.com', '01/04/79', 68, 8);
INSERT INTO usuaris VALUES (770, 'Amalio', 'Manzanares Galván', 'H', '92 Rosa de los Vientos', 13414, 'Amalio.Manzanares.Galvan@pookmail.com', '16/11/77', 94, 5);
INSERT INTO usuaris VALUES (771, 'Cuyen', 'Porras Gamez', 'D', '21 Avda. Alameda Sundheim', 22500, 'Cuyen.Porras.Gamez@dodgit.com', '01/07/82', 49, NULL);
INSERT INTO usuaris VALUES (772, 'Cordelia', 'Alanis Barrientos', 'D', '58 Crta. Cádiz-Málaga', 12230, 'Cordelia.Alanis.Barrientos@dodgit.com', '24/02/40', 21, 10);
INSERT INTO usuaris VALUES (773, 'Sophe', 'Ornelas Rosario', 'D', '36 El Roqueo', 17130, 'Sophe.Ornelas.Rosario@dodgit.com', '22/07/52', 91, 9);
INSERT INTO usuaris VALUES (774, 'Suzzane', 'Rendón Moreno', 'D', '49 Plazuela do Porto', 38300, 'Suzzane.Rendon.Moreno@mailinator.com', '27/07/50', 40, 3);
INSERT INTO usuaris VALUES (775, 'Nolan', 'Espinosa Castaneda', 'H', '71 C/ Arana', 2638, 'Nolan.Espinosa.Castaneda@trashymail.com', '03/02/57', 53, 1);
INSERT INTO usuaris VALUES (776, 'Floriana', 'Canales Bonilla', 'D', '42 Bouciña', 43890, 'Floriana.Canales.Bonilla@dodgit.com', '04/07/45', 2, 8);
INSERT INTO usuaris VALUES (777, 'Junior', 'Mena García', 'H', '69 Fuente del Gallo', 15147, 'Junior.Mena.Garcia@mailinator.com', '08/07/40', 30, 4);
INSERT INTO usuaris VALUES (778, 'Yesica', 'Maldonado Salas', 'D', '48 C/ Los Herrán', 6800, 'Yesica.Maldonado.Salas@spambob.com', '08/12/40', 62, 10);
INSERT INTO usuaris VALUES (779, 'Ferdinand', 'Lucio Cardona', 'H', '78 Avda. Andalucía', 26191, 'Ferdinand.Lucio.Cardona@dodgit.com', '03/11/67', 93, NULL);
INSERT INTO usuaris VALUES (780, 'Partenia', 'Benavides Macías', 'D', '53 C/ Cuesta del  Álamo', 29611, 'Partenia.Benavides.Macias@spambob.com', '02/06/53', 76, 4);
INSERT INTO usuaris VALUES (781, 'Noemi', 'Najera Anaya', 'D', '3 Avda. de Andalucía', 29312, 'Noemi.Najera.Anaya@pookmail.com', '20/10/75', 14, 12);
INSERT INTO usuaris VALUES (782, 'Dimas', 'Marín Quintana', 'H', '72 C/ Rosa de los Vientos', 11300, 'Dimas.Marin.Quintana@mailinator.com', '11/02/65', 46, 4);
INSERT INTO usuaris VALUES (783, 'Casandro', 'Valverde Orta', 'H', '97 C/ Rosa de los Vientos', 11200, 'Casandro.Valverde.Orta@pookmail.com', '03/01/41', 24, 10);
INSERT INTO usuaris VALUES (784, 'Fedra', 'Díaz Alfaro', 'D', '71 C/ Cuesta del  Álamo', 29500, 'Fedra.Diaz.Alfaro@trashymail.com', '22/01/77', 30, 11);
INSERT INTO usuaris VALUES (785, 'Valburga', 'Velázquez Rubio', 'D', '46 Zumalakarregi etorbidea', 7190, 'Valburga.Velazquez.Rubio@spambob.com', '18/01/40', 43, NULL);
INSERT INTO usuaris VALUES (786, 'Baruj', 'Vanegas Nino', 'H', '50 Castelao', 48910, 'Baruj.Vanegas.Nino@mailinator.com', '23/06/69', 8, 4);
INSERT INTO usuaris VALUES (787, 'Talia', 'Munguia Chavarría', 'D', '72 Avenida Cervantes', 48320, 'Talia.Munguia.Chavarria@mailinator.com', '20/03/81', 28, 10);
INSERT INTO usuaris VALUES (788, 'Achill', 'Jaramillo Pacheco', 'H', '24 Avda. Los llanos', 26292, 'Achill.Jaramillo.Pacheco@dodgit.com', '10/02/66', 24, 8);
INSERT INTO usuaris VALUES (789, 'Honorata', 'Galván Casillas', 'D', '19 C/ Domingo Beltrán', 2249, 'Honorata.Galvan.Casillas@mailinator.com', '21/11/54', 37, 11);
INSERT INTO usuaris VALUES (790, 'Bienvenida', 'Mateo Farías', 'D', '79 C/ Hijuela de Lojo', 20493, 'Bienvenida.Mateo.Farias@trashymail.com', '29/09/74', 58, 8);
INSERT INTO usuaris VALUES (791, 'Darcy', 'Aguilar Melgar', 'D', '85 Avda. Explanada Barnuevo', 35350, 'Darcy.Aguilar.Melgar@mailinator.com', '10/01/77', 57, 11);
INSERT INTO usuaris VALUES (792, 'Corrado', 'Venegas Montemayor', NULL, '12 Av. Zumalakarregi', 3180, 'Corrado.Venegas.Montemayor@pookmail.com', '26/10/51', 84, NULL);
INSERT INTO usuaris VALUES (793, 'Zina', 'Benítez Jaramillo', 'D', '12 Prolongacion San Sebastian', 21291, 'Zina.Benitez.Jaramillo@dodgit.com', '05/11/43', 70, 3);
INSERT INTO usuaris VALUES (794, 'Douglas', 'Barrera Carranza', 'H', '25 Ctra. de Fuentenueva', 28190, 'Douglas.Barrera.Carranza@trashymail.com', '24/05/68', 81, 8);
INSERT INTO usuaris VALUES (795, 'Gerald', 'Olivera Benavidez', 'H', '88 C/ Henan Cortes', 28978, 'Gerald.Olivera.Benavidez@trashymail.com', '20/04/61', 41, 2);
INSERT INTO usuaris VALUES (796, 'Fanuel', 'Guillén Jaramillo', 'H', '5 Avda. Explanada Barnuevo', 35450, 'Fanuel.Guillen.Jaramillo@trashymail.com', '02/07/41', 3, 12);
INSERT INTO usuaris VALUES (797, 'Helda', 'Escalante Banda', 'D', '74 Ctra. Bailén-Motril', 23240, 'Helda.Escalante.Banda@spambob.com', '16/07/80', 92, 4);
INSERT INTO usuaris VALUES (798, 'Zaqueo', 'Estrada Callas', 'H', '58 Avda. Andalucía', 26148, 'Zaqueo.Estrada.Callas@pookmail.com', '31/01/58', 34, 6);
INSERT INTO usuaris VALUES (799, 'Uziel', 'Leal Pantoja', 'H', '35 Constitución', 36890, 'Uziel.Leal.Pantoja@pookmail.com', '09/01/74', 64, 10);
INSERT INTO usuaris VALUES (800, 'Geoffrey', 'Canales Nevarez', 'H', '90 Calle Proc. San Sebastián', 12549, 'Geoffrey.Canales.Nevarez@spambob.com', '01/11/67', 97, 1);
INSERT INTO usuaris VALUES (801, 'Pampa', 'Almanza Mendoza', 'D', '39 C/ Manuel Iradier', 3780, 'Pampa.Almanza.Mendoza@pookmail.com', '05/02/72', 23, 3);
INSERT INTO usuaris VALUES (802, 'Onan', 'Guerrero Calderón', 'H', '8 Zumalakarregi etorbidea', 7144, 'Onan.Guerrero.Calderon@pookmail.com', '18/01/42', 73, 1);
INSERT INTO usuaris VALUES (803, 'Yamil', 'Mayonga Cedillo', 'H', '76 Urzáiz', 44530, 'Yamil.Mayonga.Cedillo@spambob.com', '28/01/78', 58, 11);
INSERT INTO usuaris VALUES (804, 'Mili', 'Godínez Urbina', 'D', '87 C/ Andalucía', 4750, 'Mili.Godinez.Urbina@dodgit.com', '21/09/77', 7, 11);
INSERT INTO usuaris VALUES (805, 'Egidio', 'Rivas Montemayor', NULL, '34 Ctra. Beas-Cortijos Nuevos', 26532, 'Egidio.Rivas.Montemayor@mailinator.com', '07/06/82', 6, NULL);
INSERT INTO usuaris VALUES (806, 'Malcolm', 'Candelaria Baeza', 'H', '40 Camiño Ancho', 37789, 'Malcolm.Candelaria.Baeza@mailinator.com', '25/10/73', 38, 2);
INSERT INTO usuaris VALUES (807, 'Meulén', 'Rodríguez Negrón', 'H', '97 C/ Cuesta del  Álamo', 29560, 'Meulen.Rodriguez.Negron@spambob.com', '04/03/76', 31, 12);
INSERT INTO usuaris VALUES (808, 'Cora', 'Marrero Rojo', 'D', '44 Urzáiz', 44540, 'Cora.Marrero.Rojo@trashymail.com', '04/12/53', 95, 1);
INSERT INTO usuaris VALUES (809, 'Hippolyte', 'Valadez Holguín', 'H', '83 Alvaro Cunqueiro', 40370, 'Hippolyte.Valadez.Holguin@mailinator.com', '25/12/43', 21, 10);
INSERT INTO usuaris VALUES (810, 'Yvette', 'Jáquez Zambrano', 'D', '65 C/ Pablo Iglesias', 26329, 'Yvette.Jaquez.Zambrano@mailinator.com', '10/10/70', 9, 9);
INSERT INTO usuaris VALUES (811, 'Asaf', 'Barela Aguilera', 'H', '64 Salzillo', 32600, 'Asaf.Barela.Aguilera@mailinator.com', '25/01/64', 24, 4);
INSERT INTO usuaris VALUES (812, 'Jon', 'Argüello Uribe', 'H', '17 Cercas Bajas', 8214, 'Jon.Arguello.Uribe@dodgit.com', '14/03/53', 30, 7);
INSERT INTO usuaris VALUES (813, 'Aron', 'Solís Duran', 'H', '27 Bouciña', 43747, 'Aron.Solis.Duran@pookmail.com', '23/05/50', 51, 4);
INSERT INTO usuaris VALUES (814, 'Melibeo', 'Barajas Rocha', 'H', '68 Puerta Nueva', 35630, 'Melibeo.Barajas.Rocha@spambob.com', '24/11/59', 77, NULL);
INSERT INTO usuaris VALUES (815, 'Casto', 'Grijalva Montanez', 'H', '3 Quevedo', 15293, 'Casto.Grijalva.Montanez@pookmail.com', '30/11/58', 64, 8);
INSERT INTO usuaris VALUES (816, 'Edaline', 'Madrid Cano', 'D', '90 Carretera del Muelle', 12311, 'Edaline.Madrid.Cano@spambob.com', '11/02/57', 88, 1);
INSERT INTO usuaris VALUES (817, 'Inocencio', 'Caballero Prado', 'H', '31 C/ Fernández de Leceta', 3369, 'Inocencio.Caballero.Prado@dodgit.com', '22/07/84', 13, 1);
INSERT INTO usuaris VALUES (818, 'Bonifacia', 'Hernandes Paez', 'D', '63 Constitución', 37129, 'Bonifacia.Hernandes.Paez@dodgit.com', '25/02/71', 96, 4);
INSERT INTO usuaris VALUES (819, 'Lelio', 'Tejada Ochoa', 'H', '68 Castelao', 49200, 'Lelio.Tejada.Ochoa@spambob.com', '30/03/78', 80, 10);
INSERT INTO usuaris VALUES (820, 'Alexandra', 'Becerra Robledo', 'D', '89 Carretera', 14630, 'Alexandra.Becerra.Robledo@dodgit.com', '08/07/73', 38, 10);
INSERT INTO usuaris VALUES (821, 'Illed', 'Orozco Bañuelos', 'D', '7 C/ Canarias', 19200, 'Illed.Orozco.Banuelos@trashymail.com', '26/09/56', 87, 2);
INSERT INTO usuaris VALUES (822, 'Tecla', 'Segura Rosario', 'D', '89 Avda. Alameda Sundheim', 22640, 'Tecla.Segura.Rosario@trashymail.com', '05/05/56', 87, 4);
INSERT INTO usuaris VALUES (823, 'Curcio', 'Escamilla Llarnas', 'H', '13 Carretera del Muelle', 12317, 'Curcio.Escamilla.Llarnas@trashymail.com', '06/04/43', 58, 1);
INSERT INTO usuaris VALUES (824, 'Ismenia', 'Echevarría Gamez', 'D', '38 Ctra. Bailén-Motril', 23320, 'Ismenia.Echevarria.Gamez@pookmail.com', '04/04/42', 85, 10);
INSERT INTO usuaris VALUES (825, 'Salvio', 'Vargas Murillo', 'H', '32 Calle Carril de la Fuente', 13193, 'Salvio.Vargas.Murillo@spambob.com', '23/09/57', 31, 12);
INSERT INTO usuaris VALUES (826, 'Jerry', 'Téllez Robledo', 'H', '38 Plazuela do Porto', 37893, 'Jerry.Tellez.Robledo@dodgit.com', '23/03/42', 15, 5);
INSERT INTO usuaris VALUES (827, 'Virna', 'Rangel Salinas', 'D', '52 C/ Benito Guinea', 8261, 'Virna.Rangel.Salinas@mailinator.com', '27/02/79', 1, 11);
INSERT INTO usuaris VALUES (828, 'Paine', 'Ávila Lemus', 'D', '5 Ctra. Bailén-Motril', 23266, 'Paine.Avila.Lemus@dodgit.com', '14/11/49', 27, 8);
INSERT INTO usuaris VALUES (829, 'Brunilda', 'Prieto Aranda', 'D', '16 C/ Señores Curas', 12127, 'Brunilda.Prieto.Aranda@dodgit.com', '07/02/80', 23, 9);
INSERT INTO usuaris VALUES (830, 'Valerie', 'Menéndez Cortez', 'D', '62 C/ Pablo Iglesias', 26312, 'Valerie.Menendez.Cortez@pookmail.com', '24/08/56', 75, 11);
INSERT INTO usuaris VALUES (831, 'Eufemio', 'Quiroz Salgado', 'H', '60 C/ Los Herrán', 6230, 'Eufemio.Quiroz.Salgado@trashymail.com', '30/07/60', 17, 4);
INSERT INTO usuaris VALUES (832, 'Tilo', 'Brito Olivárez', 'H', '90 C/ Pablo Iglesias', 26312, 'Tilo.Brito.Olivarez@trashymail.com', '31/08/57', 71, 9);
INSERT INTO usuaris VALUES (833, 'Milba', 'Vega Holguín', NULL, '38 Escuadro', 46760, 'Milba.Vega.Holguin@dodgit.com', '14/02/62', 12, 4);
INSERT INTO usuaris VALUES (834, 'Eliezer', 'Villaseñor Orta', 'H', '24 La Fontanilla', 14220, 'Eliezer.Villasenor.Orta@trashymail.com', '13/10/83', 64, 9);
INSERT INTO usuaris VALUES (835, 'Bienvenido', 'Vázquez Orozco', 'H', '45 Ourense', 43000, 'Bienvenido.Vazquez.Orozco@mailinator.com', '19/11/47', 40, 9);
INSERT INTO usuaris VALUES (836, 'Cerca', 'Gallegos Bonilla', 'D', '43 Ctra. Hornos', 26213, 'Cerca.Gallegos.Bonilla@dodgit.com', '06/06/41', 51, 6);
INSERT INTO usuaris VALUES (837, 'Petrus', 'Correa Godoy', 'H', '39 Calle Carril de la Fuente', 13193, 'Petrus.Correa.Godoy@trashymail.com', '28/09/61', 87, 8);
INSERT INTO usuaris VALUES (838, 'Magín', 'Valdés Zaragoza', 'H', '67 Castelao', 48710, 'Magin.Valdes.Zaragoza@dodgit.com', '29/03/68', 44, NULL);
INSERT INTO usuaris VALUES (839, 'Paskasi', 'Gallardo Vera', 'H', '45 Zumalakarregi etorbidea', 7311, 'Paskasi.Gallardo.Vera@dodgit.com', '13/02/62', 90, 10);
INSERT INTO usuaris VALUES (840, 'Rogelia', 'Galindo Lucio', 'D', '39 Plaza de España', 15830, 'Rogelia.Galindo.Lucio@mailinator.com', '26/07/66', 26, 11);
INSERT INTO usuaris VALUES (841, 'Rosmira', 'Gaitán Matos', 'D', '99 Comandante Izarduy', 8980, 'Rosmira.Gaitan.Matos@spambob.com', NULL, 93, 11);
INSERT INTO usuaris VALUES (842, 'Brandon', 'Pacheco Salazar', NULL, '16 Rúa do Paseo', 41927, 'Brandon.Pacheco.Salazar@spambob.com', '28/07/85', 81, 1);
INSERT INTO usuaris VALUES (843, 'Tolomeo', 'Santana Estrada', 'H', '95 Reyes Católicos', 9670, 'Tolomeo.Santana.Estrada@spambob.com', '22/03/61', 22, 10);
INSERT INTO usuaris VALUES (844, 'Douglas', 'Armas Camacho', 'H', '8 Quevedo', 15175, 'Douglas.Armas.Camacho@spambob.com', '26/08/46', 65, 4);
INSERT INTO usuaris VALUES (845, 'Lis', 'Maldonado Berrios', 'D', '48 Cartagena', 30420, 'Lis.Maldonado.Berrios@dodgit.com', '05/11/74', 66, 11);
INSERT INTO usuaris VALUES (846, 'Bonifaci', 'Ozuna Pedraza', 'H', '56 Quevedo', 15312, 'Bonifaci.Ozuna.Pedraza@dodgit.com', '13/10/84', 22, 11);
INSERT INTO usuaris VALUES (847, 'Simeón', 'Olivas Garica', 'H', '16 Alvaro Cunqueiro', 41100, 'Simeon.Olivas.Garica@dodgit.com', '28/12/76', 35, 1);
INSERT INTO usuaris VALUES (848, 'Milba', 'Leiva Agosto', 'D', '11 C/ Benito Guinea', 8291, 'Milba.Leiva.Agosto@pookmail.com', '16/02/42', 25, 7);
INSERT INTO usuaris VALUES (849, 'Antonino', 'Cotto Gonzales', 'H', '11 Rua da Rapina', 37494, 'Antonino.Cotto.Gonzales@mailinator.com', '17/04/43', 23, 8);
INSERT INTO usuaris VALUES (850, 'Juanita', 'Alfaro Ponce', 'D', '63 C/ Canarias', 20180, 'Juanita.Alfaro.Ponce@mailinator.com', '13/11/55', 28, 3);
INSERT INTO usuaris VALUES (851, 'Calíope', 'Fierro Posada', 'D', '93 Camiño Ancho', 37791, 'Caliope.Fierro.Posada@spambob.com', '26/11/72', 22, 8);
INSERT INTO usuaris VALUES (852, 'Johana', 'Parra Segura', 'D', '66 Ctra. de Siles', 27664, 'Johana.Parra.Segura@trashymail.com', '23/02/41', 97, 6);
INSERT INTO usuaris VALUES (853, 'Denisse', 'Mares Raya', 'D', '4 Avda. de la Estación', 28597, 'Denisse.Mares.Raya@trashymail.com', '06/01/41', 41, 11);
INSERT INTO usuaris VALUES (854, 'Neera', 'Orosco Bermúdez', 'D', '20 José matía', 1520, 'Neera.Orosco.Bermudez@spambob.com', '04/12/62', 13, 7);
INSERT INTO usuaris VALUES (855, 'Ama', 'Díaz Miranda', 'D', '79 C/ Canarias', 20115, 'Ama.Diaz.Miranda@spambob.com', '27/01/65', 40, 10);
INSERT INTO usuaris VALUES (856, 'Renán', 'Arana Tamayo', 'H', '79 Paseo Junquera', 12469, 'Renan.Arana.Tamayo@dodgit.com', '01/04/62', 80, 6);
INSERT INTO usuaris VALUES (857, 'Katherine', 'Barraza Quesada', 'D', '64 C/ Amoladera', 28815, 'Katherine.Barraza.Quesada@trashymail.com', '14/07/78', 1, NULL);
INSERT INTO usuaris VALUES (858, 'Gisberto', 'Castellanos Tijerina', 'H', '41 Pza. Fuensanta', 32234, 'Gisberto.Castellanos.Tijerina@dodgit.com', '07/10/51', 0, 9);
INSERT INTO usuaris VALUES (859, 'Pola', 'Puga Ceja', 'D', '80 Calle Aduana', 1300, 'Pola.Puga.Ceja@spambob.com', '19/01/54', 24, 6);
INSERT INTO usuaris VALUES (860, 'Michaela', 'Navarro Saavedra', 'D', '18 Pl. Virgen Blanca', 8500, 'Michaela.Navarro.Saavedra@spambob.com', '31/12/57', 32, 1);
INSERT INTO usuaris VALUES (861, 'Adolf', 'Garay Lebrón', 'H', '70 Pascual Yunquera', 18680, 'Adolf.Garay.Lebron@trashymail.com', '06/06/57', 28, 2);
INSERT INTO usuaris VALUES (862, 'Aimon', 'Roybal Acuna', 'H', '48 Pascual Yunquera', 18870, 'Aimon.Roybal.Acuna@spambob.com', '06/12/84', 1, 9);
INSERT INTO usuaris VALUES (863, 'Olaya', 'Ozuna Valentín', NULL, '30 C/ Angosto', 23420, 'Olaya.Ozuna.Valentin@dodgit.com', '25/12/80', 90, 9);
INSERT INTO usuaris VALUES (864, 'Idelia', 'Magana Valdivia', 'D', '65 Rúa de San Pedro', 37800, 'Idelia.Magana.Valdivia@spambob.com', '22/11/57', 78, 3);
INSERT INTO usuaris VALUES (865, 'Claudina', 'Serrato Armas', 'D', '49 Plazuela do Porto', 37892, 'Claudina.Serrato.Armas@trashymail.com', '30/06/61', 9, 8);
INSERT INTO usuaris VALUES (866, 'Giacometta', 'Iglesias Benítez', 'D', '66 Apartado de Correos', 37439, 'Giacometta.Iglesias.Benitez@trashymail.com', '23/01/44', 5, 1);
INSERT INTO usuaris VALUES (867, 'Hugolino', 'Beltrán Salazar', NULL, '72 Reiseñor', 45730, 'Hugolino.Beltran.Salazar@mailinator.com', '07/07/85', 76, 8);
INSERT INTO usuaris VALUES (868, 'Jon', 'Bravo Juárez', 'H', '4 Apartado de Correos', 37456, 'Jon.Bravo.Juarez@pookmail.com', '16/08/81', 98, NULL);
INSERT INTO usuaris VALUES (869, 'Toshi', 'Gracia Ruelas', 'H', '3 Avda. Enrique Peinador', 37182, 'Toshi.Gracia.Ruelas@pookmail.com', '16/07/65', 60, 12);
INSERT INTO usuaris VALUES (870, 'Dinah', 'Najera Martínez', 'D', '84 Constitución', 37110, 'Dinah.Najera.Martinez@mailinator.com', '19/02/67', 16, 5);
INSERT INTO usuaris VALUES (871, 'Leonarda', 'Gaytan Valadez', 'D', '44 C/ Pablo Iglesias', 26315, 'Leonarda.Gaytan.Valadez@dodgit.com', '19/10/62', 74, 1);
INSERT INTO usuaris VALUES (872, 'Nofre', 'Correa Jasso', 'H', '33 Plaza de España', 15620, 'Nofre.Correa.Jasso@dodgit.com', '26/11/70', 47, 2);
INSERT INTO usuaris VALUES (873, 'Maribel', 'Burgos Llarnas', 'D', '61 Camiño Ancho', 37767, 'Maribel.Burgos.Llarnas@pookmail.com', '11/04/42', 60, 4);
INSERT INTO usuaris VALUES (874, 'Liana', 'Maya Villalobos', 'D', '66 Ctra. Villena', 33870, 'Liana.Maya.Villalobos@spambob.com', '05/04/53', NULL, 4);
INSERT INTO usuaris VALUES (875, 'Omer', 'Medina Linares', 'H', '43 Apartado de Correos', 37440, 'Omer.Medina.Linares@trashymail.com', '03/06/85', 39, NULL);
INSERT INTO usuaris VALUES (876, 'Xochilt', 'Padrón Espinosa', 'D', '7 Cartagena', 30360, 'Xochilt.Padron.Espinosa@trashymail.com', '09/06/79', 27, 2);
INSERT INTO usuaris VALUES (877, 'Evelien', 'Batista Ayala', 'D', '37 Zumalakarregi etorbidea', 7315, 'Evelien.Batista.Ayala@trashymail.com', '12/01/42', 41, 11);
INSERT INTO usuaris VALUES (878, 'Cyprien', 'Alcalá Mondragón', 'H', '75 Ctra. Bailén-Motril', 23213, 'Cyprien.Alcala.Mondragon@trashymail.com', '17/04/45', 23, 7);
INSERT INTO usuaris VALUES (879, 'Idelfonso', 'Márquez Alcalá', 'H', '16 Rúa Olmos', 37405, 'Idelfonso.Marquez.Alcala@trashymail.com', '13/01/64', 27, 7);
INSERT INTO usuaris VALUES (880, 'Romelio', 'Nevarez Mena', 'H', '8 Valadouro', 48116, 'Romelio.Nevarez.Mena@trashymail.com', '14/06/75', 16, 9);
INSERT INTO usuaris VALUES (881, 'Palas', 'Figueroa Galvez', 'D', '7 C/ Cuesta del  Álamo', 29560, 'Palas.Figueroa.Galvez@pookmail.com', '19/09/78', 93, 6);
INSERT INTO usuaris VALUES (882, 'León', 'Lara Abreu', 'H', '98 Ctra. Villena', 34340, 'Leon.Lara.Abreu@trashymail.com', '14/08/58', 87, 3);
INSERT INTO usuaris VALUES (883, 'Arnau', 'Carrasquill Jaramillo', 'H', '63 C/ Benito Guinea', 8360, 'Arnau.Carrasquill.Jaramillo@spambob.com', '31/10/52', 25, 11);
INSERT INTO usuaris VALUES (884, 'Glauco', 'Domínguez Miramontes', 'D', '17 Apartado de Correos', 37455, 'Glauco.Dominguez.Miramontes@spambob.com', '10/04/67', 95, 7);
INSERT INTO usuaris VALUES (885, 'Marciano', 'Olivárez Almaraz', 'H', '68 Zumalakarregi etorbidea', 7140, 'Marciano.Olivarez.Almaraz@dodgit.com', '31/07/56', 65, 8);
INSERT INTO usuaris VALUES (886, 'Sylvia', 'Padrón Ontiveros', 'D', '66 Paseo del Atlántico', 18127, 'Sylvia.Padron.Ontiveros@mailinator.com', '30/09/75', 87, 9);
INSERT INTO usuaris VALUES (887, 'Annabel', 'Alemán Lira', 'D', '83 C/ Cañada del Rosal', 21647, 'Annabel.Aleman.Lira@pookmail.com', '13/03/44', 10, 8);
INSERT INTO usuaris VALUES (888, 'Jimeno', 'Árias Castro', 'H', '17 Castelao', 48891, 'Jimeno.Arias.Castro@dodgit.com', '25/03/63', 44, 12);
INSERT INTO usuaris VALUES (889, 'Maral', 'Laboy Almaraz', 'D', '14 Antonio Vázquez', 38600, 'Maral.Laboy.Almaraz@spambob.com', '03/12/80', 51, 6);
INSERT INTO usuaris VALUES (890, 'Anunciación', 'Leal Uribe', 'D', '16 Avda. Explanada Barnuevo', 35290, 'Anunciacion.Leal.Uribe@mailinator.com', '07/02/54', 79, 2);
INSERT INTO usuaris VALUES (891, 'Ileana', 'Rojo Galvez', 'D', '46 Plaza de España', 15700, 'Ileana.Rojo.Galvez@mailinator.com', '22/05/44', 17, 9);
INSERT INTO usuaris VALUES (892, 'Jacqueline', 'Monroy Rolón', NULL, '78 Padre Caro', 14000, 'Jacqueline.Monroy.Rolon@pookmail.com', '16/06/43', 67, 8);
INSERT INTO usuaris VALUES (893, 'Miren', 'Fernández Gamboa', 'D', '74 Canónigo Valiño', 46540, 'Miren.Fernandez.Gamboa@trashymail.com', '23/02/61', NULL, 11);
INSERT INTO usuaris VALUES (894, 'Martina', 'Rocha Madrigal', 'D', '65 Calle Proc. San Sebastián', 13116, 'Martina.Rocha.Madrigal@dodgit.com', '11/05/60', 80, 4);
INSERT INTO usuaris VALUES (895, 'Zoraida', 'Arteaga Herrera', 'D', '42 Cruce Casa de Postas', 18320, 'Zoraida.Arteaga.Herrera@mailinator.com', '06/10/47', 80, 1);
INSERT INTO usuaris VALUES (896, 'Clotilde', 'Godínez Trejo', 'D', '55 C/ Angosto', 23600, 'Clotilde.Godinez.Trejo@pookmail.com', '04/12/60', 25, 12);
INSERT INTO usuaris VALUES (897, 'Nimfa', 'Ruiz Lugo', 'D', '46 C/ Henan Cortes', 29180, 'Nimfa.Ruiz.Lugo@spambob.com', '05/11/57', 45, 6);
INSERT INTO usuaris VALUES (898, 'Basa', 'Pulido Reséndez', 'D', '61 C/ Cañada del Rosal', 21591, 'Basa.Pulido.Resendez@spambob.com', '31/05/51', 40, 3);
INSERT INTO usuaris VALUES (899, 'Mijail', 'Arriaga Tamez', 'H', '31 Bellavista', 49600, 'Mijail.Arriaga.Tamez@pookmail.com', '14/01/45', 75, 2);
INSERT INTO usuaris VALUES (900, 'Jerónima', 'Vargas Reyna', 'D', '64 Atamaria', 36830, 'Jeronima.Vargas.Reyna@dodgit.com', '19/12/51', 52, 1);
INSERT INTO usuaris VALUES (901, 'Orencio', 'Loya Cano', 'H', '52 C/ Cuesta del  Álamo', 29551, 'Orencio.Loya.Cano@pookmail.com', '09/06/51', 59, 6);
INSERT INTO usuaris VALUES (902, 'Ashley', 'Pelayo Corrales', 'D', '25 Fuente del Gallo', 15145, 'Ashley.Pelayo.Corrales@mailinator.com', '27/05/43', 82, 12);
INSERT INTO usuaris VALUES (903, 'Raymi', 'Urena Camarillo', 'H', '8 Puerta Nueva', 36416, 'Raymi.Urena.Camarillo@mailinator.com', '15/02/54', 1, 6);
INSERT INTO usuaris VALUES (904, 'Tilo', 'Alonso Tafoya', 'H', '5 Avda. Explanada Barnuevo', 35280, 'Tilo.Alonso.Tafoya@dodgit.com', '23/04/75', 65, 9);
INSERT INTO usuaris VALUES (905, 'Pusaki', 'Navarrete Escobedo', 'H', '67 C/ Rosa de los Vientos', 11600, 'Pusaki.Navarrete.Escobedo@trashymail.com', '18/09/54', 78, 9);
INSERT INTO usuaris VALUES (906, 'Alarico', 'Marrero Abreu', 'H', '60 C/ Henan Cortes', 28930, 'Alarico.Marrero.Abreu@trashymail.com', '27/11/45', 89, 11);
INSERT INTO usuaris VALUES (907, 'Wilton', 'Rubio Curiel', 'H', '41 Valadouro', 48150, 'Wilton.Rubio.Curiel@spambob.com', NULL, 50, 5);
INSERT INTO usuaris VALUES (908, 'Eudoxio', 'Nevarez Guajardo', 'H', '42 Ctra. de Siles', 27611, 'Eudoxio.Nevarez.Guajardo@mailinator.com', '17/03/76', 12, 12);
INSERT INTO usuaris VALUES (909, 'Victorio', 'Tovar Santacruz', 'H', '39 Avda. Los llanos', 26261, 'Victorio.Tovar.Santacruz@mailinator.com', '14/11/59', 10, 10);
INSERT INTO usuaris VALUES (910, 'Menandro', 'Granado Mares', 'H', '89 Avda. Explanada Barnuevo', 35530, 'Menandro.Granado.Mares@trashymail.com', '06/05/47', 61, 4);
INSERT INTO usuaris VALUES (911, 'Desiderato', 'Soto Razo', 'H', '87 Ctra. de la Puerta', 27270, 'Desiderato.Soto.Razo@trashymail.com', '16/08/57', 97, 10);
INSERT INTO usuaris VALUES (912, 'Ursulina', 'Figueroa Zapata', 'D', '10 Prolongacion San Sebastian', 21230, 'Ursulina.Figueroa.Zapata@spambob.com', '17/10/58', 76, 1);
INSERT INTO usuaris VALUES (913, 'Kirian', 'Montanez Duran', 'H', '5 Enxertos', 37522, 'Kirian.Montanez.Duran@spambob.com', '20/10/46', 48, 8);
INSERT INTO usuaris VALUES (914, 'Cosimus', 'Guerrero Barajas', 'H', '33 Calle Proc. San Sebastián', 13000, 'Cosimus.Guerrero.Barajas@mailinator.com', '11/10/84', 49, 8);
INSERT INTO usuaris VALUES (915, 'Manque', 'Cintrón Guevara', 'D', '1 Camiño Ancho', 37777, 'Manque.Cintron.Guevara@dodgit.com', '17/07/85', 77, 5);
INSERT INTO usuaris VALUES (916, 'Joanes', 'Reyes Estévez', 'H', '56 Puerto Lugar', 29718, 'Joanes.Reyes.Estevez@pookmail.com', '21/06/61', 25, 4);
INSERT INTO usuaris VALUES (917, 'Gilda', 'Escobedo Barragán', NULL, '53 Puerto Lugar', 30140, 'Gilda.Escobedo.Barragan@mailinator.com', '18/01/64', 76, 7);
INSERT INTO usuaris VALUES (918, 'Régulo', 'Castillo Valencia', 'H', '40 Outid de Arriba', 43730, 'Regulo.Castillo.Valencia@pookmail.com', '24/11/64', 12, 6);
INSERT INTO usuaris VALUES (919, 'Sabelia', 'Mascarenas Montez', 'D', '24 C/ Cañada del Rosal', 21640, 'Sabelia.Mascarenas.Montez@spambob.com', '25/04/69', 21, 2);
INSERT INTO usuaris VALUES (920, 'Gioseppina', 'Hurtado Borrego', 'D', '34 Ctra. de Fuentenueva', 28194, 'Gioseppina.Hurtado.Borrego@trashymail.com', '11/06/45', 50, 6);
INSERT INTO usuaris VALUES (921, 'Sócrates', 'Tello Crespo', 'H', '55 Ctra. de la Puerta', 26586, 'Socrates.Tello.Crespo@trashymail.com', '17/02/77', 18, 1);
INSERT INTO usuaris VALUES (922, 'Birgitta', 'Barragán Juárez', 'D', '29 El Roqueo', 15885, 'Birgitta.Barragan.Juarez@pookmail.com', '27/04/59', 37, 12);
INSERT INTO usuaris VALUES (923, 'Lua', 'Cerda Cadena', 'D', '60 Pza. Fuensanta', 32530, 'Lua.Cerda.Cadena@mailinator.com', '29/09/56', 57, 4);
INSERT INTO usuaris VALUES (924, 'Itaete', 'Balderas Barraza', 'H', '69 C/ Libertad', 6000, 'Itaete.Balderas.Barraza@pookmail.com', '22/10/83', 99, 12);
INSERT INTO usuaris VALUES (925, 'Relinda', 'Mata Ozuna', 'D', '46 C/ Henan Cortes', 29194, 'Relinda.Mata.Ozuna@dodgit.com', '18/07/53', 0, NULL);
INSERT INTO usuaris VALUES (926, 'Ronda', 'Rosario Amaya', 'D', '84 Boriñaur enparantza', 7519, 'Ronda.Rosario.Amaya@mailinator.com', '25/01/41', 87, 12);
INSERT INTO usuaris VALUES (927, 'Valentín', 'Canales Quiñones', 'H', '5 Avda. Explanada Barnuevo', 35290, 'Valentin.Canales.Quinones@mailinator.com', '24/07/79', 51, 6);
INSERT INTO usuaris VALUES (928, 'Fulvia', 'Quintana Cantú', 'D', '47 Ctra. Villena', 34140, 'Fulvia.Quintana.Cantu@pookmail.com', '03/08/50', 48, 2);
INSERT INTO usuaris VALUES (929, 'Anelisa', 'Ceja Delgado', 'D', '79 Prolongacion San Sebastian', 21270, 'Anelisa.Ceja.Delgado@pookmail.com', '12/12/79', 20, 9);
INSERT INTO usuaris VALUES (930, 'Edelberto', 'Serrato Farías', 'H', '2 Ctra. Bailén-Motril', 23264, 'Edelberto.Serrato.Farias@spambob.com', '24/12/47', 38, 11);
INSERT INTO usuaris VALUES (931, 'Katherine', 'Cordova Alcaraz', 'D', '33 Plazuela do Porto', 37892, 'Katherine.Cordova.Alcaraz@pookmail.com', '05/04/63', 4, 4);
INSERT INTO usuaris VALUES (932, 'Benon', 'Galindo Valladares', 'H', '42 Pascual Yunquera', 18818, 'Benon.Galindo.Valladares@mailinator.com', '02/03/59', 35, 6);
INSERT INTO usuaris VALUES (933, 'Ardón', 'Miranda Díaz', 'H', '39 Avda. Rio Nalon', 33424, 'Ardon.Miranda.Diaz@pookmail.com', '24/05/47', 59, 5);
INSERT INTO usuaris VALUES (934, 'Leneo', 'Yáñez Crespo', 'H', '90 Outid de Arriba', 43424, 'Leneo.Yanez.Crespo@mailinator.com', '16/01/51', 27, 6);
INSERT INTO usuaris VALUES (935, 'Ariano', 'Barela Leal', 'H', '38 C/ Cañada del Rosal', 21592, 'Ariano.Barela.Leal@mailinator.com', '08/02/52', 1, 8);
INSERT INTO usuaris VALUES (936, 'Yve', 'Rubio Jimínez', 'D', '31 Ctra. Beas-Cortijos Nuevos', 26550, 'Yve.Rubio.Jiminez@pookmail.com', '24/07/61', 83, 2);
INSERT INTO usuaris VALUES (937, 'Sebasten', 'Sierra Santana', 'H', '1 C/ Amoladera', 28760, 'Sebasten.Sierra.Santana@trashymail.com', '15/04/78', 68, 2);
INSERT INTO usuaris VALUES (938, 'Quique', 'Valles Nava', 'H', '50 Avda. Enrique Peinador', 37184, 'Quique.Valles.Nava@pookmail.com', '17/11/45', 74, 9);
INSERT INTO usuaris VALUES (939, 'Efreín', 'Aguilar Alcantar', NULL, '19 C/ Cañada del Rosal', 21590, 'Efrein.Aguilar.Alcantar@trashymail.com', '03/11/45', 4, 11);
INSERT INTO usuaris VALUES (940, 'Olympia', 'Negrete Canales', 'D', '11 La Fontanilla', 14208, 'Olympia.Negrete.Canales@pookmail.com', '17/11/72', 26, 10);
INSERT INTO usuaris VALUES (941, 'Eric', 'Ramírez Palomino', 'H', '11 C/ Pablo Iglesias', 26321, 'Eric.Ramirez.Palomino@dodgit.com', '24/08/67', 94, 2);
INSERT INTO usuaris VALUES (942, 'Luisana', 'Tirado Serna', 'D', '88 Ctra. de la Puerta', 27130, 'Luisana.Tirado.Serna@mailinator.com', '07/04/47', 73, 10);
INSERT INTO usuaris VALUES (943, 'Maia', 'Garrido Chávez', 'D', '31 Escuadro', 46910, 'Maia.Garrido.Chavez@pookmail.com', '28/11/52', 53, 6);
INSERT INTO usuaris VALUES (944, 'Segismundo', 'Olivárez Valdivia', 'H', '1 Extramuros', 28560, 'Segismundo.Olivarez.Valdivia@mailinator.com', '01/12/71', 6, 2);
INSERT INTO usuaris VALUES (945, 'Mirna', 'Baeza Rico', 'D', '21 Rúa de San Pedro', 37797, 'Mirna.Baeza.Rico@dodgit.com', '27/09/42', 91, NULL);
INSERT INTO usuaris VALUES (946, 'Franz', 'Escalante Serna', 'H', '50 Valadouro', 48116, 'Franz.Escalante.Serna@mailinator.com', '01/07/75', 77, 8);
INSERT INTO usuaris VALUES (947, 'Amilca', 'Armendáriz Rosales', 'D', '79 C/ Eras', 28751, 'Amilca.Armendariz.Rosales@spambob.com', '18/04/63', 50, 7);
INSERT INTO usuaris VALUES (948, 'Abancuy', 'Espino Ornelas', 'D', '31 Pza. Fuensanta', 32212, 'Abancuy.Espino.Ornelas@trashymail.com', '03/04/72', 43, 1);
INSERT INTO usuaris VALUES (949, 'Melina', 'Malave Palomo', 'D', '16 C/ Hijuela de Lojo', 20269, 'Melina.Malave.Palomo@pookmail.com', '15/10/82', 87, NULL);
INSERT INTO usuaris VALUES (950, 'Anicet', 'Gurule Carranza', 'H', '31 C/ Canarias', 20140, 'Anicet.Gurule.Carranza@spambob.com', '10/11/59', 30, 2);
INSERT INTO usuaris VALUES (951, 'Pigmalion', 'Montoya Arroyo', 'H', '65 Pl. Virgen Blanca', 8430, 'Pigmalion.Montoya.Arroyo@spambob.com', '13/09/85', 71, 9);
INSERT INTO usuaris VALUES (952, 'Dorothy', 'Bermúdez Velasco', 'D', '55 Rosa de los Vientos', 13329, 'Dorothy.Bermudez.Velasco@dodgit.com', '24/10/75', 95, 3);
INSERT INTO usuaris VALUES (953, 'Giannina', 'Abreu Ochoa', 'D', '53 Ourense', 43390, 'Giannina.Abreu.Ochoa@mailinator.com', '17/02/71', 4, 1);
INSERT INTO usuaris VALUES (954, 'Iosef', 'Ortiz Colón', 'H', '4 C/ Cuesta del  Álamo', 29566, 'Iosef.Ortiz.Colon@mailinator.com', '18/04/85', 72, 4);
INSERT INTO usuaris VALUES (955, 'Galit', 'Alonzo Casares', 'D', '63 C/ Libertad', 6000, 'Galit.Alonzo.Casares@mailinator.com', '30/12/50', 31, 4);
INSERT INTO usuaris VALUES (956, 'Olimpia', 'Leiva Colunga', 'D', '90 Avda. de Andalucía', 29300, 'Olimpia.Leiva.Colunga@spambob.com', '06/02/82', 64, 9);
INSERT INTO usuaris VALUES (957, 'Aura', 'Meraz Serna', 'D', '41 Calle Proc. San Sebastián', 13117, 'Aura.Meraz.Serna@trashymail.com', '16/01/83', 58, 4);
INSERT INTO usuaris VALUES (958, 'Melecio', 'Trejo Zúñiga', 'H', '73 Plaza de España', 15821, 'Melecio.Trejo.Zuniga@dodgit.com', '24/06/48', 85, 12);
INSERT INTO usuaris VALUES (959, 'Ebe', 'Figueroa Ordóñez', 'D', '39 Avda. Alameda Sundheim', 22800, 'Ebe.Figueroa.Ordonez@spambob.com', '19/07/42', 3, 5);
INSERT INTO usuaris VALUES (960, 'Albertina', 'Acevedo Arroyo', 'D', '78 C/ Andalucía', 4770, 'Albertina.Acevedo.Arroyo@pookmail.com', '07/06/51', 92, 2);
INSERT INTO usuaris VALUES (961, 'Oriol', 'Echevarría Alcalá', 'H', '94 San Andrés', 37281, 'Oriol.Echevarria.Alcala@spambob.com', '02/09/76', 91, 9);
INSERT INTO usuaris VALUES (962, 'Itxaso', 'Reyna Verduzco', 'H', '66 Socampo', 37659, 'Itxaso.Reyna.Verduzco@mailinator.com', '03/05/78', 74, 9);
INSERT INTO usuaris VALUES (963, 'Quintilio', 'Montano Varela', 'H', '28 Rio Segura', 31520, 'Quintilio.Montano.Varela@spambob.com', '19/08/81', 2, 1);
INSERT INTO usuaris VALUES (964, 'Mirari', 'Armas Linares', 'D', '8 Reiseñor', 46133, 'Mirari.Armas.Linares@mailinator.com', '11/06/59', 97, 5);
INSERT INTO usuaris VALUES (965, 'Azul', 'Cervantes Pabón', NULL, '69 El Roqueo', 17240, 'Azul.Cervantes.Pabon@dodgit.com', '20/05/85', 23, 7);
INSERT INTO usuaris VALUES (966, 'Joaquin', 'Fierro Quintana', 'H', '76 C/ Cuesta del  Álamo', 29570, 'Joaquin.Fierro.Quintana@trashymail.com', '26/04/63', 58, 4);
INSERT INTO usuaris VALUES (967, 'Jasper', 'Valdivia Rangel', 'H', '94 C/ Cañada del Rosal', 21389, 'Jasper.Valdivia.Rangel@spambob.com', '15/04/50', 66, 11);
INSERT INTO usuaris VALUES (968, 'Vesta', 'Fierro Griego', 'D', '61 Ctra. de Siles', 27370, 'Vesta.Fierro.Griego@trashymail.com', '12/02/42', 30, 9);
INSERT INTO usuaris VALUES (969, 'Pegaso', 'Valladares Quintana', 'H', '37 Alvaro Cunqueiro', 40360, 'Pegaso.Valladares.Quintana@spambob.com', '12/11/68', 68, 5);
INSERT INTO usuaris VALUES (970, 'Parmenio', 'Farías Luján', 'H', '65 C/ Benito Guinea', 8399, 'Parmenio.Farias.Lujan@mailinator.com', '09/06/82', 57, 11);
INSERT INTO usuaris VALUES (971, 'Leoncio', 'Esquivel Lemus', 'H', '22 Paseo Junquera', 12428, 'Leoncio.Esquivel.Lemus@spambob.com', '31/01/73', 43, 7);
INSERT INTO usuaris VALUES (972, 'Plubio', 'Longoria Guillén', 'H', '93 Rosa de los Vientos', 13412, 'Plubio.Longoria.Guillen@mailinator.com', '26/08/75', 86, 2);
INSERT INTO usuaris VALUES (973, 'Arquímedes', 'Echevarría Burgos', 'H', '96 Padre Caro', 13595, 'Arquimedes.Echevarria.Burgos@pookmail.com', '20/10/52', 61, 3);
INSERT INTO usuaris VALUES (974, 'Exaltación', 'Muro Orellana', 'D', '87 Cartagena', 30510, 'Exaltacion.Muro.Orellana@mailinator.com', '14/03/71', 84, 1);
INSERT INTO usuaris VALUES (975, 'Christian', 'Quintana Bañuelos', 'H', '37 Comandante Izarduy', 8784, 'Christian.Quintana.Banuelos@pookmail.com', '09/04/58', 45, 2);
INSERT INTO usuaris VALUES (976, 'Idumeo', 'Bahena Castellanos', 'H', '6 Quevedo', 15316, 'Idumeo.Bahena.Castellanos@dodgit.com', '10/04/46', 26, 3);
INSERT INTO usuaris VALUES (977, 'Tiziana', 'Naranjo Manzanares', 'D', '49 Cercas Bajas', 8140, 'Tiziana.Naranjo.Manzanares@trashymail.com', '14/07/59', 76, 9);
INSERT INTO usuaris VALUES (978, 'Iona', 'Cadena Zamora', 'D', '99 Ctra. de Fuentenueva', 28213, 'Iona.Cadena.Zamora@trashymail.com', '14/07/85', 9, NULL);
INSERT INTO usuaris VALUES (979, 'Janette', 'Alva Colón', NULL, '70 Cruce Casa de Postas', 18400, 'Janette.Alva.Colon@trashymail.com', '12/02/56', 67, 4);
INSERT INTO usuaris VALUES (980, 'Ginette', 'Casillas Salas', 'D', '13 Rosa de los Vientos', 13440, 'Ginette.Casillas.Salas@trashymail.com', '13/12/72', 86, 10);
INSERT INTO usuaris VALUES (981, 'Odon', 'Chávez Reyna', 'H', '78 C/ Domingo Beltrán', 2215, 'Odon.Chavez.Reyna@dodgit.com', '16/06/62', 23, 12);
INSERT INTO usuaris VALUES (982, 'Noralí', 'Vanegas Zapata', 'D', '95 Apartado de Correos', 37428, 'Norali.Vanegas.Zapata@spambob.com', '23/08/54', 35, 9);
INSERT INTO usuaris VALUES (983, 'Vito', 'Maldonado Gurule', 'H', '43 C/ Pablo Iglesias', 26330, 'Vito.Maldonado.Gurule@dodgit.com', '10/08/53', 59, 6);
INSERT INTO usuaris VALUES (984, 'Evando', 'Merino Soria', 'H', '65 C/ Pablo Iglesias', 26315, 'Evando.Merino.Soria@mailinator.com', '22/06/61', 81, 11);
INSERT INTO usuaris VALUES (985, 'Alice', 'Árias Ruvalcaba', 'D', '61 C/ Eras', 28740, 'Alice.Arias.Ruvalcaba@mailinator.com', '02/07/71', 74, 7);
INSERT INTO usuaris VALUES (986, 'Blanche', 'Aguilar Murillo', 'D', '19 Inglaterra', 18611, 'Blanche.Aguilar.Murillo@pookmail.com', '12/01/82', 86, 12);
INSERT INTO usuaris VALUES (987, 'Erwin', 'Limón Salgado', 'H', '63 Carretera', 14815, 'Erwin.Limon.Salgado@spambob.com', '20/11/48', 13, 1);
INSERT INTO usuaris VALUES (988, 'Fidelia', 'Armas Rael', 'D', '74 Ctra. Beas-Cortijos Nuevos', 26560, 'Fidelia.Armas.Rael@trashymail.com', '28/05/52', 20, 2);
INSERT INTO usuaris VALUES (989, 'Aisha', 'Bustos Espinosa', 'D', '24 Rúa de San Pedro', 37794, 'Aisha.Bustos.Espinosa@dodgit.com', '07/04/43', 21, 2);
INSERT INTO usuaris VALUES (990, 'Arlet', 'Lerma Casanova', 'H', '93 Castelao', 48950, 'Arlet.Lerma.Casanova@mailinator.com', '21/06/59', 70, 5);
INSERT INTO usuaris VALUES (991, 'Beatrix', 'Ceja Saucedo', 'D', '15 Visitación de la Encina', 37693, 'Beatrix.Ceja.Saucedo@pookmail.com', '12/09/41', 49, 6);
INSERT INTO usuaris VALUES (992, 'Leonard', 'Espino Carrasco', 'H', '29 Plazuela do Porto', 37874, 'Leonard.Espino.Carrasco@pookmail.com', '07/06/65', 59, 8);
INSERT INTO usuaris VALUES (993, 'Gea', 'Hernández Altamirano', 'D', '83 Crta. Cádiz-Málaga', 12230, 'Gea.Hernandez.Altamirano@spambob.com', '28/10/67', 2, NULL);
INSERT INTO usuaris VALUES (994, 'Mirta', 'Zayas Maestas', 'D', '58 Estrela', 39500, 'Mirta.Zayas.Maestas@spambob.com', '25/09/56', 58, 2);
INSERT INTO usuaris VALUES (995, 'Anaías', 'Carrión Sisneros', 'H', '60 Padre Caro', 13660, 'Anaias.Carrion.Sisneros@dodgit.com', '31/03/79', 68, 1);
INSERT INTO usuaris VALUES (996, 'Olinda', 'Curiel Razo', 'D', '83 Cádiz', 18513, 'Olinda.Curiel.Razo@dodgit.com', '16/11/61', 23, 2);
INSERT INTO usuaris VALUES (997, 'Flavio', 'Velez Orozco', 'H', '34 Ctra. de Fuentenueva', 28250, 'Flavio.Velez.Orozco@pookmail.com', '12/06/46', 80, 2);
INSERT INTO usuaris VALUES (998, 'Julia', 'Suárez Corona', 'D', '91 C/ Rosa de los Vientos', 11648, 'Julia.Suarez.Corona@spambob.com', '22/05/79', 30, 3);
INSERT INTO usuaris VALUES (999, 'Loris', 'Salgado Ramón', NULL, '95 Caño', 32870, 'Loris.Salgado.Ramon@mailinator.com', '23/11/43', 36, NULL);
INSERT INTO usuaris VALUES (1000, 'Elizabeth', 'Reyes Villalpando', 'D', '85 C/ Fernández de Leceta', 3510, 'Elizabeth.Reyes.Villalpando@pookmail.com', '03/06/84', 5, NULL);
INSERT INTO usuaris VALUES (1001, 'Iracema', 'Zaragoza Tamayo', 'D', '52 Avda. Los llanos', 26256, 'Iracema.Zaragoza.Tamayo@pookmail.com', '23/08/44', 52, 5);
INSERT INTO usuaris VALUES (1002, 'Phillip', 'Valdés Cuellar', NULL, '64 Avda. Enrique Peinador', 37175, 'Phillip.Valdes.Cuellar@pookmail.com', '14/01/83', 48, 5);
INSERT INTO usuaris VALUES (1003, 'Juventino', 'Castillo Castro', 'H', '5 C/ Pablo Iglesias', 26324, 'Juventino.Castillo.Castro@pookmail.com', '27/01/63', 58, 11);
INSERT INTO usuaris VALUES (1004, 'Renau', 'Adomo Gil', 'H', '67 Prolongacion San Sebastian', 21209, 'Renau.Adomo.Gil@pookmail.com', '10/10/49', 73, 5);
INSERT INTO usuaris VALUES (1005, 'Breogan', 'Benavidez Chacón', 'H', '46 Cádiz', 18480, 'Breogan.Benavidez.Chacon@dodgit.com', '08/05/42', 81, 5);
INSERT INTO usuaris VALUES (1006, 'Dugen', 'Díaz Paredes', 'H', '40 Rua da Rapina', 37510, 'Dugen.Diaz.Paredes@spambob.com', '28/12/61', 5, 2);
INSERT INTO usuaris VALUES (1007, 'Malguen', 'Tapia Verduzco', 'D', '67 C/ Rosa de los Vientos', 11500, 'Malguen.Tapia.Verduzco@pookmail.com', '31/05/62', 5, NULL);
INSERT INTO usuaris VALUES (1008, 'Ben', 'Viera Armijo', 'H', '1 Ourense', 43140, 'Ben.Viera.Armijo@mailinator.com', '18/08/63', 73, 1);
INSERT INTO usuaris VALUES (1009, 'Jade', 'Tello Vera', 'D', '32 Maestro Puig Valera', 33820, 'Jade.Tello.Vera@trashymail.com', '18/08/73', 92, 9);
INSERT INTO usuaris VALUES (1010, 'Ilian', 'Meraz Ayala', 'D', '50 Ctra. Beas-Cortijos Nuevos', 26550, 'Ilian.Meraz.Ayala@dodgit.com', '28/03/85', 80, 7);
INSERT INTO usuaris VALUES (1011, 'Delfina', 'Fajardo Calderón', 'H', '27 Rúa do Paseo', 41804, 'Delfina.Fajardo.Calderon@pookmail.com', '28/10/58', 98, 6);
INSERT INTO usuaris VALUES (1012, 'Geordie', 'Toledo Armijo', 'H', '85 Crta. Cádiz-Málaga', 12210, 'Geordie.Toledo.Armijo@trashymail.com', '05/12/59', 33, 3);
INSERT INTO usuaris VALUES (1013, 'Querubín', 'Mares Munguia', 'H', '28 Zumalakarregi etorbidea', 7315, 'Querubin.Mares.Munguia@mailinator.com', '04/12/45', 76, 4);
INSERT INTO usuaris VALUES (1014, 'Ben', 'Briseño Armenta', 'H', '34 C/ Benito Guinea', 8390, 'Ben.Briseno.Armenta@pookmail.com', '20/02/60', 74, 7);
INSERT INTO usuaris VALUES (1015, 'Aylin', 'Brito Sisneros', 'D', '10 Avda. Alameda Sundheim', 22400, 'Aylin.Brito.Sisneros@dodgit.com', '10/02/77', 33, 9);
INSERT INTO usuaris VALUES (1016, 'Kathryn', 'Duran Mejía', 'D', '8 Rúa de San Pedro', 37797, 'Kathryn.Duran.Mejia@trashymail.com', '01/08/59', 67, 1);
INSERT INTO usuaris VALUES (1017, 'Celide', 'Lucio Mena', 'D', '14 Plaza Colón', 25200, 'Celide.Lucio.Mena@dodgit.com', '14/06/60', 36, 7);
INSERT INTO usuaris VALUES (1018, 'Luna', 'Carrero Agosto', 'D', '85 Plaza de España', 15578, 'Luna.Carrero.Agosto@dodgit.com', '11/03/77', 13, 6);
INSERT INTO usuaris VALUES (1019, 'Dayanira', 'Ayala Madrid', 'D', '57 Ourense', 43000, 'Dayanira.Ayala.Madrid@pookmail.com', '09/07/73', 18, 8);
INSERT INTO usuaris VALUES (1020, 'Lain', 'Cruz Arellano', 'H', '88 Carretera Cádiz-Málaga', 20577, 'Lain.Cruz.Arellano@dodgit.com', '31/03/72', 31, 7);
INSERT INTO usuaris VALUES (1021, 'Aser', 'Escobedo Cantú', 'H', '51 Rúa do Paseo', 41805, 'Aser.Escobedo.Cantu@spambob.com', '05/08/83', 37, 9);
INSERT INTO usuaris VALUES (1022, 'Primo', 'Montenegro Anaya', 'H', '77 C/ Andalucía', 4630, 'Primo.Montenegro.Anaya@trashymail.com', '16/11/54', 98, NULL);
INSERT INTO usuaris VALUES (1023, 'Ledicia', 'Cabrera Urías', 'D', '65 Atamaria', 36626, 'Ledicia.Cabrera.Urias@dodgit.com', '12/07/64', 30, 9);
INSERT INTO usuaris VALUES (1024, 'Danilo', 'Torres Sanches', 'H', '82 Herrería', 18220, 'Danilo.Torres.Sanches@trashymail.com', '08/12/62', 59, 1);
INSERT INTO usuaris VALUES (1025, 'Abner', 'Gaitán Casárez', 'H', '41 Avda. de Andalucía', 29330, 'Abner.Gaitan.Casarez@spambob.com', '11/07/77', 59, 5);
INSERT INTO usuaris VALUES (1026, 'Jonah', 'Orta Valladares', 'H', '60 Avendaño', 4510, 'Jonah.Orta.Valladares@trashymail.com', '13/03/82', 62, 6);
INSERT INTO usuaris VALUES (1027, 'Yara', 'Elizondo Mireles', 'D', '19 C/ Andalucía', 4660, 'Yara.Elizondo.Mireles@spambob.com', '10/10/41', 4, 6);
INSERT INTO usuaris VALUES (1028, 'Jenofonte', 'Casárez Zambrano', 'H', '19 Pza. Fuensanta', 32200, 'Jenofonte.Casarez.Zambrano@mailinator.com', '01/04/83', 1, 11);
INSERT INTO usuaris VALUES (1029, 'Arnoldo', 'Armijo Aparicio', 'H', '30 Avda. Generalísimo', 31587, 'Arnoldo.Armijo.Aparicio@spambob.com', '20/01/42', 62, 3);
INSERT INTO usuaris VALUES (1030, 'Dallas', 'Villalpando Orozco', 'H', '25 Celso Emilio Ferreiro', 50360, 'Dallas.Villalpando.Orozco@spambob.com', '28/03/55', 95, 5);
INSERT INTO usuaris VALUES (1031, 'Ainoha', 'Mojica Rincón', NULL, '55 Plazuela do Porto', 37891, 'Ainoha.Mojica.Rincon@dodgit.com', '13/12/41', 34, NULL);
INSERT INTO usuaris VALUES (1032, 'Geoffrey', 'Valdés Concepción', 'H', '84 Plaza Colón', 26111, 'Geoffrey.Valdes.Concepcion@pookmail.com', '20/05/65', 7, 12);
INSERT INTO usuaris VALUES (1033, 'Néstor', 'Caldera Sanches', 'H', '33 C/ Pablo Iglesias', 26325, 'Nestor.Caldera.Sanches@mailinator.com', '12/05/76', 66, 10);
INSERT INTO usuaris VALUES (1034, 'Alexia', 'Sedillo Balderas', 'D', '10 Plazuela do Porto', 38436, 'Alexia.Sedillo.Balderas@pookmail.com', '12/08/55', 88, 7);
INSERT INTO usuaris VALUES (1035, 'Cayo', 'Valentín Irizarry', 'H', '57 Camiño Real', 48480, 'Cayo.Valentin.Irizarry@pookmail.com', '23/07/69', 8, 10);
INSERT INTO usuaris VALUES (1036, 'Everardo', 'Chacón Arroyo', 'H', '51 Carretera', 14530, 'Everardo.Chacon.Arroyo@dodgit.com', '12/06/67', 60, 4);
INSERT INTO usuaris VALUES (1037, 'Meredith', 'Nieto Castillo', 'D', '21 Avenida Cervantes', 48269, 'Meredith.Nieto.Castillo@pookmail.com', '21/12/53', 87, 4);
INSERT INTO usuaris VALUES (1038, 'Eulogia', 'Aranda Galván', NULL, '3 Rosa de los Vientos', 13341, 'Eulogia.Aranda.Galvan@spambob.com', '05/08/74', 64, 2);
INSERT INTO usuaris VALUES (1039, 'Neptuno', 'Terrazas Blanco', 'H', '38 C/ Fernández de Leceta', 3420, 'Neptuno.Terrazas.Blanco@spambob.com', '10/04/45', 76, 7);
INSERT INTO usuaris VALUES (1040, 'Zósimo', 'Soliz Avilés', 'H', '25 Lamas Carbajal', 41660, 'Zosimo.Soliz.Aviles@dodgit.com', '09/12/80', 60, 12);
INSERT INTO usuaris VALUES (1041, 'Ibar', 'Adame Pena', 'H', '93 Cañadilla', 21730, 'Ibar.Adame.Pena@spambob.com', '21/12/70', 36, 1);
INSERT INTO usuaris VALUES (1042, 'Roy', 'Gallegos Marrero', 'H', '63 Escuadro', 47150, 'Roy.Gallegos.Marrero@trashymail.com', '13/04/75', 33, 10);
INSERT INTO usuaris VALUES (1043, 'Christopher', 'Osorio Uribe', 'D', '74 Puerta Nueva', 36390, 'Christopher.Osorio.Uribe@mailinator.com', '03/03/78', 28, 9);
INSERT INTO usuaris VALUES (1044, 'Nazar', 'Almanza Jaramillo', 'H', '15 Avda. Rio Nalon', 33527, 'Nazar.Almanza.Jaramillo@pookmail.com', '06/03/57', 60, 2);
INSERT INTO usuaris VALUES (1045, 'Froilán', 'Sandoval Riojas', 'H', '39 Calle Aduana', 1000, 'Froilan.Sandoval.Riojas@spambob.com', '07/10/57', 63, 7);
INSERT INTO usuaris VALUES (1046, 'Muredac', 'Nava León', 'H', '53 C/ Arana', 2610, 'Muredac.Nava.Leon@dodgit.com', '19/02/72', 14, 12);
INSERT INTO usuaris VALUES (1047, 'Jesualdo', 'Badillo Rivero', 'H', '15 Camiño Ancho', 37785, 'Jesualdo.Badillo.Rivero@pookmail.com', '31/10/50', 74, 10);
INSERT INTO usuaris VALUES (1048, 'Ayax', 'Duarte Árias', 'H', '66 Ctra. Beas-Cortijos Nuevos', 26559, 'Ayax.Duarte.Arias@dodgit.com', '24/05/69', 0, 11);
INSERT INTO usuaris VALUES (1049, 'Vaniria', 'Jáquez Romo', 'D', '22 Socampo', 37657, 'Vaniria.Jaquez.Romo@trashymail.com', '14/12/61', 20, 9);
INSERT INTO usuaris VALUES (1050, 'Antoinette', 'Maestas Orosco', 'D', '44 Prolongacion San Sebastian', 21300, 'Antoinette.Maestas.Orosco@trashymail.com', '30/06/44', 49, 11);
INSERT INTO usuaris VALUES (1051, 'Agar', 'Lomeli Cervántez', 'H', '16 Puerto Lugar', 29700, 'Agar.Lomeli.Cervantez@mailinator.com', '05/11/70', 74, 1);
INSERT INTO usuaris VALUES (1052, 'Alfred', 'González Urrútia', 'H', '70 Ctra. Bailén-Motril', 23200, 'Alfred.Gonzalez.Urrutia@trashymail.com', '30/09/42', 72, 2);
INSERT INTO usuaris VALUES (1053, 'Quirina', 'Zúñiga Prieto', 'D', '77 Pza. Fuensanta', 32411, 'Quirina.Zuniga.Prieto@mailinator.com', '28/04/74', 3, 3);
INSERT INTO usuaris VALUES (1054, 'Alisa', 'Ocampo Velez', 'D', '54 Avda. de la Estación', 28693, 'Alisa.Ocampo.Velez@spambob.com', '13/12/61', 46, 9);
INSERT INTO usuaris VALUES (1055, 'Zarina', 'Maldonado Casanova', 'D', '3 Padre Caro', 13779, 'Zarina.Maldonado.Casanova@spambob.com', '17/07/44', 35, 8);
INSERT INTO usuaris VALUES (1056, 'Melisa', 'Gaytan Cárdenas', 'D', '92 Castelao', 48970, 'Melisa.Gaytan.Cardenas@trashymail.com', '27/07/61', 28, 12);
INSERT INTO usuaris VALUES (1057, 'Pilato', 'Becerra Jaime', 'H', '28 Boriñaur enparantza', 7520, 'Pilato.Becerra.Jaime@spambob.com', NULL, 54, 3);
INSERT INTO usuaris VALUES (1058, 'Eiru', 'Elizondo Carrasquill', 'D', '64 Calle Proc. San Sebastián', 12591, 'Eiru.Elizondo.Carrasquill@spambob.com', '16/11/44', 51, 8);
INSERT INTO usuaris VALUES (1059, 'Faustine', 'Nevarez Figueroa', 'D', '30 Avda. Explanada Barnuevo', 35260, 'Faustine.Nevarez.Figueroa@dodgit.com', NULL, 72, 1);
INSERT INTO usuaris VALUES (1060, 'Archer', 'Tapia Magana', 'H', '89 José matía', 1400, 'Archer.Tapia.Magana@mailinator.com', '13/06/66', 5, 2);
INSERT INTO usuaris VALUES (1061, 'Amara', 'Jaimes Mena', 'D', '75 Ctra. de Fuentenueva', 28213, 'Amara.Jaimes.Mena@mailinator.com', '20/08/71', 41, 6);
INSERT INTO usuaris VALUES (1062, 'Bernabeu', 'Cervantes Valdez', 'H', '34 Urzáiz', 44530, 'Bernabeu.Cervantes.Valdez@pookmail.com', '08/05/73', 40, 10);
INSERT INTO usuaris VALUES (1063, 'Ciril', 'Villalpando Flores', 'H', '38 C/ Los Herrán', 6900, 'Ciril.Villalpando.Flores@mailinator.com', '19/01/59', 70, 1);
INSERT INTO usuaris VALUES (1064, 'Keren', 'Mejía Calvillo', 'D', '70 Valadouro', 48190, 'Keren.Mejia.Calvillo@spambob.com', '29/04/64', 26, 4);
INSERT INTO usuaris VALUES (1065, 'Leto', 'Cordova Almaraz', 'H', '90 Calvo Sotelo', 47490, 'Leto.Cordova.Almaraz@mailinator.com', '12/01/60', 18, 5);
INSERT INTO usuaris VALUES (1066, 'Grace', 'Naranjo Arévalo', 'D', '59 Alcon Molina', 30859, 'Grace.Naranjo.Arevalo@dodgit.com', '14/05/81', 14, 6);
INSERT INTO usuaris VALUES (1067, 'Marón', 'Juárez Mondragón', 'H', '54 Rosa de los Vientos', 13410, 'Maron.Juarez.Mondragon@dodgit.com', '24/11/47', 53, 2);
INSERT INTO usuaris VALUES (1068, 'Haydee', 'Frías Bahena', 'D', '52 C/ Cuesta del  Álamo', 29560, 'Haydee.Frias.Bahena@dodgit.com', '04/02/72', 12, NULL);
INSERT INTO usuaris VALUES (1069, 'Deyanira', 'Aguilera Griego', 'D', '83 C/ Andalucía', 4760, 'Deyanira.Aguilera.Griego@spambob.com', '09/11/72', 37, 4);
INSERT INTO usuaris VALUES (1070, 'Lucinda', 'Duarte Franco', 'D', '80 San Andrés', 37254, 'Lucinda.Duarte.Franco@spambob.com', '25/03/75', 18, 1);
INSERT INTO usuaris VALUES (1071, 'Tulio', 'Alcantar Cerda', 'H', '44 Herrería', 18181, 'Tulio.Alcantar.Cerda@trashymail.com', '15/12/57', 42, 12);
INSERT INTO usuaris VALUES (1072, 'Nadine', 'Alanis Estévez', 'D', '38 Antonio Vázquez', 38715, 'Nadine.Alanis.Estevez@spambob.com', '15/05/74', 16, 8);
INSERT INTO usuaris VALUES (1073, 'Eilal', 'Armas Veliz', 'H', '52 Castelao', 48880, 'Eilal.Armas.Veliz@mailinator.com', '07/12/44', 33, 8);
INSERT INTO usuaris VALUES (1074, 'Agnelo', 'Alanis Longoria', 'H', '43 Inglaterra', 18530, 'Agnelo.Alanis.Longoria@trashymail.com', '28/02/70', 97, 4);
INSERT INTO usuaris VALUES (1075, 'Oda', 'Cazares Samaniego', 'D', '99 C/ Arana', 2435, 'Oda.Cazares.Samaniego@mailinator.com', '11/10/60', 53, 6);
INSERT INTO usuaris VALUES (1076, 'Enrica', 'Santacruz Pedraza', 'D', '25 Avenida Cervantes', 48330, 'Enrica.Santacruz.Pedraza@pookmail.com', '04/10/53', 81, 4);
INSERT INTO usuaris VALUES (1077, 'Ananías', 'Camarillo Madera', 'H', '20 Valadouro', 48100, 'Ananias.Camarillo.Madera@trashymail.com', '21/08/61', 85, 6);
INSERT INTO usuaris VALUES (1078, 'Rodas', 'Cordero Verduzco', 'H', '72 Ctra. Villena', 34480, 'Rodas.Cordero.Verduzco@spambob.com', '09/05/72', 35, 1);
INSERT INTO usuaris VALUES (1079, 'Caridad', 'Jimínez Aponte', 'D', '79 Camiño Ancho', 37779, 'Caridad.Jiminez.Aponte@trashymail.com', '07/11/68', 36, 2);
INSERT INTO usuaris VALUES (1080, 'Alarico', 'Romero Padrón', 'H', '69 C/ Domingo Beltrán', 2215, 'Alarico.Romero.Padron@mailinator.com', '23/06/41', 77, 12);
INSERT INTO usuaris VALUES (1081, 'Janvier', 'Rosales Granado', 'H', '78 Celso Emilio Ferreiro', 50340, 'Janvier.Rosales.Granado@dodgit.com', '28/08/60', 88, 1);
INSERT INTO usuaris VALUES (1082, 'Geordie', 'Badillo Paz', 'H', '71 Maestro Puig Valera', 33770, 'Geordie.Badillo.Paz@mailinator.com', '11/04/47', 47, 7);
INSERT INTO usuaris VALUES (1083, 'Armentario', 'Ibarra Rojas', 'H', '20 Avda. Enrique Peinador', 37170, 'Armentario.Ibarra.Rojas@spambob.com', '03/07/59', 14, 11);
INSERT INTO usuaris VALUES (1084, 'Simplicio', 'Luna Jaimes', 'H', '72 C/ Angosto', 23476, 'Simplicio.Luna.Jaimes@spambob.com', '14/05/63', 75, 3);
INSERT INTO usuaris VALUES (1085, 'Libio', 'Muñoz Alvarado', 'H', '75 Carretera del Muelle', 12415, 'Libio.Munoz.Alvarado@dodgit.com', '01/02/47', 79, 5);
INSERT INTO usuaris VALUES (1086, 'Natacha', 'Lozano Saucedo', 'D', '74 Valadouro', 48143, 'Natacha.Lozano.Saucedo@spambob.com', '17/06/62', 29, 1);
INSERT INTO usuaris VALUES (1087, 'Argentina', 'Lucero Ramírez', 'D', '8 Zumalakarregi etorbidea', 7192, 'Argentina.Lucero.Ramirez@dodgit.com', '25/11/59', 50, 3);
INSERT INTO usuaris VALUES (1088, 'Plubio', 'Arriaga Tórrez', 'H', '58 Crta. Cádiz-Málaga', 12184, 'Plubio.Arriaga.Torrez@pookmail.com', '22/02/73', 51, 6);
INSERT INTO usuaris VALUES (1089, 'Dommina', 'Valles Mateo', 'D', '99 C/ Cuevas de Ambrosio', 23711, 'Dommina.Valles.Mateo@mailinator.com', '12/06/67', 93, 8);
INSERT INTO usuaris VALUES (1090, 'Edén', 'Saavedra Godínez', 'D', '2 C/ Pablo Iglesias', 26312, 'Eden.Saavedra.Godinez@spambob.com', '31/05/47', 77, NULL);
INSERT INTO usuaris VALUES (1091, 'Cesáreo', 'Saavedra Quiñones', 'H', '91 C/ Domingo Beltrán', 2230, 'Cesareo.Saavedra.Quinones@mailinator.com', '10/02/73', 38, 7);
INSERT INTO usuaris VALUES (1092, 'Verbena', 'Solano Curiel', 'D', '4 Calle Proc. San Sebastián', 12580, 'Verbena.Solano.Curiel@trashymail.com', '29/08/59', 55, 2);
INSERT INTO usuaris VALUES (1093, 'Fermina', 'Saldivar Terrazas', 'D', '78 C/ Canarias', 20200, 'Fermina.Saldivar.Terrazas@mailinator.com', '18/09/75', 37, 5);
INSERT INTO usuaris VALUES (1094, 'Anian', 'Gaona Navarro', 'D', '90 Calle Carril de la Fuente', 13279, 'Anian.Gaona.Navarro@trashymail.com', '06/02/72', 45, 1);
INSERT INTO usuaris VALUES (1095, 'Gabriele', 'Briones Sierra', 'D', '34 Cartagena', 30612, 'Gabriele.Briones.Sierra@dodgit.com', '06/05/70', 44, 1);
INSERT INTO usuaris VALUES (1096, 'Cástor', 'Moreno Carmona', 'H', '81 Ctra. de Fuentenueva', 28190, 'Castor.Moreno.Carmona@dodgit.com', '20/11/64', 95, 8);
INSERT INTO usuaris VALUES (1097, 'Romano', 'Cintrón Pichardo', 'H', '88 Estrela', 39577, 'Romano.Cintron.Pichardo@dodgit.com', '07/12/44', 53, 11);
INSERT INTO usuaris VALUES (1098, 'Martha', 'Jaimes Rosas', 'D', '69 Ctra. de la Puerta', 27150, 'Martha.Jaimes.Rosas@dodgit.com', '28/08/43', 60, 6);
INSERT INTO usuaris VALUES (1099, 'Asa', 'Orosco Tijerina', 'H', '3 Salzillo', 32650, 'Asa.Orosco.Tijerina@spambob.com', '08/01/71', 97, 10);
INSERT INTO usuaris VALUES (1100, 'Rocco', 'Esquivel Valverde', 'H', '68 C/ Fernández de Leceta', 3350, 'Rocco.Esquivel.Valverde@spambob.com', '08/09/48', 28, NULL);
INSERT INTO usuaris VALUES (1101, 'Fabiana', 'Bermúdez Cortez', 'D', '18 C/ Hijuela de Lojo', 20491, 'Fabiana.Bermudez.Cortez@pookmail.com', '22/04/54', 6, 5);
INSERT INTO usuaris VALUES (1102, 'Federigo', 'Alvarez Covas', 'H', '81 Atamaria', 36860, 'Federigo.Alvarez.Covas@trashymail.com', '08/11/40', 64, 11);
INSERT INTO usuaris VALUES (1103, 'Nazaret', 'Apodaca Rael', 'H', '48 Quevedo', 15313, 'Nazaret.Apodaca.Rael@trashymail.com', '28/02/41', 36, 6);
INSERT INTO usuaris VALUES (1104, 'Alucan', 'Campos Arteaga', 'H', '23 Castelao', 48900, 'Alucan.Campos.Arteaga@pookmail.com', '27/09/54', 86, 12);
INSERT INTO usuaris VALUES (1105, 'Ceadas', 'Ávila Esquibel', 'H', '91 Carretera Cádiz-Málaga', 20739, 'Ceadas.Avila.Esquibel@pookmail.com', '12/03/66', 5, 4);
INSERT INTO usuaris VALUES (1106, 'Osmar', 'Holguín Olivas', 'H', '58 Constitución', 37000, 'Osmar.Holguin.Olivas@pookmail.com', '12/02/79', 72, 2);
INSERT INTO usuaris VALUES (1107, 'Melín', 'Centeno Corral', 'D', '34 Cádiz', 18512, 'Melin.Centeno.Corral@trashymail.com', '30/05/75', 90, 6);
INSERT INTO usuaris VALUES (1108, 'Hartman', 'Armendáriz Ibarra', 'H', '58 Estrela', 39740, 'Hartman.Armendariz.Ibarra@pookmail.com', '29/09/62', 9, 10);
INSERT INTO usuaris VALUES (1109, 'Cleo', 'Valle Santacruz', 'D', '98 Avda. Explanada Barnuevo', 35500, 'Cleo.Valle.Santacruz@mailinator.com', '19/05/56', 47, 2);
INSERT INTO usuaris VALUES (1110, 'Eulogius', 'Salazar Canales', 'H', '45 Rúa do Paseo', 41820, 'Eulogius.Salazar.Canales@spambob.com', '08/04/56', 88, NULL);
INSERT INTO usuaris VALUES (1111, 'Alsan', 'Verduzco Caraballo', 'H', '40 Calle Aduana', 1170, 'Alsan.Verduzco.Caraballo@trashymail.com', '22/11/60', 61, 2);
INSERT INTO usuaris VALUES (1112, 'Alardo', 'Gaitán Cano', 'H', '48 Rosa de los Vientos', 13413, 'Alardo.Gaitan.Cano@spambob.com', '29/01/55', 58, 7);
INSERT INTO usuaris VALUES (1113, 'Joav', 'Berrios Vigil', 'H', '9 Canónigo Valiño', 46410, 'Joav.Berrios.Vigil@mailinator.com', '04/07/75', 5, 9);
INSERT INTO usuaris VALUES (1114, 'Elpidio', 'Alanis Avilés', 'H', '98 Urzáiz', 45000, 'Elpidio.Alanis.Aviles@dodgit.com', '22/08/47', NULL, 6);
INSERT INTO usuaris VALUES (1115, 'Jessie', 'Elizondo Negrón', NULL, '29 Rúa do Paseo', 41850, 'Jessie.Elizondo.Negron@dodgit.com', '22/02/68', 71, 2);
INSERT INTO usuaris VALUES (1116, 'Gulmen', 'Peres Pelayo', 'H', '7 Pascual Yunquera', 18670, 'Gulmen.Peres.Pelayo@dodgit.com', '24/11/59', 90, 9);
INSERT INTO usuaris VALUES (1117, 'Gelasio', 'Mercado Briones', 'H', '94 Alcon Molina', 30890, 'Gelasio.Mercado.Briones@mailinator.com', '29/10/71', 86, 4);
INSERT INTO usuaris VALUES (1118, 'Estelinda', 'Estévez Vargas', 'D', '75 Avda. Alameda Sundheim', 22580, 'Estelinda.Estevez.Vargas@mailinator.com', '28/06/45', 18, 7);
INSERT INTO usuaris VALUES (1119, 'Plinio', 'Cedillo Gracia', 'H', '25 C/ Domingo Beltrán', 2214, 'Plinio.Cedillo.Gracia@pookmail.com', '14/10/72', 78, 3);
INSERT INTO usuaris VALUES (1120, 'Evaristo', 'Briseño Vasquez', 'H', '84 Rio Segura', 31310, 'Evaristo.Briseno.Vasquez@trashymail.com', '11/02/74', 38, 5);
INSERT INTO usuaris VALUES (1121, 'Licinio', 'Espinoza Samaniego', 'H', '15 Avenida Cervantes', 48250, 'Licinio.Espinoza.Samaniego@trashymail.com', '05/09/66', 35, 10);
INSERT INTO usuaris VALUES (1122, 'Rina', 'Atencio Mora', 'D', '75 Avda. Andalucía', 26135, 'Rina.Atencio.Mora@trashymail.com', '27/08/85', 0, 2);
INSERT INTO usuaris VALUES (1123, 'Elinda', 'Malave Pulido', 'D', '83 Escuadro', 46900, 'Elinda.Malave.Pulido@pookmail.com', '12/05/79', 85, 8);
INSERT INTO usuaris VALUES (1124, 'Morela', 'Verduzco Olivas', 'D', '95 Extramuros', 28491, 'Morela.Verduzco.Olivas@dodgit.com', '10/10/71', 84, NULL);
INSERT INTO usuaris VALUES (1125, 'Belisa', 'Árias León', NULL, '59 Inglaterra', 18518, 'Belisa.Arias.Leon@mailinator.com', '20/02/73', 40, 2);
INSERT INTO usuaris VALUES (1126, 'Damaris', 'Mares Serna', 'D', '12 Avda. Los llanos', 26300, 'Damaris.Mares.Serna@mailinator.com', '24/03/41', 24, NULL);
INSERT INTO usuaris VALUES (1127, 'Manfredo', 'Grijalva Angulo', 'H', '46 Eusebio Dávila', 41370, 'Manfredo.Grijalva.Angulo@spambob.com', '04/08/57', 64, 1);
INSERT INTO usuaris VALUES (1128, 'Amancai', 'Reyna Montero', 'D', '25 Fuente del Gallo', 14930, 'Amancai.Reyna.Montero@mailinator.com', '05/04/84', 18, 9);
INSERT INTO usuaris VALUES (1129, 'Ilve', 'Hernádez Rentería', 'D', '79 C/ Cuevas de Ambrosio', 24100, 'Ilve.Hernadez.Renteria@dodgit.com', '26/02/82', 94, 5);
INSERT INTO usuaris VALUES (1130, 'Licio', 'Pagan Pineda', 'H', '94 Avda. de la Estación', 28598, 'Licio.Pagan.Pineda@pookmail.com', '17/08/76', 17, 4);
INSERT INTO usuaris VALUES (1131, 'Belisaria', 'Benavides Merino', 'D', '11 Quevedo', 15230, 'Belisaria.Benavides.Merino@trashymail.com', '18/07/54', 27, 3);
INSERT INTO usuaris VALUES (1132, 'Leonila', 'Verduzco Ochoa', 'D', '79 Puerta Nueva', 36200, 'Leonila.Verduzco.Ochoa@trashymail.com', '12/08/56', 75, 10);
INSERT INTO usuaris VALUES (1133, 'Marcia', 'Barreto Armijo', 'D', '13 C/ Andalucía', 4838, 'Marcia.Barreto.Armijo@dodgit.com', '19/01/83', 58, 3);
INSERT INTO usuaris VALUES (1134, 'Neri', 'Alcaraz Jaimes', 'H', '88 Calle Carril de la Fuente', 13160, 'Neri.Alcaraz.Jaimes@spambob.com', '08/05/79', 76, 12);
INSERT INTO usuaris VALUES (1135, 'Enoc', 'Zúñiga Serrano', 'H', '42 Constitución', 37147, 'Enoc.Zuniga.Serrano@pookmail.com', '28/09/85', 96, 12);
INSERT INTO usuaris VALUES (1136, 'Otoniel', 'Cerda Cervántez', 'H', '22 Caño', 32911, 'Otoniel.Cerda.Cervantez@trashymail.com', '17/07/50', 9, 3);
INSERT INTO usuaris VALUES (1137, 'Merlino', 'Cortez Ballesteros', 'H', '25 Atamaria', 36540, 'Merlino.Cortez.Ballesteros@mailinator.com', '08/01/73', 17, 7);
INSERT INTO usuaris VALUES (1138, 'Severino', 'Tafoya Huerta', 'H', '39 Rua da Rapina', 37469, 'Severino.Tafoya.Huerta@mailinator.com', '06/09/81', 37, 11);
INSERT INTO usuaris VALUES (1139, 'Crisipo', 'Trujillo Bustos', 'H', '75 Avda. Explanada Barnuevo', 35340, 'Crisipo.Trujillo.Bustos@spambob.com', '01/07/73', NULL, 7);
INSERT INTO usuaris VALUES (1140, 'Onella', 'Domínquez Garica', 'D', '59 Antonio Vázquez', 38750, 'Onella.Dominquez.Garica@spambob.com', '30/03/41', 22, 3);
INSERT INTO usuaris VALUES (1141, 'Ottón', 'Crespo Arredondo', 'H', '54 C/ Libertad', 5260, 'Otton.Crespo.Arredondo@spambob.com', '13/07/55', 4, 5);
INSERT INTO usuaris VALUES (1142, 'Angelo', 'Esquibel Oquendo', 'H', '32 C/ Fernández de Leceta', 3369, 'Angelo.Esquibel.Oquendo@pookmail.com', '25/01/44', 55, 7);
INSERT INTO usuaris VALUES (1143, 'Ailen', 'Fonseca Camarillo', 'D', '98 Paseo del Atlántico', 18150, 'Ailen.Fonseca.Camarillo@mailinator.com', '13/04/63', 80, 4);
INSERT INTO usuaris VALUES (1144, 'Circe', 'Nieves Orozco', 'D', '55 C/ Canarias', 20214, 'Circe.Nieves.Orozco@dodgit.com', '29/10/79', 12, 11);
INSERT INTO usuaris VALUES (1145, 'Pancho', 'Longoria Alemán', 'H', '48 C/ Manuel Iradier', 3769, 'Pancho.Longoria.Aleman@mailinator.com', '14/05/70', 60, 1);
INSERT INTO usuaris VALUES (1146, 'Candy', 'Brito Munguia', 'D', '1 Crta. Cádiz-Málaga', 12170, 'Candy.Brito.Munguia@dodgit.com', '22/11/52', 97, NULL);
INSERT INTO usuaris VALUES (1147, 'Adair', 'Arriaga Tafoya', 'H', '52 Castelao', 48970, 'Adair.Arriaga.Tafoya@trashymail.com', '15/09/64', 7, 3);
INSERT INTO usuaris VALUES (1148, 'Manela', 'Armenta Rojo', 'D', '78 Pascual Yunquera', 18712, 'Manela.Armenta.Rojo@mailinator.com', '26/02/69', 4, 2);
INSERT INTO usuaris VALUES (1149, 'Crispo', 'Marrero Díaz', 'H', '83 Cartagena', 30320, 'Crispo.Marrero.Diaz@pookmail.com', '03/09/81', 31, 10);
INSERT INTO usuaris VALUES (1150, 'Ecio', 'Ulibarri Sandoval', 'H', '19 C/ Canarias', 19200, 'Ecio.Ulibarri.Sandoval@mailinator.com', '22/05/79', 85, 3);
INSERT INTO usuaris VALUES (1151, 'Kiara', 'Lira Salazar', 'D', '98 Fuente del Gallo', 15115, 'Kiara.Lira.Salazar@pookmail.com', '27/02/80', 86, 3);
INSERT INTO usuaris VALUES (1152, 'Alesia', 'Armenta Orellana', 'D', '79 Enxertos', 37523, 'Alesia.Armenta.Orellana@mailinator.com', '04/10/57', 50, 3);
INSERT INTO usuaris VALUES (1153, 'Eliane', 'Saldana Monroy', 'D', '25 Apartado de Correos', 37429, 'Eliane.Saldana.Monroy@spambob.com', '05/04/41', 40, 12);
INSERT INTO usuaris VALUES (1154, 'Hector', 'Galvez Espinoza', 'H', '56 Puerta Nueva', 36380, 'Hector.Galvez.Espinoza@trashymail.com', '12/07/53', 22, 9);
INSERT INTO usuaris VALUES (1155, 'Pantaleón', 'Rangel Urrútia', 'H', '49 San Andrés', 37248, 'Pantaleon.Rangel.Urrutia@dodgit.com', '29/03/55', 1, 3);
INSERT INTO usuaris VALUES (1156, 'Laelia', 'Saavedra Anguiano', 'D', '12 San Andrés', 37258, 'Laelia.Saavedra.Anguiano@trashymail.com', '11/02/70', 2, 3);
INSERT INTO usuaris VALUES (1157, 'Aluhe', 'Cuellar Velasco', 'D', '66 Ctra. Villena', 34230, 'Aluhe.Cuellar.Velasco@pookmail.com', '07/11/65', 50, 1);
INSERT INTO usuaris VALUES (1158, 'Indalecia', 'Baca Guevara', 'D', '86 C/ Manuel Iradier', 3812, 'Indalecia.Baca.Guevara@pookmail.com', '06/05/45', 66, 5);
INSERT INTO usuaris VALUES (1159, 'Alice', 'Hurtado Hurtado', 'D', '64 C/ Benito Guinea', 8392, 'Alice.Hurtado.Hurtado@pookmail.com', '11/06/84', 34, 5);
INSERT INTO usuaris VALUES (1160, 'Sempronio', 'Hidalgo Armijo', 'H', '52 Ventanilla de Beas', 27720, 'Sempronio.Hidalgo.Armijo@spambob.com', '04/02/55', 97, NULL);
INSERT INTO usuaris VALUES (1161, 'Miqueas', 'Carrasco Leyva', 'D', '11 Ourense', 43340, 'Miqueas.Carrasco.Leyva@dodgit.com', '25/05/66', 84, 1);
INSERT INTO usuaris VALUES (1162, 'Landerico', 'Quiñones Ramón', 'H', '14 C/ Andalucía', 4638, 'Landerico.Quinones.Ramon@spambob.com', '15/01/55', 78, 11);
INSERT INTO usuaris VALUES (1163, 'Hadrian', 'Jiménez Godoy', 'H', '4 La Fontanilla', 14450, 'Hadrian.Jimenez.Godoy@trashymail.com', '21/06/45', 94, 11);
INSERT INTO usuaris VALUES (1164, 'Aramis', 'Díaz Polanco', 'H', '45 Avda. Rio Nalon', 33300, 'Aramis.Diaz.Polanco@pookmail.com', '03/07/78', 83, 2);
INSERT INTO usuaris VALUES (1165, 'Myrna', 'Valladares Gracia', 'D', '53 Camiño Real', 48382, 'Myrna.Valladares.Gracia@spambob.com', '08/11/59', 38, 4);
INSERT INTO usuaris VALUES (1166, 'Teodomiro', 'Soto Haro', 'H', '20 Eusebio Dávila', 41540, 'Teodomiro.Soto.Haro@spambob.com', '13/10/59', 17, 6);
INSERT INTO usuaris VALUES (1167, 'Régulo', 'Coronado Campos', 'H', '16 C/ Los Herrán', 6420, 'Regulo.Coronado.Campos@mailinator.com', '13/08/84', 58, NULL);
INSERT INTO usuaris VALUES (1168, 'Amalio', 'Tafoya Zamora', 'H', '18 Outid de Arriba', 43540, 'Amalio.Tafoya.Zamora@spambob.com', '17/04/81', 89, 2);
INSERT INTO usuaris VALUES (1169, 'Bibiano', 'Cuellar Mejía', 'H', '68 Carretera del Muelle', 12311, 'Bibiano.Cuellar.Mejia@pookmail.com', '10/10/62', 1, 3);
INSERT INTO usuaris VALUES (1170, 'Maialen', 'Bueno Rodrígez', 'D', '26 Avda. Los llanos', 26258, 'Maialen.Bueno.Rodrigez@mailinator.com', '17/08/78', 18, 9);
INSERT INTO usuaris VALUES (1171, 'Giuseppe', 'Gómez Garibay', 'H', '36 Cercas Bajas', 8150, 'Giuseppe.Gomez.Garibay@trashymail.com', '26/03/63', 17, 1);
INSERT INTO usuaris VALUES (1172, 'Marie', 'Nieves Chacón', NULL, '26 Camiño Real', 48600, 'Marie.Nieves.Chacon@spambob.com', '07/09/61', 95, 9);
INSERT INTO usuaris VALUES (1173, 'Mileva', 'Ulloa Padilla', 'D', '27 Zumalakarregi etorbidea', 7240, 'Mileva.Ulloa.Padilla@trashymail.com', '27/03/42', 61, 8);
INSERT INTO usuaris VALUES (1174, 'Olimpo', 'Quezada Muñoz', 'H', '66 C/ Canarias', 20170, 'Olimpo.Quezada.Munoz@trashymail.com', '11/03/75', 89, 11);
INSERT INTO usuaris VALUES (1175, 'Calanit', 'Iglesias Quesada', 'D', '35 C/ Andalucía', 4860, 'Calanit.Iglesias.Quesada@pookmail.com', '23/12/47', 74, 6);
INSERT INTO usuaris VALUES (1176, 'Tyson', 'Rivas Serrato', 'H', '49 Avda. Los llanos', 26230, 'Tyson.Rivas.Serrato@trashymail.com', '28/04/43', 66, 9);
INSERT INTO usuaris VALUES (1177, 'Flavie', 'Grijalva Haro', 'D', '3 Escuadro', 46830, 'Flavie.Grijalva.Haro@mailinator.com', '20/11/79', 22, 7);
INSERT INTO usuaris VALUES (1178, 'Steven', 'Sarabia Quezada', 'H', '35 Avendaño', 4510, 'Steven.Sarabia.Quezada@spambob.com', '13/09/81', 29, 9);
INSERT INTO usuaris VALUES (1179, 'Anunciación', 'Morales Villalpando', 'D', '89 Ctra. Hornos', 26225, 'Anunciacion.Morales.Villalpando@pookmail.com', '13/02/48', 58, 1);
INSERT INTO usuaris VALUES (1180, 'George', 'Riojas García', 'H', '21 C/ Eras', 28742, 'George.Riojas.Garcia@dodgit.com', '08/06/52', 76, 11);
INSERT INTO usuaris VALUES (1181, 'Cinthia', 'Medrano Reséndez', 'D', '23 Rua da Rapina', 37460, 'Cinthia.Medrano.Resendez@mailinator.com', '16/01/76', 65, 4);
INSERT INTO usuaris VALUES (1182, 'Isanqui', 'Barreto Fajardo', 'D', '24 Reiseñor', 45700, 'Isanqui.Barreto.Fajardo@mailinator.com', '18/10/67', 10, 9);
INSERT INTO usuaris VALUES (1183, 'Isaura', 'Monroy Soliz', 'D', '74 Escuadro', 46800, 'Isaura.Monroy.Soliz@mailinator.com', '25/08/42', 23, 3);
INSERT INTO usuaris VALUES (1184, 'Incul', 'Cabán Tirado', 'H', '31 Ctra. Bailén-Motril', 23230, 'Incul.Caban.Tirado@dodgit.com', '06/04/84', 54, 2);
INSERT INTO usuaris VALUES (1185, 'Claribel', 'Becerra Viera', 'D', '62 Camiño Ancho', 37785, 'Claribel.Becerra.Viera@pookmail.com', '28/12/79', 50, 8);
INSERT INTO usuaris VALUES (1186, 'Saidi', 'Montés Rosas', 'D', '24 Alvaro Cunqueiro', 40400, 'Saidi.Montes.Rosas@mailinator.com', '24/06/49', 87, 4);
INSERT INTO usuaris VALUES (1187, 'Larry', 'Tejeda Castaneda', 'H', '36 C/ Arana', 2460, 'Larry.Tejeda.Castaneda@dodgit.com', '02/03/46', 78, 10);
INSERT INTO usuaris VALUES (1188, 'Minna', 'Baez Nevarez', 'D', '56 C/ Andalucía', 4639, 'Minna.Baez.Nevarez@dodgit.com', '11/11/49', 6, 9);
INSERT INTO usuaris VALUES (1189, 'Taciana', 'Cotto Lovato', 'D', '78 Camiño Ancho', 37765, 'Taciana.Cotto.Lovato@mailinator.com', '06/03/57', 0, 10);
INSERT INTO usuaris VALUES (1190, 'Piero', 'Collazo Camarillo', 'H', '73 El Roqueo', 15960, 'Piero.Collazo.Camarillo@trashymail.com', '16/11/60', 46, 2);
INSERT INTO usuaris VALUES (1191, 'Deidamia', 'Aponte Urena', 'D', '52 Boriñaur enparantza', 7630, 'Deidamia.Aponte.Urena@pookmail.com', '08/08/63', 22, 9);
INSERT INTO usuaris VALUES (1192, 'Karin', 'Barragán Godínez', 'D', '8 Avda. Enrique Peinador', 37173, 'Karin.Barragan.Godinez@pookmail.com', '14/08/52', 75, 8);
INSERT INTO usuaris VALUES (1193, 'Caridad', 'Covas Veliz', 'D', '26 Avda. Los llanos', 26240, 'Caridad.Covas.Veliz@dodgit.com', '08/12/50', 7, 3);
INSERT INTO usuaris VALUES (1194, 'Maha', 'Carrero Prado', 'D', '17 C/ Pablo Iglesias', 26320, 'Maha.Carrero.Prado@pookmail.com', '07/06/69', 94, 4);
INSERT INTO usuaris VALUES (1195, 'Michaela', 'Varela Angulo', 'D', '87 C/ Cañada del Rosal', 21610, 'Michaela.Varela.Angulo@spambob.com', '23/06/43', 68, 7);
INSERT INTO usuaris VALUES (1196, 'Jocelín', 'Lugo Ybarra', 'D', '7 Valadouro', 48170, 'Jocelin.Lugo.Ybarra@mailinator.com', '27/05/76', 17, 12);
INSERT INTO usuaris VALUES (1197, 'Zahir', 'Vera Banda', 'H', '40 Socampo', 37619, 'Zahir.Vera.Banda@spambob.com', '19/05/48', 97, 1);
INSERT INTO usuaris VALUES (1198, 'Augustin', 'Pelayo Serrato', 'H', '3 Quevedo', 15563, 'Augustin.Pelayo.Serrato@trashymail.com', '03/02/46', 52, 6);
INSERT INTO usuaris VALUES (1199, 'Christian', 'Briseño Calderón', 'H', '41 Atamaria', 36636, 'Christian.Briseno.Calderon@pookmail.com', '27/06/44', 83, 5);
INSERT INTO usuaris VALUES (1200, 'Marisa', 'Magana Alfaro', 'D', '8 Av. Santiago Lapuente', 50710, 'Marisa.Magana.Alfaro@dodgit.com', '22/06/52', 61, 5);
INSERT INTO usuaris VALUES (1201, 'Aristarco', 'Porras Aponte', 'H', '14 C/ Señores Curas', 11660, 'Aristarco.Porras.Aponte@pookmail.com', '29/09/60', 97, 12);
INSERT INTO usuaris VALUES (1202, 'Alondra', 'Covas Lugo', 'D', '6 Paseo del Atlántico', 18120, 'Alondra.Covas.Lugo@spambob.com', '23/09/76', 73, 8);
INSERT INTO usuaris VALUES (1203, 'Midas', 'Casárez Nieves', 'H', '74 Cartagena', 30510, 'Midas.Casarez.Nieves@dodgit.com', '13/10/77', 9, 2);
INSERT INTO usuaris VALUES (1204, 'Liberal', 'Arreola Correa', 'H', '36 Celso Emilio Ferreiro', 50690, 'Liberal.Arreola.Correa@mailinator.com', '30/03/72', 49, 11);
INSERT INTO usuaris VALUES (1205, 'Taiana', 'Regalado Macías', 'D', '73 Reiseñor', 46120, 'Taiana.Regalado.Macias@dodgit.com', '13/02/73', 3, 4);
INSERT INTO usuaris VALUES (1206, 'Generosa', 'Galván Camarillo', 'D', '82 Ctra. de Fuentenueva', 28260, 'Generosa.Galvan.Camarillo@mailinator.com', '29/07/43', 32, 6);
INSERT INTO usuaris VALUES (1207, 'Shulamit', 'Llarnas Mora', 'D', '41 C/ Domingo Beltrán', 2326, 'Shulamit.Llarnas.Mora@dodgit.com', '04/10/74', 89, 3);
INSERT INTO usuaris VALUES (1208, 'Erminia', 'Rangel Cano', 'D', '7 Pascual Yunquera', 18700, 'Erminia.Rangel.Cano@trashymail.com', '04/03/72', 13, 1);
INSERT INTO usuaris VALUES (1209, 'Idelfonso', 'Marroquín Cisneros', 'H', '70 Avenida Cervantes', 48360, 'Idelfonso.Marroquin.Cisneros@spambob.com', '27/12/52', 20, 4);
INSERT INTO usuaris VALUES (1210, 'Mariana', 'Griego Collado', 'D', '8 Avda. Los llanos', 26288, 'Mariana.Griego.Collado@spambob.com', '11/04/80', 90, 6);
INSERT INTO usuaris VALUES (1211, 'Anian', 'Fernández Solano', 'D', '80 Camiño Real', 48480, 'Anian.Fernandez.Solano@pookmail.com', '08/01/52', 44, 12);
INSERT INTO usuaris VALUES (1212, 'Galatea', 'Fierro Mireles', 'D', '16 Caño', 32750, 'Galatea.Fierro.Mireles@dodgit.com', '06/03/52', 94, 6);
INSERT INTO usuaris VALUES (1213, 'Sandor', 'Carbajal Ceballos', 'H', '90 Valadouro', 48191, 'Sandor.Carbajal.Ceballos@spambob.com', '01/09/58', 56, NULL);
INSERT INTO usuaris VALUES (1214, 'Ludovico', 'Gil Vaca', 'H', '19 Reiseñor', 46110, 'Ludovico.Gil.Vaca@mailinator.com', '23/07/81', 87, 9);
INSERT INTO usuaris VALUES (1215, 'Verna', 'Sepúlveda Escobar', 'D', '69 Cañadilla', 21830, 'Verna.Sepulveda.Escobar@spambob.com', '04/04/44', 39, 3);
INSERT INTO usuaris VALUES (1216, 'Fidelia', 'Gaitán Pineda', 'D', '65 Ctra. de Fuentenueva', 28280, 'Fidelia.Gaitan.Pineda@pookmail.com', '22/06/62', 46, 5);
INSERT INTO usuaris VALUES (1217, 'Caitán', 'Barraza Caraballo', 'H', '26 C/ Henan Cortes', 29160, 'Caitan.Barraza.Caraballo@pookmail.com', '11/11/50', 51, 3);
INSERT INTO usuaris VALUES (1218, 'Ammiel', 'Callas Quiñónez', 'H', '23 C/ Eras', 28729, 'Ammiel.Callas.Quinonez@dodgit.com', '08/04/67', 56, 12);
INSERT INTO usuaris VALUES (1219, 'Luna', 'Posada Bravo', 'D', '11 Avenida Cervantes', 48314, 'Luna.Posada.Bravo@trashymail.com', '16/09/44', 65, 7);
INSERT INTO usuaris VALUES (1220, 'Milton', 'Villegas Reséndez', 'H', '78 C/ Amoladera', 28817, 'Milton.Villegas.Resendez@spambob.com', '13/10/59', 14, 5);
INSERT INTO usuaris VALUES (1221, 'Jésica', 'Carbajal Alaniz', 'D', '33 Canónigo Valiño', 46240, 'Jesica.Carbajal.Alaniz@spambob.com', '03/08/74', 55, 5);
INSERT INTO usuaris VALUES (1222, 'Dina', 'Ayala Moreno', 'D', '64 C/ Canarias', 20210, 'Dina.Ayala.Moreno@mailinator.com', '03/07/71', 4, 7);
INSERT INTO usuaris VALUES (1223, 'Vilfredo', 'Arce Ruvalcaba', 'H', '29 Cercas Bajas', 8240, 'Vilfredo.Arce.Ruvalcaba@mailinator.com', '29/09/64', 44, 4);
INSERT INTO usuaris VALUES (1224, 'Selesio', 'Longoria Puga', 'H', '51 C/ Los Herrán', 6490, 'Selesio.Longoria.Puga@pookmail.com', '22/02/73', 58, 3);
INSERT INTO usuaris VALUES (1225, 'Bruno', 'Benítez Galvez', 'H', '29 C/ Cuesta del  Álamo', 29610, 'Bruno.Benitez.Galvez@mailinator.com', '11/09/84', 3, 5);
INSERT INTO usuaris VALUES (1226, 'Yamil', 'González Atencio', 'H', '37 Camiño Ancho', 37770, 'Yamil.Gonzalez.Atencio@spambob.com', '12/01/67', 26, 8);
INSERT INTO usuaris VALUES (1227, 'Samir', 'Corrales Zavala', 'H', '90 Puerto Lugar', 29719, 'Samir.Corrales.Zavala@mailinator.com', '10/01/63', 63, 9);
INSERT INTO usuaris VALUES (1228, 'Lorna', 'Cervántez León', NULL, '80 Camiño Real', 48480, 'Lorna.Cervantez.Leon@mailinator.com', '11/03/47', 37, 4);
INSERT INTO usuaris VALUES (1229, 'Naroa', 'Barela Marcos', 'D', '11 Extramuros', 28411, 'Naroa.Barela.Marcos@mailinator.com', '14/10/74', 51, 6);
INSERT INTO usuaris VALUES (1230, 'Norman', 'Solórzano Matías', 'H', '87 Paseo Junquera', 12470, 'Norman.Solorzano.Matias@pookmail.com', '21/12/49', 1, 4);
INSERT INTO usuaris VALUES (1231, 'Pascua', 'Armendáriz Espinoza', 'D', '21 Canónigo Valiño', 46540, 'Pascua.Armendariz.Espinoza@spambob.com', '12/12/54', 11, 11);
INSERT INTO usuaris VALUES (1232, 'Grau', 'Gastelum Valencia', 'H', '33 Calle Carril de la Fuente', 13270, 'Grau.Gastelum.Valencia@mailinator.com', '31/01/40', 57, 1);
INSERT INTO usuaris VALUES (1233, 'Tirsa', 'Guajardo Cordova', 'D', '89 C/ Manuel Iradier', 3812, 'Tirsa.Guajardo.Cordova@mailinator.com', '07/05/74', 99, 7);
INSERT INTO usuaris VALUES (1234, 'Lior', 'Zelaya Venegas', 'H', '96 Paseo Junquera', 12448, 'Lior.Zelaya.Venegas@spambob.com', '09/11/46', 4, 12);
INSERT INTO usuaris VALUES (1235, 'Marlon', 'Urrútia Santana', 'H', '95 Paraguay', 3680, 'Marlon.Urrutia.Santana@trashymail.com', '04/03/74', 81, 5);
INSERT INTO usuaris VALUES (1236, 'Gay', 'Najera Salinas', 'H', '75 Plaza Maior', 37217, 'Gay.Najera.Salinas@pookmail.com', '19/07/40', 84, 6);
INSERT INTO usuaris VALUES (1237, 'Hebe', 'Romo Quintero', 'D', '18 C/ Amoladera', 28890, 'Hebe.Romo.Quintero@trashymail.com', '06/05/80', 97, 2);
INSERT INTO usuaris VALUES (1238, 'Oleguer', 'Soria Apodaca', 'H', '91 C/ Hijuela de Lojo', 20268, 'Oleguer.Soria.Apodaca@mailinator.com', '18/10/64', 9, 6);
INSERT INTO usuaris VALUES (1239, 'Dillan', 'Soria Casanova', 'H', '12 Alvaro Cunqueiro', 40200, 'Dillan.Soria.Casanova@mailinator.com', '27/04/48', 13, 1);
INSERT INTO usuaris VALUES (1240, 'Evangelino', 'Ulibarri Camarillo', 'H', '60 Caño', 32765, 'Evangelino.Ulibarri.Camarillo@spambob.com', '11/11/56', 50, 4);
INSERT INTO usuaris VALUES (1241, 'Ivan', 'Alfaro Garica', 'H', '59 Avda. de la Estación', 28609, 'Ivan.Alfaro.Garica@trashymail.com', '09/08/42', 57, 2);
INSERT INTO usuaris VALUES (1242, 'Octaviano', 'Cintrón Leiva', 'H', '36 Av. Zumalakarregi', 2694, 'Octaviano.Cintron.Leiva@spambob.com', '01/05/55', 65, 9);
INSERT INTO usuaris VALUES (1243, 'Velasco', 'Pantoja Carmona', 'H', '68 Eusebio Dávila', 41430, 'Velasco.Pantoja.Carmona@pookmail.com', '17/12/77', 70, 12);
INSERT INTO usuaris VALUES (1244, 'Ari', 'Herrera Tijerina', 'H', '57 C/ Libertad', 4870, 'Ari.Herrera.Tijerina@dodgit.com', '06/02/46', 9, 11);
INSERT INTO usuaris VALUES (1245, 'Agatón', 'Barragán Soria', 'H', '91 Reiseñor', 45880, 'Agaton.Barragan.Soria@dodgit.com', '28/04/67', 37, 12);
INSERT INTO usuaris VALUES (1246, 'Amapola', 'Juárez Palomo', 'D', '62 Rúa do Paseo', 41920, 'Amapola.Juarez.Palomo@dodgit.com', '17/03/70', 59, 9);
INSERT INTO usuaris VALUES (1247, 'Yamel', 'Avilés Velez', 'D', '71 Alcon Molina', 30880, 'Yamel.Aviles.Velez@mailinator.com', '11/01/74', 85, 11);
INSERT INTO usuaris VALUES (1248, 'Nicanor', 'Carranza Soliz', 'H', '45 Lamas Carbajal', 41760, 'Nicanor.Carranza.Soliz@dodgit.com', '04/10/74', 7, 5);
INSERT INTO usuaris VALUES (1249, 'Valburga', 'Quesada Orozco', 'D', '54 Herrería', 18197, 'Valburga.Quesada.Orozco@spambob.com', '31/12/45', 74, 1);
INSERT INTO usuaris VALUES (1250, 'Ludovico', 'Adomo Montés', 'H', '22 Pl. Virgen Blanca', 8680, 'Ludovico.Adomo.Montes@dodgit.com', '27/02/83', 6, 11);
INSERT INTO usuaris VALUES (1251, 'Castalia', 'Madrid Zavala', 'D', '73 Cádiz', 18513, 'Castalia.Madrid.Zavala@mailinator.com', '13/01/75', 48, 5);
INSERT INTO usuaris VALUES (1252, 'Kenti', 'Saenz Padilla', 'D', '3 C/ Rosa de los Vientos', 11560, 'Kenti.Saenz.Padilla@mailinator.com', '12/05/61', 7, 6);
INSERT INTO usuaris VALUES (1253, 'Jairo', 'Robles Guzmán', 'H', '6 Fuente del Gallo', 14914, 'Jairo.Robles.Guzman@dodgit.com', '26/03/57', 51, 11);
INSERT INTO usuaris VALUES (1254, 'Alceo', 'Patino Grijalva', 'H', '45 Socampo', 37630, 'Alceo.Patino.Grijalva@dodgit.com', '13/12/69', 16, 12);
INSERT INTO usuaris VALUES (1255, 'Zunilda', 'Covas Riojas', 'D', '75 Zumalakarregi etorbidea', 7250, 'Zunilda.Covas.Riojas@trashymail.com', '23/11/65', 49, 5);
INSERT INTO usuaris VALUES (1256, 'Gabino', 'Olivera Ramírez', 'H', '4 Avda. de Andalucía', 29370, 'Gabino.Olivera.Ramirez@dodgit.com', '03/11/61', 42, 7);
INSERT INTO usuaris VALUES (1257, 'José Luis', 'Martínez Puga', 'H', '75 Camiño Ancho', 37768, 'Jose.Luis.Martinez.Puga@mailinator.com', '28/12/80', 42, 4);
INSERT INTO usuaris VALUES (1258, 'Zoila', 'Escobedo Sauceda', 'D', '49 C/ Manuel Iradier', 3769, 'Zoila.Escobedo.Sauceda@pookmail.com', '25/07/82', 41, 2);
INSERT INTO usuaris VALUES (1259, 'Siglinda', 'Rodarte Patino', 'D', '34 Cartagena', 30611, 'Siglinda.Rodarte.Patino@trashymail.com', '12/04/83', 61, 5);
INSERT INTO usuaris VALUES (1260, 'Xena', 'Alonzo Alfaro', 'D', '24 C/ Cuevas de Ambrosio', 23760, 'Xena.Alonzo.Alfaro@spambob.com', '26/01/70', 16, 10);
INSERT INTO usuaris VALUES (1261, 'Jesse', 'Alvarez Sedillo', 'D', '96 Ctra. Hornos', 26226, 'Jesse.Alvarez.Sedillo@dodgit.com', '03/10/85', 65, 11);
INSERT INTO usuaris VALUES (1262, 'Carl', 'Mota Olivera', 'H', '40 Salzillo', 32540, 'Carl.Mota.Olivera@trashymail.com', '18/07/45', 2, 1);
INSERT INTO usuaris VALUES (1263, 'Eider', 'Acevedo Atencio', 'D', '70 C/ Cuesta del  Álamo', 29491, 'Eider.Acevedo.Atencio@mailinator.com', '09/01/42', 25, 8);
INSERT INTO usuaris VALUES (1264, 'Nela', 'Ybarra Batista', 'D', '88 Fuente del Gallo', 14960, 'Nela.Ybarra.Batista@dodgit.com', '01/06/60', 95, 3);
INSERT INTO usuaris VALUES (1265, 'Adamo', 'Tejeda Pichardo', 'H', '70 C/ Domingo Beltrán', 2329, 'Adamo.Tejeda.Pichardo@mailinator.com', '11/06/82', 29, 5);
INSERT INTO usuaris VALUES (1266, 'Melisa', 'Saldana Aragón', NULL, '89 Camiño Real', 48382, 'Melisa.Saldana.Aragon@dodgit.com', '15/04/78', 47, 6);
INSERT INTO usuaris VALUES (1267, 'Honorata', 'Avilés Matías', 'D', '96 Avda. de la Estación', 28570, 'Honorata.Aviles.Matias@pookmail.com', '21/12/41', NULL, 6);
INSERT INTO usuaris VALUES (1268, 'Nelly', 'Quintana Samaniego', 'D', '49 Canónigo Valiño', 46610, 'Nelly.Quintana.Samaniego@spambob.com', '14/05/45', 75, 11);
INSERT INTO usuaris VALUES (1269, 'Ayrton', 'Montez Blanco', 'H', '31 Cádiz', 18514, 'Ayrton.Montez.Blanco@dodgit.com', '05/02/81', 37, 11);
INSERT INTO usuaris VALUES (1270, 'Almandos', 'Barraza Robledo', 'H', '95 Rosa de los Vientos', 13411, 'Almandos.Barraza.Robledo@trashymail.com', '07/09/42', 35, 6);
INSERT INTO usuaris VALUES (1271, 'Simeón', 'Díaz Castillo', 'H', '46 San Andrés', 37292, 'Simeon.Diaz.Castillo@pookmail.com', '19/06/42', 42, 3);
INSERT INTO usuaris VALUES (1272, 'Leuco', 'Yáñez Villegas', 'H', '32 Boriñaur enparantza', 7430, 'Leuco.Yanez.Villegas@trashymail.com', '12/06/55', 0, 7);
INSERT INTO usuaris VALUES (1273, 'Dinorah', 'Maestas Rolón', NULL, '58 C/ Benito Guinea', 8250, 'Dinorah.Maestas.Rolon@dodgit.com', '24/06/45', 46, 12);
INSERT INTO usuaris VALUES (1274, 'Maureen', 'Pedraza González', 'D', '70 Avda. Generalísimo', 31550, 'Maureen.Pedraza.Gonzalez@trashymail.com', '27/09/42', 40, 3);
INSERT INTO usuaris VALUES (1275, 'Valfredo', 'Cepeda Gamboa', 'H', '92 Plaza Colón', 25600, 'Valfredo.Cepeda.Gamboa@pookmail.com', '12/05/46', 63, 11);
INSERT INTO usuaris VALUES (1276, 'Lindor', 'Godínez Juárez', 'H', '83 Apartado de Correos', 37427, 'Lindor.Godinez.Juarez@dodgit.com', '22/12/67', 36, 9);
INSERT INTO usuaris VALUES (1277, 'Ibar', 'Sanches Llarnas', 'H', '58 Avda. Explanada Barnuevo', 35330, 'Ibar.Sanches.Llarnas@pookmail.com', '28/01/47', 70, 8);
INSERT INTO usuaris VALUES (1278, 'Aria', 'Pedraza Baez', 'D', '75 Paraguay', 3769, 'Aria.Pedraza.Baez@pookmail.com', '13/09/44', 0, 10);
INSERT INTO usuaris VALUES (1279, 'Morena', 'Leyva Romo', 'D', '54 Rosa de los Vientos', 13420, 'Morena.Leyva.Romo@trashymail.com', '25/04/77', 99, 3);
INSERT INTO usuaris VALUES (1280, 'Gal', 'Betancourt Ramírez', 'D', '48 C/ Angosto', 23610, 'Gal.Betancourt.Ramirez@spambob.com', '14/11/47', 7, 3);
INSERT INTO usuaris VALUES (1281, 'Alano', 'Alba Lira', 'H', '13 Reyes Católicos', 9540, 'Alano.Alba.Lira@pookmail.com', '25/09/79', 13, 9);
INSERT INTO usuaris VALUES (1282, 'Kemal', 'Gurule Jiménez', 'H', '79 Escuadro', 46980, 'Kemal.Gurule.Jimenez@mailinator.com', '25/03/57', 16, 6);
INSERT INTO usuaris VALUES (1283, 'Atila', 'Baeza Soria', 'H', '39 Av. Santiago Lapuente', 50840, 'Atila.Baeza.Soria@dodgit.com', '17/12/61', 19, 6);
INSERT INTO usuaris VALUES (1284, 'Mahdi', 'Bañuelos Arce', 'D', '76 Pascual Yunquera', 18800, 'Mahdi.Banuelos.Arce@pookmail.com', '02/07/85', 73, 12);
INSERT INTO usuaris VALUES (1285, 'Cannan', 'Sedillo Figueroa', 'H', '81 Paraguay', 3670, 'Cannan.Sedillo.Figueroa@dodgit.com', '26/06/71', 38, 6);
INSERT INTO usuaris VALUES (1286, 'Gilda', 'Mercado Regalado', 'D', '21 Pascual Yunquera', 18816, 'Gilda.Mercado.Regalado@dodgit.com', '23/01/54', 85, 10);
INSERT INTO usuaris VALUES (1287, 'Nontue', 'Chapa Patino', 'D', '77 Ctra. de Fuentenueva', 28190, 'Nontue.Chapa.Patino@trashymail.com', '16/05/54', 34, 3);
INSERT INTO usuaris VALUES (1288, 'Dionisio', 'Echevarría Rodrígez', 'H', '33 Puerto Lugar', 29752, 'Dionisio.Echevarria.Rodrigez@pookmail.com', '04/10/40', 95, 12);
INSERT INTO usuaris VALUES (1289, 'Ingmar', 'Zavala Campos', 'H', '88 Avda. de Andalucía', 29410, 'Ingmar.Zavala.Campos@spambob.com', '28/10/68', 22, NULL);
INSERT INTO usuaris VALUES (1290, 'Eladio', 'Murillo Armenta', 'H', '19 C/ Cañada del Rosal', 21620, 'Eladio.Murillo.Armenta@mailinator.com', '24/12/54', 62, 10);
INSERT INTO usuaris VALUES (1291, 'Harumi', 'Calvillo Longoria', 'D', '53 Avda. Los llanos', 26258, 'Harumi.Calvillo.Longoria@mailinator.com', '03/07/43', 73, 10);
INSERT INTO usuaris VALUES (1292, 'Davina', 'Olivera Zúñiga', 'D', '70 C/ Angosto', 23591, 'Davina.Olivera.Zuniga@dodgit.com', '06/05/63', 0, 6);
INSERT INTO usuaris VALUES (1293, 'Mariquena', 'Abeyta Toro', 'D', '14 Calle Carril de la Fuente', 13191, 'Mariquena.Abeyta.Toro@pookmail.com', '12/05/40', 30, 12);
INSERT INTO usuaris VALUES (1294, 'Eddie', 'Arce Figueroa', 'H', '79 Ventanilla de Beas', 27720, 'Eddie.Arce.Figueroa@trashymail.com', '09/10/83', 43, 8);
INSERT INTO usuaris VALUES (1295, 'Plácida', 'Briones Ruelas', 'D', '56 Ctra. de la Puerta', 27300, 'Placida.Briones.Ruelas@dodgit.com', '17/12/65', 69, 1);
INSERT INTO usuaris VALUES (1296, 'Brutus', 'Villareal Molina', 'H', '41 Boriñaur enparantza', 7360, 'Brutus.Villareal.Molina@pookmail.com', '27/12/69', 25, 1);
INSERT INTO usuaris VALUES (1297, 'Yoana', 'Lara Méndez', 'D', '43 Pascual Yunquera', 18660, 'Yoana.Lara.Mendez@mailinator.com', '14/04/62', 84, 9);
INSERT INTO usuaris VALUES (1298, 'Xiomara', 'Concepción Franco', 'D', '18 C/ Manuel Iradier', 3795, 'Xiomara.Concepcion.Franco@spambob.com', '28/09/60', 73, 7);
INSERT INTO usuaris VALUES (1299, 'Getulio', 'Ramón Salgado', 'H', '35 Avda. de Andalucía', 29195, 'Getulio.Ramon.Salgado@trashymail.com', '20/03/43', 62, 11);
INSERT INTO usuaris VALUES (1300, 'Crispo', 'Ruvalcaba Munguia', 'H', '36 Reiseñor', 45593, 'Crispo.Ruvalcaba.Munguia@dodgit.com', '02/10/47', 23, 10);
INSERT INTO usuaris VALUES (1301, 'Juvencia', 'Villagómez Carrasco', 'D', '95 Reiseñor', 46185, 'Juvencia.Villagomez.Carrasco@spambob.com', '05/11/78', 20, 4);
INSERT INTO usuaris VALUES (1302, 'Edén', 'Linares Munguia', 'D', '21 Escuadro', 46900, 'Eden.Linares.Munguia@trashymail.com', '20/06/59', 27, 2);
INSERT INTO usuaris VALUES (1303, 'Brandon', 'Otero Adame', 'H', '5 C/ Amoladera', 28890, 'Brandon.Otero.Adame@spambob.com', '21/09/49', 68, 12);
INSERT INTO usuaris VALUES (1304, 'Canan', 'Velasco Robledo', 'H', '27 Plaza Maior', 37215, 'Canan.Velasco.Robledo@pookmail.com', '17/04/75', 82, 6);
INSERT INTO usuaris VALUES (1305, 'Onofre', 'Bahena Garay', 'H', '31 Valadouro', 48114, 'Onofre.Bahena.Garay@mailinator.com', '14/03/84', 44, 9);
INSERT INTO usuaris VALUES (1306, 'Inán', 'Tejada Alanis', 'D', '9 Cádiz', 18516, 'Inan.Tejada.Alanis@trashymail.com', '11/05/59', 99, 9);
INSERT INTO usuaris VALUES (1307, 'Rosalina', 'Esparza Alejandro', 'D', '78 C/ Pablo Iglesias', 26315, 'Rosalina.Esparza.Alejandro@mailinator.com', '25/09/50', 85, 3);
INSERT INTO usuaris VALUES (1308, 'Merced', 'Santiago Ulloa', 'D', '47 Boriñaur enparantza', 7500, 'Merced.Santiago.Ulloa@dodgit.com', '20/02/85', 57, 2);
INSERT INTO usuaris VALUES (1309, 'Arydea', 'Garza Lucio', 'D', '59 Plaza Maior', 37213, 'Arydea.Garza.Lucio@dodgit.com', '09/03/59', 29, 5);
INSERT INTO usuaris VALUES (1310, 'Escolástico', 'Cano Baez', 'H', '79 Plazuela do Porto', 38436, 'Escolastico.Cano.Baez@dodgit.com', '02/02/48', 18, 6);
INSERT INTO usuaris VALUES (1311, 'Malena', 'Olivo Riojas', 'D', '56 Puerta Nueva', 35628, 'Malena.Olivo.Riojas@trashymail.com', '20/05/83', 97, 12);
INSERT INTO usuaris VALUES (1312, 'Sotero', 'Nino Casillas', 'H', '84 Visitación de la Encina', 37725, 'Sotero.Nino.Casillas@pookmail.com', '25/10/77', 40, 12);
INSERT INTO usuaris VALUES (1313, 'Bernardita', 'Esquibel Alcaraz', 'D', '37 Avda. Rio Nalon', 33450, 'Bernardita.Esquibel.Alcaraz@dodgit.com', '20/04/77', 33, 6);
INSERT INTO usuaris VALUES (1314, 'Aquiles', 'Olmos Rosado', 'H', '16 Paseo del Atlántico', 18126, 'Aquiles.Olmos.Rosado@mailinator.com', '31/10/46', 97, 11);
INSERT INTO usuaris VALUES (1315, 'Nilce', 'Corrales Montero', 'D', '78 C/ Los Herrán', 6500, 'Nilce.Corrales.Montero@pookmail.com', '25/05/41', 0, 10);
INSERT INTO usuaris VALUES (1316, 'Damia', 'Urías Bueno', 'D', '17 Maestro Puig Valera', 33578, 'Damia.Urias.Bueno@trashymail.com', '06/05/48', 53, 8);
INSERT INTO usuaris VALUES (1317, 'Naomi', 'Ulibarri Camarillo', 'D', '77 San Andrés', 37257, 'Naomi.Ulibarri.Camarillo@trashymail.com', '05/10/59', 12, 1);
INSERT INTO usuaris VALUES (1318, 'Emperatriz', 'Sosa Gastelum', 'D', '31 Cruce Casa de Postas', 18311, 'Emperatriz.Sosa.Gastelum@dodgit.com', '30/09/64', 34, 5);
INSERT INTO usuaris VALUES (1319, 'Indíbil', 'Rael Aguayo', 'H', '55 Paraguay', 3729, 'Indibil.Rael.Aguayo@dodgit.com', '29/12/70', 37, 7);
INSERT INTO usuaris VALUES (1320, 'Lucho', 'Guzmán Portillo', 'H', '21 C/ Domingo Beltrán', 2329, 'Lucho.Guzman.Portillo@mailinator.com', '26/04/56', 83, 1);
INSERT INTO usuaris VALUES (1321, 'Augusto', 'Zavala Viera', 'H', '76 Crta. Cádiz-Málaga', 12230, 'Augusto.Zavala.Viera@pookmail.com', '06/09/68', 57, 6);
INSERT INTO usuaris VALUES (1322, 'Cira', 'Duarte Balderas', 'D', '90 Reyes Católicos', 10200, 'Cira.Duarte.Balderas@spambob.com', '26/12/69', 73, 10);
INSERT INTO usuaris VALUES (1323, 'Hadrian', 'Veliz Ulibarri', 'H', '37 Extramuros', 28440, 'Hadrian.Veliz.Ulibarri@trashymail.com', '27/01/44', 83, 9);
INSERT INTO usuaris VALUES (1324, 'Orieta', 'Cisneros Gastelum', 'D', '35 Plaza de España', 15620, 'Orieta.Cisneros.Gastelum@mailinator.com', '05/03/55', 68, NULL);
INSERT INTO usuaris VALUES (1325, 'Kenti', 'Ulibarri Gallegos', 'D', '12 C/ Pablo Iglesias', 26326, 'Kenti.Ulibarri.Gallegos@trashymail.com', '28/10/53', 8, 2);
INSERT INTO usuaris VALUES (1326, 'Jocelin', 'Estévez Maldonado', 'H', '81 C/ Los Herrán', 6340, 'Jocelin.Estevez.Maldonado@spambob.com', '14/07/80', 71, 9);
INSERT INTO usuaris VALUES (1327, 'Parménides', 'Lara Saucedo', 'H', '89 Bellavista', 49610, 'Parmenides.Lara.Saucedo@dodgit.com', '16/04/82', 86, 6);
INSERT INTO usuaris VALUES (1328, 'Inaxio', 'Quiñónez Camarillo', 'H', '34 C/ Cañada del Rosal', 21630, 'Inaxio.Quinonez.Camarillo@pookmail.com', '02/06/49', 84, 12);
INSERT INTO usuaris VALUES (1329, 'Aidano', 'Montano Espinosa', 'H', '55 Ourense', 41980, 'Aidano.Montano.Espinosa@pookmail.com', '12/07/78', 92, 7);
INSERT INTO usuaris VALUES (1330, 'Alessandra', 'Orozco Aguilera', 'D', '23 Outid de Arriba', 43470, 'Alessandra.Orozco.Aguilera@pookmail.com', '15/01/40', 96, 11);
INSERT INTO usuaris VALUES (1331, 'Demian', 'Beltrán Benítez', 'H', '12 Puerta Nueva', 35640, 'Demian.Beltran.Benitez@spambob.com', '09/08/46', 17, 9);
INSERT INTO usuaris VALUES (1332, 'Utka', 'Maestas Sanches', 'H', '91 Avda. Alameda Sundheim', 22534, 'Utka.Maestas.Sanches@spambob.com', '20/06/56', 65, 1);
INSERT INTO usuaris VALUES (1333, 'Lihue', 'Zelaya Treviño', 'D', '57 Crta. Cádiz-Málaga', 12221, 'Lihue.Zelaya.Trevino@mailinator.com', '02/10/51', 86, 7);
INSERT INTO usuaris VALUES (1334, 'Nicolasa', 'Canales Díaz', 'D', '50 Paseo Junquera', 12527, 'Nicolasa.Canales.Diaz@trashymail.com', '30/07/69', 89, 4);
INSERT INTO usuaris VALUES (1335, 'Zuleika', 'Salgado Arreola', 'D', '99 Plaza Colón', 26124, 'Zuleika.Salgado.Arreola@spambob.com', '11/07/76', 63, 2);
INSERT INTO usuaris VALUES (1336, 'Desiderius', 'Madrid Tijerina', 'H', '63 C/ Angosto', 23393, 'Desiderius.Madrid.Tijerina@trashymail.com', '24/03/75', 99, 11);
INSERT INTO usuaris VALUES (1337, 'Mora', 'Velez Urrútia', 'D', '42 Avda. de Andalucía', 29210, 'Mora.Velez.Urrutia@spambob.com', '17/12/45', 47, 2);
INSERT INTO usuaris VALUES (1338, 'Tzípora', 'Rodríguez Madera', 'D', '36 Cádiz', 18452, 'Tzipora.Rodriguez.Madera@spambob.com', '16/02/40', 4, NULL);
INSERT INTO usuaris VALUES (1339, 'Silvio', 'Calvillo Manzanares', 'H', '91 Celso Emilio Ferreiro', 50500, 'Silvio.Calvillo.Manzanares@mailinator.com', '16/09/77', 17, 6);
INSERT INTO usuaris VALUES (1340, 'Josué', 'Cano Rodarte', 'H', '64 Plaza de España', 15808, 'Josue.Cano.Rodarte@pookmail.com', '16/05/41', 89, 5);
INSERT INTO usuaris VALUES (1341, 'Demian', 'Lomeli Maestas', 'H', '31 Eusebio Dávila', 41390, 'Demian.Lomeli.Maestas@trashymail.com', '25/08/71', 46, 8);
INSERT INTO usuaris VALUES (1342, 'Muredac', 'Nieto Madera', 'H', '60 C/ Henan Cortes', 28960, 'Muredac.Nieto.Madera@dodgit.com', '20/10/51', 87, 3);
INSERT INTO usuaris VALUES (1343, 'Nelo', 'Juárez Valdivia', 'H', '79 Camiño Ancho', 37788, 'Nelo.Juarez.Valdivia@pookmail.com', '05/09/68', 50, 11);
INSERT INTO usuaris VALUES (1344, 'Tilo', 'Saldana Mascarenas', 'H', '57 Visitación de la Encina', 37730, 'Tilo.Saldana.Mascarenas@spambob.com', '04/09/84', 15, 11);
INSERT INTO usuaris VALUES (1345, 'Baudilio', 'Urena Mares', 'H', '21 Rúa de San Pedro', 37830, 'Baudilio.Urena.Mares@pookmail.com', '14/04/66', 55, 7);
INSERT INTO usuaris VALUES (1346, 'Teodequilda', 'Delgadillo Padrón', NULL, '47 Pza. Fuensanta', 32212, 'Teodequilda.Delgadillo.Padron@spambob.com', '23/08/53', 58, 12);
INSERT INTO usuaris VALUES (1347, 'Gretel', 'Olivárez Viera', 'D', '95 Constitución', 37129, 'Gretel.Olivarez.Viera@dodgit.com', '27/02/51', 21, 12);
INSERT INTO usuaris VALUES (1348, 'Lis', 'Flórez Terrazas', 'D', '18 Paseo del Atlántico', 18129, 'Lis.Florez.Terrazas@trashymail.com', '05/12/58', 55, 12);
INSERT INTO usuaris VALUES (1349, 'Kelly', 'Santillán Ozuna', 'D', '8 Valadouro', 48141, 'Kelly.Santillan.Ozuna@mailinator.com', '21/08/66', 73, 4);
INSERT INTO usuaris VALUES (1350, 'Palaciada', 'Gallardo Bustos', 'D', '79 Avda. Alameda Sundheim', 22530, 'Palaciada.Gallardo.Bustos@pookmail.com', '17/03/71', 41, 2);
INSERT INTO usuaris VALUES (1351, 'Anabel', 'Rivera Téllez', 'D', '19 Rio Segura', 31520, 'Anabel.Rivera.Tellez@dodgit.com', '18/11/70', 68, 10);
INSERT INTO usuaris VALUES (1352, 'Nabor', 'Magana Fernández', 'H', '61 Paseo del Atlántico', 18128, 'Nabor.Magana.Fernandez@dodgit.com', '25/04/81', 81, 5);
INSERT INTO usuaris VALUES (1353, 'Sulamita', 'Ávila Velázquez', 'D', '78 Rua da Rapina', 37480, 'Sulamita.Avila.Velazquez@trashymail.com', '24/05/74', 30, 10);
INSERT INTO usuaris VALUES (1354, 'Britanic', 'Estévez Barreto', 'H', '52 Estrela', 40000, 'Britanic.Estevez.Barreto@dodgit.com', '12/04/66', 44, 5);
INSERT INTO usuaris VALUES (1355, 'raven', 'Tijerina Granado', 'D', '28 Paraguay', 3700, 'raven.Tijerina.Granado@pookmail.com', '14/06/42', 10, 12);
INSERT INTO usuaris VALUES (1356, 'Macrina', 'Salcedo Ceballos', 'D', '67 Ctra. Hornos', 26216, 'Macrina.Salcedo.Ceballos@spambob.com', '18/01/73', 39, 9);
INSERT INTO usuaris VALUES (1357, 'Remedios', 'Pedraza Henríquez', 'D', '14 Avda. Rio Nalon', 33518, 'Remedios.Pedraza.Henriquez@spambob.com', '20/12/56', 34, 4);
INSERT INTO usuaris VALUES (1358, 'Agata', 'Juárez Padrón', NULL, '17 Camiño Real', 48600, 'Agata.Juarez.Padron@dodgit.com', '20/07/48', 96, 11);
INSERT INTO usuaris VALUES (1359, 'Semira', 'Montoya Mata', 'D', '84 Ctra. Villena', 33829, 'Semira.Montoya.Mata@dodgit.com', '05/08/52', 20, 8);
INSERT INTO usuaris VALUES (1360, 'Eleonora', 'Villaseñor Rojas', 'D', '59 Cartagena', 30560, 'Eleonora.Villasenor.Rojas@spambob.com', '13/03/52', 58, 10);
INSERT INTO usuaris VALUES (1361, 'Vicki', 'Chávez Suárez', 'D', '80 Ctra. Beas-Cortijos Nuevos', 26376, 'Vicki.Chavez.Suarez@mailinator.com', '07/04/79', 36, 12);
INSERT INTO usuaris VALUES (1362, 'Laelia', 'Armas Benavides', 'D', '46 Avda. Generalísimo', 32000, 'Laelia.Armas.Benavides@dodgit.com', '04/12/79', 6, 4);
INSERT INTO usuaris VALUES (1363, 'Lais', 'Rangel Montoya', 'D', '66 Ctra. de la Puerta', 26589, 'Lais.Rangel.Montoya@spambob.com', '29/05/45', 96, 6);
INSERT INTO usuaris VALUES (1364, 'Gian', 'Naranjo Herrera', 'H', '94 Caño', 32740, 'Gian.Naranjo.Herrera@pookmail.com', '10/12/50', 71, 8);
INSERT INTO usuaris VALUES (1365, 'Alina', 'Paz Marroquín', NULL, '12 Calle Aduana', 1311, 'Alina.Paz.Marroquin@trashymail.com', '16/04/73', 34, 9);
INSERT INTO usuaris VALUES (1366, 'Nazaret', 'Venegas Quintanilla', 'H', '44 Camiño Real', 48530, 'Nazaret.Venegas.Quintanilla@pookmail.com', '26/05/74', 16, 11);
INSERT INTO usuaris VALUES (1367, 'Eufemia', 'Cavazos Caraballo', 'D', '25 C/ Arana', 2600, 'Eufemia.Cavazos.Caraballo@pookmail.com', '28/07/82', 59, 12);
INSERT INTO usuaris VALUES (1368, 'Suyai', 'Cabrera Zamora', 'H', '71 Ctra. Bailén-Motril', 23230, 'Suyai.Cabrera.Zamora@mailinator.com', '11/10/51', 6, 11);
INSERT INTO usuaris VALUES (1369, 'Galo', 'López Saucedo', 'H', '39 Av. Zumalakarregi', 3170, 'Galo.Lopez.Saucedo@mailinator.com', '24/12/69', 83, 8);
INSERT INTO usuaris VALUES (1370, 'Fritz', 'Zambrano Rico', 'H', '59 C/ Henan Cortes', 28960, 'Fritz.Zambrano.Rico@dodgit.com', '03/12/62', 9, 9);
INSERT INTO usuaris VALUES (1371, 'Peregrino', 'Urías Villagómez', 'H', '6 Carretera', 14630, 'Peregrino.Urias.Villagomez@dodgit.com', '04/12/79', 57, 11);
INSERT INTO usuaris VALUES (1372, 'Bartley', 'Reyna Rangel', 'H', '91 Canónigo Valiño', 46470, 'Bartley.Reyna.Rangel@spambob.com', '26/07/44', 61, 5);
INSERT INTO usuaris VALUES (1373, 'Eliú', 'Menchaca Guzmán', NULL, '27 C/ Arana', 2434, 'Eliu.Menchaca.Guzman@dodgit.com', '04/01/53', 32, 8);
INSERT INTO usuaris VALUES (1374, 'Ales', 'Olivárez Camacho', 'H', '10 Canónigo Valiño', 46230, 'Ales.Olivarez.Camacho@spambob.com', '25/06/42', 24, 1);
INSERT INTO usuaris VALUES (1375, 'Ratrudis', 'Carrero Gastelum', 'D', '71 Cercas Bajas', 8230, 'Ratrudis.Carrero.Gastelum@spambob.com', '08/10/40', 84, 2);
INSERT INTO usuaris VALUES (1376, 'Bona', 'Badillo Bonilla', 'D', '98 Paseo Junquera', 12480, 'Bona.Badillo.Bonilla@dodgit.com', '01/03/49', 43, 9);
INSERT INTO usuaris VALUES (1377, 'Sófocles', 'Valladares Roldán', 'H', '27 Calle Aduana', 1212, 'Sofocles.Valladares.Roldan@pookmail.com', '14/06/73', 11, 1);
INSERT INTO usuaris VALUES (1378, 'Pastora', 'Ávila Solís', 'D', '82 Cartagena', 30613, 'Pastora.Avila.Solis@mailinator.com', '07/01/78', 13, NULL);
INSERT INTO usuaris VALUES (1379, 'Katu', 'Jaramillo Mena', 'D', '93 Plaza Maior', 37188, 'Katu.Jaramillo.Mena@spambob.com', '17/04/61', 0, 5);
INSERT INTO usuaris VALUES (1380, 'Alcia', 'Zepeda Domínguez', 'D', '16 Puerta Nueva', 36416, 'Alcia.Zepeda.Dominguez@trashymail.com', '29/05/68', 4, 10);
INSERT INTO usuaris VALUES (1381, 'Macario', 'Valladares Benavides', 'H', '42 Avda. Alameda Sundheim', 22800, 'Macario.Valladares.Benavides@dodgit.com', '16/05/55', 33, 12);
INSERT INTO usuaris VALUES (1382, 'Dion', 'Casanova Echevarría', 'H', '91 Maestro Puig Valera', 33717, 'Dion.Casanova.Echevarria@dodgit.com', '01/10/59', 14, 10);
INSERT INTO usuaris VALUES (1383, 'Cesario', 'Casárez Carrera', 'H', '47 Lamas Carbajal', 41566, 'Cesario.Casarez.Carrera@mailinator.com', '07/05/56', 3, 11);
INSERT INTO usuaris VALUES (1384, 'Alphonse', 'Valle Vanegas', 'H', '18 Ctra. de Fuentenueva', 28250, 'Alphonse.Valle.Vanegas@pookmail.com', '23/05/85', 81, 9);
INSERT INTO usuaris VALUES (1385, 'Luvencio', 'Oquendo Alejandro', 'H', '60 Avda. Andalucía', 26125, 'Luvencio.Oquendo.Alejandro@pookmail.com', '05/08/53', 60, NULL);
INSERT INTO usuaris VALUES (1386, 'Gioconda', 'Arévalo Maya', 'D', '41 José matía', 2212, 'Gioconda.Arevalo.Maya@spambob.com', '09/08/42', 96, 8);
INSERT INTO usuaris VALUES (1387, 'Eitan', 'Griego Fierro', 'H', '86 C/ Hijuela de Lojo', 20240, 'Eitan.Griego.Fierro@mailinator.com', '26/03/41', 70, 10);
INSERT INTO usuaris VALUES (1388, 'Geoffrey', 'Madrid Viera', 'H', '1 Prolongacion San Sebastian', 21280, 'Geoffrey.Madrid.Viera@pookmail.com', '22/05/57', 57, 2);
INSERT INTO usuaris VALUES (1389, 'Yazmín', 'Galván Tapia', 'D', '21 Cruce Casa de Postas', 18247, 'Yazmin.Galvan.Tapia@trashymail.com', '25/06/46', 47, 11);
INSERT INTO usuaris VALUES (1390, 'Ida', 'Gutiérrez Ortiz', 'D', '15 C/ Eras', 28723, 'Ida.Gutierrez.Ortiz@mailinator.com', '01/05/48', 11, 12);
INSERT INTO usuaris VALUES (1391, 'Benjamín', 'Rodarte Marín', 'H', '28 Salzillo', 32644, 'Benjamin.Rodarte.Marin@dodgit.com', '12/09/69', 97, 11);
INSERT INTO usuaris VALUES (1392, 'Arcángela', 'Angulo Guerra', 'D', '3 Maestro Puig Valera', 33717, 'Arcangela.Angulo.Guerra@trashymail.com', '12/02/62', 44, 8);
INSERT INTO usuaris VALUES (1393, 'Yemina', 'Arévalo Montoya', 'D', '23 Bouciña', 43784, 'Yemina.Arevalo.Montoya@pookmail.com', '12/08/49', 34, 8);
INSERT INTO usuaris VALUES (1394, 'Liduvina', 'Olmos Hernandes', 'D', '33 Antonio Vázquez', 38715, 'Liduvina.Olmos.Hernandes@trashymail.com', '10/07/57', 35, 11);
INSERT INTO usuaris VALUES (1395, 'Elia', 'Almanza Montés', 'D', '25 C/ Libertad', 5440, 'Elia.Almanza.Montes@mailinator.com', '03/02/41', 76, 5);
INSERT INTO usuaris VALUES (1396, 'Desiderius', 'Vargas Magana', 'H', '28 Enxertos', 37514, 'Desiderius.Vargas.Magana@dodgit.com', '12/11/41', 91, 6);
INSERT INTO usuaris VALUES (1397, 'Inacayal', 'Toro Roque', 'H', '82 Paraguay', 3660, 'Inacayal.Toro.Roque@dodgit.com', '02/11/68', 59, 12);
INSERT INTO usuaris VALUES (1398, 'Adhemar', 'Barrientos Saucedo', 'H', '57 Urzáiz', 44500, 'Adhemar.Barrientos.Saucedo@mailinator.com', '09/05/44', 56, 1);
INSERT INTO usuaris VALUES (1399, 'Melvin', 'Valle Casanova', 'D', '61 Reyes Católicos', 9560, 'Melvin.Valle.Casanova@mailinator.com', '31/03/64', 26, 10);
INSERT INTO usuaris VALUES (1400, 'Obadia', 'Villalobos Arana', 'H', '35 Puerta Nueva', 35820, 'Obadia.Villalobos.Arana@mailinator.com', '09/11/69', 68, NULL);
INSERT INTO usuaris VALUES (1401, 'Sergei', 'Sosa Borrego', 'H', '20 C/ Hijuela de Lojo', 20491, 'Sergei.Sosa.Borrego@dodgit.com', '20/11/58', 87, 12);
INSERT INTO usuaris VALUES (1402, 'Miles', 'Mondragón Carmona', 'H', '18 C/ Arana', 2436, 'Miles.Mondragon.Carmona@pookmail.com', '21/06/77', 21, 6);
INSERT INTO usuaris VALUES (1403, 'Tesira', 'Peralta Macías', 'D', '64 Avendaño', 4280, 'Tesira.Peralta.Macias@mailinator.com', '29/12/42', 28, 3);
INSERT INTO usuaris VALUES (1404, 'Romana', 'Aranda Ceballos', 'D', '71 José matía', 2160, 'Romana.Aranda.Ceballos@trashymail.com', '01/03/47', 19, 5);
INSERT INTO usuaris VALUES (1405, 'Giuliana', 'Cabán Villagómez', 'D', '39 Pl. Virgen Blanca', 8540, 'Giuliana.Caban.Villagomez@dodgit.com', '27/08/42', 97, NULL);
INSERT INTO usuaris VALUES (1406, 'Kenneth', 'Polanco Miramontes', 'H', '17 Paseo del Atlántico', 18120, 'Kenneth.Polanco.Miramontes@trashymail.com', '27/06/80', 21, 4);
INSERT INTO usuaris VALUES (1407, 'Antígona', 'Solano Barajas', 'D', '87 C/ Rosa de los Vientos', 11178, 'Antigona.Solano.Barajas@trashymail.com', '04/06/72', 73, 3);
INSERT INTO usuaris VALUES (1408, 'Déborah', 'Esquibel Prado', 'D', '8 Salzillo', 32634, 'Deborah.Esquibel.Prado@trashymail.com', '08/03/51', 63, 12);
INSERT INTO usuaris VALUES (1409, 'Casdoa', 'Árias Solórzano', 'D', '53 Avenida Cervantes', 48220, 'Casdoa.Arias.Solorzano@spambob.com', '19/08/42', 72, 7);
INSERT INTO usuaris VALUES (1410, 'Sotero', 'Benavidez Cervantes', 'H', '91 Escuadro', 47151, 'Sotero.Benavidez.Cervantes@mailinator.com', '10/07/58', 0, 10);
INSERT INTO usuaris VALUES (1411, 'Querubín', 'Gamboa Méndez', 'H', '83 Herrería', 18183, 'Querubin.Gamboa.Mendez@pookmail.com', '03/04/48', 35, 5);
INSERT INTO usuaris VALUES (1412, 'Fidela', 'Godoy Quiñónez', 'D', '32 Herrería', 18183, 'Fidela.Godoy.Quinonez@pookmail.com', '10/01/43', 60, 8);
INSERT INTO usuaris VALUES (1413, 'Idalina', 'Ortiz Duran', NULL, '27 Quevedo', 15500, 'Idalina.Ortiz.Duran@pookmail.com', '25/04/48', 40, 11);
INSERT INTO usuaris VALUES (1414, 'Aurele', 'Velez Rodarte', 'H', '97 Alcon Molina', 31171, 'Aurele.Velez.Rodarte@trashymail.com', '21/09/40', 49, 2);
INSERT INTO usuaris VALUES (1415, 'Ebo', 'Murillo Gaitán', 'H', '49 C/ Henan Cortes', 29109, 'Ebo.Murillo.Gaitan@pookmail.com', '08/09/74', 76, NULL);
INSERT INTO usuaris VALUES (1416, 'Noralí', 'Bustamante Armijo', 'D', '25 Salzillo', 32701, 'Norali.Bustamante.Armijo@mailinator.com', NULL, 24, 9);
INSERT INTO usuaris VALUES (1417, 'Dalila', 'Escalante Raya', 'D', '43 Comandante Izarduy', 9000, 'Dalila.Escalante.Raya@pookmail.com', '29/07/46', 84, 2);
INSERT INTO usuaris VALUES (1418, 'Gracia', 'Salcedo Matías', 'D', '66 C/ Domingo Beltrán', 2310, 'Gracia.Salcedo.Matias@mailinator.com', '22/07/48', 52, 11);
INSERT INTO usuaris VALUES (1419, 'Morfeo', 'Valentín Castro', 'H', '47 Plaza Colón', 25100, 'Morfeo.Valentin.Castro@mailinator.com', '15/10/66', 56, 3);
INSERT INTO usuaris VALUES (1420, 'Edén', 'Barreto Ballesteros', 'D', '94 C/ Cañada del Rosal', 21500, 'Eden.Barreto.Ballesteros@spambob.com', '28/07/62', 38, 11);
INSERT INTO usuaris VALUES (1421, 'Cinty', 'Gallegos Tijerina', 'D', '19 C/ Amoladera', 28820, 'Cinty.Gallegos.Tijerina@dodgit.com', '12/10/44', 1, 2);
INSERT INTO usuaris VALUES (1422, 'Eric', 'Echevarría Ruiz', 'H', '71 Maestro Puig Valera', 33800, 'Eric.Echevarria.Ruiz@trashymail.com', '01/12/69', 41, 6);
INSERT INTO usuaris VALUES (1423, 'Alisa', 'Abeyta Ozuna', 'D', '80 Apartado de Correos', 37440, 'Alisa.Abeyta.Ozuna@pookmail.com', '05/07/43', 69, 11);
INSERT INTO usuaris VALUES (1424, 'Grisel', 'Becerra Santiago', 'D', '79 Rio Segura', 31261, 'Grisel.Becerra.Santiago@spambob.com', '03/04/59', 1, NULL);
INSERT INTO usuaris VALUES (1425, 'Sheila', 'Corona Armendáriz', 'D', '83 Paseo del Atlántico', 17500, 'Sheila.Corona.Armendariz@pookmail.com', '12/04/43', 32, 7);
INSERT INTO usuaris VALUES (1426, 'Ornella', 'Menéndez Mascarenas', 'D', '25 Avda. Andalucía', 26135, 'Ornella.Menendez.Mascarenas@dodgit.com', '13/01/67', 19, 12);
INSERT INTO usuaris VALUES (1427, 'Aynkan', 'Salcedo Mata', 'D', '72 Ctra. de Siles', 27400, 'Aynkan.Salcedo.Mata@trashymail.com', '17/01/42', 92, NULL);
INSERT INTO usuaris VALUES (1428, 'Juvencio', 'Cervantes Ocampo', 'H', '31 Rúa de San Pedro', 37860, 'Juvencio.Cervantes.Ocampo@trashymail.com', '03/11/67', 90, 4);
INSERT INTO usuaris VALUES (1429, 'Ales', 'Cepeda Velasco', 'H', '4 Rio Segura', 31520, 'Ales.Cepeda.Velasco@dodgit.com', '29/07/85', 69, 4);
INSERT INTO usuaris VALUES (1430, 'Eusebia', 'Navarro Covarrubias', 'D', '80 C/ Cuevas de Ambrosio', 23650, 'Eusebia.Navarro.Covarrubias@mailinator.com', '17/12/51', 4, 7);
INSERT INTO usuaris VALUES (1431, 'Fina', 'Armas Cuellar', 'D', '60 Avda. Alameda Sundheim', 23120, 'Fina.Armas.Cuellar@pookmail.com', '18/04/46', 79, NULL);
INSERT INTO usuaris VALUES (1432, 'Noelino', 'Collado Cabrera', 'H', '79 Avda. Andalucía', 26190, 'Noelino.Collado.Cabrera@mailinator.com', '03/01/70', 64, 10);
INSERT INTO usuaris VALUES (1433, 'Serafina', 'Betancourt Garay', 'D', '78 Alvaro Cunqueiro', 40400, 'Serafina.Betancourt.Garay@dodgit.com', '03/09/40', 85, 5);
INSERT INTO usuaris VALUES (1434, 'Wendi', 'Esquibel Linares', 'D', '93 Ctra. Beas-Cortijos Nuevos', 26512, 'Wendi.Esquibel.Linares@spambob.com', '05/10/64', 48, 9);
INSERT INTO usuaris VALUES (1435, 'Sofiel', 'Bañuelos Ortiz', 'H', '14 Plaza de España', 15621, 'Sofiel.Banuelos.Ortiz@spambob.com', '22/01/69', 77, 5);
INSERT INTO usuaris VALUES (1436, 'Pace', 'Corona Mayonga', 'H', '32 Caño', 33000, 'Pace.Corona.Mayonga@spambob.com', '06/09/77', 7, 7);
INSERT INTO usuaris VALUES (1437, 'Lot', 'Vasquez Caballero', 'H', '96 Zumalakarregi etorbidea', 7109, 'Lot.Vasquez.Caballero@trashymail.com', '02/09/54', 31, 6);
INSERT INTO usuaris VALUES (1438, 'Ursula', 'Garrido Lucero', 'D', '63 Crta. Cádiz-Málaga', 12225, 'Ursula.Garrido.Lucero@pookmail.com', '26/09/84', 31, 4);
INSERT INTO usuaris VALUES (1439, 'Violetta', 'Galván Negrete', 'D', '29 Alcon Molina', 31194, 'Violetta.Galvan.Negrete@dodgit.com', '01/09/71', 25, 10);
INSERT INTO usuaris VALUES (1440, 'Prometeo', 'Irizarry Carmona', 'H', '69 Enxertos', 37520, 'Prometeo.Irizarry.Carmona@mailinator.com', '17/05/79', 1, 12);
INSERT INTO usuaris VALUES (1441, 'Sinesio', 'Torres Espinal', 'H', '89 C/ Cuesta del  Álamo', 29610, 'Sinesio.Torres.Espinal@dodgit.com', '14/11/56', 54, 7);
INSERT INTO usuaris VALUES (1442, 'Justin', 'Granados Chavarría', 'H', '81 Avda. Andalucía', 26144, 'Justin.Granados.Chavarria@trashymail.com', '20/12/55', 93, 8);
INSERT INTO usuaris VALUES (1443, 'Nale', 'Nieto Puga', 'D', '7 Rúa de San Pedro', 37797, 'Nale.Nieto.Puga@dodgit.com', '27/07/43', 45, NULL);
INSERT INTO usuaris VALUES (1444, 'Barnie', 'Blanco Jimínez', 'H', '98 Salzillo', 32549, 'Barnie.Blanco.Jiminez@dodgit.com', '20/08/56', 77, 10);
INSERT INTO usuaris VALUES (1445, 'Janvier', 'Noriega Esquivel', 'H', '97 Zumalakarregi etorbidea', 7170, 'Janvier.Noriega.Esquivel@dodgit.com', '20/04/66', 10, NULL);
INSERT INTO usuaris VALUES (1446, 'Jairo', 'Mata Alonso', 'H', '2 C/ Arana', 2640, 'Jairo.Mata.Alonso@spambob.com', '29/11/41', 42, 12);
INSERT INTO usuaris VALUES (1447, 'Amal', 'Sandoval Alcalá', 'D', '37 Av. Zumalakarregi', 3187, 'Amal.Sandoval.Alcala@mailinator.com', '25/02/68', 59, 10);
INSERT INTO usuaris VALUES (1448, 'Marín', 'Olivárez Tapia', 'H', '66 Camiño Real', 48390, 'Marin.Olivarez.Tapia@dodgit.com', '10/03/85', 46, 11);
INSERT INTO usuaris VALUES (1449, 'Querubina', 'Partida Delgadillo', 'D', '46 Rúa Olmos', 37338, 'Querubina.Partida.Delgadillo@trashymail.com', '24/05/74', 92, 11);
INSERT INTO usuaris VALUES (1450, 'Wilton', 'Tafoya Marín', 'H', '70 Rua da Rapina', 37497, 'Wilton.Tafoya.Marin@pookmail.com', '08/12/81', 15, 6);
INSERT INTO usuaris VALUES (1451, 'Giannina', 'Carranza Nava', 'D', '74 Calle Carril de la Fuente', 13327, 'Giannina.Carranza.Nava@mailinator.com', '11/09/71', 22, 8);
INSERT INTO usuaris VALUES (1452, 'Brunilda', 'Saenz Ocasio', 'D', '46 Comandante Izarduy', 8960, 'Brunilda.Saenz.Ocasio@spambob.com', '22/04/43', 75, 4);
INSERT INTO usuaris VALUES (1453, 'Minotauro', 'Cordero Sepúlveda', 'H', '9 Enxertos', 37520, 'Minotauro.Cordero.Sepulveda@spambob.com', '04/08/81', 2, 3);
INSERT INTO usuaris VALUES (1454, 'Cira', 'Almaraz Abeyta', 'D', '62 Calle Aduana', 1200, 'Cira.Almaraz.Abeyta@trashymail.com', '03/12/43', 88, 8);
INSERT INTO usuaris VALUES (1455, 'Karim', 'Casanova Nava', 'D', '8 Eusebio Dávila', 41318, 'Karim.Casanova.Nava@mailinator.com', '18/03/81', 68, 4);
INSERT INTO usuaris VALUES (1456, 'Primo', 'Archuleta Jimínez', 'H', '64 C/ Señores Curas', 12135, 'Primo.Archuleta.Jiminez@spambob.com', '31/03/43', 22, 4);
INSERT INTO usuaris VALUES (1457, 'Dámaso', 'Armendáriz Varela', 'H', '86 Rio Segura', 31310, 'Damaso.Armendariz.Varela@trashymail.com', '02/06/83', 76, 2);
INSERT INTO usuaris VALUES (1458, 'Calístrato', 'Zambrano Ruiz', 'H', '50 Calle Carril de la Fuente', 13300, 'Calistrato.Zambrano.Ruiz@trashymail.com', '12/06/52', 80, 3);
INSERT INTO usuaris VALUES (1459, 'Mahoma', 'Velez Mayonga', 'H', '16 Avda. de la Estación', 28660, 'Mahoma.Velez.Mayonga@spambob.com', '26/12/84', 7, 10);
INSERT INTO usuaris VALUES (1460, 'Cirinea', 'Ruvalcaba Armas', 'D', '57 C/ Domingo Beltrán', 2314, 'Cirinea.Ruvalcaba.Armas@trashymail.com', '14/10/62', 34, 12);
INSERT INTO usuaris VALUES (1461, 'Lola', 'Pichardo Rendón', NULL, '83 Bouciña', 43881, 'Lola.Pichardo.Rendon@dodgit.com', '12/04/52', 23, 8);
INSERT INTO usuaris VALUES (1462, 'Alipio', 'Duarte Bahena', 'H', '99 Zumalakarregi etorbidea', 7179, 'Alipio.Duarte.Bahena@trashymail.com', '13/01/40', 16, 9);
INSERT INTO usuaris VALUES (1463, 'Leylen', 'Leal Espino', 'D', '17 Visitación de la Encina', 37712, 'Leylen.Leal.Espino@spambob.com', '06/09/59', 64, 3);
INSERT INTO usuaris VALUES (1464, 'Casto', 'Figueroa Montez', 'H', '70 Calle Carril de la Fuente', 13320, 'Casto.Figueroa.Montez@spambob.com', '14/08/40', 93, 5);
INSERT INTO usuaris VALUES (1465, 'Memmon', 'Murillo Trujillo', 'H', '54 Avda. de la Estación', 28594, 'Memmon.Murillo.Trujillo@trashymail.com', '12/03/52', 90, 10);
INSERT INTO usuaris VALUES (1466, 'Kaitan', 'Perales González', 'H', '86 Plazuela do Porto', 37892, 'Kaitan.Perales.Gonzalez@pookmail.com', '29/08/81', 71, 12);
INSERT INTO usuaris VALUES (1467, 'Cilinia', 'Ortega Sánchez', 'D', '98 Extramuros', 28370, 'Cilinia.Ortega.Sanchez@pookmail.com', '28/10/49', 92, 1);
INSERT INTO usuaris VALUES (1468, 'Eitan', 'Salazar Nevarez', 'H', '76 C/ Arana', 2610, 'Eitan.Salazar.Nevarez@trashymail.com', '25/11/52', 15, NULL);
INSERT INTO usuaris VALUES (1469, 'Audrey', 'Raya Farías', 'D', '53 Apartado de Correos', 37427, 'Audrey.Raya.Farias@spambob.com', '24/04/46', 18, 3);
INSERT INTO usuaris VALUES (1470, 'Edna', 'Dávila Dueñas', 'D', '97 C/ Arana', 2450, 'Edna.Davila.Duenas@pookmail.com', '21/09/58', 42, 6);
INSERT INTO usuaris VALUES (1471, 'Segundino', 'Corral Ortega', 'H', '91 Ventanilla de Beas', 27740, 'Segundino.Corral.Ortega@mailinator.com', '21/07/42', 36, 9);
INSERT INTO usuaris VALUES (1472, 'Isod', 'Godoy Lomeli', 'H', '84 Outid de Arriba', 43700, 'Isod.Godoy.Lomeli@pookmail.com', '09/10/68', 37, 4);
INSERT INTO usuaris VALUES (1473, 'Bonifacia', 'Jáquez Ornelas', 'D', '84 Prolongacion San Sebastian', 21291, 'Bonifacia.Jaquez.Ornelas@pookmail.com', '28/03/53', 2, 6);
INSERT INTO usuaris VALUES (1474, 'Tancredo', 'Merino Zavala', 'H', '34 Herrería', 18170, 'Tancredo.Merino.Zavala@trashymail.com', '16/03/52', 29, 11);
INSERT INTO usuaris VALUES (1475, 'Abril', 'Guerrero Duarte', 'D', '8 Ctra. Villena', 34400, 'Abril.Guerrero.Duarte@dodgit.com', '07/09/61', 86, 5);
INSERT INTO usuaris VALUES (1476, 'Adulfo', 'Mercado Aponte', 'H', '75 Rúa do Paseo', 41888, 'Adulfo.Mercado.Aponte@pookmail.com', '24/09/44', 55, NULL);
INSERT INTO usuaris VALUES (1477, 'Maku', 'Aguayo Menéndez', 'D', '64 Salzillo', 32690, 'Maku.Aguayo.Menendez@dodgit.com', '26/09/54', 54, 9);
INSERT INTO usuaris VALUES (1478, 'Ciríaco', 'Canales Padilla', 'H', '33 Pl. Virgen Blanca', 8450, 'Ciriaco.Canales.Padilla@mailinator.com', '23/11/77', 81, 12);
INSERT INTO usuaris VALUES (1479, 'Indiana', 'Salazar Urbina', 'D', '19 Plaza Colón', 24420, 'Indiana.Salazar.Urbina@mailinator.com', '19/07/84', 33, 3);
INSERT INTO usuaris VALUES (1480, 'Melisa', 'Montanez Cervantes', 'D', '83 Avenida Cervantes', 48310, 'Melisa.Montanez.Cervantes@spambob.com', '16/09/78', 5, 10);
INSERT INTO usuaris VALUES (1481, 'Marcelina', 'Granado Barrios', 'D', '36 Cruce Casa de Postas', 18420, 'Marcelina.Granado.Barrios@trashymail.com', '12/06/61', 82, 11);
INSERT INTO usuaris VALUES (1482, 'Catrian', 'Velez Saavedra', 'H', '28 Reiseñor', 45500, 'Catrian.Velez.Saavedra@trashymail.com', '02/04/49', 25, 2);
INSERT INTO usuaris VALUES (1483, 'Barbara', 'Alcalá Alonso', 'D', '45 El Roqueo', 15940, 'Barbara.Alcala.Alonso@trashymail.com', '13/09/78', 76, 1);
INSERT INTO usuaris VALUES (1484, 'Naimid', 'Munguia Archuleta', 'D', '94 Rua da Rapina', 37460, 'Naimid.Munguia.Archuleta@dodgit.com', '30/12/61', 62, 11);
INSERT INTO usuaris VALUES (1485, 'Elda', 'Callas Carvajal', 'D', '77 Pl. Virgen Blanca', 8710, 'Elda.Callas.Carvajal@mailinator.com', '28/05/56', 18, 10);
INSERT INTO usuaris VALUES (1486, 'Paine', 'Polanco Nieto', 'D', '38 Fuente del Gallo', 14960, 'Paine.Polanco.Nieto@mailinator.com', '20/02/54', 85, 2);
INSERT INTO usuaris VALUES (1487, 'Karmina', 'Paz Armijo', 'D', '70 Bellavista', 49600, 'Karmina.Paz.Armijo@spambob.com', '31/12/61', 40, 12);
INSERT INTO usuaris VALUES (1488, 'Amadis', 'Vergara Reyna', 'D', '98 Salzillo', 32710, 'Amadis.Vergara.Reyna@dodgit.com', NULL, 80, 7);
INSERT INTO usuaris VALUES (1489, 'Agalia', 'Concepción Padrón', NULL, '73 Alvaro Cunqueiro', 41240, 'Agalia.Concepcion.Padron@spambob.com', '21/10/65', 80, 3);
INSERT INTO usuaris VALUES (1490, 'Tiana', 'Narváez Juárez', 'D', '14 C/ Manuel Iradier', 3779, 'Tiana.Narvaez.Juarez@pookmail.com', '04/06/76', 29, 1);
INSERT INTO usuaris VALUES (1491, 'Elisea', 'Esquibel Esparza', 'D', '87 Camiño Ancho', 37762, 'Elisea.Esquibel.Esparza@pookmail.com', '15/09/53', 98, 10);
INSERT INTO usuaris VALUES (1492, 'Solano', 'Quintanilla Padrón', 'H', '78 Ventanilla de Beas', 27891, 'Solano.Quintanilla.Padron@trashymail.com', NULL, 27, 11);
INSERT INTO usuaris VALUES (1493, 'Sintiques', 'Echevarría Rivero', 'D', '57 Camiño Real', 48600, 'Sintiques.Echevarria.Rivero@pookmail.com', '10/09/65', 79, 4);
INSERT INTO usuaris VALUES (1494, 'Enrico', 'Riojas Barrera', 'H', '8 Reyes Católicos', 11100, 'Enrico.Riojas.Barrera@pookmail.com', '11/01/44', 88, 9);
INSERT INTO usuaris VALUES (1495, 'Adalgiso', 'Lomeli Olivares', 'H', '89 Antonio Vázquez', 38470, 'Adalgiso.Lomeli.Olivares@dodgit.com', '08/01/49', 54, 10);
INSERT INTO usuaris VALUES (1496, 'Jocelyn', 'Arce Nevarez', 'D', '24 Paseo Junquera', 12499, 'Jocelyn.Arce.Nevarez@spambob.com', '01/01/52', 52, 2);
INSERT INTO usuaris VALUES (1497, 'Margaret', 'Avilés Domínguez', 'D', '27 Atamaria', 36660, 'Margaret.Aviles.Dominguez@trashymail.com', '30/04/71', 44, 11);
INSERT INTO usuaris VALUES (1498, 'Cloe', 'Almaraz Chávez', 'D', '86 C/ Cuesta del  Álamo', 29567, 'Cloe.Almaraz.Chavez@dodgit.com', '13/03/55', 5, NULL);
INSERT INTO usuaris VALUES (1499, 'Atilano', 'Garica Corrales', 'H', '42 Outid de Arriba', 43700, 'Atilano.Garica.Corrales@spambob.com', '01/11/75', NULL, 5);
INSERT INTO usuaris VALUES (1500, 'Hossana', 'Mateo Alemán', NULL, '99 Salzillo', 32625, 'Hossana.Mateo.Aleman@spambob.com', '08/05/84', 6, 7);
INSERT INTO usuaris VALUES (1501, 'Makenna', 'Valdez Henríquez', 'D', '22 Canónigo Valiño', 46400, 'Makenna.Valdez.Henriquez@pookmail.com', '25/05/42', 85, 12);
INSERT INTO usuaris VALUES (1502, 'Thais', 'Quesada Henríquez', 'D', '67 Avda. Alameda Sundheim', 22630, 'Thais.Quesada.Henriquez@pookmail.com', '17/12/83', 42, 6);
INSERT INTO usuaris VALUES (1503, 'Eurico', 'Caballero Covarrubias', 'H', '21 La Fontanilla', 14260, 'Eurico.Caballero.Covarrubias@pookmail.com', '28/11/51', 2, 3);
INSERT INTO usuaris VALUES (1504, 'Casiano', 'Villaseñor Carranza', 'H', '44 C/ Cañada del Rosal', 21620, 'Casiano.Villasenor.Carranza@trashymail.com', '05/10/77', 68, 11);
INSERT INTO usuaris VALUES (1505, 'Taciano', 'Valdivia Arreola', 'H', '96 Avda. Explanada Barnuevo', 35400, 'Taciano.Valdivia.Arreola@trashymail.com', '01/07/74', 99, 11);
INSERT INTO usuaris VALUES (1506, 'Cannan', 'Corrales Casillas', 'H', '84 Urzáiz', 44760, 'Cannan.Corrales.Casillas@mailinator.com', '10/10/44', 65, 4);
INSERT INTO usuaris VALUES (1507, 'Helida', 'Aguilera Ojeda', 'D', '63 Comandante Izarduy', 8780, 'Helida.Aguilera.Ojeda@mailinator.com', '26/01/61', 93, 3);
INSERT INTO usuaris VALUES (1508, 'Aarón', 'Ceja Carrasco', 'H', '74 Av. Santiago Lapuente', 50740, 'Aaron.Ceja.Carrasco@trashymail.com', '28/05/45', 72, 10);
INSERT INTO usuaris VALUES (1509, 'Tiziano', 'Alcalá Segura', 'H', '13 Pza. Fuensanta', 32455, 'Tiziano.Alcala.Segura@trashymail.com', '10/10/76', 1, 4);
INSERT INTO usuaris VALUES (1510, 'Egeo', 'Berrios Estévez', 'H', '73 Cartagena', 30500, 'Egeo.Berrios.Estevez@trashymail.com', '08/05/80', 80, 11);
INSERT INTO usuaris VALUES (1511, 'Niobe', 'Arroyo Sepúlveda', 'D', '29 Salzillo', 32557, 'Niobe.Arroyo.Sepulveda@pookmail.com', '12/08/57', 77, 5);
INSERT INTO usuaris VALUES (1512, 'Román', 'Argüello Malave', 'H', '6 Estrela', 39738, 'Roman.Arguello.Malave@spambob.com', '24/05/66', 98, 2);
INSERT INTO usuaris VALUES (1513, 'Obdulia', 'Cazares Pérez', 'D', '71 Visitación de la Encina', 37724, 'Obdulia.Cazares.Perez@mailinator.com', '30/06/65', 7, 2);
INSERT INTO usuaris VALUES (1514, 'Ileana', 'Llarnas Castaneda', 'D', '97 Plaza Colón', 26122, 'Ileana.Llarnas.Castaneda@dodgit.com', '19/03/60', 90, 4);
INSERT INTO usuaris VALUES (1515, 'Tirza', 'Meléndez Guzmán', NULL, '62 C/ Cuesta del  Álamo', 29492, 'Tirza.Melendez.Guzman@trashymail.com', '08/04/70', 69, 11);
INSERT INTO usuaris VALUES (1516, 'Dacil', 'Atencio Camarillo', 'D', '55 Ctra. Hornos', 26213, 'Dacil.Atencio.Camarillo@trashymail.com', '06/12/45', 40, 4);
INSERT INTO usuaris VALUES (1517, 'Ornella', 'Soto Lucero', 'D', '33 Plaza Colón', 25400, 'Ornella.Soto.Lucero@spambob.com', '09/08/41', 82, 7);
INSERT INTO usuaris VALUES (1518, 'Sabra', 'Guajardo Valladares', 'D', '52 Rio Segura', 31261, 'Sabra.Guajardo.Valladares@spambob.com', '07/02/65', 27, 7);
INSERT INTO usuaris VALUES (1519, 'Mia', 'Enríquez Ornelas', 'D', '40 Reiseñor', 46134, 'Mia.Enriquez.Ornelas@mailinator.com', '29/10/69', 99, 8);
INSERT INTO usuaris VALUES (1520, 'Micky', 'Tapia Aguayo', 'H', '82 Antonio Vázquez', 38715, 'Micky.Tapia.Aguayo@dodgit.com', '07/05/42', 85, 4);
INSERT INTO usuaris VALUES (1521, 'Huara', 'Cabán Escalante', 'D', '61 Reyes Católicos', 9250, 'Huara.Caban.Escalante@trashymail.com', '07/01/45', 87, 11);
INSERT INTO usuaris VALUES (1522, 'Virgil', 'Bonilla Rico', 'H', '92 Urzáiz', 44520, 'Virgil.Bonilla.Rico@trashymail.com', '04/05/56', 59, 10);
INSERT INTO usuaris VALUES (1523, 'Azanías', 'Tejada Anguiano', 'H', '93 Paseo del Atlántico', 17486, 'Azanias.Tejada.Anguiano@trashymail.com', '15/05/64', 73, 2);
INSERT INTO usuaris VALUES (1524, 'Olmo', 'Benítez Toledo', 'H', '31 Avda. Alameda Sundheim', 23110, 'Olmo.Benitez.Toledo@spambob.com', '18/03/82', 43, 3);
INSERT INTO usuaris VALUES (1525, 'Pericles', 'Tapia Delgadillo', 'H', '63 Avda. Enrique Peinador', 37183, 'Pericles.Tapia.Delgadillo@spambob.com', '20/02/82', 73, 6);
INSERT INTO usuaris VALUES (1526, 'Edda', 'Madrid Molina', 'D', '21 Calvo Sotelo', 47230, 'Edda.Madrid.Molina@pookmail.com', '02/08/47', 48, 3);
INSERT INTO usuaris VALUES (1527, 'Hada', 'Chapa Medina', 'D', '41 Calle Proc. San Sebastián', 12539, 'Hada.Chapa.Medina@mailinator.com', '29/10/79', 90, 10);
INSERT INTO usuaris VALUES (1528, 'Aleksandra', 'Díaz Santillán', NULL, '43 Castelao', 48891, 'Aleksandra.Diaz.Santillan@mailinator.com', '29/03/82', 49, 12);
INSERT INTO usuaris VALUES (1529, 'Ascla', 'Romo Montanez', 'D', '48 Rúa do Paseo', 41820, 'Ascla.Romo.Montanez@trashymail.com', '29/12/41', 53, 4);
INSERT INTO usuaris VALUES (1530, 'Lorenz', 'Prieto Sotelo', 'H', '8 Boriñaur enparantza', 7700, 'Lorenz.Prieto.Sotelo@dodgit.com', '19/08/80', 39, NULL);
INSERT INTO usuaris VALUES (1531, 'Roser', 'Benavides Bustamante', 'H', '2 Castelao', 48879, 'Roser.Benavides.Bustamante@spambob.com', '13/05/56', 50, 4);
INSERT INTO usuaris VALUES (1532, 'Pericles', 'Rael Ledesma', 'H', '75 Ourense', 43200, 'Pericles.Rael.Ledesma@mailinator.com', '26/02/82', 8, NULL);
INSERT INTO usuaris VALUES (1533, 'Gladys', 'Merino Hidalgo', 'D', '71 Herrería', 18192, 'Gladys.Merino.Hidalgo@pookmail.com', '18/03/70', 91, 1);
INSERT INTO usuaris VALUES (1534, 'Danilo', 'Yáñez Abreu', 'H', '66 C/ Henan Cortes', 29100, 'Danilo.Yanez.Abreu@spambob.com', '20/12/67', 23, 7);
INSERT INTO usuaris VALUES (1535, 'Mileva', 'Soliz Navarro', 'D', '90 Avendaño', 4240, 'Mileva.Soliz.Navarro@spambob.com', '05/02/55', 70, 6);
INSERT INTO usuaris VALUES (1536, 'Iberia', 'Muñiz Ballesteros', 'D', '48 C/ Arana', 2614, 'Iberia.Muniz.Ballesteros@pookmail.com', '05/01/50', 61, 4);
INSERT INTO usuaris VALUES (1537, 'Gregor', 'Valdés Mejía', 'H', '54 C/ Cuesta del  Álamo', 29494, 'Gregor.Valdes.Mejia@spambob.com', '07/01/50', 93, 11);
INSERT INTO usuaris VALUES (1538, 'Emeterio', 'Aparicio Hurtado', 'H', '61 Cercas Bajas', 7800, 'Emeterio.Aparicio.Hurtado@spambob.com', '14/12/63', 45, 8);
INSERT INTO usuaris VALUES (1539, 'Menna', 'Callas Mesa', 'D', '10 Bellavista', 49820, 'Menna.Callas.Mesa@trashymail.com', '28/05/40', 64, 10);
INSERT INTO usuaris VALUES (1540, 'Ludwiq', 'Rendón Duran', 'H', '3 C/ Henan Cortes', 28970, 'Ludwiq.Rendon.Duran@spambob.com', '14/02/49', 18, 10);
INSERT INTO usuaris VALUES (1541, 'Gisela', 'Ulibarri Lucio', 'D', '40 C/ Henan Cortes', 29108, 'Gisela.Ulibarri.Lucio@spambob.com', '30/12/56', 71, 4);
INSERT INTO usuaris VALUES (1542, 'Thina', 'Vega Lovato', 'D', '2 Ventanilla de Beas', 28140, 'Thina.Vega.Lovato@dodgit.com', '21/05/76', 24, 10);
INSERT INTO usuaris VALUES (1543, 'Pelayo', 'Pizarro Valverde', 'H', '1 Paseo del Atlántico', 17800, 'Pelayo.Pizarro.Valverde@dodgit.com', '07/12/84', 67, 3);
INSERT INTO usuaris VALUES (1544, 'Serafina', 'Haro Anguiano', 'D', '12 Avda. Enrique Peinador', 37180, 'Serafina.Haro.Anguiano@dodgit.com', '24/08/66', 58, NULL);
INSERT INTO usuaris VALUES (1545, 'Tulla', 'Coronado Griego', 'D', '28 C/ Hijuela de Lojo', 20492, 'Tulla.Coronado.Griego@dodgit.com', '19/05/56', 63, 7);
INSERT INTO usuaris VALUES (1546, 'Eufemia', 'Valverde Ruiz', 'D', '37 Rúa Olmos', 37317, 'Eufemia.Valverde.Ruiz@mailinator.com', '29/01/72', 99, 9);
INSERT INTO usuaris VALUES (1547, 'Ursy', 'Zamudio Rivas', 'D', '72 Avda. Generalísimo', 32000, 'Ursy.Zamudio.Rivas@mailinator.com', '18/03/76', 29, 12);
INSERT INTO usuaris VALUES (1548, 'Dositeo', 'Salgado Colón', 'H', '66 Carretera Cádiz-Málaga', 20870, 'Dositeo.Salgado.Colon@trashymail.com', '27/09/58', 16, 8);
INSERT INTO usuaris VALUES (1549, 'Verenice', 'Mondragón Echevarría', 'D', '34 Ctra. Beas-Cortijos Nuevos', 26559, 'Verenice.Mondragon.Echevarria@dodgit.com', '11/05/50', 24, 3);
INSERT INTO usuaris VALUES (1550, 'Nadine', 'Pagan Guevara', 'D', '11 Paseo Junquera', 12500, 'Nadine.Pagan.Guevara@mailinator.com', '31/12/59', 19, 3);
INSERT INTO usuaris VALUES (1551, 'Rebecca', 'Nava Grijalva', 'D', '94 Plazuela do Porto', 38200, 'Rebecca.Nava.Grijalva@spambob.com', '30/06/60', 30, 1);
INSERT INTO usuaris VALUES (1552, 'Desdémona', 'Hinojosa Muro', 'D', '65 Camiño Real', 48508, 'Desdemona.Hinojosa.Muro@trashymail.com', '12/10/74', 61, 5);
INSERT INTO usuaris VALUES (1553, 'Bibiana', 'Becerra Domínquez', 'D', '74 Constitución', 37139, 'Bibiana.Becerra.Dominquez@pookmail.com', NULL, 36, 7);
INSERT INTO usuaris VALUES (1554, 'Danilo', 'Alonso Robledo', 'H', '92 C/ Señores Curas', 12125, 'Danilo.Alonso.Robledo@spambob.com', '31/07/77', 20, 3);
INSERT INTO usuaris VALUES (1555, 'Odilón', 'Solórzano Salas', 'H', '4 Alcon Molina', 30859, 'Odilon.Solorzano.Salas@mailinator.com', '16/06/64', 61, 6);
INSERT INTO usuaris VALUES (1556, 'Quintilian', 'Blanco Duarte', 'H', '61 C/ Angosto', 23530, 'Quintilian.Blanco.Duarte@trashymail.com', '22/04/48', 42, 6);
INSERT INTO usuaris VALUES (1557, 'Amadeo', 'Acuna Reynoso', 'H', '98 C/ Libertad', 4890, 'Amadeo.Acuna.Reynoso@mailinator.com', '19/07/43', 20, 6);
INSERT INTO usuaris VALUES (1558, 'Heraclea', 'Menchaca Medrano', 'D', '60 Padre Caro', 14100, 'Heraclea.Menchaca.Medrano@pookmail.com', '05/05/65', 84, 6);
INSERT INTO usuaris VALUES (1559, 'Dionisio', 'Villaseñor Soliz', 'H', '78 Plaza Colón', 26110, 'Dionisio.Villasenor.Soliz@mailinator.com', '24/09/61', 28, 2);
INSERT INTO usuaris VALUES (1560, 'Danika', 'Villanueva Reyes', 'D', '79 Puerto Lugar', 29710, 'Danika.Villanueva.Reyes@spambob.com', '29/11/62', 71, 10);
INSERT INTO usuaris VALUES (1561, 'Aciscio', 'Carrasquill Rangel', 'H', '4 Puerto Lugar', 29700, 'Aciscio.Carrasquill.Rangel@pookmail.com', '15/01/45', 49, 8);
INSERT INTO usuaris VALUES (1562, 'Ademaro', 'Argüello Echevarría', 'H', '84 Paseo Junquera', 12428, 'Ademaro.Arguello.Echevarria@dodgit.com', '17/05/68', 99, 2);
INSERT INTO usuaris VALUES (1563, 'Nofre', 'Melgar Velázquez', 'H', '13 Plazuela do Porto', 38420, 'Nofre.Melgar.Velazquez@mailinator.com', '04/08/80', 21, 5);
INSERT INTO usuaris VALUES (1564, 'Anibal', 'Alba Pérez', 'H', '70 Castelao', 48980, 'Anibal.Alba.Perez@dodgit.com', '14/12/52', 6, 3);
INSERT INTO usuaris VALUES (1565, 'Daryl', 'Flórez Becerra', 'H', '26 Reiseñor', 45800, 'Daryl.Florez.Becerra@spambob.com', '25/11/46', 30, 11);
INSERT INTO usuaris VALUES (1566, 'Ambrosia', 'Elizondo Valverde', 'D', '82 C/ Canarias', 20200, 'Ambrosia.Elizondo.Valverde@spambob.com', '14/02/44', 55, 6);
INSERT INTO usuaris VALUES (1567, 'Adelmaro', 'Vallejo Ordóñez', 'H', '65 Urzáiz', 44530, 'Adelmaro.Vallejo.Ordonez@pookmail.com', '13/05/75', 5, 1);
INSERT INTO usuaris VALUES (1568, 'Milca', 'Cordova Mena', 'D', '50 Urzáiz', 45100, 'Milca.Cordova.Mena@dodgit.com', '24/08/78', 53, 10);
INSERT INTO usuaris VALUES (1569, 'Claro', 'Rangel Figueroa', 'H', '66 Antonio Vázquez', 38550, 'Claro.Rangel.Figueroa@dodgit.com', '07/01/52', 45, NULL);
INSERT INTO usuaris VALUES (1570, 'Covadonga', 'Betancourt Candelaria', 'D', '51 Caño', 32780, 'Covadonga.Betancourt.Candelaria@trashymail.com', '29/12/77', 57, NULL);
INSERT INTO usuaris VALUES (1571, 'Atala', 'Salcedo Ulloa', 'D', '62 Outid de Arriba', 43500, 'Atala.Salcedo.Ulloa@trashymail.com', '11/08/70', 85, 2);
INSERT INTO usuaris VALUES (1572, 'Flavio', 'Casas Comejo', 'H', '32 C/ Cañada del Rosal', 21410, 'Flavio.Casas.Comejo@dodgit.com', '05/11/73', 74, 6);
INSERT INTO usuaris VALUES (1573, 'Domitila', 'Burgos Valverde', 'D', '83 Avendaño', 3817, 'Domitila.Burgos.Valverde@trashymail.com', '14/02/81', 39, 5);
INSERT INTO usuaris VALUES (1574, 'Blas', 'Vanegas Feliciano', 'H', '55 Cruce Casa de Postas', 18339, 'Blas.Vanegas.Feliciano@dodgit.com', '17/12/71', 80, NULL);
INSERT INTO usuaris VALUES (1575, 'Haydee', 'Zarate Sanabria', 'D', '21 C/ Fernández de Leceta', 3350, 'Haydee.Zarate.Sanabria@trashymail.com', '28/08/54', 68, 12);
INSERT INTO usuaris VALUES (1576, 'Grato', 'Sisneros Gurule', 'H', '39 Ctra. de la Puerta', 26587, 'Grato.Sisneros.Gurule@trashymail.com', '17/01/41', 72, 4);
INSERT INTO usuaris VALUES (1577, 'Egidia', 'Gracia Valdivia', 'D', '61 Paseo Junquera', 12447, 'Egidia.Gracia.Valdivia@trashymail.com', '19/12/75', 67, 1);
INSERT INTO usuaris VALUES (1578, 'Jessie', 'Olivas Valladares', 'D', '71 Padre Caro', 13600, 'Jessie.Olivas.Valladares@trashymail.com', '10/12/73', 29, NULL);
INSERT INTO usuaris VALUES (1579, 'Lilian', 'Rivas Barrera', 'D', '72 Constitución', 37100, 'Lilian.Rivas.Barrera@mailinator.com', '08/07/59', 16, 7);
INSERT INTO usuaris VALUES (1580, 'Mahoma', 'Tijerina Leyva', 'H', '7 Rúa Olmos', 37329, 'Mahoma.Tijerina.Leyva@dodgit.com', '07/11/82', 18, 4);
INSERT INTO usuaris VALUES (1581, 'Benet', 'Solorio Menéndez', 'H', '47 Constitución', 37000, 'Benet.Solorio.Menendez@mailinator.com', '25/08/45', 81, 5);
INSERT INTO usuaris VALUES (1582, 'Nela', 'Armijo Barraza', 'D', '18 Eusebio Dávila', 41530, 'Nela.Armijo.Barraza@pookmail.com', '31/07/61', 18, NULL);
INSERT INTO usuaris VALUES (1583, 'Israela', 'Peres Beltrán', NULL, '4 San Andrés', 37259, 'Israela.Peres.Beltran@mailinator.com', '28/04/78', 37, 7);
INSERT INTO usuaris VALUES (1584, 'Malcom', 'Atencio Fuentes', 'H', '36 Prolongacion San Sebastian', 21230, 'Malcom.Atencio.Fuentes@mailinator.com', '26/09/84', 68, 5);
INSERT INTO usuaris VALUES (1585, 'Eri', 'Rendón Cruz', 'H', '38 Avda. de Andalucía', 29328, 'Eri.Rendon.Cruz@trashymail.com', '29/10/74', 98, 6);
INSERT INTO usuaris VALUES (1586, 'Inmaculada', 'Beltrán Duran', NULL, '91 Cercas Bajas', 8240, 'Inmaculada.Beltran.Duran@spambob.com', '17/04/57', 27, 5);
INSERT INTO usuaris VALUES (1587, 'Corrado', 'Luevano Valdés', 'H', '92 Celso Emilio Ferreiro', 50500, 'Corrado.Luevano.Valdes@dodgit.com', '31/10/58', 19, 5);
INSERT INTO usuaris VALUES (1588, 'Emeterio', 'Rascón Otero', 'H', '64 Camiño Ancho', 37789, 'Emeterio.Rascon.Otero@trashymail.com', '10/10/56', 12, 8);
INSERT INTO usuaris VALUES (1589, 'Nuriya', 'Valladares Quintana', 'D', '1 Plaza de España', 15578, 'Nuriya.Valladares.Quintana@spambob.com', '28/07/50', 54, 11);
INSERT INTO usuaris VALUES (1590, 'Abaco', 'Guerra Reyes', 'H', '44 Calle Carril de la Fuente', 13193, 'Abaco.Guerra.Reyes@dodgit.com', '14/11/52', 5, 10);
INSERT INTO usuaris VALUES (1591, 'Sagar', 'Franco Santana', 'H', '40 C/ Angosto', 23460, 'Sagar.Franco.Santana@pookmail.com', '17/04/68', 40, 2);
INSERT INTO usuaris VALUES (1592, 'Juancruz', 'Rolón Osorio', 'H', '81 Outid de Arriba', 43460, 'Juancruz.Rolon.Osorio@dodgit.com', '19/05/79', 19, 9);
INSERT INTO usuaris VALUES (1593, 'Edelmiro', 'Rosario Armijo', 'H', '10 Avda. Los llanos', 26311, 'Edelmiro.Rosario.Armijo@dodgit.com', '16/10/73', 58, 9);
INSERT INTO usuaris VALUES (1594, 'Segundino', 'Aguilar Bustos', 'H', '30 Carretera del Muelle', 12312, 'Segundino.Aguilar.Bustos@dodgit.com', '28/05/75', 83, 9);
INSERT INTO usuaris VALUES (1595, 'Heli', 'Carrillo Hinojosa', 'D', '82 Inglaterra', 18656, 'Heli.Carrillo.Hinojosa@spambob.com', '11/02/45', 58, 11);
INSERT INTO usuaris VALUES (1596, 'Adina', 'Maestas Mondragón', NULL, '44 Paseo Junquera', 12430, 'Adina.Maestas.Mondragon@mailinator.com', '09/09/76', 11, 12);
INSERT INTO usuaris VALUES (1597, 'Ahinoa', 'Esparza Partida', 'D', '44 Avda. Alameda Sundheim', 23000, 'Ahinoa.Esparza.Partida@trashymail.com', '02/01/44', 24, NULL);
INSERT INTO usuaris VALUES (1598, 'Iago', 'Molina Robledo', 'H', '32 Reyes Católicos', 10500, 'Iago.Molina.Robledo@mailinator.com', '24/08/75', 2, 11);
INSERT INTO usuaris VALUES (1599, 'Taciano', 'Padrón Maya', 'H', '5 Plaza Colón', 26123, 'Taciano.Padron.Maya@mailinator.com', '09/01/58', 69, 3);
INSERT INTO usuaris VALUES (1600, 'Natal', 'Borrego Peralta', 'H', '83 C/ Henan Cortes', 28900, 'Natal.Borrego.Peralta@spambob.com', '02/04/69', 32, 3);
INSERT INTO usuaris VALUES (1601, 'Ena', 'Nieves Becerra', 'D', '77 Avda. de Andalucía', 29328, 'Ena.Nieves.Becerra@mailinator.com', '10/03/57', 27, 10);
INSERT INTO usuaris VALUES (1602, 'Dennis', 'Velasco Zelaya', 'H', '54 Ctra. de Fuentenueva', 28293, 'Dennis.Velasco.Zelaya@dodgit.com', '01/06/57', 99, 12);
INSERT INTO usuaris VALUES (1603, 'Turquesa', 'Terrazas Benavidez', 'D', '61 Ctra. Bailén-Motril', 23260, 'Turquesa.Terrazas.Benavidez@trashymail.com', '23/01/80', 54, 7);
INSERT INTO usuaris VALUES (1604, 'Mar', 'Menéndez Montalvo', 'D', '55 Av. Zumalakarregi', 3169, 'Mar.Menendez.Montalvo@pookmail.com', '02/01/57', 16, 2);
INSERT INTO usuaris VALUES (1605, 'Theo', 'Mireles Medina', 'H', '55 C/ Los Herrán', 6480, 'Theo.Mireles.Medina@spambob.com', '11/01/45', 59, 1);
INSERT INTO usuaris VALUES (1606, 'Marón', 'Raya Barrera', 'H', '98 Reiseñor', 45593, 'Maron.Raya.Barrera@spambob.com', '11/08/69', 43, 3);
INSERT INTO usuaris VALUES (1607, 'Styalianos', 'Segura Rivera', 'H', '91 C/ Los Herrán', 6200, 'Styalianos.Segura.Rivera@pookmail.com', '08/04/67', 96, 11);
INSERT INTO usuaris VALUES (1608, 'Maia', 'Caraballo Mireles', 'D', '79 C/ Andalucía', 4830, 'Maia.Caraballo.Mireles@mailinator.com', '04/01/79', 52, NULL);
INSERT INTO usuaris VALUES (1609, 'Calixta', 'Juárez Alejandro', 'D', '92 Herrería', 18220, 'Calixta.Juarez.Alejandro@spambob.com', '20/03/60', 67, 6);
INSERT INTO usuaris VALUES (1610, 'Fabienne', 'Guevara Macías', 'D', '36 Plaza de España', 15840, 'Fabienne.Guevara.Macias@spambob.com', '08/03/42', 65, 6);
INSERT INTO usuaris VALUES (1611, 'Edelmar', 'Delgadillo Holguín', 'H', '86 Alvaro Cunqueiro', 41210, 'Edelmar.Delgadillo.Holguin@mailinator.com', '17/10/41', 56, 6);
INSERT INTO usuaris VALUES (1612, 'Maribel', 'Bañuelos Soliz', 'D', '90 Celso Emilio Ferreiro', 50650, 'Maribel.Banuelos.Soliz@trashymail.com', '06/02/78', 32, 8);
INSERT INTO usuaris VALUES (1613, 'Maha', 'Perea Armendáriz', 'D', '9 Avda. Rio Nalon', 33430, 'Maha.Perea.Armendariz@pookmail.com', '28/09/79', 4, 11);
INSERT INTO usuaris VALUES (1614, 'Rolán', 'Coronado Mascarenas', 'H', '21 Bouciña', 43890, 'Rolan.Coronado.Mascarenas@mailinator.com', '04/12/82', 8, 2);
INSERT INTO usuaris VALUES (1615, 'Nera', 'Maldonado Mercado', 'H', '7 Atamaria', 36645, 'Nera.Maldonado.Mercado@spambob.com', '19/09/84', 33, 11);
INSERT INTO usuaris VALUES (1616, 'Marlon', 'Menéndez Henríquez', 'H', '49 Cruce Casa de Postas', 18413, 'Marlon.Menendez.Henriquez@mailinator.com', '08/09/64', 45, 7);
INSERT INTO usuaris VALUES (1617, 'Adena', 'Guerrero Montoya', 'D', '55 Alcon Molina', 31160, 'Adena.Guerrero.Montoya@pookmail.com', '22/08/70', 71, 3);
INSERT INTO usuaris VALUES (1618, 'Pánfilo', 'Palacios Arroyo', 'H', '7 Reyes Católicos', 9500, 'Panfilo.Palacios.Arroyo@spambob.com', '23/11/70', 43, 11);
INSERT INTO usuaris VALUES (1619, 'Privato', 'Tirado Vasquez', 'H', '14 Visitación de la Encina', 37718, 'Privato.Tirado.Vasquez@dodgit.com', NULL, 30, 11);
INSERT INTO usuaris VALUES (1620, 'Pascua', 'Meléndez Henríquez', 'D', '50 C/ Henan Cortes', 28970, 'Pascua.Melendez.Henriquez@pookmail.com', '06/09/50', 42, 11);
INSERT INTO usuaris VALUES (1621, 'Melusina', 'Badillo Camacho', 'D', '1 Celso Emilio Ferreiro', 50461, 'Melusina.Badillo.Camacho@mailinator.com', '07/05/80', 69, 9);
INSERT INTO usuaris VALUES (1622, 'Cameron', 'Rojo Cabán', 'H', '19 Ctra. Hornos', 26215, 'Cameron.Rojo.Caban@trashymail.com', '17/11/78', 76, 12);
INSERT INTO usuaris VALUES (1623, 'Raymi', 'Cabán Vergara', 'H', '91 Visitación de la Encina', 37750, 'Raymi.Caban.Vergara@mailinator.com', '13/01/47', 54, 10);
INSERT INTO usuaris VALUES (1624, 'Melibea', 'Acuna Mireles', 'D', '29 C/ Eras', 28737, 'Melibea.Acuna.Mireles@spambob.com', '19/02/84', 45, 5);
INSERT INTO usuaris VALUES (1625, 'Didier', 'Blanco Carrillo', 'H', '16 C/ Los Herrán', 6400, 'Didier.Blanco.Carrillo@pookmail.com', '02/06/40', 57, 7);
INSERT INTO usuaris VALUES (1626, 'Antoinette', 'Crespo Muñoz', 'D', '74 Avenida Cervantes', 48250, 'Antoinette.Crespo.Munoz@pookmail.com', '09/01/75', 79, 10);
INSERT INTO usuaris VALUES (1627, 'Libio', 'Valadez Rivera', 'H', '71 Cádiz', 18518, 'Libio.Valadez.Rivera@spambob.com', '08/05/83', 34, 12);
INSERT INTO usuaris VALUES (1628, 'Enos', 'Jaime Tovar', NULL, '80 Estrela', 39694, 'Enos.Jaime.Tovar@pookmail.com', '18/05/52', 37, 5);
INSERT INTO usuaris VALUES (1629, 'Hassan', 'Ozuna Suárez', 'H', '62 Quevedo', 15317, 'Hassan.Ozuna.Suarez@trashymail.com', '19/04/62', 83, 1);
INSERT INTO usuaris VALUES (1630, 'Erminia', 'Armas Ayala', 'D', '29 Calle Carril de la Fuente', 13195, 'Erminia.Armas.Ayala@pookmail.com', '17/06/75', 19, 7);
INSERT INTO usuaris VALUES (1631, 'Augustin', 'Garica Frías', 'H', '60 C/ Hijuela de Lojo', 20267, 'Augustin.Garica.Frias@trashymail.com', '02/05/44', 98, 4);
INSERT INTO usuaris VALUES (1632, 'Amantzi', 'Sánchez Valladares', 'H', '23 C/ Pablo Iglesias', 26325, 'Amantzi.Sanchez.Valladares@dodgit.com', '17/09/66', 29, NULL);
INSERT INTO usuaris VALUES (1633, 'Eulogia', 'Galvez Candelaria', 'D', '20 Avda. de la Estación', 28670, 'Eulogia.Galvez.Candelaria@spambob.com', '25/04/49', 12, 8);
INSERT INTO usuaris VALUES (1634, 'Fructuoso', 'Fajardo Preciado', 'H', '65 Outid de Arriba', 43740, 'Fructuoso.Fajardo.Preciado@mailinator.com', '01/07/75', 35, 1);
INSERT INTO usuaris VALUES (1635, 'Bernardina', 'Cerda Marrero', 'D', '21 C/ Pablo Iglesias', 26340, 'Bernardina.Cerda.Marrero@pookmail.com', '26/07/83', 25, 7);
INSERT INTO usuaris VALUES (1636, 'Mar', 'Castaneda Villareal', 'D', '27 Reyes Católicos', 10900, 'Mar.Castaneda.Villareal@dodgit.com', '20/02/48', 97, 3);
INSERT INTO usuaris VALUES (1637, 'Ida', 'Rojo Duran', NULL, '64 C/ Hijuela de Lojo', 20494, 'Ida.Rojo.Duran@pookmail.com', '07/08/49', 34, 12);
INSERT INTO usuaris VALUES (1638, 'Prisca', 'Chapa Salcido', 'D', '36 Ctra. de la Puerta', 27120, 'Prisca.Chapa.Salcido@pookmail.com', '14/04/77', 39, 1);
INSERT INTO usuaris VALUES (1639, 'Maureen', 'Ozuna Quezada', 'D', '35 Plaza de España', 15619, 'Maureen.Ozuna.Quezada@mailinator.com', '02/05/69', 9, 4);
INSERT INTO usuaris VALUES (1640, 'Michael', 'Correa Arreola', 'H', '80 Ctra. Villena', 33826, 'Michael.Correa.Arreola@pookmail.com', '03/09/64', 0, 3);
INSERT INTO usuaris VALUES (1641, 'Osmundo', 'Bravo Arredondo', 'H', '43 Ctra. Beas-Cortijos Nuevos', 26500, 'Osmundo.Bravo.Arredondo@mailinator.com', '27/10/69', 12, NULL);
INSERT INTO usuaris VALUES (1642, 'Edén', 'Soria Ybarra', 'D', '10 Zumalakarregi etorbidea', 7190, 'Eden.Soria.Ybarra@dodgit.com', '28/12/41', 74, 8);
INSERT INTO usuaris VALUES (1643, 'Flavia', 'Monroy Vallejo', 'D', '25 Alvaro Cunqueiro', 40480, 'Flavia.Monroy.Vallejo@mailinator.com', '02/09/56', 49, 3);
INSERT INTO usuaris VALUES (1644, 'Aglae', 'Saldana Vigil', 'H', '69 Ctra. de la Puerta', 27250, 'Aglae.Saldana.Vigil@mailinator.com', '10/06/68', 6, 12);
INSERT INTO usuaris VALUES (1645, 'Dibe', 'Baca Villareal', 'D', '53 Atamaria', 36841, 'Dibe.Baca.Villareal@spambob.com', '10/08/66', 51, 11);
INSERT INTO usuaris VALUES (1646, 'Astolfo', 'Balderas Santana', 'H', '18 C/ Domingo Beltrán', 2270, 'Astolfo.Balderas.Santana@mailinator.com', '26/04/76', 92, 1);
INSERT INTO usuaris VALUES (1647, 'Epicuro', 'Ulloa Estévez', 'H', '66 Visitación de la Encina', 37755, 'Epicuro.Ulloa.Estevez@dodgit.com', '26/09/78', 7, 8);
INSERT INTO usuaris VALUES (1648, 'Roque', 'Serna Muñiz', 'H', '86 Rúa do Paseo', 41830, 'Roque.Serna.Muniz@dodgit.com', NULL, 66, 1);
INSERT INTO usuaris VALUES (1649, 'Montserrat', 'Lara Hurtado', 'H', '93 Lamas Carbajal', 41700, 'Montserrat.Lara.Hurtado@spambob.com', '24/05/45', 58, 8);
INSERT INTO usuaris VALUES (1650, 'Basileo', 'Guardado Valdivia', 'H', '51 Ctra. de Fuentenueva', 28320, 'Basileo.Guardado.Valdivia@dodgit.com', '10/04/73', 27, 8);
INSERT INTO usuaris VALUES (1651, 'Trinity', 'Gamez Hurtado', 'D', '68 Rúa Olmos', 37317, 'Trinity.Gamez.Hurtado@spambob.com', '07/08/41', 32, NULL);
INSERT INTO usuaris VALUES (1652, 'Gigí', 'Olivárez Ordóñez', 'D', '69 Alvaro Cunqueiro', 41110, 'Gigi.Olivarez.Ordonez@mailinator.com', NULL, 57, 12);
INSERT INTO usuaris VALUES (1653, 'Abelard', 'González Valverde', 'H', '2 San Andrés', 37312, 'Abelard.Gonzalez.Valverde@pookmail.com', '26/06/67', 38, 11);
INSERT INTO usuaris VALUES (1654, 'Jules', 'Gaytan Valles', 'H', '59 Enxertos', 37541, 'Jules.Gaytan.Valles@mailinator.com', '15/03/60', 23, 12);
INSERT INTO usuaris VALUES (1655, 'Cuyén', 'Mejía Patino', 'H', '88 Carretera del Muelle', 12300, 'Cuyen.Mejia.Patino@trashymail.com', '16/07/43', 24, 1);
INSERT INTO usuaris VALUES (1656, 'Avelina', 'Quiroz Ocampo', 'D', '58 Valadouro', 48191, 'Avelina.Quiroz.Ocampo@spambob.com', '02/12/66', 39, 4);
INSERT INTO usuaris VALUES (1657, 'Clarissa', 'Tamez Velázquez', 'D', '96 Bouciña', 43784, 'Clarissa.Tamez.Velazquez@spambob.com', '09/12/51', 95, 6);
INSERT INTO usuaris VALUES (1658, 'Leni', 'Vergara Cuellar', NULL, '27 Canónigo Valiño', 46250, 'Leni.Vergara.Cuellar@mailinator.com', '16/11/48', 18, NULL);
INSERT INTO usuaris VALUES (1659, 'Elía', 'Cintrón Berrios', 'H', '42 Prolongacion San Sebastian', 21350, 'Elia.Cintron.Berrios@dodgit.com', '27/06/42', 5, 10);
INSERT INTO usuaris VALUES (1660, 'Barbie', 'Nieto Espino', 'D', '56 Plaza de España', 15700, 'Barbie.Nieto.Espino@trashymail.com', '28/01/79', 23, NULL);
INSERT INTO usuaris VALUES (1661, 'Zenadia', 'Rosas Venegas', 'D', '82 Herrería', 18170, 'Zenadia.Rosas.Venegas@dodgit.com', '26/06/44', 11, 10);
INSERT INTO usuaris VALUES (1662, 'Shasa', 'Rodrígez Roybal', 'D', '72 C/ Cañada del Rosal', 21595, 'Shasa.Rodrigez.Roybal@spambob.com', '25/04/83', 8, 3);
INSERT INTO usuaris VALUES (1663, 'Pamela', 'Cedillo Roldán', NULL, '23 C/ Arana', 2440, 'Pamela.Cedillo.Roldan@pookmail.com', '20/01/70', 45, 8);
INSERT INTO usuaris VALUES (1664, 'Beat', 'Sotelo Corrales', 'H', '32 C/ Fernández de Leceta', 3517, 'Beat.Sotelo.Corrales@spambob.com', '11/12/40', 30, 11);
INSERT INTO usuaris VALUES (1665, 'Mitra', 'Prado Rivero', 'D', '74 Socampo', 37650, 'Mitra.Prado.Rivero@trashymail.com', '28/10/55', 24, NULL);
INSERT INTO usuaris VALUES (1666, 'Tecla', 'Burgos Flórez', 'D', '45 Paseo del Atlántico', 18132, 'Tecla.Burgos.Florez@dodgit.com', '19/07/61', 75, 5);
INSERT INTO usuaris VALUES (1667, 'Lena', 'Chavarría Rentería', 'D', '88 Canónigo Valiño', 46460, 'Lena.Chavarria.Renteria@mailinator.com', '04/09/67', 22, 4);
INSERT INTO usuaris VALUES (1668, 'Karin', 'Ojeda Dávila', 'D', '50 Avendaño', 4410, 'Karin.Ojeda.Davila@trashymail.com', '25/07/55', 84, 9);
INSERT INTO usuaris VALUES (1669, 'Iona', 'Magana Márquez', 'D', '5 Av. Santiago Lapuente', 50750, 'Iona.Magana.Marquez@dodgit.com', '10/02/81', 50, NULL);
INSERT INTO usuaris VALUES (1670, 'Abo', 'Treviño Gaitán', 'H', '58 La Fontanilla', 14140, 'Abo.Trevino.Gaitan@trashymail.com', '28/11/40', 95, 10);
INSERT INTO usuaris VALUES (1671, 'Fabricio', 'Fonseca Valles', 'H', '93 Puerto Lugar', 29738, 'Fabricio.Fonseca.Valles@dodgit.com', '29/05/69', 23, 5);
INSERT INTO usuaris VALUES (1672, 'Jessenia', 'Díaz Muñoz', 'D', '10 Pascual Yunquera', 18817, 'Jessenia.Diaz.Munoz@pookmail.com', '24/11/60', 62, 1);
INSERT INTO usuaris VALUES (1673, 'Duilio', 'Rascón Sauceda', 'H', '37 Rúa Olmos', 37329, 'Duilio.Rascon.Sauceda@pookmail.com', '16/10/71', 91, 9);
INSERT INTO usuaris VALUES (1674, 'Osmán', 'Partida Rascón', 'H', '25 Rúa Olmos', 37329, 'Osman.Partida.Rascon@dodgit.com', '07/05/49', 14, 9);
INSERT INTO usuaris VALUES (1675, 'Alba', 'Castaneda Espinoza', 'D', '47 Reiseñor', 46133, 'Alba.Castaneda.Espinoza@trashymail.com', '10/02/82', 76, 8);
INSERT INTO usuaris VALUES (1676, 'Isadora', 'Molina Orosco', 'D', '82 Plaza Maior', 37217, 'Isadora.Molina.Orosco@mailinator.com', '06/04/45', 18, 3);
INSERT INTO usuaris VALUES (1677, 'Massimo', 'Tejeda Arreola', 'H', '85 Extramuros', 28470, 'Massimo.Tejeda.Arreola@pookmail.com', '09/09/81', 94, 11);
INSERT INTO usuaris VALUES (1678, 'Cleto', 'Quiñones Perea', 'H', '61 C/ Andalucía', 4810, 'Cleto.Quinones.Perea@dodgit.com', '28/09/64', 25, 11);
INSERT INTO usuaris VALUES (1679, 'Barbelo', 'Ramón Peralta', 'H', '97 C/ Benito Guinea', 8350, 'Barbelo.Ramon.Peralta@mailinator.com', '13/09/58', 93, 4);
INSERT INTO usuaris VALUES (1680, 'Matteo', 'Alvarado Ledesma', 'H', '5 Alvaro Cunqueiro', 40470, 'Matteo.Alvarado.Ledesma@spambob.com', '19/07/85', NULL, 10);
INSERT INTO usuaris VALUES (1681, 'Percival', 'Urrútia Villalpando', 'H', '90 Puerto Lugar', 30140, 'Percival.Urrutia.Villalpando@trashymail.com', '09/09/73', 80, 11);
INSERT INTO usuaris VALUES (1682, 'Randall', 'Balderas Alfaro', 'H', '37 Reyes Católicos', 10300, 'Randall.Balderas.Alfaro@dodgit.com', '19/03/83', 20, 2);
INSERT INTO usuaris VALUES (1683, 'Cleo', 'Nieves Nieto', 'D', '46 Urzáiz', 44380, 'Cleo.Nieves.Nieto@trashymail.com', '29/06/83', 1, 7);
INSERT INTO usuaris VALUES (1684, 'Aggie', 'Ledesma Raya', 'D', '53 Ctra. Villena', 33829, 'Aggie.Ledesma.Raya@spambob.com', '12/08/73', 6, 10);
INSERT INTO usuaris VALUES (1685, 'Fulxencio', 'Galarza Maestas', 'H', '38 Comandante Izarduy', 8770, 'Fulxencio.Galarza.Maestas@trashymail.com', '30/10/58', 3, 12);
INSERT INTO usuaris VALUES (1686, 'Malcon', 'Villareal Orta', 'H', '15 Apartado de Correos', 37427, 'Malcon.Villareal.Orta@pookmail.com', '24/01/53', 90, 12);
INSERT INTO usuaris VALUES (1687, 'Zoilo', 'Arteaga Almaraz', 'H', '88 Cercas Bajas', 8240, 'Zoilo.Arteaga.Almaraz@dodgit.com', '19/03/78', 1, 3);
INSERT INTO usuaris VALUES (1688, 'Malisa', 'Ocasio Yáñez', 'D', '59 Zumalakarregi etorbidea', 7140, 'Malisa.Ocasio.Yanez@dodgit.com', '01/10/42', 93, 7);
INSERT INTO usuaris VALUES (1689, 'Adelaide', 'Soria Madrid', 'D', '4 Valadouro', 48160, 'Adelaide.Soria.Madrid@spambob.com', '03/07/51', 31, 3);
INSERT INTO usuaris VALUES (1690, 'Basileo', 'Arreola Galarza', 'H', '19 C/ Cuesta del  Álamo', 29492, 'Basileo.Arreola.Galarza@spambob.com', '30/08/80', 67, 9);
INSERT INTO usuaris VALUES (1691, 'Melvin', 'Valenzuela Espinoza', 'D', '97 C/ Domingo Beltrán', 2270, 'Melvin.Valenzuela.Espinoza@trashymail.com', '26/07/85', 75, 4);
INSERT INTO usuaris VALUES (1692, 'Delta', 'Arreola Gil', 'D', '87 Canónigo Valiño', 46470, 'Delta.Arreola.Gil@mailinator.com', '14/12/47', 15, 3);
INSERT INTO usuaris VALUES (1693, 'Blanca', 'Reynoso Miramontes', 'D', '41 Avda. Explanada Barnuevo', 35290, 'Blanca.Reynoso.Miramontes@mailinator.com', '18/11/75', 95, 11);
INSERT INTO usuaris VALUES (1694, 'Kalil', 'Pena Leyva', 'H', '53 San Andrés', 37257, 'Kalil.Pena.Leyva@trashymail.com', '05/01/48', 28, 1);
INSERT INTO usuaris VALUES (1695, 'Ibrahim', 'Velasco Rocha', 'H', '65 Eusebio Dávila', 41550, 'Ibrahim.Velasco.Rocha@pookmail.com', '24/07/84', 5, 9);
INSERT INTO usuaris VALUES (1696, 'Milburga', 'Roybal Barrientos', 'D', '47 Cartagena', 30520, 'Milburga.Roybal.Barrientos@spambob.com', '24/04/53', 49, NULL);
INSERT INTO usuaris VALUES (1697, 'Fredeswinda', 'Altamirano Nazario', 'D', '95 Zumalakarregi etorbidea', 7315, 'Fredeswinda.Altamirano.Nazario@trashymail.com', '28/12/78', 22, 12);
INSERT INTO usuaris VALUES (1698, 'Semarias', 'Batista Pulido', 'H', '93 Calle Carril de la Fuente', 13300, 'Semarias.Batista.Pulido@spambob.com', '25/06/48', 77, 1);
INSERT INTO usuaris VALUES (1699, 'Gracián', 'Laboy Montano', 'H', '56 Cartagena', 30190, 'Gracian.Laboy.Montano@dodgit.com', '22/05/42', 90, 1);
INSERT INTO usuaris VALUES (1700, 'Matilde', 'Candelaria Armenta', 'D', '70 Salzillo', 32616, 'Matilde.Candelaria.Armenta@mailinator.com', '07/07/66', 14, 12);
INSERT INTO usuaris VALUES (1701, 'Miqueo', 'Nino Castro', 'H', '79 Prolongacion San Sebastian', 21292, 'Miqueo.Nino.Castro@spambob.com', '28/02/46', 25, 11);
INSERT INTO usuaris VALUES (1702, 'Kathryn', 'Valladares Chávez', 'D', '15 Celso Emilio Ferreiro', 50461, 'Kathryn.Valladares.Chavez@spambob.com', '24/05/83', 85, NULL);
INSERT INTO usuaris VALUES (1703, 'Melibeo', 'Ávila Rolón', 'H', '6 Herrería', 18230, 'Melibeo.Avila.Rolon@dodgit.com', '09/03/51', 2, 6);
INSERT INTO usuaris VALUES (1704, 'Rudecindo', 'Meza Acuna', 'H', '41 Eusebio Dávila', 41540, 'Rudecindo.Meza.Acuna@pookmail.com', '04/09/45', 97, NULL);
INSERT INTO usuaris VALUES (1705, 'Leda', 'Bermúdez Quintanilla', 'D', '11 Puerto Lugar', 29788, 'Leda.Bermudez.Quintanilla@mailinator.com', '08/09/54', 13, 9);
INSERT INTO usuaris VALUES (1706, 'Holly', 'Castellanos Medina', 'D', '13 Ctra. de la Puerta', 26589, 'Holly.Castellanos.Medina@trashymail.com', '06/04/70', 57, 8);
INSERT INTO usuaris VALUES (1707, 'Farisa', 'Quiñones Fajardo', 'D', '5 C/ Pablo Iglesias', 26312, 'Farisa.Quinones.Fajardo@dodgit.com', '06/10/42', 8, 11);
INSERT INTO usuaris VALUES (1708, 'Segundo', 'Almonte Ruvalcaba', 'H', '94 Rio Segura', 31513, 'Segundo.Almonte.Ruvalcaba@spambob.com', '28/01/66', 5, 6);
INSERT INTO usuaris VALUES (1709, 'Palmira', 'Solorio Padrón', NULL, '18 Paseo Junquera', 12429, 'Palmira.Solorio.Padron@mailinator.com', '03/01/40', 67, 6);
INSERT INTO usuaris VALUES (1710, 'Alaia', 'Loera Ibarra', 'D', '92 Ctra. Bailén-Motril', 23370, 'Alaia.Loera.Ibarra@trashymail.com', '23/04/60', 58, 9);
INSERT INTO usuaris VALUES (1711, 'Dorian', 'González Avilés', 'D', '5 Boriñaur enparantza', 7550, 'Dorian.Gonzalez.Aviles@pookmail.com', '09/07/83', 42, 10);
INSERT INTO usuaris VALUES (1712, 'Nilton', 'Campos Arce', 'H', '7 Puerta Nueva', 35572, 'Nilton.Campos.Arce@pookmail.com', '20/04/65', 78, 11);
INSERT INTO usuaris VALUES (1713, 'Delfina', 'Raya Reyes', 'H', '47 Plaza Maior', 37218, 'Delfina.Raya.Reyes@spambob.com', '15/03/77', 48, 2);
INSERT INTO usuaris VALUES (1714, 'Olivia', 'Montano Pagan', NULL, '93 C/ Andalucía', 4740, 'Olivia.Montano.Pagan@dodgit.com', '27/02/48', 70, 7);
INSERT INTO usuaris VALUES (1715, 'Eneida', 'Zepeda Árias', 'D', '95 Cartagena', 30640, 'Eneida.Zepeda.Arias@dodgit.com', '01/09/57', 32, NULL);
INSERT INTO usuaris VALUES (1716, 'Terence', 'Acevedo Gurule', 'H', '9 Alcon Molina', 31190, 'Terence.Acevedo.Gurule@spambob.com', '14/09/47', 88, 9);
INSERT INTO usuaris VALUES (1717, 'Apolo', 'Vargas Segovia', 'H', '92 Salzillo', 32618, 'Apolo.Vargas.Segovia@pookmail.com', '23/07/70', 80, 12);
INSERT INTO usuaris VALUES (1718, 'Seraphin', 'Ulibarri Segovia', 'H', '88 Bouciña', 43791, 'Seraphin.Ulibarri.Segovia@dodgit.com', '09/03/42', 90, 8);
INSERT INTO usuaris VALUES (1719, 'Bienvenido', 'Alcaraz Sierra', 'H', '98 Camiño Real', 48392, 'Bienvenido.Alcaraz.Sierra@mailinator.com', '12/02/50', 81, 8);
INSERT INTO usuaris VALUES (1720, 'Azas', 'Hidalgo Longoria', 'H', '38 Outid de Arriba', 43560, 'Azas.Hidalgo.Longoria@pookmail.com', '27/01/57', 64, 7);
INSERT INTO usuaris VALUES (1721, 'Yesica', 'Botello Granado', 'D', '36 Camiño Ancho', 37785, 'Yesica.Botello.Granado@dodgit.com', '17/01/61', 49, 9);
INSERT INTO usuaris VALUES (1722, 'Queta', 'Marrero Rael', 'D', '85 C/ Benito Guinea', 8260, 'Queta.Marrero.Rael@dodgit.com', '07/03/72', 86, 1);
INSERT INTO usuaris VALUES (1723, 'Taffy', 'Terán Padilla', 'D', '79 Cartagena', 30613, 'Taffy.Teran.Padilla@spambob.com', '25/01/69', 87, 6);
INSERT INTO usuaris VALUES (1724, 'Azrael', 'Lira Muñiz', 'H', '84 C/ Angosto', 23560, 'Azrael.Lira.Muniz@spambob.com', '06/09/42', 80, 10);
INSERT INTO usuaris VALUES (1725, 'Iracema', 'Madrigal Carrión', NULL, '78 Carretera Cádiz-Málaga', 20800, 'Iracema.Madrigal.Carrion@dodgit.com', '23/06/69', NULL, 7);
INSERT INTO usuaris VALUES (1726, 'Jaasiel', 'Luján Jaramillo', 'H', '29 Ctra. Villena', 33826, 'Jaasiel.Lujan.Jaramillo@spambob.com', '31/12/42', 15, 12);
INSERT INTO usuaris VALUES (1727, 'Aixa', 'Toledo Bustos', 'D', '6 C/ Andalucía', 4825, 'Aixa.Toledo.Bustos@pookmail.com', '04/03/51', 20, 12);
INSERT INTO usuaris VALUES (1728, 'Moria', 'Ávalos Zamora', 'D', '50 Rúa de San Pedro', 37796, 'Moria.Avalos.Zamora@trashymail.com', '04/05/47', 39, 3);
INSERT INTO usuaris VALUES (1729, 'Amina', 'Rubio Cordero', 'D', '12 Avenida Cervantes', 48260, 'Amina.Rubio.Cordero@trashymail.com', '29/03/71', 47, 7);
INSERT INTO usuaris VALUES (1730, 'Cassandra', 'Salcedo Rascón', NULL, '72 Carretera del Muelle', 12350, 'Cassandra.Salcedo.Rascon@pookmail.com', '20/07/77', 93, 5);
INSERT INTO usuaris VALUES (1731, 'Inaxio', 'Loera Porras', 'H', '37 Rúa Olmos', 37405, 'Inaxio.Loera.Porras@mailinator.com', '26/04/65', 85, 4);
INSERT INTO usuaris VALUES (1732, 'Naira', 'Barreto Carmona', 'D', '92 C/ Domingo Beltrán', 2214, 'Naira.Barreto.Carmona@spambob.com', '18/10/60', 34, 4);
INSERT INTO usuaris VALUES (1733, 'Luigi', 'Suárez Sepúlveda', 'H', '55 Prolongacion San Sebastian', 21369, 'Luigi.Suarez.Sepulveda@trashymail.com', '17/06/62', 93, 8);
INSERT INTO usuaris VALUES (1734, 'Relinda', 'Ocasio Arroyo', 'D', '40 C/ Cañada del Rosal', 21510, 'Relinda.Ocasio.Arroyo@pookmail.com', '10/05/62', 84, NULL);
INSERT INTO usuaris VALUES (1735, 'Nuri', 'Vaca Montano', 'H', '33 Ctra. Villena', 33993, 'Nuri.Vaca.Montano@mailinator.com', '14/03/85', 1, 5);
INSERT INTO usuaris VALUES (1736, 'Ahinoa', 'Correa Serrano', 'D', '94 La Fontanilla', 14206, 'Ahinoa.Correa.Serrano@spambob.com', '21/11/44', 82, 7);
INSERT INTO usuaris VALUES (1737, 'Zina', 'Merino Collado', 'D', '30 Rúa Olmos', 37407, 'Zina.Merino.Collado@trashymail.com', '13/12/47', 91, NULL);
INSERT INTO usuaris VALUES (1738, 'Elisea', 'Ulibarri Figueroa', 'D', '22 Caño', 33114, 'Elisea.Ulibarri.Figueroa@pookmail.com', '14/01/85', 97, 10);
INSERT INTO usuaris VALUES (1739, 'Ophelia', 'Granado Aponte', 'D', '95 José matía', 2212, 'Ophelia.Granado.Aponte@pookmail.com', '29/03/76', 2, 1);
INSERT INTO usuaris VALUES (1740, 'Aristocles', 'Ontiveros Mesa', 'H', '5 Enxertos', 37554, 'Aristocles.Ontiveros.Mesa@spambob.com', '13/11/49', 34, 2);
INSERT INTO usuaris VALUES (1741, 'Ticiano', 'Suárez Sánchez', 'H', '13 C/ Señores Curas', 12125, 'Ticiano.Suarez.Sanchez@pookmail.com', '02/10/40', 6, 11);
INSERT INTO usuaris VALUES (1742, 'Aniceto', 'Mora Nazario', 'H', '48 C/ Manuel Iradier', 3787, 'Aniceto.Mora.Nazario@trashymail.com', '02/06/42', 13, 6);
INSERT INTO usuaris VALUES (1743, 'José Luis', 'Figueroa Rael', 'H', '62 Fuente del Gallo', 15130, 'Jose.Luis.Figueroa.Rael@trashymail.com', '25/07/70', 64, 4);
INSERT INTO usuaris VALUES (1744, 'Zelmar', 'Ramos Meraz', 'H', '14 Inglaterra', 18630, 'Zelmar.Ramos.Meraz@dodgit.com', '25/03/61', 3, 9);
INSERT INTO usuaris VALUES (1745, 'Zulma', 'Samaniego Henríquez', 'D', '47 Av. Santiago Lapuente', 50780, 'Zulma.Samaniego.Henriquez@pookmail.com', '11/04/80', 36, 6);
INSERT INTO usuaris VALUES (1746, 'Joanna', 'Galván Frías', 'D', '26 Cádiz', 18514, 'Joanna.Galvan.Frias@mailinator.com', '23/11/55', 22, 2);
INSERT INTO usuaris VALUES (1747, 'Celio', 'Correa Carrero', 'H', '94 C/ Cuesta del  Álamo', 29570, 'Celio.Correa.Carrero@dodgit.com', '18/11/57', 56, 12);
INSERT INTO usuaris VALUES (1748, 'Leontina', 'Ballesteros Fuentes', 'D', '9 Cercas Bajas', 8110, 'Leontina.Ballesteros.Fuentes@spambob.com', '08/05/46', 35, 8);
INSERT INTO usuaris VALUES (1749, 'Harold', 'Romero Ybarra', 'H', '33 Reiseñor', 45516, 'Harold.Romero.Ybarra@dodgit.com', '25/01/79', 77, 1);
INSERT INTO usuaris VALUES (1750, 'Mael', 'Delgado Solorio', 'H', '6 Cercas Bajas', 7810, 'Mael.Delgado.Solorio@mailinator.com', '12/09/44', 33, 12);
INSERT INTO usuaris VALUES (1751, 'Salvino', 'Urena Galarza', 'H', '88 C/ Pablo Iglesias', 26314, 'Salvino.Urena.Galarza@dodgit.com', '21/09/43', 79, 10);
INSERT INTO usuaris VALUES (1752, 'Anian', 'Nieves Cárdenas', 'D', '53 Constitución', 36980, 'Anian.Nieves.Cardenas@dodgit.com', '02/11/82', 43, 10);
INSERT INTO usuaris VALUES (1753, 'Anxela', 'Huerta León', NULL, '25 Rúa Olmos', 37405, 'Anxela.Huerta.Leon@dodgit.com', '20/01/78', 92, 3);
INSERT INTO usuaris VALUES (1754, 'Barbie', 'Mota Zapata', 'D', '6 Caño', 33114, 'Barbie.Mota.Zapata@trashymail.com', '11/06/57', 32, 2);
INSERT INTO usuaris VALUES (1755, 'Teo', 'Jaime Madrid', 'H', '11 C/ Eras', 28755, 'Teo.Jaime.Madrid@trashymail.com', '21/01/51', 12, 10);
INSERT INTO usuaris VALUES (1756, 'Haydee', 'Naranjo Mesa', 'D', '4 Calle Carril de la Fuente', 13194, 'Haydee.Naranjo.Mesa@dodgit.com', '14/02/43', 65, 4);
INSERT INTO usuaris VALUES (1757, 'Verena', 'Amador Rodrígez', 'D', '58 Eusebio Dávila', 41510, 'Verena.Amador.Rodrigez@mailinator.com', '19/10/85', 84, 7);
INSERT INTO usuaris VALUES (1758, 'Elvis', 'Verduzco Segovia', 'H', '52 Ctra. Hornos', 26213, 'Elvis.Verduzco.Segovia@dodgit.com', '18/10/71', 1, 5);
INSERT INTO usuaris VALUES (1759, 'Day', 'Rincón Osorio', 'H', '11 Carretera del Muelle', 12415, 'Day.Rincon.Osorio@spambob.com', '04/01/57', 90, 11);
INSERT INTO usuaris VALUES (1760, 'Casildo', 'Narváez Montanez', 'H', '1 Enxertos', 37512, 'Casildo.Narvaez.Montanez@spambob.com', '30/08/58', 36, 4);
INSERT INTO usuaris VALUES (1761, 'Peregrino', 'Lemus Enríquez', 'H', '98 Rio Segura', 31390, 'Peregrino.Lemus.Enriquez@trashymail.com', '26/02/43', 53, 4);
INSERT INTO usuaris VALUES (1762, 'Badomero', 'Grijalva Corrales', 'H', '25 Reiseñor', 46137, 'Badomero.Grijalva.Corrales@dodgit.com', '01/08/65', 18, 9);
INSERT INTO usuaris VALUES (1763, 'Micheline', 'Samaniego Tórrez', 'D', '18 Ctra. de Fuentenueva', 28294, 'Micheline.Samaniego.Torrez@dodgit.com', '27/06/57', 15, 10);
INSERT INTO usuaris VALUES (1764, 'Filomeno', 'Fonseca Navarro', 'H', '91 Castelao', 48810, 'Filomeno.Fonseca.Navarro@trashymail.com', '13/11/69', 18, 11);
INSERT INTO usuaris VALUES (1765, 'Libio', 'Carrero Valverde', 'H', '74 Ourense', 43350, 'Libio.Carrero.Valverde@trashymail.com', '28/08/64', 51, 1);
INSERT INTO usuaris VALUES (1766, 'Felisardo', 'Escobedo Alvarez', 'H', '96 Plaza de España', 15686, 'Felisardo.Escobedo.Alvarez@dodgit.com', '13/02/65', 66, 9);
INSERT INTO usuaris VALUES (1767, 'Ahmend', 'Molina Gaitán', 'H', '83 Rio Segura', 31370, 'Ahmend.Molina.Gaitan@pookmail.com', '05/10/66', 41, 3);
INSERT INTO usuaris VALUES (1768, 'Gina', 'Iglesias Paz', 'D', '68 Puerto Lugar', 30140, 'Gina.Iglesias.Paz@trashymail.com', '13/02/82', 40, 11);
INSERT INTO usuaris VALUES (1769, 'Elí', 'Gonzales Agosto', 'D', '34 C/ Manuel Iradier', 3769, 'Eli.Gonzales.Agosto@trashymail.com', '25/05/54', 74, 7);
INSERT INTO usuaris VALUES (1770, 'Aicardo', 'Cardona Orozco', 'H', '79 Bouciña', 43814, 'Aicardo.Cardona.Orozco@mailinator.com', '14/12/63', 51, 1);
INSERT INTO usuaris VALUES (1771, 'Heliena', 'Mendoza Luevano', 'D', '77 Ctra. de Fuentenueva', 28192, 'Heliena.Mendoza.Luevano@mailinator.com', '28/09/41', 11, 7);
INSERT INTO usuaris VALUES (1772, 'Lie', 'Segovia Molina', 'H', '3 Avda. Rio Nalon', 33535, 'Lie.Segovia.Molina@mailinator.com', '24/02/58', 62, 2);
INSERT INTO usuaris VALUES (1773, 'Nahum', 'Arredondo Salas', 'H', '68 C/ Canarias', 20120, 'Nahum.Arredondo.Salas@trashymail.com', '18/02/81', 20, 6);
INSERT INTO usuaris VALUES (1774, 'Lair', 'Saavedra Botello', 'H', '96 C/ Libertad', 5113, 'Lair.Saavedra.Botello@spambob.com', '10/03/45', 54, NULL);
INSERT INTO usuaris VALUES (1775, 'Venancio', 'Escalante Caballero', 'H', '85 Calle Carril de la Fuente', 13190, 'Venancio.Escalante.Caballero@spambob.com', '28/02/69', 1, 12);
INSERT INTO usuaris VALUES (1776, 'Quiliano', 'Delgadillo Yáñez', 'H', '92 C/ Señores Curas', 12132, 'Quiliano.Delgadillo.Yanez@spambob.com', '14/07/85', 2, 9);
INSERT INTO usuaris VALUES (1777, 'Mia', 'Rivera Díaz', 'D', '11 Av. Zumalakarregi', 3159, 'Mia.Rivera.Diaz@mailinator.com', '08/12/52', 72, 1);
INSERT INTO usuaris VALUES (1778, 'Waldino', 'Espino Bermúdez', 'H', '83 Avda. Andalucía', 26126, 'Waldino.Espino.Bermudez@pookmail.com', '23/08/66', 7, 11);
INSERT INTO usuaris VALUES (1779, 'Shantell', 'Galarza Caballero', 'D', '39 Cruce Casa de Postas', 18416, 'Shantell.Galarza.Caballero@trashymail.com', '18/11/56', 56, 4);
INSERT INTO usuaris VALUES (1780, 'Selim', 'Briones Botello', 'H', '72 C/ Libertad', 5230, 'Selim.Briones.Botello@mailinator.com', '03/12/53', 79, 2);
INSERT INTO usuaris VALUES (1781, 'Gabrielle', 'Sanches Mora', 'D', '23 Camiño Ancho', 37789, 'Gabrielle.Sanches.Mora@pookmail.com', '05/10/62', 21, 4);
INSERT INTO usuaris VALUES (1782, 'Sofiel', 'Covas Villanueva', 'H', '9 El Roqueo', 15940, 'Sofiel.Covas.Villanueva@pookmail.com', '08/01/72', 62, 5);
INSERT INTO usuaris VALUES (1783, 'Tetis', 'Ramos Hidalgo', 'D', '11 Carretera del Muelle', 12414, 'Tetis.Ramos.Hidalgo@dodgit.com', '15/05/79', 82, 3);
INSERT INTO usuaris VALUES (1784, 'Adair', 'Alemán Bueno', 'H', '79 Ventanilla de Beas', 28023, 'Adair.Aleman.Bueno@dodgit.com', '09/12/66', 76, 2);
INSERT INTO usuaris VALUES (1785, 'Melquisedec', 'Barreto Escamilla', 'H', '72 Bellavista', 49820, 'Melquisedec.Barreto.Escamilla@dodgit.com', '29/05/75', 62, 12);
INSERT INTO usuaris VALUES (1786, 'América', 'Salinas Lerma', 'D', '39 Calle Carril de la Fuente', 13192, 'America.Salinas.Lerma@spambob.com', '23/03/63', 14, 5);
INSERT INTO usuaris VALUES (1787, 'Altair', 'Olivo Comejo', 'D', '30 Estrela', 39738, 'Altair.Olivo.Comejo@trashymail.com', '14/08/43', 71, 4);
INSERT INTO usuaris VALUES (1788, 'Herminda', 'Perea Zapata', 'D', '86 C/ Henan Cortes', 29108, 'Herminda.Perea.Zapata@mailinator.com', '30/06/79', 82, NULL);
INSERT INTO usuaris VALUES (1789, 'Natalie', 'Archuleta Polanco', 'D', '27 Antonio Vázquez', 38715, 'Natalie.Archuleta.Polanco@trashymail.com', '09/10/77', 1, 3);
INSERT INTO usuaris VALUES (1790, 'Coralia', 'Jiménez Lucero', 'D', '53 Antonio Vázquez', 38730, 'Coralia.Jimenez.Lucero@trashymail.com', '10/02/81', 1, 4);
INSERT INTO usuaris VALUES (1791, 'Vannina', 'Granados Serrato', 'D', '2 Ctra. de Siles', 27332, 'Vannina.Granados.Serrato@mailinator.com', '30/04/70', 51, 3);
INSERT INTO usuaris VALUES (1792, 'Lioba', 'Mateo Henríquez', 'D', '56 Carretera del Muelle', 12400, 'Lioba.Mateo.Henriquez@mailinator.com', '06/04/75', 53, 9);
INSERT INTO usuaris VALUES (1793, 'Manila', 'Ríos Comejo', 'D', '85 Quevedo', 15337, 'Manila.Rios.Comejo@trashymail.com', '23/07/79', 72, NULL);
INSERT INTO usuaris VALUES (1794, 'Ambar', 'Rascón Lemus', 'D', '49 Bellavista', 50220, 'Ambar.Rascon.Lemus@trashymail.com', '06/08/54', 24, 2);
INSERT INTO usuaris VALUES (1795, 'Kim', 'Espinoza Elizondo', 'D', '60 Puerta Nueva', 36130, 'Kim.Espinoza.Elizondo@mailinator.com', '01/12/50', 23, 9);
INSERT INTO usuaris VALUES (1796, 'Adair', 'Cruz Samaniego', 'H', '13 Prolongacion San Sebastian', 21230, 'Adair.Cruz.Samaniego@pookmail.com', '23/10/77', 56, 11);
INSERT INTO usuaris VALUES (1797, 'Silvano', 'Almaraz Beltrán', 'H', '75 Rúa do Paseo', 41880, 'Silvano.Almaraz.Beltran@dodgit.com', '24/05/45', 32, 1);
INSERT INTO usuaris VALUES (1798, 'Prisc', 'Lucero Saenz', 'H', '10 Ctra. Villena', 34210, 'Prisc.Lucero.Saenz@trashymail.com', '23/07/73', 3, 3);
INSERT INTO usuaris VALUES (1799, 'Violeta', 'Fernández Mares', 'D', '66 C/ Canarias', 20115, 'Violeta.Fernandez.Mares@pookmail.com', '05/03/47', 85, 6);
INSERT INTO usuaris VALUES (1800, 'Fulk', 'Orozco Jaramillo', 'H', '91 Eusebio Dávila', 41420, 'Fulk.Orozco.Jaramillo@mailinator.com', '20/12/51', 90, 12);
INSERT INTO usuaris VALUES (1801, 'Crimilda', 'Arredondo Blanco', 'D', '38 Antonio Vázquez', 38715, 'Crimilda.Arredondo.Blanco@trashymail.com', '27/12/53', 3, 10);
INSERT INTO usuaris VALUES (1802, 'Maile', 'López Botello', 'D', '6 Av. Zumalakarregi', 3193, 'Maile.Lopez.Botello@mailinator.com', '16/12/80', 35, 3);
INSERT INTO usuaris VALUES (1803, 'Eloisa', 'Marroquín Duarte', 'D', '11 C/ Cuevas de Ambrosio', 23659, 'Eloisa.Marroquin.Duarte@dodgit.com', '21/05/85', 82, 12);
INSERT INTO usuaris VALUES (1804, 'Sylvia', 'Bonilla Arteaga', 'D', '85 C/ Cuevas de Ambrosio', 23710, 'Sylvia.Bonilla.Arteaga@trashymail.com', '30/12/69', NULL, 9);
INSERT INTO usuaris VALUES (1805, 'Nazario', 'Madrid Pichardo', 'H', '60 Atamaria', 36612, 'Nazario.Madrid.Pichardo@spambob.com', '25/08/83', 6, 5);
INSERT INTO usuaris VALUES (1806, 'Raymi', 'Montalvo Muro', 'H', '49 C/ Henan Cortes', 28980, 'Raymi.Montalvo.Muro@mailinator.com', '17/10/75', 86, 11);
INSERT INTO usuaris VALUES (1807, 'Ursy', 'Anaya Munguia', 'D', '32 San Andrés', 37258, 'Ursy.Anaya.Munguia@pookmail.com', '17/01/60', 54, 3);
INSERT INTO usuaris VALUES (1808, 'Juan Carlos', 'Montemayor Rosario', 'H', '73 Extramuros', 28511, 'Juan.Carlos.Montemayor.Rosario@trashymail.com', '16/07/45', 1, 2);
INSERT INTO usuaris VALUES (1809, 'Ayelén', 'Anaya Urena', 'D', '25 C/ Amoladera', 28813, 'Ayelen.Anaya.Urena@spambob.com', '16/06/53', 53, 5);
INSERT INTO usuaris VALUES (1810, 'Angélica', 'Botello Urena', 'D', '78 Pascual Yunquera', 18812, 'Angelica.Botello.Urena@pookmail.com', '17/01/58', 81, 11);
INSERT INTO usuaris VALUES (1811, 'Valentín', 'Quiñones Fernández', 'H', '81 Cartagena', 30562, 'Valentin.Quinones.Fernandez@spambob.com', '28/10/62', 79, 6);
INSERT INTO usuaris VALUES (1812, 'Sylvester', 'Rentería Cabrera', 'H', '56 Urzáiz', 44760, 'Sylvester.Renteria.Cabrera@pookmail.com', '12/12/81', 75, 10);
INSERT INTO usuaris VALUES (1813, 'Tubau', 'Alfaro Miranda', 'H', '66 Avda. Enrique Peinador', 37170, 'Tubau.Alfaro.Miranda@dodgit.com', '02/04/67', 52, 2);
INSERT INTO usuaris VALUES (1814, 'Evangelino', 'Cruz Cruz', 'H', '5 C/ Domingo Beltrán', 2213, 'Evangelino.Cruz.Cruz@pookmail.com', '22/09/45', 26, 10);
INSERT INTO usuaris VALUES (1815, 'Oriana', 'Cordova Soria', 'D', '39 Ctra. Hornos', 26212, 'Oriana.Cordova.Soria@pookmail.com', '09/01/45', 84, 8);
INSERT INTO usuaris VALUES (1816, 'Urania', 'Heredia Lomeli', 'D', '31 C/ Señores Curas', 11690, 'Urania.Heredia.Lomeli@trashymail.com', '11/05/78', 96, 4);
INSERT INTO usuaris VALUES (1817, 'Remo', 'Guerra Marroquín', 'H', '8 Alcon Molina', 31177, 'Remo.Guerra.Marroquin@spambob.com', '17/05/57', 9, NULL);
INSERT INTO usuaris VALUES (1818, 'Megan', 'Meza Hurtado', 'D', '87 C/ Los Herrán', 6760, 'Megan.Meza.Hurtado@trashymail.com', '27/01/40', 86, 5);
INSERT INTO usuaris VALUES (1819, 'Ammia', 'Arana Molina', 'D', '40 Maestro Puig Valera', 33578, 'Ammia.Arana.Molina@spambob.com', '04/07/52', 27, 10);
INSERT INTO usuaris VALUES (1820, 'Isaias', 'Robledo Montenegro', 'H', '31 Avda. Explanada Barnuevo', 35217, 'Isaias.Robledo.Montenegro@trashymail.com', '05/10/47', 97, 2);
INSERT INTO usuaris VALUES (1821, 'Menajem', 'Olivo Salcedo', 'H', '57 José matía', 2154, 'Menajem.Olivo.Salcedo@trashymail.com', '29/10/41', 24, 7);
INSERT INTO usuaris VALUES (1822, 'Maxelinda', 'Vanegas Ontiveros', 'D', '39 C/ Hijuela de Lojo', 20248, 'Maxelinda.Vanegas.Ontiveros@dodgit.com', '20/08/78', 71, 8);
INSERT INTO usuaris VALUES (1823, 'Iosef', 'Pantoja Carranza', 'H', '79 Puerta Nueva', 36518, 'Iosef.Pantoja.Carranza@spambob.com', '21/05/40', 8, 7);
INSERT INTO usuaris VALUES (1824, 'Hermenegildo', 'Cordero Lucio', 'H', '11 Pza. Fuensanta', 32300, 'Hermenegildo.Cordero.Lucio@trashymail.com', '25/03/41', 41, 7);
INSERT INTO usuaris VALUES (1825, 'Quichauel', 'Rubio Villalpando', 'D', '76 C/ Angosto', 23476, 'Quichauel.Rubio.Villalpando@pookmail.com', '20/12/79', 19, 5);
INSERT INTO usuaris VALUES (1826, 'Sabelia', 'Valdez Casillas', 'D', '10 Rio Segura', 31360, 'Sabelia.Valdez.Casillas@dodgit.com', '13/04/40', 15, 3);
INSERT INTO usuaris VALUES (1827, 'Romero', 'Roque Alfaro', 'H', '42 C/ Canarias', 20214, 'Romero.Roque.Alfaro@trashymail.com', '10/02/62', 39, 2);
INSERT INTO usuaris VALUES (1828, 'Elijah', 'Alcantar Gastelum', NULL, '9 C/ Arana', 2636, 'Elijah.Alcantar.Gastelum@dodgit.com', '14/07/70', 46, 11);
INSERT INTO usuaris VALUES (1829, 'Benjamín', 'Arana Grijalva', 'H', '56 Lamas Carbajal', 41620, 'Benjamin.Arana.Grijalva@pookmail.com', '16/05/67', 19, 6);
INSERT INTO usuaris VALUES (1830, 'Baldomero', 'Ávalos Echevarría', 'H', '36 Calle Aduana', 1218, 'Baldomero.Avalos.Echevarria@mailinator.com', '09/10/67', 27, 8);
INSERT INTO usuaris VALUES (1831, 'Adelaida', 'Raya Mireles', 'D', '81 C/ Canarias', 20000, 'Adelaida.Raya.Mireles@spambob.com', '13/02/69', 41, 12);
INSERT INTO usuaris VALUES (1832, 'Ondina', 'Romero Botello', 'D', '25 Ctra. Beas-Cortijos Nuevos', 26509, 'Ondina.Romero.Botello@dodgit.com', '25/07/71', 27, 12);
INSERT INTO usuaris VALUES (1833, 'Haydee', 'Zarate Gonzales', 'D', '20 Calle Aduana', 1117, 'Haydee.Zarate.Gonzales@pookmail.com', '15/04/58', 73, 2);
INSERT INTO usuaris VALUES (1834, 'Brutus', 'Zayas Barrera', 'H', '90 Cercas Bajas', 8240, 'Brutus.Zayas.Barrera@mailinator.com', '12/12/61', 22, NULL);
INSERT INTO usuaris VALUES (1835, 'Aicardo', 'Briseño Orta', 'H', '87 Avendaño', 4470, 'Aicardo.Briseno.Orta@dodgit.com', '24/05/69', 15, 6);
INSERT INTO usuaris VALUES (1836, 'Mayda', 'García Vela', 'D', '98 Rúa de San Pedro', 37863, 'Mayda.Garcia.Vela@dodgit.com', '11/09/46', 94, 11);
INSERT INTO usuaris VALUES (1837, 'Lanin', 'Caraballo Barreto', 'D', '63 Cañadilla', 21740, 'Lanin.Caraballo.Barreto@mailinator.com', '19/03/67', 13, 9);
INSERT INTO usuaris VALUES (1838, 'Metran', 'Paredes Aparicio', 'H', '69 Pascual Yunquera', 18708, 'Metran.Paredes.Aparicio@pookmail.com', '28/05/70', 63, NULL);
INSERT INTO usuaris VALUES (1839, 'Yole', 'Pabón Nieto', 'D', '60 Avda. Andalucía', 26126, 'Yole.Pabon.Nieto@spambob.com', '27/10/81', 22, NULL);
INSERT INTO usuaris VALUES (1840, 'Yoana', 'Parra Rodarte', 'D', '2 Atamaria', 36670, 'Yoana.Parra.Rodarte@dodgit.com', '17/01/74', 89, 2);
INSERT INTO usuaris VALUES (1841, 'Agatón', 'Aguirre Fernández', 'H', '11 Puerto Lugar', 29752, 'Agaton.Aguirre.Fernandez@pookmail.com', '30/03/80', 60, 5);
INSERT INTO usuaris VALUES (1842, 'Rayen', 'Gaitán Vergara', 'H', '43 Avenida Cervantes', 48240, 'Rayen.Gaitan.Vergara@mailinator.com', '06/05/78', 35, 1);
INSERT INTO usuaris VALUES (1843, 'Peggy', 'Monroy Soliz', 'D', '69 Rua da Rapina', 37487, 'Peggy.Monroy.Soliz@pookmail.com', '26/06/63', 69, 3);
INSERT INTO usuaris VALUES (1844, 'Melina', 'Madrigal Valles', 'D', '63 Av. Zumalakarregi', 3160, 'Melina.Madrigal.Valles@spambob.com', '19/11/78', 71, NULL);
INSERT INTO usuaris VALUES (1845, 'Elihu', 'Ordóñez Hernádez', 'H', '50 Enxertos', 37531, 'Elihu.Ordonez.Hernadez@trashymail.com', '09/06/44', 69, 4);
INSERT INTO usuaris VALUES (1846, 'Damián', 'Morales Sosa', 'H', '64 Celso Emilio Ferreiro', 50400, 'Damian.Morales.Sosa@spambob.com', '12/03/59', 98, 6);
INSERT INTO usuaris VALUES (1847, 'Damia', 'Valverde Adomo', 'D', '50 C/ Libertad', 5260, 'Damia.Valverde.Adomo@pookmail.com', '08/05/74', 44, 1);
INSERT INTO usuaris VALUES (1848, 'Madox', 'Contreras Amaya', 'H', '93 Bouciña', 43780, 'Madox.Contreras.Amaya@mailinator.com', '04/09/80', 11, 12);
INSERT INTO usuaris VALUES (1849, 'Elí', 'Trejo Echevarría', 'D', '17 Calle Aduana', 1314, 'Eli.Trejo.Echevarria@dodgit.com', '27/08/46', 51, 9);
INSERT INTO usuaris VALUES (1850, 'Andy', 'Orellana Veliz', 'H', '84 Calle Carril de la Fuente', 13193, 'Andy.Orellana.Veliz@spambob.com', '13/12/67', 31, 8);
INSERT INTO usuaris VALUES (1851, 'Marlon', 'Sarabia Covarrubias', 'H', '48 Outid de Arriba', 43720, 'Marlon.Sarabia.Covarrubias@pookmail.com', '17/08/59', 93, 12);
INSERT INTO usuaris VALUES (1852, 'Peter', 'Salgado Casárez', 'H', '71 Constitución', 37114, 'Peter.Salgado.Casarez@spambob.com', '01/10/71', 16, 5);
INSERT INTO usuaris VALUES (1853, 'Natanael', 'Lozada Urbina', 'H', '80 Pza. Fuensanta', 32454, 'Natanael.Lozada.Urbina@spambob.com', '09/12/60', 20, 6);
INSERT INTO usuaris VALUES (1854, 'Pusaki', 'Hernádez Domínquez', 'H', '8 C/ Los Herrán', 6400, 'Pusaki.Hernadez.Dominquez@spambob.com', '24/10/70', 42, 11);
INSERT INTO usuaris VALUES (1855, 'Kalid', 'Treviño Godínez', 'D', '19 Bouciña', 43770, 'Kalid.Trevino.Godinez@trashymail.com', '07/07/58', 91, 8);
INSERT INTO usuaris VALUES (1856, 'Saskia', 'Rubio Campos', 'D', '52 C/ Rosa de los Vientos', 11612, 'Saskia.Rubio.Campos@spambob.com', '06/06/41', 9, 1);
INSERT INTO usuaris VALUES (1857, 'Ebe', 'Ávila Berrios', 'D', '53 Outid de Arriba', 43710, 'Ebe.Avila.Berrios@spambob.com', '21/04/49', 33, 5);
INSERT INTO usuaris VALUES (1858, 'Wanda', 'Iglesias Cadena', 'D', '25 Av. Zumalakarregi', 3316, 'Wanda.Iglesias.Cadena@dodgit.com', '24/07/42', 83, 2);
INSERT INTO usuaris VALUES (1859, 'Leontino', 'Ordóñez Carrasquill', 'H', '28 C/ Henan Cortes', 29109, 'Leontino.Ordonez.Carrasquill@dodgit.com', '29/01/46', 11, 10);
INSERT INTO usuaris VALUES (1860, 'Ailén', 'Marcos Pelayo', 'H', '37 Pascual Yunquera', 18659, 'Ailen.Marcos.Pelayo@spambob.com', '16/01/55', 70, 4);
INSERT INTO usuaris VALUES (1861, 'Ptolomeo', 'Luevano Chavarría', 'H', '95 Reiseñor', 46137, 'Ptolomeo.Luevano.Chavarria@spambob.com', '12/08/62', 27, 7);
INSERT INTO usuaris VALUES (1862, 'Idalia', 'Bustamante Robles', 'D', '52 C/ Eras', 28723, 'Idalia.Bustamante.Robles@mailinator.com', '13/10/42', 62, 8);
INSERT INTO usuaris VALUES (1863, 'Rotrauda', 'Gonzales Montenegro', 'D', '84 Cruce Casa de Postas', 18430, 'Rotrauda.Gonzales.Montenegro@mailinator.com', '05/05/83', 68, 9);
INSERT INTO usuaris VALUES (1864, 'Goliard', 'Cortés Molina', 'H', '81 Plaza Maior', 37219, 'Goliard.Cortes.Molina@dodgit.com', '28/08/80', 38, 1);
INSERT INTO usuaris VALUES (1865, 'Yone', 'Solano Moreno', 'D', '83 Reiseñor', 46180, 'Yone.Solano.Moreno@dodgit.com', '16/05/67', 58, 12);
INSERT INTO usuaris VALUES (1866, 'Parménides', 'Casares Guardado', 'H', '88 El Roqueo', 17240, 'Parmenides.Casares.Guardado@mailinator.com', '26/02/74', 66, 6);
INSERT INTO usuaris VALUES (1867, 'Flaminia', 'Saavedra Caballero', 'D', '59 Rosa de los Vientos', 13344, 'Flaminia.Saavedra.Caballero@mailinator.com', '01/09/42', 7, 7);
INSERT INTO usuaris VALUES (1868, 'Astor', 'Almanza Valenzuela', 'H', '94 Pl. Virgen Blanca', 8758, 'Astor.Almanza.Valenzuela@mailinator.com', '01/12/48', 78, 2);
INSERT INTO usuaris VALUES (1869, 'QuINTO', 'Benavides Echevarría', 'H', '30 Avda. Alameda Sundheim', 22510, 'QuINTO.Benavides.Echevarria@pookmail.com', '07/06/43', 47, 3);
INSERT INTO usuaris VALUES (1870, 'Neera', 'Grijalva Benítez', 'D', '16 Ventanilla de Beas', 27720, 'Neera.Grijalva.Benitez@mailinator.com', '18/10/58', 69, 8);
INSERT INTO usuaris VALUES (1871, 'Macaria', 'Callas Puente', 'D', '40 Canónigo Valiño', 46610, 'Macaria.Callas.Puente@trashymail.com', '26/01/47', 77, 12);
INSERT INTO usuaris VALUES (1872, 'Israela', 'Saenz Montoya', 'D', '98 Plaza de España', 15818, 'Israela.Saenz.Montoya@trashymail.com', '06/02/40', 51, 12);
INSERT INTO usuaris VALUES (1873, 'Fedra', 'Badillo Elizondo', 'D', '8 Ourense', 43390, 'Fedra.Badillo.Elizondo@trashymail.com', '06/12/43', 85, NULL);
INSERT INTO usuaris VALUES (1874, 'Jalil', 'Botello Tamez', 'H', '51 Ctra. Bailén-Motril', 23390, 'Jalil.Botello.Tamez@dodgit.com', '26/06/57', 81, 7);
INSERT INTO usuaris VALUES (1875, 'Cibrán', 'Olivo Velázquez', 'H', '66 Avda. Andalucía', 26134, 'Cibran.Olivo.Velazquez@dodgit.com', '04/11/49', 48, 2);
INSERT INTO usuaris VALUES (1876, 'Licinio', 'Balderas Rangel', 'H', '33 Ctra. Hornos', 26224, 'Licinio.Balderas.Rangel@dodgit.com', '15/11/43', 76, 4);
INSERT INTO usuaris VALUES (1877, 'Owen', 'Leal Reyes', 'H', '43 C/ Andalucía', 4640, 'Owen.Leal.Reyes@trashymail.com', '30/09/44', 28, 3);
INSERT INTO usuaris VALUES (1878, 'Esmirna', 'Bravo Sevilla', 'D', '7 Apartado de Correos', 37439, 'Esmirna.Bravo.Sevilla@trashymail.com', '09/11/66', 60, 9);
INSERT INTO usuaris VALUES (1879, 'Veronique', 'Echevarría Arreola', 'D', '83 Padre Caro', 13700, 'Veronique.Echevarria.Arreola@spambob.com', '03/02/57', 10, 3);
INSERT INTO usuaris VALUES (1880, 'Roy', 'Alemán Adomo', 'H', '33 Rúa Olmos', 37337, 'Roy.Aleman.Adomo@dodgit.com', '09/03/60', 59, 10);
INSERT INTO usuaris VALUES (1881, 'Evarista', 'Zepeda Soto', 'D', '20 Pascual Yunquera', 18659, 'Evarista.Zepeda.Soto@pookmail.com', '28/02/78', 67, 5);
INSERT INTO usuaris VALUES (1882, 'Adam', 'Roque Banda', 'H', '65 Caño', 32812, 'Adam.Roque.Banda@trashymail.com', '25/02/45', 83, 7);
INSERT INTO usuaris VALUES (1883, 'Juan José', 'Cantú Saenz', 'H', '15 C/ Amoladera', 28812, 'Juan.Jose.Cantu.Saenz@pookmail.com', '22/11/54', 29, 2);
INSERT INTO usuaris VALUES (1884, 'Irupé', 'Vela Villaseñor', 'D', '80 Calvo Sotelo', 47510, 'Irupe.Vela.Villasenor@pookmail.com', '19/04/52', 86, 2);
INSERT INTO usuaris VALUES (1885, 'Adelmar', 'Cotto Tamayo', 'H', '91 Atamaria', 36530, 'Adelmar.Cotto.Tamayo@mailinator.com', '13/12/43', 50, 9);
INSERT INTO usuaris VALUES (1886, 'Lucía', 'Ontiveros Feliciano', 'D', '57 San Andrés', 37257, 'Lucia.Ontiveros.Feliciano@pookmail.com', '20/11/52', 90, 5);
INSERT INTO usuaris VALUES (1887, 'Rotrauda', 'Esquibel Dueñas', 'D', '98 C/ Señores Curas', 11670, 'Rotrauda.Esquibel.Duenas@spambob.com', '18/01/71', 33, 12);
INSERT INTO usuaris VALUES (1888, 'Sebasten', 'Marrero Haro', 'H', '46 Plaza Maior', 37209, 'Sebasten.Marrero.Haro@spambob.com', '12/10/81', 98, 3);
INSERT INTO usuaris VALUES (1889, 'Blas', 'Aragón Vanegas', 'H', '41 Puerta Nueva', 36518, 'Blas.Aragon.Vanegas@spambob.com', '06/03/80', 51, 1);
INSERT INTO usuaris VALUES (1890, 'Dalma', 'Solorio Mora', 'D', '91 Pl. Virgen Blanca', 8530, 'Dalma.Solorio.Mora@pookmail.com', '05/06/40', 2, 12);
INSERT INTO usuaris VALUES (1891, 'Nilda', 'Urías Vaca', 'D', '69 Ventanilla de Beas', 27870, 'Nilda.Urias.Vaca@spambob.com', '20/07/50', 86, 7);
INSERT INTO usuaris VALUES (1892, 'Princesa', 'Vargas Zepeda', 'D', '44 C/ Andalucía', 4760, 'Princesa.Vargas.Zepeda@dodgit.com', '05/08/73', 94, NULL);
INSERT INTO usuaris VALUES (1893, 'Zelmar', 'Ibarra Rojo', 'H', '90 José matía', 1400, 'Zelmar.Ibarra.Rojo@mailinator.com', '15/02/66', 84, 10);
INSERT INTO usuaris VALUES (1894, 'Meline', 'Parra Carrera', 'D', '55 Escuadro', 46860, 'Meline.Parra.Carrera@dodgit.com', '01/02/42', 13, 7);
INSERT INTO usuaris VALUES (1895, 'Longinos', 'Meza Muro', 'H', '47 Canónigo Valiño', 46460, 'Longinos.Meza.Muro@pookmail.com', '18/04/82', 34, 7);
INSERT INTO usuaris VALUES (1896, 'Cordelia', 'Gallegos Irizarry', 'D', '23 C/ Eras', 28721, 'Cordelia.Gallegos.Irizarry@spambob.com', '24/02/65', 22, 6);
INSERT INTO usuaris VALUES (1897, 'Belisaria', 'Ferrer Galindo', 'D', '49 Crta. Cádiz-Málaga', 12194, 'Belisaria.Ferrer.Galindo@mailinator.com', '04/01/48', 31, 10);
INSERT INTO usuaris VALUES (1898, 'Charo', 'Casares Venegas', 'D', '34 Ourense', 42330, 'Charo.Casares.Venegas@dodgit.com', '30/01/69', 72, 11);
INSERT INTO usuaris VALUES (1899, 'Evangelina', 'Porras Zamora', 'D', '47 Constitución', 37139, 'Evangelina.Porras.Zamora@dodgit.com', '02/06/56', 34, 9);
INSERT INTO usuaris VALUES (1900, 'Morfeo', 'Ceballos Feliciano', 'H', '44 C/ Manuel Iradier', 3813, 'Morfeo.Ceballos.Feliciano@mailinator.com', '06/08/85', 3, 11);
INSERT INTO usuaris VALUES (1901, 'Brandon', 'Ocasio Negrete', 'H', '97 Salzillo', 32630, 'Brandon.Ocasio.Negrete@trashymail.com', '11/09/45', 48, 5);
INSERT INTO usuaris VALUES (1902, 'Yoav', 'Montoya Villalpando', 'H', '26 Cruce Casa de Postas', 18400, 'Yoav.Montoya.Villalpando@spambob.com', '30/11/70', 51, 5);
INSERT INTO usuaris VALUES (1903, 'Vito', 'Vaca Franco', 'H', '35 Antonio Vázquez', 38715, 'Vito.Vaca.Franco@spambob.com', '15/02/54', 51, 11);
INSERT INTO usuaris VALUES (1904, 'Janvier', 'Cardona Adame', 'H', '58 Paseo del Atlántico', 18140, 'Janvier.Cardona.Adame@pookmail.com', '02/12/73', 15, 8);
INSERT INTO usuaris VALUES (1905, 'Exal', 'Griego Brito', 'D', '91 Apartado de Correos', 37449, 'Exal.Griego.Brito@trashymail.com', '21/10/43', 59, 5);
INSERT INTO usuaris VALUES (1906, 'Febes', 'Espinosa Guevara', 'D', '51 Ctra. de Siles', 27377, 'Febes.Espinosa.Guevara@mailinator.com', '24/09/56', 19, 8);
INSERT INTO usuaris VALUES (1907, 'Lía', 'Zarate Quiñones', 'D', '46 Bellavista', 50230, 'Lia.Zarate.Quinones@mailinator.com', '15/10/63', 91, 12);
INSERT INTO usuaris VALUES (1908, 'Lioba', 'Alvarez Tórrez', 'D', '27 Plazuela do Porto', 38200, 'Lioba.Alvarez.Torrez@pookmail.com', '22/01/82', 47, 3);
INSERT INTO usuaris VALUES (1909, 'Dulce', 'Estévez Hernández', 'D', '33 Cercas Bajas', 8140, 'Dulce.Estevez.Hernandez@dodgit.com', '12/08/78', 54, 5);
INSERT INTO usuaris VALUES (1910, 'Eric', 'Madera Hernández', 'H', '4 Cañadilla', 21720, 'Eric.Madera.Hernandez@trashymail.com', NULL, 34, 7);
INSERT INTO usuaris VALUES (1911, 'Sharif', 'Treviño Regalado', 'H', '40 Bellavista', 50170, 'Sharif.Trevino.Regalado@pookmail.com', '19/09/67', 13, 5);
INSERT INTO usuaris VALUES (1912, 'Lázaro', 'Almaraz Juárez', 'D', '37 Pascual Yunquera', 18700, 'Lazaro.Almaraz.Juarez@spambob.com', '17/12/78', 1, 11);
INSERT INTO usuaris VALUES (1913, 'Elea', 'Burgos Acuna', 'D', '74 Avda. Los llanos', 26228, 'Elea.Burgos.Acuna@pookmail.com', '09/04/84', 21, NULL);
INSERT INTO usuaris VALUES (1914, 'Segismundo', 'Ortiz Leal', 'H', '95 Quevedo', 15560, 'Segismundo.Ortiz.Leal@mailinator.com', '24/02/83', 77, 3);
INSERT INTO usuaris VALUES (1915, 'Etel', 'Pabón Carranza', 'D', '15 C/ Fernández de Leceta', 3517, 'Etel.Pabon.Carranza@spambob.com', '11/04/52', 39, 1);
INSERT INTO usuaris VALUES (1916, 'Bernarda', 'Rodríguez Echevarría', 'D', '80 C/ Amoladera', 28815, 'Bernarda.Rodriguez.Echevarria@dodgit.com', '11/03/50', 92, 10);
INSERT INTO usuaris VALUES (1917, 'Grau', 'Pabón Razo', 'H', '58 Carretera Cádiz-Málaga', 20800, 'Grau.Pabon.Razo@pookmail.com', '16/08/58', 2, 5);
INSERT INTO usuaris VALUES (1918, 'Inan', 'Delgadillo Herrera', 'H', '23 Herrería', 18152, 'Inan.Delgadillo.Herrera@trashymail.com', '02/01/72', 96, 5);
INSERT INTO usuaris VALUES (1919, 'Agape', 'Castillo Alejandro', 'D', '99 Plazuela do Porto', 38436, 'Agape.Castillo.Alejandro@dodgit.com', '02/09/47', 0, 11);
INSERT INTO usuaris VALUES (1920, 'Bartie', 'Holguín Merino', 'H', '64 Alvaro Cunqueiro', 41100, 'Bartie.Holguin.Merino@mailinator.com', '06/08/47', 10, 8);
INSERT INTO usuaris VALUES (1921, 'Palixena', 'Pacheco Argüello', 'D', '75 Paseo Junquera', 12470, 'Palixena.Pacheco.Arguello@spambob.com', '20/04/79', 20, 7);
INSERT INTO usuaris VALUES (1922, 'Querían', 'Posada Mayonga', 'H', '28 Cartagena', 30564, 'Querian.Posada.Mayonga@pookmail.com', '03/01/49', 12, 7);
INSERT INTO usuaris VALUES (1923, 'Eustacio', 'Calvillo Comejo', 'H', '49 Paraguay', 3750, 'Eustacio.Calvillo.Comejo@dodgit.com', '11/08/48', 80, 8);
INSERT INTO usuaris VALUES (1924, 'Ampelio', 'Vaca Ramón', 'H', '49 Calle Proc. San Sebastián', 12592, 'Ampelio.Vaca.Ramon@spambob.com', '23/12/47', 56, 9);
INSERT INTO usuaris VALUES (1925, 'Sonia', 'Quezada Vaca', 'D', '36 Camiño Real', 48498, 'Sonia.Quezada.Vaca@dodgit.com', '16/02/81', 69, 9);
INSERT INTO usuaris VALUES (1926, 'Rafa', 'Maestas Rodrígez', 'H', '75 Plaza Colón', 25600, 'Rafa.Maestas.Rodrigez@trashymail.com', '01/11/62', 0, 7);
INSERT INTO usuaris VALUES (1927, 'Lian', 'Jasso Lozada', 'H', '48 Pascual Yunquera', 18800, 'Lian.Jasso.Lozada@spambob.com', '27/08/50', 92, 9);
INSERT INTO usuaris VALUES (1928, 'Partenia', 'Prado Palacios', 'D', '41 C/ Cuesta del  Álamo', 29550, 'Partenia.Prado.Palacios@pookmail.com', '25/06/77', 8, 10);
INSERT INTO usuaris VALUES (1929, 'Reina', 'Ferrer Guardado', 'D', '5 Apartado de Correos', 37454, 'Reina.Ferrer.Guardado@pookmail.com', '22/10/50', 10, 4);
INSERT INTO usuaris VALUES (1930, 'Chandra', 'Díaz Cazares', 'D', '55 Avda. Explanada Barnuevo', 34820, 'Chandra.Diaz.Cazares@mailinator.com', '02/02/50', 32, 6);
INSERT INTO usuaris VALUES (1931, 'Edelweiss', 'Lerma Merino', 'D', '26 Comandante Izarduy', 8820, 'Edelweiss.Lerma.Merino@trashymail.com', '20/08/50', NULL, 3);
INSERT INTO usuaris VALUES (1932, 'Alvar', 'Briones Perales', 'H', '20 Maestro Puig Valera', 33800, 'Alvar.Briones.Perales@trashymail.com', '03/11/62', 91, 3);
INSERT INTO usuaris VALUES (1933, 'Sora', 'Pena Castaneda', 'D', '29 C/ Angosto', 23568, 'Sora.Pena.Castaneda@dodgit.com', '16/08/53', 66, 1);
INSERT INTO usuaris VALUES (1934, 'Arminda', 'Barrientos Nieves', 'D', '41 Carretera del Muelle', 12310, 'Arminda.Barrientos.Nieves@mailinator.com', '23/05/48', 70, 3);
INSERT INTO usuaris VALUES (1935, 'Zara', 'Urbina Madrid', 'D', '88 C/ Henan Cortes', 29194, 'Zara.Urbina.Madrid@pookmail.com', '06/05/68', 21, 6);
INSERT INTO usuaris VALUES (1936, 'Liafdag', 'Irizarry Salcido', 'H', '32 Avda. Explanada Barnuevo', 35300, 'Liafdag.Irizarry.Salcido@mailinator.com', '21/08/54', 77, 10);
INSERT INTO usuaris VALUES (1937, 'Ivana', 'Madrid Pulido', 'D', '26 Canónigo Valiño', 46440, 'Ivana.Madrid.Pulido@pookmail.com', '13/10/59', 95, 4);
INSERT INTO usuaris VALUES (1938, 'Umberto', 'Díaz Zaragoza', 'H', '27 Puerta Nueva', 36110, 'Umberto.Diaz.Zaragoza@spambob.com', '18/07/41', 61, 12);
INSERT INTO usuaris VALUES (1939, 'Eneida', 'Madrigal Corral', 'D', '57 C/ Fernández de Leceta', 3369, 'Eneida.Madrigal.Corral@pookmail.com', '07/03/67', 21, 7);
INSERT INTO usuaris VALUES (1940, 'Anías', 'Quiroz Quintanilla', 'H', '24 Ctra. de la Puerta', 27250, 'Anias.Quiroz.Quintanilla@dodgit.com', '29/08/55', 76, 7);
INSERT INTO usuaris VALUES (1941, 'Zenadia', 'Feliciano Villalpando', 'D', '73 Ctra. Hornos', 26211, 'Zenadia.Feliciano.Villalpando@dodgit.com', '22/10/59', 85, 2);
INSERT INTO usuaris VALUES (1942, 'Macaria', 'Badillo Bermúdez', 'D', '50 Zumalakarregi etorbidea', 7300, 'Macaria.Badillo.Bermudez@dodgit.com', '24/12/56', 93, 3);
INSERT INTO usuaris VALUES (1943, 'Albin', 'Franco Molina', 'H', '84 La Fontanilla', 14290, 'Albin.Franco.Molina@mailinator.com', '10/11/44', 41, 7);
INSERT INTO usuaris VALUES (1944, 'Mar', 'Pantoja Chapa', 'D', '10 Ctra. de Siles', 27664, 'Mar.Pantoja.Chapa@trashymail.com', '06/06/77', 70, 8);
INSERT INTO usuaris VALUES (1945, 'Camila', 'Mondragón Sauceda', 'D', '56 Calle Carril de la Fuente', 13195, 'Camila.Mondragon.Sauceda@pookmail.com', '31/03/42', 80, 2);
INSERT INTO usuaris VALUES (1946, 'Maxelinda', 'Ibarra Longoria', 'D', '8 Apartado de Correos', 37450, 'Maxelinda.Ibarra.Longoria@mailinator.com', '19/09/44', 71, 1);
INSERT INTO usuaris VALUES (1947, 'Lisandro', 'Corral Loera', 'H', '10 Antonio Vázquez', 38440, 'Lisandro.Corral.Loera@mailinator.com', '22/03/55', 99, 5);
INSERT INTO usuaris VALUES (1948, 'Juliana', 'Pérez Mota', 'D', '98 Cartagena', 30560, 'Juliana.Perez.Mota@trashymail.com', '07/07/56', 56, 7);
INSERT INTO usuaris VALUES (1949, 'Raffi', 'Hinojosa Sarabia', 'H', '51 C/ Cañada del Rosal', 21590, 'Raffi.Hinojosa.Sarabia@dodgit.com', '20/11/40', 41, 1);
INSERT INTO usuaris VALUES (1950, 'Austín', 'Serna Cotto', 'H', '58 Plaza Colón', 26000, 'Austin.Serna.Cotto@dodgit.com', '23/05/50', 52, 2);
INSERT INTO usuaris VALUES (1951, 'Raidis', 'Arellano Berrios', 'H', '85 Calvo Sotelo', 47500, 'Raidis.Arellano.Berrios@pookmail.com', '24/01/56', 84, 3);
INSERT INTO usuaris VALUES (1952, 'Alina', 'Iglesias Cervántez', 'D', '41 Cartagena', 30500, 'Alina.Iglesias.Cervantez@spambob.com', '20/12/40', 62, 9);
INSERT INTO usuaris VALUES (1953, 'Myra', 'Rocha Ramírez', 'D', '1 Celso Emilio Ferreiro', 50400, 'Myra.Rocha.Ramirez@pookmail.com', '08/05/73', 91, NULL);
INSERT INTO usuaris VALUES (1954, 'Dallas', 'Saucedo Preciado', 'H', '78 Prolongacion San Sebastian', 21291, 'Dallas.Saucedo.Preciado@spambob.com', '30/12/84', 70, 10);
INSERT INTO usuaris VALUES (1955, 'Anelida', 'Baeza Urena', 'D', '81 Enxertos', 37520, 'Anelida.Baeza.Urena@dodgit.com', '01/11/85', 82, 8);
INSERT INTO usuaris VALUES (1956, 'Renaldo', 'Galarza Salinas', 'H', '9 San Andrés', 37248, 'Renaldo.Galarza.Salinas@pookmail.com', '13/01/52', 18, 7);
INSERT INTO usuaris VALUES (1957, 'Miren', 'Fonseca Oquendo', 'D', '81 Plaza Maior', 37216, 'Miren.Fonseca.Oquendo@mailinator.com', '27/09/72', 1, 5);
INSERT INTO usuaris VALUES (1958, 'Oswald', 'Delgado Guajardo', 'H', '15 Ctra. Villena', 33830, 'Oswald.Delgado.Guajardo@mailinator.com', '09/05/44', 55, 8);
INSERT INTO usuaris VALUES (1959, 'Giuliano', 'Morales Lomeli', 'H', '16 Rúa de San Pedro', 37797, 'Giuliano.Morales.Lomeli@dodgit.com', '16/12/75', 71, 3);
INSERT INTO usuaris VALUES (1960, 'Teodequilda', 'Girón Alarcón', NULL, '58 Visitación de la Encina', 37712, 'Teodequilda.Giron.Alarcon@mailinator.com', '15/06/57', 4, 5);
INSERT INTO usuaris VALUES (1961, 'Martial', 'Jiménez Gutiérrez', 'H', '44 Visitación de la Encina', 37727, 'Martial.Jimenez.Gutierrez@mailinator.com', '21/11/60', 13, 8);
INSERT INTO usuaris VALUES (1962, 'Dionel', 'Lomeli Serrano', 'H', '32 Ventanilla de Beas', 28130, 'Dionel.Lomeli.Serrano@dodgit.com', '03/10/49', 92, 11);
INSERT INTO usuaris VALUES (1963, 'Ezio', 'Arellano Arteaga', 'H', '50 Rosa de los Vientos', 13412, 'Ezio.Arellano.Arteaga@dodgit.com', '21/12/84', 87, 4);
INSERT INTO usuaris VALUES (1964, 'Luca', 'Delgado Garrido', 'H', '97 C/ Canarias', 20160, 'Luca.Delgado.Garrido@spambob.com', '20/08/75', 97, 12);
INSERT INTO usuaris VALUES (1965, 'Yoshi', 'Fonseca Saucedo', 'H', '55 Reyes Católicos', 10300, 'Yoshi.Fonseca.Saucedo@spambob.com', '19/10/45', 42, 10);
INSERT INTO usuaris VALUES (1966, 'Cañumil', 'Sotelo Caraballo', 'H', '17 Avda. Explanada Barnuevo', 35260, 'Canumil.Sotelo.Caraballo@trashymail.com', '30/01/57', 14, 12);
INSERT INTO usuaris VALUES (1967, 'Lisbet', 'Pabón Cortés', 'D', '34 C/ Henan Cortes', 28979, 'Lisbet.Pabon.Cortes@mailinator.com', '18/05/76', 9, 5);
INSERT INTO usuaris VALUES (1968, 'Heráclito', 'Valdivia Escobar', NULL, '3 Carretera', 14546, 'Heraclito.Valdivia.Escobar@mailinator.com', '04/03/50', 81, 4);
INSERT INTO usuaris VALUES (1969, 'Casandra', 'Jaramillo Botello', 'D', '85 Extramuros', 28515, 'Casandra.Jaramillo.Botello@trashymail.com', '24/06/40', 45, 5);
INSERT INTO usuaris VALUES (1970, 'Bru', 'Tejada Ballesteros', 'H', '55 Rúa de San Pedro', 37797, 'Bru.Tejada.Ballesteros@spambob.com', '14/10/83', 46, 2);
INSERT INTO usuaris VALUES (1971, 'Tyson', 'Cadena Téllez', 'H', '62 C/ Hijuela de Lojo', 20248, 'Tyson.Cadena.Tellez@pookmail.com', '01/10/71', 24, 1);
INSERT INTO usuaris VALUES (1972, 'Fructuoso', 'Ocasio Alcalá', 'H', '70 Paseo del Atlántico', 17820, 'Fructuoso.Ocasio.Alcala@pookmail.com', '25/04/69', 17, 10);
INSERT INTO usuaris VALUES (1973, 'Kristine', 'Adame Ocampo', 'D', '78 C/ Domingo Beltrán', 2250, 'Kristine.Adame.Ocampo@trashymail.com', '04/04/64', 57, 2);
INSERT INTO usuaris VALUES (1974, 'Evasio', 'Callas Berrios', 'H', '16 Extramuros', 28550, 'Evasio.Callas.Berrios@mailinator.com', '09/12/52', 99, 12);
INSERT INTO usuaris VALUES (1975, 'Janoc', 'Urbina Garrido', 'H', '18 Herrería', 18192, 'Janoc.Urbina.Garrido@mailinator.com', '26/04/65', 71, 2);
INSERT INTO usuaris VALUES (1976, 'Enrico', 'Galindo Cervántez', 'H', '70 Ctra. de Siles', 27430, 'Enrico.Galindo.Cervantez@pookmail.com', '08/09/52', 18, 8);
INSERT INTO usuaris VALUES (1977, 'Gesualdo', 'Orta Mena', 'H', '28 Plaza Maior', 37208, 'Gesualdo.Orta.Mena@trashymail.com', '28/11/51', 36, 9);
INSERT INTO usuaris VALUES (1978, 'Kemberley', 'Comejo Ozuna', 'D', '76 Lamas Carbajal', 41620, 'Kemberley.Comejo.Ozuna@mailinator.com', '24/09/74', 54, 10);
INSERT INTO usuaris VALUES (1979, 'Menqui', 'Toro Montemayor', NULL, '91 Valadouro', 48190, 'Menqui.Toro.Montemayor@mailinator.com', '24/10/46', 88, 8);
INSERT INTO usuaris VALUES (1980, 'Máximo', 'Jiménez Pacheco', 'H', '2 Visitación de la Encina', 37720, 'Maximo.Jimenez.Pacheco@trashymail.com', '04/01/55', 1, 9);
INSERT INTO usuaris VALUES (1981, 'Virgil', 'Galarza Soliz', 'H', '6 Plazuela do Porto', 37891, 'Virgil.Galarza.Soliz@dodgit.com', '03/11/66', 15, 4);
INSERT INTO usuaris VALUES (1982, 'Rudolf', 'Zarate Baeza', 'H', '22 Pza. Fuensanta', 32200, 'Rudolf.Zarate.Baeza@mailinator.com', '25/06/54', 90, 1);
INSERT INTO usuaris VALUES (1983, 'Atica', 'Valdez Otero', 'D', '63 La Fontanilla', 14208, 'Atica.Valdez.Otero@pookmail.com', '14/04/54', 94, 7);
INSERT INTO usuaris VALUES (1984, 'Amaranto', 'Roldán Beltrán', 'H', '43 Avda. Andalucía', 26134, 'Amaranto.Roldan.Beltran@dodgit.com', '03/08/75', 11, 9);
INSERT INTO usuaris VALUES (1985, 'Escolástica', 'Jáquez Rocha', 'D', '52 Carretera Cádiz-Málaga', 20720, 'Escolastica.Jaquez.Rocha@spambob.com', '03/01/83', 94, 8);
INSERT INTO usuaris VALUES (1986, 'Giorgio', 'Quiroz Montés', 'H', '55 Boriñaur enparantza', 7530, 'Giorgio.Quiroz.Montes@pookmail.com', '08/04/44', 38, 5);
INSERT INTO usuaris VALUES (1987, 'Nilo', 'Bahena Gracia', 'H', '16 Calle Aduana', 1211, 'Nilo.Bahena.Gracia@spambob.com', '23/06/45', 5, 4);
INSERT INTO usuaris VALUES (1988, 'Dulcinea', 'Mena Guerra', 'D', '93 Estrela', 39770, 'Dulcinea.Mena.Guerra@trashymail.com', '27/01/42', 29, 4);
INSERT INTO usuaris VALUES (1989, 'Etelvina', 'Villanueva Jaime', 'D', '78 San Andrés', 37256, 'Etelvina.Villanueva.Jaime@mailinator.com', '16/09/56', 85, 7);
INSERT INTO usuaris VALUES (1990, 'Heidy', 'Alicea Bueno', 'D', '34 Pza. Fuensanta', 32232, 'Heidy.Alicea.Bueno@spambob.com', '03/08/84', 75, 7);
INSERT INTO usuaris VALUES (1991, 'Ulises', 'Villalpando Quezada', 'H', '50 Puerto Lugar', 29791, 'Ulises.Villalpando.Quezada@spambob.com', '22/04/72', 67, 4);
INSERT INTO usuaris VALUES (1992, 'Valentine', 'Ríos Arce', 'D', '10 Inglaterra', 18564, 'Valentine.Rios.Arce@spambob.com', '11/06/77', 15, 11);
INSERT INTO usuaris VALUES (1993, 'Cándida', 'Trejo Galvez', 'D', '61 Fuente del Gallo', 14900, 'Candida.Trejo.Galvez@mailinator.com', '04/06/48', 15, 5);
INSERT INTO usuaris VALUES (1994, 'Irving', 'Negrón Orosco', 'H', '81 Fuente del Gallo', 15165, 'Irving.Negron.Orosco@mailinator.com', '11/01/43', 95, 1);
INSERT INTO usuaris VALUES (1995, 'Teodosio', 'Mesa Ayala', 'H', '50 Puerta Nueva', 36500, 'Teodosio.Mesa.Ayala@pookmail.com', '05/05/49', 79, 1);
INSERT INTO usuaris VALUES (1996, 'Dionne', 'Amaya Almonte', 'D', '12 Rio Segura', 31340, 'Dionne.Amaya.Almonte@spambob.com', '18/02/44', 53, 8);
INSERT INTO usuaris VALUES (1997, 'Florencia', 'Sanches Partida', 'D', '58 Cartagena', 30430, 'Florencia.Sanches.Partida@trashymail.com', '20/06/85', 25, NULL);
INSERT INTO usuaris VALUES (1998, 'Kaukel', 'Muro Huerta', 'H', '48 C/ Los Herrán', 7000, 'Kaukel.Muro.Huerta@mailinator.com', '18/05/44', 78, 7);
INSERT INTO usuaris VALUES (1999, 'Pablo', 'Montez Rodríguez', 'H', '80 Prolongacion San Sebastian', 21290, 'Pablo.Montez.Rodriguez@mailinator.com', '15/12/75', 58, 6);
INSERT INTO usuaris VALUES (2000, 'Ciset', 'Carreón Almanza', 'H', '82 Ctra. Villena', 33950, 'Ciset.Carreon.Almanza@dodgit.com', '31/10/63', 22, NULL);
INSERT INTO usuaris VALUES (2001, 'Cristian', 'Velez Rangel', 'H', '25 Rúa de San Pedro', 37792, 'Cristian.Velez.Rangel@dodgit.com', '26/06/63', 24, 7);
INSERT INTO usuaris VALUES (2002, 'Augusto', 'Amaya Fernández', 'H', '26 Cruce Casa de Postas', 18417, 'Augusto.Amaya.Fernandez@trashymail.com', NULL, 50, 4);
INSERT INTO usuaris VALUES (2003, 'Ezechiele', 'Herrera Espinal', 'H', '32 Estrela', 39509, 'Ezechiele.Herrera.Espinal@mailinator.com', '27/11/76', 83, 12);
INSERT INTO usuaris VALUES (2004, 'Adalbaro', 'Cepeda Montanez', 'H', '85 C/ Señores Curas', 12159, 'Adalbaro.Cepeda.Montanez@trashymail.com', '20/08/77', 0, 2);
INSERT INTO usuaris VALUES (2005, 'Vannina', 'Becerra Melgar', 'D', '50 Avda. de Andalucía', 29320, 'Vannina.Becerra.Melgar@dodgit.com', '10/05/76', 73, NULL);
INSERT INTO usuaris VALUES (2006, 'Eileen', 'Tijerina Paez', 'D', '42 Avenida Cervantes', 48309, 'Eileen.Tijerina.Paez@trashymail.com', '04/07/55', 68, 1);
INSERT INTO usuaris VALUES (2007, 'Orson', 'Sanabria Valdés', 'H', '79 Rúa Olmos', 37400, 'Orson.Sanabria.Valdes@pookmail.com', '20/08/45', 15, 9);
INSERT INTO usuaris VALUES (2008, 'Yanet', 'Meza Segura', 'D', '86 Valadouro', 48142, 'Yanet.Meza.Segura@trashymail.com', '28/02/47', 59, 10);
INSERT INTO usuaris VALUES (2009, 'Liliana', 'Vasquez Ledesma', 'D', '56 Carretera del Muelle', 12414, 'Liliana.Vasquez.Ledesma@dodgit.com', '18/03/54', 63, 1);
INSERT INTO usuaris VALUES (2010, 'Liza', 'Olvera Gallegos', 'D', '54 Avda. Explanada Barnuevo', 35280, 'Liza.Olvera.Gallegos@spambob.com', NULL, 30, 5);
INSERT INTO usuaris VALUES (2011, 'Nolasco', 'Tamez Puga', 'H', '60 Cruce Casa de Postas', 18370, 'Nolasco.Tamez.Puga@spambob.com', '01/06/83', 53, 7);
INSERT INTO usuaris VALUES (2012, 'Exal', 'Olivárez Montenegro', 'D', '58 Calvo Sotelo', 47270, 'Exal.Olivarez.Montenegro@spambob.com', '25/02/73', 88, 5);
INSERT INTO usuaris VALUES (2013, 'Zelmar', 'Serna Madrid', 'H', '89 Quevedo', 15300, 'Zelmar.Serna.Madrid@mailinator.com', '28/04/60', 59, 4);
INSERT INTO usuaris VALUES (2014, 'Verena', 'Apodaca Briones', 'D', '83 Celso Emilio Ferreiro', 50540, 'Verena.Apodaca.Briones@spambob.com', '03/11/60', 4, 3);
INSERT INTO usuaris VALUES (2015, 'Hedda', 'Villalobos Orta', 'D', '39 Bellavista', 49600, 'Hedda.Villalobos.Orta@spambob.com', '06/03/47', 10, NULL);
INSERT INTO usuaris VALUES (2016, 'Alec', 'Meza Quesada', 'H', '49 Urzáiz', 45300, 'Alec.Meza.Quesada@trashymail.com', '29/12/63', 55, 10);
INSERT INTO usuaris VALUES (2017, 'Argentino', 'Villaseñor Cortez', 'H', '99 C/ Fernández de Leceta', 3350, 'Argentino.Villasenor.Cortez@trashymail.com', '23/01/41', 60, 3);
INSERT INTO usuaris VALUES (2018, 'Andrómeda', 'Gamboa Salinas', 'D', '13 Enxertos', 37592, 'Andromeda.Gamboa.Salinas@spambob.com', '02/03/52', 9, 6);
INSERT INTO usuaris VALUES (2019, 'Wenceslao', 'Vasquez Mora', 'H', '48 Enxertos', 37530, 'Wenceslao.Vasquez.Mora@mailinator.com', '29/01/59', 12, 7);
INSERT INTO usuaris VALUES (2020, 'Malvina', 'García Carranza', 'D', '34 Prolongacion San Sebastian', 21369, 'Malvina.Garcia.Carranza@trashymail.com', '24/01/85', 86, 5);
INSERT INTO usuaris VALUES (2021, 'Errolán', 'Meza Lucio', 'H', '12 C/ Rosa de los Vientos', 11500, 'Errolan.Meza.Lucio@pookmail.com', '22/07/55', 63, 5);
INSERT INTO usuaris VALUES (2022, 'Sein', 'Flórez Borrego', 'H', '17 Plaza de España', 15685, 'Sein.Florez.Borrego@trashymail.com', '28/05/80', 82, 6);
INSERT INTO usuaris VALUES (2023, 'Karitte', 'Murillo Nazario', 'D', '73 Cádiz', 18518, 'Karitte.Murillo.Nazario@pookmail.com', '03/10/77', 29, 2);
INSERT INTO usuaris VALUES (2024, 'Fito', 'Veliz Torres', 'H', '41 Quevedo', 15350, 'Fito.Veliz.Torres@spambob.com', '27/07/56', 1, 8);
INSERT INTO usuaris VALUES (2025, 'Ida', 'Padrón Arenas', 'D', '80 Puerto Lugar', 29755, 'Ida.Padron.Arenas@pookmail.com', '08/11/40', 67, 2);
INSERT INTO usuaris VALUES (2026, 'Vilfredo', 'Flores Armijo', 'H', '97 Puerta Nueva', 36450, 'Vilfredo.Flores.Armijo@spambob.com', '20/08/46', 60, NULL);
INSERT INTO usuaris VALUES (2027, 'Mirabel', 'Tórrez Arenas', 'D', '40 Ctra. de la Puerta', 27113, 'Mirabel.Torrez.Arenas@mailinator.com', '24/01/78', 58, 4);
INSERT INTO usuaris VALUES (2028, 'Custodio', 'Galarza Vela', 'H', '51 Constitución', 37110, 'Custodio.Galarza.Vela@trashymail.com', '29/06/85', 72, NULL);
INSERT INTO usuaris VALUES (2029, 'Basa', 'Aranda Ballesteros', 'D', '47 Padre Caro', 13640, 'Basa.Aranda.Ballesteros@spambob.com', '27/01/56', 60, 12);
INSERT INTO usuaris VALUES (2030, 'Jael', 'Aparicio Zelaya', 'D', '31 Calle Carril de la Fuente', 13194, 'Jael.Aparicio.Zelaya@mailinator.com', '14/12/64', 26, 1);
INSERT INTO usuaris VALUES (2031, 'Araceli', 'Vázquez Villalpando', 'D', '14 Castelao', 48990, 'Araceli.Vazquez.Villalpando@spambob.com', '12/06/66', 6, 8);
INSERT INTO usuaris VALUES (2032, 'Jezabel', 'Salcido Viera', 'D', '54 Cartagena', 30600, 'Jezabel.Salcido.Viera@pookmail.com', '11/10/70', 75, 8);
INSERT INTO usuaris VALUES (2033, 'Manfredo', 'Rodarte Regalado', 'H', '44 Atamaria', 36600, 'Manfredo.Rodarte.Regalado@mailinator.com', '12/12/81', 17, 8);
INSERT INTO usuaris VALUES (2034, 'Valiant', 'Tejeda Bonilla', 'D', '6 Paraguay', 3680, 'Valiant.Tejeda.Bonilla@mailinator.com', '30/10/40', 18, 9);
INSERT INTO usuaris VALUES (2035, 'Illcapil', 'Rodrígez Ibarra', 'D', '36 Avda. Generalísimo', 31560, 'Illcapil.Rodrigez.Ibarra@mailinator.com', '14/01/58', 68, 1);
INSERT INTO usuaris VALUES (2036, 'Leonilda', 'Zavala Almanza', 'D', '81 C/ Angosto', 23450, 'Leonilda.Zavala.Almanza@spambob.com', '17/09/65', 23, 11);
INSERT INTO usuaris VALUES (2037, 'Lope', 'Llarnas Briones', 'H', '89 C/ Andalucía', 4830, 'Lope.Llarnas.Briones@spambob.com', '12/08/83', 50, 1);
INSERT INTO usuaris VALUES (2038, 'Zofía', 'Roque Moreno', 'D', '21 Escuadro', 46841, 'Zofia.Roque.Moreno@pookmail.com', '02/01/52', 34, 1);
INSERT INTO usuaris VALUES (2039, 'Heinz', 'Cantú Jimínez', 'H', '33 Antonio Vázquez', 38530, 'Heinz.Cantu.Jiminez@spambob.com', '15/06/62', 75, 1);
INSERT INTO usuaris VALUES (2040, 'Gail', 'Pelayo Barela', 'D', '68 Cartagena', 30540, 'Gail.Pelayo.Barela@pookmail.com', '15/09/63', 72, 1);
INSERT INTO usuaris VALUES (2041, 'Lala', 'Gallegos Cepeda', 'D', '51 Avda. de Andalucía', 29312, 'Lala.Gallegos.Cepeda@pookmail.com', '17/07/78', 23, 3);
INSERT INTO usuaris VALUES (2042, 'Abdón', 'Madrigal Caldera', 'H', '60 Escuadro', 46860, 'Abdon.Madrigal.Caldera@spambob.com', '01/04/44', 87, 6);
INSERT INTO usuaris VALUES (2043, 'Agnes', 'Garibay Laboy', 'D', '28 Ctra. Villena', 34800, 'Agnes.Garibay.Laboy@pookmail.com', '17/09/62', 94, 4);
INSERT INTO usuaris VALUES (2044, 'Aristóbulo', 'Ocampo Tirado', 'H', '29 Calvo Sotelo', 47320, 'Aristobulo.Ocampo.Tirado@trashymail.com', '27/11/73', 97, 8);
INSERT INTO usuaris VALUES (2045, 'Luján', 'Santana Correa', 'H', '94 La Fontanilla', 14412, 'Lujan.Santana.Correa@mailinator.com', '17/10/49', 60, 6);
INSERT INTO usuaris VALUES (2046, 'Hassan', 'Solorio Olvera', 'H', '51 Puerto Lugar', 29719, 'Hassan.Solorio.Olvera@spambob.com', '05/12/63', 10, 2);
INSERT INTO usuaris VALUES (2047, 'Ceumar', 'Nazario Ybarra', 'H', '38 C/ Amoladera', 28815, 'Ceumar.Nazario.Ybarra@trashymail.com', '31/05/74', 61, 3);
INSERT INTO usuaris VALUES (2048, 'Valquiria', 'Gamboa Cordero', 'D', '6 Puerta Nueva', 36300, 'Valquiria.Gamboa.Cordero@dodgit.com', '23/02/54', 44, 7);
INSERT INTO usuaris VALUES (2049, 'Sophie', 'Covas Gamez', 'D', '57 José matía', 2124, 'Sophie.Covas.Gamez@trashymail.com', '08/12/44', 46, 8);
INSERT INTO usuaris VALUES (2050, 'Allison', 'Barajas Ceballos', 'D', '6 C/ Arana', 2435, 'Allison.Barajas.Ceballos@mailinator.com', '25/09/53', 64, 1);
INSERT INTO usuaris VALUES (2051, 'Eulogius', 'Cazares Velasco', 'H', '92 Cádiz', 18438, 'Eulogius.Cazares.Velasco@dodgit.com', '26/11/64', 75, 8);
INSERT INTO usuaris VALUES (2052, 'Rufo', 'Samaniego Iglesias', 'H', '22 C/ Libertad', 5200, 'Rufo.Samaniego.Iglesias@pookmail.com', '31/05/64', 7, 8);
INSERT INTO usuaris VALUES (2053, 'Dulas', 'Barrios Méndez', 'H', '26 Calle Aduana', 1340, 'Dulas.Barrios.Mendez@mailinator.com', '04/12/56', 5, 12);
INSERT INTO usuaris VALUES (2054, 'Elea', 'Cordero Cervantes', 'D', '22 Carretera del Muelle', 12311, 'Elea.Cordero.Cervantes@pookmail.com', '01/01/48', 17, 10);
INSERT INTO usuaris VALUES (2055, 'Oleguer', 'Orta Treviño', 'H', '9 Avda. de Andalucía', 29328, 'Oleguer.Orta.Trevino@trashymail.com', '18/08/74', 69, 1);
INSERT INTO usuaris VALUES (2056, 'Cintia', 'Árias Chávez', 'D', '6 Avda. de la Estación', 28609, 'Cintia.Arias.Chavez@pookmail.com', '28/04/49', 41, 10);
INSERT INTO usuaris VALUES (2057, 'Rómula', 'Covas Amador', 'D', '5 Ctra. de Fuentenueva', 28270, 'Romula.Covas.Amador@pookmail.com', '30/12/44', 22, 8);
INSERT INTO usuaris VALUES (2058, 'Gregoria', 'Guerrero Gaitán', NULL, '46 Ctra. Bailén-Motril', 23370, 'Gregoria.Guerrero.Gaitan@pookmail.com', '24/03/47', 90, 7);
INSERT INTO usuaris VALUES (2059, 'Celma', 'Valladares Jurado', 'D', '82 Caño', 32812, 'Celma.Valladares.Jurado@trashymail.com', '27/11/46', 27, NULL);
INSERT INTO usuaris VALUES (2060, 'Sam', 'Rincón Castellanos', 'H', '54 Escuadro', 47140, 'Sam.Rincon.Castellanos@trashymail.com', '10/03/40', 96, 3);
INSERT INTO usuaris VALUES (2061, 'Yael', 'Martínez Cabán', NULL, '54 Paseo del Atlántico', 18131, 'Yael.Martinez.Caban@trashymail.com', '17/10/79', 57, 3);
INSERT INTO usuaris VALUES (2062, 'Gisel', 'Ortega Solano', 'D', '39 Avenida Cervantes', 48292, 'Gisel.Ortega.Solano@spambob.com', '05/10/85', 5, NULL);
INSERT INTO usuaris VALUES (2063, 'Palmira', 'Salcedo Correa', 'D', '42 C/ Domingo Beltrán', 2230, 'Palmira.Salcedo.Correa@dodgit.com', '22/03/68', 75, 8);
INSERT INTO usuaris VALUES (2064, 'Joanes', 'Luján Carrasquill', 'H', '33 Ctra. Bailén-Motril', 23280, 'Joanes.Lujan.Carrasquill@mailinator.com', '04/04/50', 85, NULL);
INSERT INTO usuaris VALUES (2065, 'Ovidio', 'Grijalva Rolón', 'H', '42 Zumalakarregi etorbidea', 7250, 'Ovidio.Grijalva.Rolon@trashymail.com', '20/10/56', 21, 3);
INSERT INTO usuaris VALUES (2066, 'Heldo', 'Rangel Urbina', 'H', '3 Caño', 33114, 'Heldo.Rangel.Urbina@pookmail.com', '27/03/43', 78, 4);
INSERT INTO usuaris VALUES (2067, 'Sira', 'Saucedo Terán', NULL, '30 Lamas Carbajal', 41657, 'Sira.Saucedo.Teran@pookmail.com', '03/02/58', 77, 8);
INSERT INTO usuaris VALUES (2068, 'Adara', 'Soliz Godoy', 'D', '81 Estrela', 39577, 'Adara.Soliz.Godoy@spambob.com', '04/11/80', 42, 2);
INSERT INTO usuaris VALUES (2069, 'Christine', 'Carvajal Quiroz', 'D', '35 Ctra. de la Puerta', 26588, 'Christine.Carvajal.Quiroz@pookmail.com', '06/11/83', 13, 9);
INSERT INTO usuaris VALUES (2070, 'Thais', 'Olivera Esquibel', 'D', '92 Socampo', 37684, 'Thais.Olivera.Esquibel@mailinator.com', '23/08/40', 92, 5);
INSERT INTO usuaris VALUES (2071, 'Anian', 'Alva Mateo', 'D', '51 Ctra. Hornos', 26222, 'Anian.Alva.Mateo@mailinator.com', '23/11/41', 81, 9);
INSERT INTO usuaris VALUES (2072, 'Natal', 'Haro Muñoz', 'H', '82 Paraguay', 3700, 'Natal.Haro.Munoz@mailinator.com', '30/09/45', 41, 4);
INSERT INTO usuaris VALUES (2073, 'Ottón', 'Casanova Menchaca', 'H', '95 Rua da Rapina', 37487, 'Otton.Casanova.Menchaca@dodgit.com', '17/11/41', 69, 4);
INSERT INTO usuaris VALUES (2074, 'Daff', 'Vargas Gallardo', 'D', '40 Ctra. Bailén-Motril', 23300, 'Daff.Vargas.Gallardo@dodgit.com', '15/12/85', 78, 10);
INSERT INTO usuaris VALUES (2075, 'Gulmen', 'Irizarry Alvarado', 'H', '76 C/ Señores Curas', 11659, 'Gulmen.Irizarry.Alvarado@dodgit.com', '08/10/58', 55, 2);
INSERT INTO usuaris VALUES (2076, 'Dalmacio', 'Tamayo Farías', 'H', '72 El Roqueo', 16630, 'Dalmacio.Tamayo.Farias@trashymail.com', '30/04/74', 53, 7);
INSERT INTO usuaris VALUES (2077, 'Mael', 'Muñoz Ojeda', 'H', '90 Calle Carril de la Fuente', 13200, 'Mael.Munoz.Ojeda@pookmail.com', '27/04/50', 11, 7);
INSERT INTO usuaris VALUES (2078, 'Nicomedes', 'Paz Velez', 'H', '47 Urzáiz', 45470, 'Nicomedes.Paz.Velez@pookmail.com', '24/02/48', 14, 12);
INSERT INTO usuaris VALUES (2079, 'Geppe', 'Salinas Rael', 'H', '19 Outid de Arriba', 43519, 'Geppe.Salinas.Rael@dodgit.com', '23/08/68', 46, 3);
INSERT INTO usuaris VALUES (2080, 'Crisólogo', 'Peralta Carbajal', 'H', '44 Visitación de la Encina', 37725, 'Crisologo.Peralta.Carbajal@trashymail.com', '26/05/82', 61, 5);
INSERT INTO usuaris VALUES (2081, 'Querubín', 'Montoya Meza', 'H', '30 Calle Carril de la Fuente', 13195, 'Querubin.Montoya.Meza@spambob.com', '19/05/40', 14, 7);
INSERT INTO usuaris VALUES (2082, 'Antipas', 'Meza Zapata', 'H', '44 C/ Cañada del Rosal', 21668, 'Antipas.Meza.Zapata@pookmail.com', '29/11/49', 35, 12);
INSERT INTO usuaris VALUES (2083, 'Rudolph', 'Pulido Corona', 'H', '23 Valadouro', 48160, 'Rudolph.Pulido.Corona@pookmail.com', '13/06/58', 89, 10);
INSERT INTO usuaris VALUES (2084, 'Winni', 'Ceballos Franco', 'D', '28 Herrería', 18210, 'Winni.Ceballos.Franco@spambob.com', '15/05/67', 68, 10);
INSERT INTO usuaris VALUES (2085, 'Angus', 'Alonso Pena', 'H', '58 Bouciña', 43830, 'Angus.Alonso.Pena@dodgit.com', '23/01/42', 97, 11);
INSERT INTO usuaris VALUES (2086, 'Adriadna', 'Carrasco Serna', 'D', '36 Plaza Maior', 37219, 'Adriadna.Carrasco.Serna@pookmail.com', '14/10/66', 82, NULL);
INSERT INTO usuaris VALUES (2087, 'Hugolino', 'Vaca Solórzano', 'H', '16 C/ Hijuela de Lojo', 20300, 'Hugolino.Vaca.Solorzano@dodgit.com', '23/10/74', 27, 7);
INSERT INTO usuaris VALUES (2088, 'Valentín', 'Mora Alejandro', 'H', '87 San Andrés', 37247, 'Valentin.Mora.Alejandro@dodgit.com', '25/11/40', 96, 3);
INSERT INTO usuaris VALUES (2089, 'Melibeo', 'Velázquez Irizarry', 'H', '8 Carretera Cádiz-Málaga', 20560, 'Melibeo.Velazquez.Irizarry@trashymail.com', '17/10/46', 39, 5);
INSERT INTO usuaris VALUES (2090, 'Dimas', 'Zaragoza Noriega', 'H', '25 Ctra. de Siles', 27650, 'Dimas.Zaragoza.Noriega@trashymail.com', '03/02/61', 34, 11);
INSERT INTO usuaris VALUES (2091, 'Delfín', 'Ornelas Comejo', 'H', '30 Ctra. Hornos', 26225, 'Delfin.Ornelas.Comejo@mailinator.com', NULL, 69, 12);
INSERT INTO usuaris VALUES (2092, 'Vito', 'Segovia Lebrón', 'H', '77 Calvo Sotelo', 47491, 'Vito.Segovia.Lebron@trashymail.com', '25/02/67', 80, 3);
INSERT INTO usuaris VALUES (2093, 'Homero', 'Razo Barraza', 'H', '34 Paseo del Atlántico', 18110, 'Homero.Razo.Barraza@mailinator.com', '20/12/77', 16, 12);
INSERT INTO usuaris VALUES (2094, 'Jack', 'Arce Valdez', 'H', '97 Avda. de la Estación', 28720, 'Jack.Arce.Valdez@spambob.com', '23/06/45', 51, NULL);
INSERT INTO usuaris VALUES (2095, 'Maida', 'Casas Sepúlveda', 'D', '78 Canónigo Valiño', 46460, 'Maida.Casas.Sepulveda@mailinator.com', '05/11/49', 73, 2);
INSERT INTO usuaris VALUES (2096, 'Ralph', 'Salcedo Rivas', 'H', '43 Cercas Bajas', 7860, 'Ralph.Salcedo.Rivas@dodgit.com', '04/05/57', 67, 10);
INSERT INTO usuaris VALUES (2097, 'Presentación', 'Chapa Barreto', 'D', '40 Canónigo Valiño', 46210, 'Presentacion.Chapa.Barreto@mailinator.com', '09/03/84', 43, 12);
INSERT INTO usuaris VALUES (2098, 'Pelayo', 'Velasco Lerma', 'H', '17 Reiseñor', 46160, 'Pelayo.Velasco.Lerma@pookmail.com', '29/12/60', 28, 3);
INSERT INTO usuaris VALUES (2099, 'Folco', 'Acosta Santacruz', 'H', '5 Comandante Izarduy', 9210, 'Folco.Acosta.Santacruz@dodgit.com', '24/06/75', 55, 9);
INSERT INTO usuaris VALUES (2100, 'Agesislao', 'Casares Najera', 'H', '65 Zumalakarregi etorbidea', 7260, 'Agesislao.Casares.Najera@dodgit.com', '07/07/44', 54, 2);
INSERT INTO usuaris VALUES (2101, 'Luisina', 'Dueñas Hurtado', 'D', '79 Rio Segura', 31390, 'Luisina.Duenas.Hurtado@mailinator.com', '22/11/47', 26, 3);
INSERT INTO usuaris VALUES (2102, 'Nuria', 'Bernal Valdivia', 'D', '67 Ctra. Beas-Cortijos Nuevos', 26530, 'Nuria.Bernal.Valdivia@mailinator.com', '07/08/80', 81, 2);
INSERT INTO usuaris VALUES (2103, 'Cruz', 'Salcedo Ortiz', 'H', '66 José matía', 2154, 'Cruz.Salcedo.Ortiz@spambob.com', '24/10/53', 32, 1);
INSERT INTO usuaris VALUES (2104, 'Anelsy', 'Zambrano Paz', 'D', '17 Constitución', 36900, 'Anelsy.Zambrano.Paz@trashymail.com', '17/07/77', 67, 7);
INSERT INTO usuaris VALUES (2105, 'Justina', 'Leiva Viera', 'D', '37 Ctra. de Fuentenueva', 28213, 'Justina.Leiva.Viera@trashymail.com', '02/05/52', 1, 9);
INSERT INTO usuaris VALUES (2106, 'Iona', 'Orellana Hernádez', 'D', '65 C/ Domingo Beltrán', 2310, 'Iona.Orellana.Hernadez@trashymail.com', '28/03/69', 80, 6);
INSERT INTO usuaris VALUES (2107, 'Thalia', 'Jurado Bravo', 'D', '31 Lamas Carbajal', 41568, 'Thalia.Jurado.Bravo@spambob.com', '23/03/43', 25, NULL);
INSERT INTO usuaris VALUES (2108, 'Salvator', 'Terán Perales', 'H', '89 C/ Amoladera', 28811, 'Salvator.Teran.Perales@dodgit.com', '24/04/81', 93, 1);
INSERT INTO usuaris VALUES (2109, 'Catón', 'Mayonga Valenzuela', 'H', '50 Avendaño', 4400, 'Caton.Mayonga.Valenzuela@spambob.com', '18/12/56', 28, 7);
INSERT INTO usuaris VALUES (2110, 'Cirila', 'Burgos Vergara', 'D', '37 Alcon Molina', 30730, 'Cirila.Burgos.Vergara@dodgit.com', '14/02/52', 80, NULL);
INSERT INTO usuaris VALUES (2111, 'Katherine', 'Valentín Girón', NULL, '10 Avda. Generalísimo', 31860, 'Katherine.Valentin.Giron@dodgit.com', '18/04/66', 65, 2);
INSERT INTO usuaris VALUES (2112, 'Pío', 'Limón Valenzuela', 'H', '15 C/ Fernández de Leceta', 3518, 'Pio.Limon.Valenzuela@spambob.com', '01/06/83', 81, 1);
INSERT INTO usuaris VALUES (2113, 'Nandor', 'Estévez Saucedo', 'H', '9 Socampo', 37691, 'Nandor.Estevez.Saucedo@dodgit.com', '25/02/84', 23, 11);
INSERT INTO usuaris VALUES (2114, 'Dalmacio', 'Rentería Dávila', 'H', '7 C/ Domingo Beltrán', 2215, 'Dalmacio.Renteria.Davila@spambob.com', '05/02/48', 10, 2);
INSERT INTO usuaris VALUES (2115, 'Agalia', 'Hurtado Quiñones', 'D', '76 Reyes Católicos', 9550, 'Agalia.Hurtado.Quinones@dodgit.com', '27/09/72', 87, 4);
INSERT INTO usuaris VALUES (2116, 'Girzie', 'Varela Olivares', 'D', '8 Outid de Arriba', 43719, 'Girzie.Varela.Olivares@dodgit.com', '03/02/47', 54, 8);
INSERT INTO usuaris VALUES (2117, 'Guaraci', 'Guzmán Pedroza', 'D', '47 C/ Fernández de Leceta', 3369, 'Guaraci.Guzman.Pedroza@pookmail.com', '07/06/56', 98, 4);
INSERT INTO usuaris VALUES (2118, 'Nabil', 'Lomeli Otero', 'H', '39 Cruce Casa de Postas', 18420, 'Nabil.Lomeli.Otero@mailinator.com', '13/09/56', 96, 5);
INSERT INTO usuaris VALUES (2119, 'Laercio', 'Naranjo Gaytan', 'H', '66 Calle Carril de la Fuente', 13190, 'Laercio.Naranjo.Gaytan@pookmail.com', '23/04/54', 22, 11);
INSERT INTO usuaris VALUES (2120, 'Nataly', 'Guardado Lovato', 'D', '23 Rua da Rapina', 37485, 'Nataly.Guardado.Lovato@spambob.com', '22/03/40', 98, 8);
INSERT INTO usuaris VALUES (2121, 'Olinda', 'Huerta Ibarra', 'D', '63 Estrela', 39200, 'Olinda.Huerta.Ibarra@mailinator.com', '01/10/44', 40, 4);
INSERT INTO usuaris VALUES (2122, 'Debra', 'Padrón Alcaraz', 'D', '3 Estrela', 40000, 'Debra.Padron.Alcaraz@pookmail.com', '15/02/79', 29, 4);
INSERT INTO usuaris VALUES (2123, 'Agesislao', 'Curiel Flores', 'H', '64 Reiseñor', 46134, 'Agesislao.Curiel.Flores@dodgit.com', '19/06/70', 40, 12);
INSERT INTO usuaris VALUES (2124, 'Circe', 'Medrano Franco', 'D', '34 El Roqueo', 16220, 'Circe.Medrano.Franco@dodgit.com', '17/09/46', 78, 8);
INSERT INTO usuaris VALUES (2125, 'Eliel', 'Raya Fonseca', 'H', '94 Cruce Casa de Postas', 18280, 'Eliel.Raya.Fonseca@trashymail.com', '01/06/67', 69, 8);
INSERT INTO usuaris VALUES (2126, 'Ulpiano', 'Prieto Hidalgo', 'H', '3 C/ Fernández de Leceta', 3380, 'Ulpiano.Prieto.Hidalgo@spambob.com', '22/02/79', 89, 4);
INSERT INTO usuaris VALUES (2127, 'Asela', 'Mares Tirado', 'D', '99 Avda. de la Estación', 28607, 'Asela.Mares.Tirado@spambob.com', '28/12/52', 58, 4);
INSERT INTO usuaris VALUES (2128, 'Zemira', 'Longoria Calderón', NULL, '69 Maestro Puig Valera', 33820, 'Zemira.Longoria.Calderon@spambob.com', '31/07/80', 63, 7);
INSERT INTO usuaris VALUES (2129, 'Karla', 'Vasquez Riojas', 'D', '70 Camiño Real', 48392, 'Karla.Vasquez.Riojas@mailinator.com', '17/10/58', 86, 3);
INSERT INTO usuaris VALUES (2130, 'Orieta', 'Puga Estévez', 'D', '92 Fuente del Gallo', 14930, 'Orieta.Puga.Estevez@pookmail.com', '30/12/55', 31, 4);
INSERT INTO usuaris VALUES (2131, 'Luken', 'Casas Najera', 'H', '85 Ourense', 42300, 'Luken.Casas.Najera@dodgit.com', '13/07/40', 26, 7);
INSERT INTO usuaris VALUES (2132, 'Calímaco', 'Peres Abeyta', 'H', '17 Calle Carril de la Fuente', 13195, 'Calimaco.Peres.Abeyta@pookmail.com', '24/12/41', 48, 6);
INSERT INTO usuaris VALUES (2133, 'Josías', 'Meraz Ceballos', 'H', '63 Puerta Nueva', 35572, 'Josias.Meraz.Ceballos@pookmail.com', '04/07/84', 69, 10);
INSERT INTO usuaris VALUES (2134, 'Jésica', 'Morales Pagan', NULL, '31 C/ Benito Guinea', 8397, 'Jesica.Morales.Pagan@spambob.com', '08/12/69', 89, 1);
INSERT INTO usuaris VALUES (2135, 'Hugolina', 'Loya Cisneros', 'D', '92 Rio Segura', 31300, 'Hugolina.Loya.Cisneros@trashymail.com', '08/07/72', 79, 11);
INSERT INTO usuaris VALUES (2136, 'Karitte', 'Centeno Rojo', 'D', '97 C/ Henan Cortes', 29170, 'Karitte.Centeno.Rojo@trashymail.com', '23/04/71', 66, 11);
INSERT INTO usuaris VALUES (2137, 'Liam', 'Reynoso Carrasco', 'H', '89 C/ Canarias', 20180, 'Liam.Reynoso.Carrasco@pookmail.com', '15/06/54', 39, 12);
INSERT INTO usuaris VALUES (2138, 'Eufrasio', 'Garay Esparza', 'H', '94 Canónigo Valiño', 46290, 'Eufrasio.Garay.Esparza@dodgit.com', '09/02/84', 29, 4);
INSERT INTO usuaris VALUES (2139, 'Desiderio', 'Madrid Jáquez', 'H', '22 C/ Señores Curas', 12135, 'Desiderio.Madrid.Jaquez@spambob.com', '15/02/68', 47, 12);
INSERT INTO usuaris VALUES (2140, 'Janvier', 'Ocampo Nazario', 'H', '15 Prolongacion San Sebastian', 21220, 'Janvier.Ocampo.Nazario@dodgit.com', '16/01/45', 23, 11);
INSERT INTO usuaris VALUES (2141, 'Elsira', 'Pelayo Alba', 'D', '23 Lamas Carbajal', 41580, 'Elsira.Pelayo.Alba@dodgit.com', '06/08/77', 8, 3);
INSERT INTO usuaris VALUES (2142, 'Caitán', 'Abreu Calvillo', 'H', '75 Bouciña', 43791, 'Caitan.Abreu.Calvillo@spambob.com', '16/08/46', 51, 4);
INSERT INTO usuaris VALUES (2143, 'Dagoberto', 'Olivárez Cavazos', 'H', '63 Reyes Católicos', 10000, 'Dagoberto.Olivarez.Cavazos@pookmail.com', '05/07/56', 42, 10);
INSERT INTO usuaris VALUES (2144, 'Eulogius', 'Murillo Peres', 'H', '92 Crta. Cádiz-Málaga', 12200, 'Eulogius.Murillo.Peres@mailinator.com', '27/03/69', 6, 8);
INSERT INTO usuaris VALUES (2145, 'Adelardo', 'Tórrez Reyna', 'H', '43 Visitación de la Encina', 37694, 'Adelardo.Torrez.Reyna@trashymail.com', '05/07/45', 58, 10);
INSERT INTO usuaris VALUES (2146, 'Clide', 'Vigil Anguiano', 'D', '43 C/ Henan Cortes', 29100, 'Clide.Vigil.Anguiano@trashymail.com', '15/09/46', 84, 11);
INSERT INTO usuaris VALUES (2147, 'Merlín', 'Pina Núñez', 'H', '5 Ctra. Beas-Cortijos Nuevos', 26370, 'Merlin.Pina.Nunez@trashymail.com', '15/05/51', 28, 8);
INSERT INTO usuaris VALUES (2148, 'Verona', 'Lozano Tejada', 'D', '82 Ventanilla de Beas', 27836, 'Verona.Lozano.Tejada@pookmail.com', '15/06/75', 82, 6);
INSERT INTO usuaris VALUES (2149, 'Omaro', 'Aguilera Bonilla', 'H', '86 C/ Fernández de Leceta', 3459, 'Omaro.Aguilera.Bonilla@trashymail.com', '22/02/53', 68, 6);
INSERT INTO usuaris VALUES (2150, 'Takara', 'Olmos Colunga', 'D', '39 Cruce Casa de Postas', 18310, 'Takara.Olmos.Colunga@trashymail.com', '01/02/82', 36, 4);
INSERT INTO usuaris VALUES (2151, 'Tarsilia', 'Alicea Villanueva', 'D', '21 C/ Angosto', 23568, 'Tarsilia.Alicea.Villanueva@trashymail.com', '22/12/46', 33, NULL);
INSERT INTO usuaris VALUES (2152, 'Ghita', 'Noriega Rentería', 'D', '5 Rúa Olmos', 37406, 'Ghita.Noriega.Renteria@mailinator.com', '15/01/61', 17, 12);
INSERT INTO usuaris VALUES (2153, 'Grau', 'Lemus Carreón', 'H', '68 José matía', 2153, 'Grau.Lemus.Carreon@pookmail.com', '13/02/64', 5, 4);
INSERT INTO usuaris VALUES (2154, 'Janoc', 'Tamayo Sisneros', 'H', '98 Herrería', 18152, 'Janoc.Tamayo.Sisneros@pookmail.com', '07/02/51', 63, 11);
INSERT INTO usuaris VALUES (2155, 'Anabel', 'Alvarado Acosta', 'D', '74 C/ Angosto', 23440, 'Anabel.Alvarado.Acosta@mailinator.com', '10/08/46', 90, 10);
INSERT INTO usuaris VALUES (2156, 'Dolly', 'Solís Vanegas', 'D', '24 Constitución', 37100, 'Dolly.Solis.Vanegas@pookmail.com', '13/08/46', 66, 2);
INSERT INTO usuaris VALUES (2157, 'Randolfo', 'Verduzco Ríos', 'H', '58 Avda. de la Estación', 28649, 'Randolfo.Verduzco.Rios@dodgit.com', '24/06/41', 97, NULL);
INSERT INTO usuaris VALUES (2158, 'Florentino', 'Rendón Matos', 'H', '99 José matía', 2154, 'Florentino.Rendon.Matos@pookmail.com', '18/07/44', 58, 3);
INSERT INTO usuaris VALUES (2159, 'Jose', 'Tello Arce', 'H', '87 Avda. Los llanos', 26280, 'Jose.Tello.Arce@pookmail.com', '27/10/57', 19, 6);
INSERT INTO usuaris VALUES (2160, 'Jenifer', 'Brito Sánchez', 'D', '6 Paseo Junquera', 12526, 'Jenifer.Brito.Sanchez@dodgit.com', '26/08/54', 83, 7);
INSERT INTO usuaris VALUES (2161, 'Lonhard', 'Espino Paz', 'H', '76 Ctra. Beas-Cortijos Nuevos', 26512, 'Lonhard.Espino.Paz@trashymail.com', '11/12/80', 23, NULL);
INSERT INTO usuaris VALUES (2162, 'Odilón', 'Romo Arroyo', 'H', '61 Salzillo', 32625, 'Odilon.Romo.Arroyo@dodgit.com', '24/11/47', 2, 2);
INSERT INTO usuaris VALUES (2163, 'Larisa', 'Esparza Montero', 'D', '64 C/ Amoladera', 28818, 'Larisa.Esparza.Montero@pookmail.com', '31/03/56', 35, 5);
INSERT INTO usuaris VALUES (2164, 'Cleodora', 'Uribe Meza', 'D', '84 C/ Fernández de Leceta', 3459, 'Cleodora.Uribe.Meza@mailinator.com', '01/07/66', 27, 11);
INSERT INTO usuaris VALUES (2165, 'Nominanda', 'Mora Salas', 'D', '33 Caño', 33117, 'Nominanda.Mora.Salas@dodgit.com', '17/08/77', 96, 8);
INSERT INTO usuaris VALUES (2166, 'Nicholas', 'Escobedo Valles', 'H', '29 Avda. Los llanos', 26270, 'Nicholas.Escobedo.Valles@dodgit.com', '01/07/48', 27, 1);
INSERT INTO usuaris VALUES (2167, 'Vladimir', 'Alcaraz Manzanares', 'H', '64 Ctra. de la Puerta', 26587, 'Vladimir.Alcaraz.Manzanares@mailinator.com', '10/10/48', 3, 3);
INSERT INTO usuaris VALUES (2168, 'Arabela', 'Gaytan Viera', 'D', '75 Paseo del Atlántico', 18126, 'Arabela.Gaytan.Viera@mailinator.com', '10/06/68', 83, 5);
INSERT INTO usuaris VALUES (2169, 'Theodora', 'Estévez Uribe', 'D', '22 Lamas Carbajal', 41650, 'Theodora.Estevez.Uribe@spambob.com', NULL, 10, 3);
INSERT INTO usuaris VALUES (2170, 'Stanislao', 'Barragán Díaz', 'H', '88 Salzillo', 32689, 'Stanislao.Barragan.Diaz@mailinator.com', '02/09/75', 6, 11);
INSERT INTO usuaris VALUES (2171, 'Wanda', 'Roybal Ramos', 'D', '17 Bouciña', 43890, 'Wanda.Roybal.Ramos@pookmail.com', '28/09/48', 16, 5);
INSERT INTO usuaris VALUES (2172, 'Elba', 'Carrión Sanabria', 'D', '96 Ctra. Hornos', 26215, 'Elba.Carrion.Sanabria@dodgit.com', '23/12/52', 57, 4);
INSERT INTO usuaris VALUES (2173, 'Ebe', 'Paez Chacón', NULL, '99 C/ Domingo Beltrán', 2315, 'Ebe.Paez.Chacon@dodgit.com', '05/03/66', 49, 12);
INSERT INTO usuaris VALUES (2174, 'Gigí', 'Escobedo Valadez', 'D', '93 Ventanilla de Beas', 27740, 'Gigi.Escobedo.Valadez@pookmail.com', '02/08/62', 79, 7);
INSERT INTO usuaris VALUES (2175, 'Recaredo', 'Lucio Peralta', 'H', '48 Puerta Nueva', 36140, 'Recaredo.Lucio.Peralta@mailinator.com', '12/08/47', 2, 2);
INSERT INTO usuaris VALUES (2176, 'Loreley', 'Casas Matías', 'D', '75 C/ Canarias', 20211, 'Loreley.Casas.Matias@dodgit.com', '15/05/54', 73, 1);
INSERT INTO usuaris VALUES (2177, 'Jan', 'Mondragón Moreno', 'H', '96 Carretera del Muelle', 12415, 'Jan.Mondragon.Moreno@dodgit.com', '02/10/44', 74, 11);
INSERT INTO usuaris VALUES (2178, 'Cenobio', 'Lerma Huerta', 'H', '16 Ctra. Hornos', 26210, 'Cenobio.Lerma.Huerta@mailinator.com', '04/08/81', 9, 2);
INSERT INTO usuaris VALUES (2179, 'Palemon', 'Betancourt Maldonado', 'H', '70 C/ Domingo Beltrán', 2215, 'Palemon.Betancourt.Maldonado@dodgit.com', '24/12/69', 14, 7);
INSERT INTO usuaris VALUES (2180, 'Geselle', 'Rico Urbina', 'D', '37 Cercas Bajas', 8214, 'Geselle.Rico.Urbina@trashymail.com', '02/06/76', 41, NULL);
INSERT INTO usuaris VALUES (2181, 'Anxela', 'Pabón Medina', 'D', '82 Eusebio Dávila', 41429, 'Anxela.Pabon.Medina@mailinator.com', '02/09/85', 23, 11);
INSERT INTO usuaris VALUES (2182, 'Hullen', 'Chávez Reyes', 'D', '33 Crta. Cádiz-Málaga', 12230, 'Hullen.Chavez.Reyes@trashymail.com', '10/12/50', 35, 3);
INSERT INTO usuaris VALUES (2183, 'Torcuato', 'Oquendo Ayala', 'H', '45 Puerto Lugar', 29791, 'Torcuato.Oquendo.Ayala@spambob.com', '10/04/70', 26, 5);
INSERT INTO usuaris VALUES (2184, 'Giordano', 'Casares Verdugo', 'H', '73 Cartagena', 30520, 'Giordano.Casares.Verdugo@spambob.com', '20/07/58', 45, NULL);
INSERT INTO usuaris VALUES (2185, 'Olinda', 'Najera Vaca', 'D', '11 Ctra. Villena', 34400, 'Olinda.Najera.Vaca@pookmail.com', '09/07/84', 66, 1);
INSERT INTO usuaris VALUES (2186, 'Danilo', 'Aparicio Hernandes', 'H', '97 Antonio Vázquez', 38712, 'Danilo.Aparicio.Hernandes@pookmail.com', '22/01/47', 24, 9);
INSERT INTO usuaris VALUES (2187, 'Sagar', 'Jaimes Badillo', 'H', '37 Ourense', 43420, 'Sagar.Jaimes.Badillo@spambob.com', '04/09/54', 16, 8);
INSERT INTO usuaris VALUES (2188, 'Gianluca', 'Baca Manzanares', 'H', '26 Avenida Cervantes', 48314, 'Gianluca.Baca.Manzanares@dodgit.com', '28/08/53', 17, 5);
INSERT INTO usuaris VALUES (2189, 'Ariana', 'Balderas Cordova', 'D', '42 Pza. Fuensanta', 32411, 'Ariana.Balderas.Cordova@dodgit.com', '02/05/78', 74, 3);
INSERT INTO usuaris VALUES (2190, 'Androcles', 'Abreu Montemayor', NULL, '16 C/ Domingo Beltrán', 2314, 'Androcles.Abreu.Montemayor@pookmail.com', '02/12/82', 91, 4);
INSERT INTO usuaris VALUES (2191, 'Geraldine', 'Tejada Torres', 'D', '90 Rua da Rapina', 37468, 'Geraldine.Tejada.Torres@trashymail.com', '22/03/41', 63, 4);
INSERT INTO usuaris VALUES (2192, 'Tzípora', 'Chacón Urbina', 'D', '39 Cercas Bajas', 8140, 'Tzipora.Chacon.Urbina@spambob.com', '28/05/65', 41, 10);
INSERT INTO usuaris VALUES (2193, 'Miqueo', 'Alvarado Miramontes', 'H', '60 Lamas Carbajal', 41650, 'Miqueo.Alvarado.Miramontes@trashymail.com', '25/08/52', 13, 7);
INSERT INTO usuaris VALUES (2194, 'Argentino', 'Bahena Guzmán', 'H', '72 Puerto Lugar', 30140, 'Argentino.Bahena.Guzman@dodgit.com', '14/04/61', 27, 8);
INSERT INTO usuaris VALUES (2195, 'Merces', 'Razo Posada', 'D', '86 Puerto Lugar', 29714, 'Merces.Razo.Posada@trashymail.com', '08/11/44', 1, 8);
INSERT INTO usuaris VALUES (2196, 'Emanuel', 'Ballesteros Maestas', 'H', '44 Avda. Explanada Barnuevo', 35530, 'Emanuel.Ballesteros.Maestas@mailinator.com', '16/02/43', 70, 7);
INSERT INTO usuaris VALUES (2197, 'Camil', 'Zapata Fajardo', 'D', '85 Inglaterra', 18611, 'Camil.Zapata.Fajardo@trashymail.com', '03/07/59', 14, 7);
INSERT INTO usuaris VALUES (2198, 'Gioconda', 'Alanis Barragán', NULL, '73 Antonio Vázquez', 38480, 'Gioconda.Alanis.Barragan@dodgit.com', '20/08/40', 69, 5);
INSERT INTO usuaris VALUES (2199, 'Hamanchay', 'Jaime Caraballo', 'D', '44 Castelao', 49400, 'Hamanchay.Jaime.Caraballo@trashymail.com', '23/04/42', 41, 1);
INSERT INTO usuaris VALUES (2200, 'Yole', 'Callas Rico', 'D', '48 Herrería', 18230, 'Yole.Callas.Rico@spambob.com', '13/08/41', 31, NULL);
INSERT INTO usuaris VALUES (2201, 'Cloe', 'Arriaga Ruelas', 'D', '56 Salzillo', 32695, 'Cloe.Arriaga.Ruelas@dodgit.com', '17/10/68', 38, 2);
INSERT INTO usuaris VALUES (2202, 'Alexa', 'Colunga Carrillo', 'D', '40 C/ Angosto', 23550, 'Alexa.Colunga.Carrillo@spambob.com', '21/12/45', 37, 1);
INSERT INTO usuaris VALUES (2203, 'Rolán', 'Camacho Brito', 'H', '54 Ourense', 42110, 'Rolan.Camacho.Brito@mailinator.com', '07/10/66', 11, 2);
INSERT INTO usuaris VALUES (2204, 'Eleanor', 'Pizarro Nazario', 'D', '55 Castelao', 48990, 'Eleanor.Pizarro.Nazario@trashymail.com', '25/02/47', 7, 1);
INSERT INTO usuaris VALUES (2205, 'Licerio', 'Mesa Trejo', 'H', '83 Escuadro', 46940, 'Licerio.Mesa.Trejo@dodgit.com', '07/08/55', 53, 6);
INSERT INTO usuaris VALUES (2206, 'Fusiano', 'Romero Ojeda', 'H', '75 Rosa de los Vientos', 13360, 'Fusiano.Romero.Ojeda@trashymail.com', '07/09/71', 64, 12);
INSERT INTO usuaris VALUES (2207, 'Eitan', 'Escobedo Madera', 'H', '74 Camiño Ancho', 37764, 'Eitan.Escobedo.Madera@pookmail.com', '21/07/49', 65, 1);
INSERT INTO usuaris VALUES (2208, 'Elisea', 'Trujillo Ornelas', 'D', '27 Salzillo', 32695, 'Elisea.Trujillo.Ornelas@mailinator.com', '31/08/57', 59, 8);
INSERT INTO usuaris VALUES (2209, 'Rogerio', 'Téllez Sarabia', 'H', '13 Carretera del Muelle', 12232, 'Rogerio.Tellez.Sarabia@trashymail.com', '26/04/62', 98, 11);
INSERT INTO usuaris VALUES (2210, 'Adela', 'Mejía Griego', 'D', '17 Cercas Bajas', 7800, 'Adela.Mejia.Griego@trashymail.com', '09/08/56', 93, 10);
INSERT INTO usuaris VALUES (2211, 'Domiciano', 'Archuleta Alarcón', 'H', '85 Crta. Cádiz-Málaga', 12163, 'Domiciano.Archuleta.Alarcon@spambob.com', '24/10/64', 36, 7);
INSERT INTO usuaris VALUES (2212, 'Aurele', 'Villalpando Cazares', 'H', '43 Camiño Real', 48620, 'Aurele.Villalpando.Cazares@pookmail.com', '28/07/58', 5, NULL);
INSERT INTO usuaris VALUES (2213, 'Barnie', 'Santacruz Rosario', 'H', '71 C/ Rosa de los Vientos', 11350, 'Barnie.Santacruz.Rosario@dodgit.com', '02/09/49', 69, 8);
INSERT INTO usuaris VALUES (2214, 'Dalmazio', 'Medina Griego', 'H', '34 Visitación de la Encina', 37710, 'Dalmazio.Medina.Griego@dodgit.com', '14/01/47', 5, 7);
INSERT INTO usuaris VALUES (2215, 'Jeanette', 'Salinas Brito', 'D', '22 Eusebio Dávila', 41470, 'Jeanette.Salinas.Brito@pookmail.com', '26/09/40', 82, 8);
INSERT INTO usuaris VALUES (2216, 'Adulfo', 'Carranza Nevarez', 'H', '19 Plazuela do Porto', 38370, 'Adulfo.Carranza.Nevarez@mailinator.com', '18/02/57', 74, 12);
INSERT INTO usuaris VALUES (2217, 'Plinio', 'Navarrete Rodarte', 'H', '8 Avda. Enrique Peinador', 37185, 'Plinio.Navarrete.Rodarte@dodgit.com', '01/11/83', 14, 10);
INSERT INTO usuaris VALUES (2218, 'Cintia', 'Lugo Lerma', 'D', '54 Puerto Lugar', 29710, 'Cintia.Lugo.Lerma@pookmail.com', '09/02/51', 44, 2);
INSERT INTO usuaris VALUES (2219, 'Martiniana', 'Macías Sepúlveda', 'D', '83 Avda. de Andalucía', 29330, 'Martiniana.Macias.Sepulveda@spambob.com', '04/05/69', 93, 10);
INSERT INTO usuaris VALUES (2220, 'Sandro', 'Corrales Razo', 'H', '49 Rúa Olmos', 37339, 'Sandro.Corrales.Razo@mailinator.com', '05/07/79', 71, 10);
INSERT INTO usuaris VALUES (2221, 'Larisa', 'Terrazas Zamudio', 'D', '24 Apartado de Correos', 37451, 'Larisa.Terrazas.Zamudio@spambob.com', '24/05/81', 76, 2);
INSERT INTO usuaris VALUES (2222, 'Cristopher', 'Lozano Urena', 'H', '66 Puerto Lugar', 29717, 'Cristopher.Lozano.Urena@spambob.com', '12/08/79', 67, NULL);
INSERT INTO usuaris VALUES (2223, 'Abdo', 'Arévalo Cabán', 'H', '6 Cruce Casa de Postas', 18430, 'Abdo.Arevalo.Caban@dodgit.com', '13/02/41', 47, 8);
INSERT INTO usuaris VALUES (2224, 'Orson', 'Enríquez Márquez', 'H', '39 Carretera', 14546, 'Orson.Enriquez.Marquez@spambob.com', '06/07/49', 5, 5);
INSERT INTO usuaris VALUES (2225, 'Hadwig', 'Palomo González', 'D', '12 C/ Angosto', 23510, 'Hadwig.Palomo.Gonzalez@spambob.com', '08/09/71', 26, 8);
INSERT INTO usuaris VALUES (2226, 'Filemón', 'Regalado Barragán', 'H', '27 Alvaro Cunqueiro', 40196, 'Filemon.Regalado.Barragan@spambob.com', '22/03/52', 73, NULL);
INSERT INTO usuaris VALUES (2227, 'Ezilda', 'Lerma Treviño', 'D', '85 Estrela', 38870, 'Ezilda.Lerma.Trevino@trashymail.com', '21/12/70', 99, 2);
INSERT INTO usuaris VALUES (2228, 'Nominanda', 'Tafoya Hernández', 'D', '24 C/ Arana', 2450, 'Nominanda.Tafoya.Hernandez@spambob.com', '21/05/64', 93, 9);
INSERT INTO usuaris VALUES (2229, 'Errolán', 'Arana Juárez', 'H', '54 Pascual Yunquera', 18699, 'Errolan.Arana.Juarez@mailinator.com', '19/12/57', 70, 5);
INSERT INTO usuaris VALUES (2230, 'Ceadas', 'Zamudio Aragón', 'H', '6 C/ Libertad', 5416, 'Ceadas.Zamudio.Aragon@trashymail.com', '09/08/58', 85, 7);
INSERT INTO usuaris VALUES (2231, 'Dion', 'Pérez Carreón', 'H', '18 Ctra. Beas-Cortijos Nuevos', 26584, 'Dion.Perez.Carreon@mailinator.com', '13/02/69', 86, 7);
INSERT INTO usuaris VALUES (2232, 'Calfu', 'Garza Padrón', NULL, '43 C/ Cuesta del  Álamo', 29492, 'Calfu.Garza.Padron@trashymail.com', '14/10/48', 60, NULL);
INSERT INTO usuaris VALUES (2233, 'Melecio', 'Estévez Rascón', 'H', '65 Ctra. de Siles', 27430, 'Melecio.Estevez.Rascon@spambob.com', '03/08/77', 38, 5);
INSERT INTO usuaris VALUES (2234, 'Prudenciano', 'Santillán Segura', 'H', '14 C/ Canarias', 20140, 'Prudenciano.Santillan.Segura@pookmail.com', '11/04/41', 47, 11);
INSERT INTO usuaris VALUES (2235, 'Esmirna', 'Hinojosa Vigil', 'D', '30 C/ Cañada del Rosal', 21594, 'Esmirna.Hinojosa.Vigil@spambob.com', '14/08/63', 39, NULL);
INSERT INTO usuaris VALUES (2236, 'Gregory', 'Heredia Sarabia', 'D', '62 Puerto Lugar', 29719, 'Gregory.Heredia.Sarabia@mailinator.com', '18/12/40', 45, NULL);
INSERT INTO usuaris VALUES (2237, 'Israela', 'Escobar Gallardo', 'D', '41 C/ Libertad', 4890, 'Israela.Escobar.Gallardo@dodgit.com', '07/08/42', 71, 4);
INSERT INTO usuaris VALUES (2238, 'Anfos', 'Sedillo Bernal', 'H', '40 Cañadilla', 21850, 'Anfos.Sedillo.Bernal@trashymail.com', '11/06/64', 3, 8);
INSERT INTO usuaris VALUES (2239, 'Elpidia', 'Apodaca Alcaraz', 'D', '85 Rúa Olmos', 37320, 'Elpidia.Apodaca.Alcaraz@dodgit.com', '20/10/55', 56, 4);
INSERT INTO usuaris VALUES (2240, 'Polifemo', 'Meraz Ceja', 'H', '7 Ctra. de Siles', 27340, 'Polifemo.Meraz.Ceja@spambob.com', '13/08/67', 84, 4);
INSERT INTO usuaris VALUES (2241, 'Abo', 'Robledo Solís', 'H', '60 Zumalakarregi etorbidea', 7210, 'Abo.Robledo.Solis@pookmail.com', '16/02/58', 22, 5);
INSERT INTO usuaris VALUES (2242, 'Atala', 'León Arenas', 'D', '36 Prolongacion San Sebastian', 21300, 'Atala.Leon.Arenas@dodgit.com', '24/11/68', 58, 5);
INSERT INTO usuaris VALUES (2243, 'Taciana', 'Olivárez Porras', 'D', '88 Avda. Rio Nalon', 33554, 'Taciana.Olivarez.Porras@spambob.com', '09/03/76', 79, 12);
INSERT INTO usuaris VALUES (2244, 'Lautaro', 'Quintana Esquivel', 'H', '99 Av. Zumalakarregi', 3179, 'Lautaro.Quintana.Esquivel@spambob.com', '27/10/71', 82, 5);
INSERT INTO usuaris VALUES (2245, 'Olinda', 'Pagan Feliciano', 'D', '18 Puerta Nueva', 36000, 'Olinda.Pagan.Feliciano@trashymail.com', '25/07/50', 98, 5);
INSERT INTO usuaris VALUES (2246, 'Vincent', 'Almaraz Regalado', 'H', '47 Estrela', 38840, 'Vincent.Almaraz.Regalado@mailinator.com', '17/11/60', 60, 2);
INSERT INTO usuaris VALUES (2247, 'Tíquico', 'Flórez Martínez', 'H', '68 Avda. Los llanos', 26256, 'Tiquico.Florez.Martinez@pookmail.com', '02/10/82', 23, 10);
INSERT INTO usuaris VALUES (2248, 'Herodiade', 'Ordóñez Mejía', 'D', '28 Caño', 32911, 'Herodiade.Ordonez.Mejia@mailinator.com', '26/09/80', 80, 3);
INSERT INTO usuaris VALUES (2249, 'Esmerada', 'Aguilar Castillo', 'D', '8 Ctra. Beas-Cortijos Nuevos', 26513, 'Esmerada.Aguilar.Castillo@pookmail.com', '03/06/71', 53, 8);
INSERT INTO usuaris VALUES (2250, 'Tirso', 'Mares Lozada', 'H', '31 La Fontanilla', 14448, 'Tirso.Mares.Lozada@trashymail.com', '21/06/59', 47, 6);
INSERT INTO usuaris VALUES (2251, 'Marion', 'Feliciano Vargas', 'D', '19 C/ Canarias', 20140, 'Marion.Feliciano.Vargas@spambob.com', '19/09/53', 29, 11);
INSERT INTO usuaris VALUES (2252, 'Dositeo', 'Pacheco Olvera', 'H', '67 Socampo', 37608, 'Dositeo.Pacheco.Olvera@pookmail.com', '12/04/54', 51, 9);
INSERT INTO usuaris VALUES (2253, 'Nimfa', 'Navarro Collazo', 'D', '52 Rua da Rapina', 37468, 'Nimfa.Navarro.Collazo@spambob.com', '04/06/70', 29, 3);
INSERT INTO usuaris VALUES (2254, 'Orencio', 'Corral Borrego', 'H', '25 C/ Señores Curas', 12124, 'Orencio.Corral.Borrego@mailinator.com', '17/02/53', 75, 5);
INSERT INTO usuaris VALUES (2255, 'Angus', 'Curiel Murillo', 'H', '64 Pza. Fuensanta', 32232, 'Angus.Curiel.Murillo@dodgit.com', '07/11/80', 57, 10);
INSERT INTO usuaris VALUES (2256, 'Letizia', 'Flórez Salcedo', 'D', '21 C/ Andalucía', 4692, 'Letizia.Florez.Salcedo@dodgit.com', '11/09/40', 29, 5);
INSERT INTO usuaris VALUES (2257, 'Dámaso', 'Bueno Collazo', 'H', '91 C/ Cañada del Rosal', 21593, 'Damaso.Bueno.Collazo@mailinator.com', '16/11/54', 65, 9);
INSERT INTO usuaris VALUES (2258, 'Parménides', 'Prieto Arteaga', 'H', '49 Calle Carril de la Fuente', 13300, 'Parmenides.Prieto.Arteaga@dodgit.com', '08/01/78', 78, 9);
INSERT INTO usuaris VALUES (2259, 'Mayda', 'Mares Delgado', 'D', '97 Avda. de la Estación', 28680, 'Mayda.Mares.Delgado@dodgit.com', '23/04/52', 92, 1);
INSERT INTO usuaris VALUES (2260, 'Cinthia', 'Caraballo Arévalo', 'D', '2 C/ Fernández de Leceta', 3410, 'Cinthia.Caraballo.Arevalo@spambob.com', '07/08/67', 73, NULL);
INSERT INTO usuaris VALUES (2261, 'Febes', 'Granados Valdés', 'D', '3 Apartado de Correos', 37439, 'Febes.Granados.Valdes@mailinator.com', '12/09/40', NULL, 5);
INSERT INTO usuaris VALUES (2262, 'Hobart', 'Almonte Zamudio', 'H', '59 Alcon Molina', 31177, 'Hobart.Almonte.Zamudio@dodgit.com', '02/05/49', 96, NULL);
INSERT INTO usuaris VALUES (2263, 'Dennis', 'Briseño Laureano', 'H', '50 Estrela', 39610, 'Dennis.Briseno.Laureano@mailinator.com', '06/05/69', 42, 12);
INSERT INTO usuaris VALUES (2264, 'Calfú', 'Collazo Malave', 'H', '76 Avda. Rio Nalon', 33411, 'Calfu.Collazo.Malave@pookmail.com', '04/08/47', 77, 11);
INSERT INTO usuaris VALUES (2265, 'Meulén', 'Samaniego Almaraz', 'H', '9 Carretera Cádiz-Málaga', 20720, 'Meulen.Samaniego.Almaraz@trashymail.com', '10/07/47', 2, 1);
INSERT INTO usuaris VALUES (2266, 'Medea', 'Rodrígez Lugo', 'D', '84 Pascual Yunquera', 18870, 'Medea.Rodrigez.Lugo@dodgit.com', '18/03/71', 36, 1);
INSERT INTO usuaris VALUES (2267, 'Hernando', 'Barela Sotelo', 'H', '96 C/ Cañada del Rosal', 21668, 'Hernando.Barela.Sotelo@mailinator.com', '01/03/70', 10, NULL);
INSERT INTO usuaris VALUES (2268, 'Rogelia', 'Almaraz Montés', 'D', '96 Plaza Colón', 25620, 'Rogelia.Almaraz.Montes@trashymail.com', '26/01/64', 5, 5);
INSERT INTO usuaris VALUES (2269, 'Cassandra', 'Velásquez Luna', 'D', '77 Carretera Cádiz-Málaga', 20700, 'Cassandra.Velasquez.Luna@trashymail.com', '14/12/46', 79, 11);
INSERT INTO usuaris VALUES (2270, 'Vulcano', 'Dueñas Vega', 'H', '8 Antonio Vázquez', 38730, 'Vulcano.Duenas.Vega@spambob.com', '13/06/77', 45, 2);
INSERT INTO usuaris VALUES (2271, 'Anatolio', 'Raya Saldivar', NULL, '47 Valadouro', 48195, 'Anatolio.Raya.Saldivar@dodgit.com', '22/05/72', 35, 9);
INSERT INTO usuaris VALUES (2272, 'Nera', 'Cortés Toro', 'H', '33 C/ Andalucía', 4692, 'Nera.Cortes.Toro@mailinator.com', '19/08/57', 7, 5);
INSERT INTO usuaris VALUES (2273, 'Milwida', 'Galvez Casárez', 'D', '96 Boriñaur enparantza', 7760, 'Milwida.Galvez.Casarez@dodgit.com', '01/03/41', 12, 10);
INSERT INTO usuaris VALUES (2274, 'Belisaria', 'Orosco Nazario', 'D', '89 Rosa de los Vientos', 13430, 'Belisaria.Orosco.Nazario@dodgit.com', '18/02/51', 89, NULL);
INSERT INTO usuaris VALUES (2275, 'Anelisa', 'Covas Orosco', 'D', '82 Rua da Rapina', 37460, 'Anelisa.Covas.Orosco@trashymail.com', '20/11/79', 20, 4);
INSERT INTO usuaris VALUES (2276, 'Dinah', 'Barrientos Barela', 'D', '15 C/ Arana', 2530, 'Dinah.Barrientos.Barela@trashymail.com', '01/07/45', 91, 2);
INSERT INTO usuaris VALUES (2277, 'Spiro', 'Estrada Carrasquill', 'H', '3 Valadouro', 48195, 'Spiro.Estrada.Carrasquill@trashymail.com', '07/05/72', 2, 6);
INSERT INTO usuaris VALUES (2278, 'Llanos', 'Ferrer Casas', 'H', '45 Valadouro', 48112, 'Llanos.Ferrer.Casas@spambob.com', '07/10/41', 95, 8);
INSERT INTO usuaris VALUES (2279, 'Mickey', 'Sarabia Alarcón', 'H', '41 Quevedo', 15314, 'Mickey.Sarabia.Alarcon@pookmail.com', '19/05/84', 77, 3);
INSERT INTO usuaris VALUES (2280, 'Eyén', 'Saldana Archuleta', 'D', '61 Rosa de los Vientos', 13414, 'Eyen.Saldana.Archuleta@pookmail.com', '18/11/46', 88, NULL);
INSERT INTO usuaris VALUES (2281, 'Germana', 'Pina Concepción', NULL, '59 Zumalakarregi etorbidea', 7260, 'Germana.Pina.Concepcion@spambob.com', '17/10/47', 68, 12);
INSERT INTO usuaris VALUES (2282, 'Adalvino', 'Cotto Verduzco', 'H', '99 Celso Emilio Ferreiro', 50298, 'Adalvino.Cotto.Verduzco@dodgit.com', '14/11/60', 83, 4);
INSERT INTO usuaris VALUES (2283, 'Maitane', 'Ávalos Cotto', 'D', '72 Carretera del Muelle', 12415, 'Maitane.Avalos.Cotto@mailinator.com', '25/03/62', 61, 5);
INSERT INTO usuaris VALUES (2284, 'Olaya', 'Acuna Frías', 'D', '70 C/ Libertad', 4890, 'Olaya.Acuna.Frias@pookmail.com', '13/12/44', 42, 12);
INSERT INTO usuaris VALUES (2285, 'Yulan', 'Carrasquill Cantú', 'H', '37 Plaza Colón', 25100, 'Yulan.Carrasquill.Cantu@dodgit.com', '30/04/66', 75, 12);
INSERT INTO usuaris VALUES (2286, 'Vesna', 'Hinojosa Valadez', 'D', '81 Crta. Cádiz-Málaga', 12165, 'Vesna.Hinojosa.Valadez@spambob.com', '18/04/73', 42, 7);
INSERT INTO usuaris VALUES (2287, 'Salustio', 'Mayonga Corrales', 'H', '58 Eusebio Dávila', 41310, 'Salustio.Mayonga.Corrales@pookmail.com', '30/08/63', 17, 11);
INSERT INTO usuaris VALUES (2288, 'Ayrton', 'Carrasco Flórez', 'H', '18 Bellavista', 49600, 'Ayrton.Carrasco.Florez@mailinator.com', '03/01/55', 86, 8);
INSERT INTO usuaris VALUES (2289, 'Betsabé', 'Valenzuela Acuna', 'D', '46 Boriñaur enparantza', 7740, 'Betsabe.Valenzuela.Acuna@trashymail.com', '02/04/59', 12, 10);
INSERT INTO usuaris VALUES (2290, 'Bela', 'Vergara Macías', 'D', '52 Ourense', 42250, 'Bela.Vergara.Macias@trashymail.com', '29/05/80', 9, 4);
INSERT INTO usuaris VALUES (2291, 'Laura', 'Rojo Blanco', 'D', '60 C/ Señores Curas', 12130, 'Laura.Rojo.Blanco@dodgit.com', '06/12/46', 68, 11);
INSERT INTO usuaris VALUES (2292, 'Escipion', 'Venegas Rodríguez', 'H', '5 C/ Libertad', 5600, 'Escipion.Venegas.Rodriguez@dodgit.com', '18/01/66', 64, 10);
INSERT INTO usuaris VALUES (2293, 'Iberia', 'Granado Barreto', 'D', '39 Rua da Rapina', 37491, 'Iberia.Granado.Barreto@trashymail.com', '25/03/53', 77, 8);
INSERT INTO usuaris VALUES (2294, 'Macario', 'Ceballos Marcos', 'H', '71 Avda. Generalísimo', 31700, 'Macario.Ceballos.Marcos@dodgit.com', '14/06/48', 50, 1);
INSERT INTO usuaris VALUES (2295, 'Martino', 'Garica Anguiano', 'H', '2 C/ Domingo Beltrán', 2327, 'Martino.Garica.Anguiano@dodgit.com', '04/04/84', 64, 9);
INSERT INTO usuaris VALUES (2296, 'Eilal', 'Bahena Terán', 'H', '19 Plaza de España', 15683, 'Eilal.Bahena.Teran@mailinator.com', '14/06/85', 96, 5);
INSERT INTO usuaris VALUES (2297, 'Libio', 'Alicea Suárez', 'H', '7 Padre Caro', 13740, 'Libio.Alicea.Suarez@trashymail.com', '28/02/44', 57, 2);
INSERT INTO usuaris VALUES (2298, 'Agop', 'Tejeda Ozuna', 'H', '86 Ctra. Villena', 33880, 'Agop.Tejeda.Ozuna@pookmail.com', '21/01/55', 65, 8);
INSERT INTO usuaris VALUES (2299, 'Gualterio', 'Estévez Barreto', 'H', '85 C/ Cuevas de Ambrosio', 23760, 'Gualterio.Estevez.Barreto@pookmail.com', '08/07/47', 87, 5);
INSERT INTO usuaris VALUES (2300, 'Claudette', 'Argüello Correa', 'D', '81 Valadouro', 48141, 'Claudette.Arguello.Correa@spambob.com', '21/10/72', 38, 1);
INSERT INTO usuaris VALUES (2301, 'Menas', 'Sanabria Alaniz', 'H', '43 Pza. Fuensanta', 32340, 'Menas.Sanabria.Alaniz@mailinator.com', '09/05/40', 81, 8);
INSERT INTO usuaris VALUES (2302, 'Karenina', 'Urías Luevano', 'D', '35 Pl. Virgen Blanca', 8520, 'Karenina.Urias.Luevano@pookmail.com', '08/09/46', 37, 11);
INSERT INTO usuaris VALUES (2303, 'Anouk', 'Rodrígez Irizarry', 'D', '41 C/ Hijuela de Lojo', 20494, 'Anouk.Rodrigez.Irizarry@trashymail.com', '14/05/50', 77, 8);
INSERT INTO usuaris VALUES (2304, 'Sigrid', 'Madrigal Lira', 'D', '30 C/ Henan Cortes', 29170, 'Sigrid.Madrigal.Lira@dodgit.com', '25/03/82', 25, 1);
INSERT INTO usuaris VALUES (2305, 'Elín', 'Zavala Posada', 'D', '33 Outid de Arriba', 43710, 'Elin.Zavala.Posada@trashymail.com', '11/06/84', 42, NULL);
INSERT INTO usuaris VALUES (2306, 'Elodia', 'Esquivel González', 'D', '6 Lamas Carbajal', 41567, 'Elodia.Esquivel.Gonzalez@dodgit.com', '25/07/59', 73, NULL);
INSERT INTO usuaris VALUES (2307, 'Gail', 'Segovia Salgado', 'D', '1 Maestro Puig Valera', 33740, 'Gail.Segovia.Salgado@spambob.com', '25/01/77', 98, 6);
INSERT INTO usuaris VALUES (2308, 'Alidia', 'Duarte Benítez', 'D', '51 Salzillo', 32620, 'Alidia.Duarte.Benitez@mailinator.com', '24/04/82', 34, 4);
INSERT INTO usuaris VALUES (2309, 'Carmine', 'Ibarra Abreu', 'D', '23 Camiño Real', 48620, 'Carmine.Ibarra.Abreu@trashymail.com', '11/06/63', 67, 5);
INSERT INTO usuaris VALUES (2310, 'Omaro', 'Ávalos Lemus', 'H', '70 Quevedo', 15510, 'Omaro.Avalos.Lemus@pookmail.com', '08/04/84', 60, 7);
INSERT INTO usuaris VALUES (2311, 'Itsaso', 'Briones Vargas', 'D', '25 Extramuros', 28410, 'Itsaso.Briones.Vargas@spambob.com', '10/04/50', 19, 12);
INSERT INTO usuaris VALUES (2312, 'Lionela', 'Perea Raya', 'D', '85 José matía', 2110, 'Lionela.Perea.Raya@mailinator.com', '17/05/71', 31, 6);
INSERT INTO usuaris VALUES (2313, 'Grizel', 'Tórrez Mena', 'D', '23 Pza. Fuensanta', 32310, 'Grizel.Torrez.Mena@spambob.com', '12/10/74', 81, 2);
INSERT INTO usuaris VALUES (2314, 'Valerie', 'Aponte Botello', 'D', '28 Ourense', 42110, 'Valerie.Aponte.Botello@mailinator.com', '08/09/76', 21, 7);
INSERT INTO usuaris VALUES (2315, 'Senan', 'Esquivel Betancourt', 'H', '59 Reyes Católicos', 11100, 'Senan.Esquivel.Betancourt@mailinator.com', '09/04/68', 86, 7);
INSERT INTO usuaris VALUES (2316, 'Samir', 'Cavazos Leiva', 'H', '34 Padre Caro', 13620, 'Samir.Cavazos.Leiva@mailinator.com', '06/07/51', 76, 4);
INSERT INTO usuaris VALUES (2317, 'Andresa', 'Rodrígez Farías', 'D', '22 Rosa de los Vientos', 13440, 'Andresa.Rodrigez.Farias@spambob.com', '24/10/73', 46, 11);
INSERT INTO usuaris VALUES (2318, 'Amaranto', 'Vaca Arce', 'H', '32 C/ Andalucía', 4800, 'Amaranto.Vaca.Arce@pookmail.com', '09/07/56', 5, 11);
INSERT INTO usuaris VALUES (2319, 'Nicéforo', 'Delgado Fajardo', 'H', '70 C/ Eras', 28738, 'Niceforo.Delgado.Fajardo@mailinator.com', '28/10/74', 80, 11);
INSERT INTO usuaris VALUES (2320, 'Margalit', 'Rentería Portillo', 'D', '89 Maestro Puig Valera', 33740, 'Margalit.Renteria.Portillo@spambob.com', '22/07/72', 62, 4);
INSERT INTO usuaris VALUES (2321, 'Arlen', 'Villalobos Aguirre', 'D', '45 Paseo Junquera', 12470, 'Arlen.Villalobos.Aguirre@pookmail.com', '18/08/51', 61, 6);
INSERT INTO usuaris VALUES (2322, 'Julio César', 'Cruz Sepúlveda', 'H', '22 Cercas Bajas', 7810, 'Julio.Cesar.Cruz.Sepulveda@mailinator.com', '23/09/55', 72, 2);
INSERT INTO usuaris VALUES (2323, 'Isabella', 'Manzanares Pena', 'D', '80 Avda. de Andalucía', 29450, 'Isabella.Manzanares.Pena@trashymail.com', '17/09/58', 11, 3);
INSERT INTO usuaris VALUES (2324, 'Danila', 'Amador Herrera', 'D', '31 Alvaro Cunqueiro', 40360, 'Danila.Amador.Herrera@dodgit.com', '05/11/51', 9, 7);
INSERT INTO usuaris VALUES (2325, 'Laurence', 'Laureano Botello', 'H', '5 Avenida Cervantes', 48350, 'Laurence.Laureano.Botello@trashymail.com', '02/12/80', 80, 10);
INSERT INTO usuaris VALUES (2326, 'Alfa', 'Prieto Ozuna', 'D', '25 C/ Benito Guinea', 8292, 'Alfa.Prieto.Ozuna@pookmail.com', '19/07/62', 61, 9);
INSERT INTO usuaris VALUES (2327, 'Alulay', 'Solís Madrid', 'D', '75 Rosa de los Vientos', 13341, 'Alulay.Solis.Madrid@pookmail.com', '17/06/54', 82, 12);
INSERT INTO usuaris VALUES (2328, 'Lua', 'Orta Galván', NULL, '45 Calle Carril de la Fuente', 13160, 'Lua.Orta.Galvan@dodgit.com', '22/06/75', 39, 1);
INSERT INTO usuaris VALUES (2329, 'Valentine', 'Pelayo Colón', NULL, '26 Quevedo', 15500, 'Valentine.Pelayo.Colon@mailinator.com', '19/05/40', 30, 4);
INSERT INTO usuaris VALUES (2330, 'Azanías', 'Parra Berrios', 'H', '23 Camiño Real', 48610, 'Azanias.Parra.Berrios@pookmail.com', '15/02/65', 28, 3);
INSERT INTO usuaris VALUES (2331, 'Zite', 'Manzanares Serrano', 'D', '13 Ventanilla de Beas', 27836, 'Zite.Manzanares.Serrano@spambob.com', '20/01/53', 45, 12);
INSERT INTO usuaris VALUES (2332, 'Elpidia', 'Curiel Vergara', 'D', '41 Plazuela do Porto', 38280, 'Elpidia.Curiel.Vergara@mailinator.com', '12/01/69', 66, 1);
INSERT INTO usuaris VALUES (2333, 'Nuncia', 'Pena Méndez', 'D', '25 C/ Cañada del Rosal', 21610, 'Nuncia.Pena.Mendez@spambob.com', '07/03/76', 85, 5);
INSERT INTO usuaris VALUES (2334, 'Axel', 'Riojas Barrientos', 'H', '32 C/ Cuevas de Ambrosio', 23700, 'Axel.Riojas.Barrientos@pookmail.com', '07/12/59', 6, 4);
INSERT INTO usuaris VALUES (2335, 'Narcis', 'González Parra', 'H', '89 Rosa de los Vientos', 13328, 'Narcis.Gonzalez.Parra@trashymail.com', '11/07/60', 11, 4);
INSERT INTO usuaris VALUES (2336, 'Cibeles', 'Rico Jasso', 'D', '74 Avda. Explanada Barnuevo', 35460, 'Cibeles.Rico.Jasso@mailinator.com', '31/08/85', 95, 8);
INSERT INTO usuaris VALUES (2337, 'Donatela', 'Sotelo Frías', 'D', '96 Avda. de la Estación', 28609, 'Donatela.Sotelo.Frias@pookmail.com', '01/04/66', 20, 11);
INSERT INTO usuaris VALUES (2338, 'Vannina', 'Dávila Becerra', 'D', '58 Urzáiz', 44200, 'Vannina.Davila.Becerra@dodgit.com', '25/07/81', 40, 2);
INSERT INTO usuaris VALUES (2339, 'Elea', 'Vallejo Alba', 'D', '81 Avda. de la Estación', 28649, 'Elea.Vallejo.Alba@dodgit.com', '02/08/64', 42, 3);
INSERT INTO usuaris VALUES (2340, 'Inocencio', 'Cárdenas Zavala', 'H', '24 C/ Rosa de los Vientos', 11300, 'Inocencio.Cardenas.Zavala@mailinator.com', '21/11/77', 88, 2);
INSERT INTO usuaris VALUES (2341, 'Ami', 'Chávez Iglesias', 'H', '18 C/ Fernández de Leceta', 3509, 'Ami.Chavez.Iglesias@trashymail.com', '30/03/77', NULL, 7);
INSERT INTO usuaris VALUES (2342, 'Tamara', 'Castellanos Torres', 'D', '56 Calle Proc. San Sebastián', 13109, 'Tamara.Castellanos.Torres@pookmail.com', '02/11/61', 0, 4);
INSERT INTO usuaris VALUES (2343, 'Marcio', 'Nino Apodaca', 'H', '44 Cartagena', 30530, 'Marcio.Nino.Apodaca@pookmail.com', '20/10/67', 93, 8);
INSERT INTO usuaris VALUES (2344, 'Ysmael', 'Madera Dueñas', 'H', '52 Reyes Católicos', 10200, 'Ysmael.Madera.Duenas@spambob.com', '01/08/59', 50, 12);
INSERT INTO usuaris VALUES (2345, 'Natal', 'Rivera Nieves', 'H', '88 C/ Cuesta del  Álamo', 29650, 'Natal.Rivera.Nieves@mailinator.com', '11/01/82', 84, 9);
INSERT INTO usuaris VALUES (2346, 'Giorgio', 'Coronado Quezada', 'H', '98 Urzáiz', 44540, 'Giorgio.Coronado.Quezada@pookmail.com', '18/07/67', 48, 7);
INSERT INTO usuaris VALUES (2347, 'Marcella', 'Laureano Rico', 'D', '27 C/ Amoladera', 28800, 'Marcella.Laureano.Rico@mailinator.com', '18/02/68', 81, 1);
INSERT INTO usuaris VALUES (2348, 'Edit', 'Paredes Salcedo', 'D', '97 C/ Señores Curas', 12132, 'Edit.Paredes.Salcedo@spambob.com', '10/12/55', 51, 10);
INSERT INTO usuaris VALUES (2349, 'Juanjo', 'Miramontes Borrego', 'H', '92 Cercas Bajas', 8181, 'Juanjo.Miramontes.Borrego@mailinator.com', '31/05/75', 20, 1);
INSERT INTO usuaris VALUES (2350, 'Ivany', 'Orosco Collazo', 'H', '53 C/ Canarias', 20159, 'Ivany.Orosco.Collazo@pookmail.com', '23/04/50', 87, NULL);
INSERT INTO usuaris VALUES (2351, 'Crescencio', 'Guillén Godoy', 'H', '91 Plazuela do Porto', 38000, 'Crescencio.Guillen.Godoy@mailinator.com', '14/05/81', 76, 1);
INSERT INTO usuaris VALUES (2352, 'Baldwin', 'Coronado Santacruz', 'H', '18 Escuadro', 46860, 'Baldwin.Coronado.Santacruz@spambob.com', '14/12/53', 75, 4);
INSERT INTO usuaris VALUES (2353, 'Casto', 'Paredes Acuna', 'H', '66 Alvaro Cunqueiro', 41240, 'Casto.Paredes.Acuna@trashymail.com', '30/05/53', 88, 8);
INSERT INTO usuaris VALUES (2354, 'Cumelén', 'Valverde Prieto', 'D', '55 C/ Domingo Beltrán', 2214, 'Cumelen.Valverde.Prieto@mailinator.com', '29/11/46', 9, 6);
INSERT INTO usuaris VALUES (2355, 'Gisella', 'Cadena Aranda', 'D', '62 Herrería', 18230, 'Gisella.Cadena.Aranda@dodgit.com', '09/05/53', 40, 1);
INSERT INTO usuaris VALUES (2356, 'Eulogia', 'Guzmán Cuellar', 'D', '62 Avda. de Andalucía', 29340, 'Eulogia.Guzman.Cuellar@spambob.com', '08/03/58', 48, NULL);
INSERT INTO usuaris VALUES (2357, 'Lalita', 'Morales Apodaca', 'D', '37 Ourense', 41980, 'Lalita.Morales.Apodaca@mailinator.com', '30/03/66', 0, 3);
INSERT INTO usuaris VALUES (2358, 'Elisabet', 'Arellano Gómez', 'D', '50 Quevedo', 15552, 'Elisabet.Arellano.Gomez@spambob.com', '01/05/80', 41, 2);
INSERT INTO usuaris VALUES (2359, 'Ludmila', 'Tejada Alicea', 'D', '36 Puerta Nueva', 35628, 'Ludmila.Tejada.Alicea@trashymail.com', '22/01/59', 72, 12);
INSERT INTO usuaris VALUES (2360, 'Agapita', 'Navarrete Noriega', 'D', '93 Cádiz', 18518, 'Agapita.Navarrete.Noriega@dodgit.com', '30/06/49', 15, 9);
INSERT INTO usuaris VALUES (2361, 'Faraón', 'Ruvalcaba Covarrubias', 'H', '14 José matía', 2162, 'Faraon.Ruvalcaba.Covarrubias@trashymail.com', '24/01/82', 69, 11);
INSERT INTO usuaris VALUES (2362, 'Brigitte', 'Medrano Corrales', 'D', '97 C/ Angosto', 23537, 'Brigitte.Medrano.Corrales@pookmail.com', '16/04/64', 84, 2);
INSERT INTO usuaris VALUES (2363, 'Cleofás', 'Galindo Granados', 'D', '2 Escuadro', 46740, 'Cleofas.Galindo.Granados@trashymail.com', '24/03/58', 3, 4);
INSERT INTO usuaris VALUES (2364, 'Suyay', 'Villa Sosa', 'D', '82 Antonio Vázquez', 38500, 'Suyay.Villa.Sosa@pookmail.com', '01/06/59', 29, 2);
INSERT INTO usuaris VALUES (2365, 'Ald', 'Cavazos Delgadillo', 'H', '9 Pl. Virgen Blanca', 8520, 'Ald.Cavazos.Delgadillo@trashymail.com', '24/03/76', 86, 1);
INSERT INTO usuaris VALUES (2366, 'Leo', 'Acevedo Olmos', 'H', '52 Rua da Rapina', 37484, 'Leo.Acevedo.Olmos@mailinator.com', '29/01/49', 15, 2);
INSERT INTO usuaris VALUES (2367, 'Nelo', 'Ramírez Villalpando', 'H', '24 C/ Pablo Iglesias', 26321, 'Nelo.Ramirez.Villalpando@trashymail.com', '30/04/65', 71, 1);
INSERT INTO usuaris VALUES (2368, 'Reuquén', 'Jurado Urías', 'H', '39 Canónigo Valiño', 46360, 'Reuquen.Jurado.Urias@spambob.com', '13/12/65', 28, 8);
INSERT INTO usuaris VALUES (2369, 'Piren', 'Hurtado Olivera', 'D', '30 Castelao', 49100, 'Piren.Hurtado.Olivera@pookmail.com', '19/03/59', 67, NULL);
INSERT INTO usuaris VALUES (2370, 'Fantino', 'Granado Guillén', 'H', '88 Visitación de la Encina', 37751, 'Fantino.Granado.Guillen@mailinator.com', '28/11/77', 96, 4);
INSERT INTO usuaris VALUES (2371, 'André', 'Castellanos Gracia', 'H', '8 Estrela', 40150, 'Andre.Castellanos.Gracia@spambob.com', '11/12/53', 21, 10);
INSERT INTO usuaris VALUES (2372, 'Noe', 'Bustamante Zamora', 'D', '25 Ctra. de la Puerta', 27130, 'Noe.Bustamante.Zamora@spambob.com', '09/01/82', 83, 4);
INSERT INTO usuaris VALUES (2373, 'Jenaro', 'Garza Alba', 'H', '11 C/ Domingo Beltrán', 2260, 'Jenaro.Garza.Alba@dodgit.com', '01/08/52', 54, 11);
INSERT INTO usuaris VALUES (2374, 'Kassia', 'Curiel Núñez', 'D', '91 C/ Pablo Iglesias', 26321, 'Kassia.Curiel.Nunez@pookmail.com', '27/05/59', 58, 7);
INSERT INTO usuaris VALUES (2375, 'Leila', 'López Bañuelos', 'D', '42 Rua da Rapina', 37465, 'Leila.Lopez.Banuelos@pookmail.com', '25/05/42', 93, 4);
INSERT INTO usuaris VALUES (2376, 'Purlan', 'Elizondo Abeyta', 'H', '9 La Fontanilla', 14207, 'Purlan.Elizondo.Abeyta@dodgit.com', '17/07/81', 83, 6);
INSERT INTO usuaris VALUES (2377, 'Lil', 'Peres Ayala', 'D', '43 Avda. Los llanos', 26291, 'Lil.Peres.Ayala@trashymail.com', '29/05/53', 50, 3);
INSERT INTO usuaris VALUES (2378, 'Argenis', 'Ávalos Velásquez', 'H', '79 Atamaria', 36640, 'Argenis.Avalos.Velasquez@dodgit.com', '25/08/72', 20, 5);
INSERT INTO usuaris VALUES (2379, 'Eneida', 'Valdivia Girón', NULL, '94 Rúa do Paseo', 41890, 'Eneida.Valdivia.Giron@pookmail.com', '24/05/62', 6, 1);
INSERT INTO usuaris VALUES (2380, 'Laurentina', 'Acosta Rivera', 'D', '94 Rúa Olmos', 37318, 'Laurentina.Acosta.Rivera@trashymail.com', '22/09/66', 56, 2);
INSERT INTO usuaris VALUES (2381, 'Gay', 'Oquendo Carrasquill', 'H', '27 C/ Domingo Beltrán', 2400, 'Gay.Oquendo.Carrasquill@spambob.com', '27/03/67', 89, 9);
INSERT INTO usuaris VALUES (2382, 'Liliana', 'Quesada Velasco', 'D', '3 Extramuros', 28515, 'Liliana.Quesada.Velasco@dodgit.com', '05/10/59', 10, 2);
INSERT INTO usuaris VALUES (2383, 'Elijah', 'Nazario Matías', 'H', '32 Ventanilla de Beas', 28023, 'Elijah.Nazario.Matias@trashymail.com', '02/06/48', 60, 10);
INSERT INTO usuaris VALUES (2384, 'Edita', 'Segura Henríquez', 'D', '27 Plazuela do Porto', 38430, 'Edita.Segura.Henriquez@trashymail.com', '12/05/52', 73, 11);
INSERT INTO usuaris VALUES (2385, 'Antipas', 'Mojica Gastelum', NULL, '68 Calle Aduana', 1206, 'Antipas.Mojica.Gastelum@trashymail.com', '17/11/52', 54, 3);
INSERT INTO usuaris VALUES (2386, 'Hortensio', 'Agosto Vaca', 'H', '18 Ctra. de la Puerta', 26588, 'Hortensio.Agosto.Vaca@pookmail.com', '23/04/81', 68, 2);
INSERT INTO usuaris VALUES (2387, 'Lioba', 'Alcantar Mata', 'D', '29 Paseo Junquera', 12450, 'Lioba.Alcantar.Mata@pookmail.com', '24/06/50', 45, 5);
INSERT INTO usuaris VALUES (2388, 'Bartolo', 'Valladares Coronado', 'H', '11 Boriñaur enparantza', 7519, 'Bartolo.Valladares.Coronado@trashymail.com', '02/05/77', 43, 10);
INSERT INTO usuaris VALUES (2389, 'Temis', 'Miramontes Centeno', 'D', '35 Paseo del Atlántico', 17486, 'Temis.Miramontes.Centeno@pookmail.com', '30/11/74', 77, 4);
INSERT INTO usuaris VALUES (2390, 'Aniria', 'Caldera Pantoja', 'D', '86 Canónigo Valiño', 46340, 'Aniria.Caldera.Pantoja@mailinator.com', '04/05/41', 35, 8);
INSERT INTO usuaris VALUES (2391, 'Acnin', 'Carranza Campos', 'D', '50 Ventanilla de Beas', 27850, 'Acnin.Carranza.Campos@dodgit.com', '14/07/74', 52, 7);
INSERT INTO usuaris VALUES (2392, 'Branko', 'Barraza Acosta', 'H', '29 Avendaño', 4271, 'Branko.Barraza.Acosta@trashymail.com', '28/09/68', 37, 11);
INSERT INTO usuaris VALUES (2393, 'Loída', 'Juárez Gonzales', 'D', '52 Comandante Izarduy', 8780, 'Loida.Juarez.Gonzales@pookmail.com', '19/09/62', 11, 6);
INSERT INTO usuaris VALUES (2394, 'Cesarina', 'Paez Avilés', 'D', '27 Herrería', 18180, 'Cesarina.Paez.Aviles@pookmail.com', '04/05/79', 28, NULL);
INSERT INTO usuaris VALUES (2395, 'Ciset', 'Serrano Marcos', 'H', '55 Avda. Rio Nalon', 33172, 'Ciset.Serrano.Marcos@spambob.com', '09/06/80', 24, 12);
INSERT INTO usuaris VALUES (2396, 'Sylvester', 'Casárez Holguín', 'H', '87 C/ Arana', 2630, 'Sylvester.Casarez.Holguin@dodgit.com', '25/10/71', 7, 10);
INSERT INTO usuaris VALUES (2397, 'Juancruz', 'Matos Fuentes', 'H', '35 Urzáiz', 44550, 'Juancruz.Matos.Fuentes@trashymail.com', '20/03/53', 5, 8);
INSERT INTO usuaris VALUES (2398, 'Valeska', 'Chacón Serrano', 'D', '47 Eusebio Dávila', 41370, 'Valeska.Chacon.Serrano@pookmail.com', '02/09/81', 35, NULL);
INSERT INTO usuaris VALUES (2399, 'Otniel', 'Rolón Villa', 'H', '92 Avda. Enrique Peinador', 37185, 'Otniel.Rolon.Villa@dodgit.com', '24/10/44', 36, 4);
INSERT INTO usuaris VALUES (2400, 'Lorenza', 'Tórrez Carrasquill', 'D', '68 Escuadro', 46860, 'Lorenza.Torrez.Carrasquill@trashymail.com', '01/07/52', 62, 1);
INSERT INTO usuaris VALUES (2401, 'Emperatriz', 'Carvajal Negrete', 'D', '98 Calle Carril de la Fuente', 13195, 'Emperatriz.Carvajal.Negrete@mailinator.com', '10/11/48', 87, 11);
INSERT INTO usuaris VALUES (2402, 'Miren', 'Salgado Girón', NULL, '77 Visitación de la Encina', 37724, 'Miren.Salgado.Giron@spambob.com', '07/03/40', 58, 11);
INSERT INTO usuaris VALUES (2403, 'Joab', 'Nazario Carrasquill', 'H', '97 Avda. de la Estación', 28594, 'Joab.Nazario.Carrasquill@spambob.com', '26/08/71', 96, 5);
INSERT INTO usuaris VALUES (2404, 'Leonard', 'Lozano Villegas', 'H', '69 Avda. Alameda Sundheim', 22550, 'Leonard.Lozano.Villegas@mailinator.com', '06/02/60', 70, 11);
INSERT INTO usuaris VALUES (2405, 'Piperion', 'Otero Navarrete', 'H', '86 C/ Libertad', 5430, 'Piperion.Otero.Navarrete@dodgit.com', '22/10/59', 26, 4);
INSERT INTO usuaris VALUES (2406, 'Fatima', 'Ruelas Maya', 'D', '67 Avda. Andalucía', 26146, 'Fatima.Ruelas.Maya@pookmail.com', '23/05/66', 82, 3);
INSERT INTO usuaris VALUES (2407, 'Noel', 'Gaitán Heredia', 'D', '35 C/ Libertad', 5113, 'Noel.Gaitan.Heredia@spambob.com', '29/10/67', 74, 12);
INSERT INTO usuaris VALUES (2408, 'Loreley', 'Colunga Rosario', 'D', '24 Celso Emilio Ferreiro', 50690, 'Loreley.Colunga.Rosario@trashymail.com', '25/06/64', 44, NULL);
INSERT INTO usuaris VALUES (2409, 'Betiana', 'Velásquez Rosado', 'D', '46 Socampo', 37656, 'Betiana.Velasquez.Rosado@pookmail.com', '09/06/77', 98, 1);
INSERT INTO usuaris VALUES (2410, 'Chandra', 'Meza Alarcón', NULL, '61 Camiño Ancho', 37779, 'Chandra.Meza.Alarcon@trashymail.com', '27/02/75', 41, 6);
INSERT INTO usuaris VALUES (2411, 'Robustiano', 'Malave Banda', 'H', '85 Reyes Católicos', 9250, 'Robustiano.Malave.Banda@trashymail.com', '03/01/79', 14, 4);
INSERT INTO usuaris VALUES (2412, 'Claudina', 'Uribe Maya', 'D', '95 Cádiz', 18518, 'Claudina.Uribe.Maya@trashymail.com', '11/02/74', 85, 6);
INSERT INTO usuaris VALUES (2413, 'Isis', 'Treviño Bahena', 'D', '5 Rua da Rapina', 37494, 'Isis.Trevino.Bahena@mailinator.com', '11/07/54', 82, 12);
INSERT INTO usuaris VALUES (2414, 'Neus', 'Roldán Collazo', 'D', '38 C/ Amoladera', 28816, 'Neus.Roldan.Collazo@spambob.com', '30/03/48', 78, 7);
INSERT INTO usuaris VALUES (2415, 'Iberio', 'Linares Jaimes', 'H', '56 Carretera del Muelle', 12400, 'Iberio.Linares.Jaimes@mailinator.com', '03/06/85', 72, 12);
INSERT INTO usuaris VALUES (2416, 'Crístoforo', 'Palomo Nazario', 'H', '47 Extramuros', 28491, 'Cristoforo.Palomo.Nazario@pookmail.com', '05/06/82', 6, 11);
INSERT INTO usuaris VALUES (2417, 'Gary', 'Aguilar Aranda', 'H', '80 Ctra. Beas-Cortijos Nuevos', 26580, 'Gary.Aguilar.Aranda@pookmail.com', '20/10/78', 36, 6);
INSERT INTO usuaris VALUES (2418, 'Justino', 'Alarcón Galván', 'H', '6 Calvo Sotelo', 47680, 'Justino.Alarcon.Galvan@pookmail.com', '05/02/59', 79, 11);
INSERT INTO usuaris VALUES (2419, 'Cornelio', 'Carmona Almonte', 'H', '48 C/ Libertad', 5130, 'Cornelio.Carmona.Almonte@pookmail.com', '15/01/47', 99, NULL);
INSERT INTO usuaris VALUES (2420, 'Canan', 'Aguilera Barraza', 'H', '33 Antonio Vázquez', 38530, 'Canan.Aguilera.Barraza@pookmail.com', '17/03/78', 41, 1);
INSERT INTO usuaris VALUES (2421, 'Abo', 'Vanegas Flores', 'H', '23 Maestro Puig Valera', 33560, 'Abo.Vanegas.Flores@pookmail.com', '28/01/59', 88, 11);
INSERT INTO usuaris VALUES (2422, 'Esaú', 'Cordero Valencia', 'H', '6 Plaza Colón', 26122, 'Esau.Cordero.Valencia@dodgit.com', '08/08/41', 30, 8);
INSERT INTO usuaris VALUES (2423, 'Filademo', 'Guevara Salas', 'H', '25 Enxertos', 37607, 'Filademo.Guevara.Salas@mailinator.com', '02/02/75', 27, 5);
INSERT INTO usuaris VALUES (2424, 'Amadeo', 'Sierra Rincón', 'H', '34 Av. Zumalakarregi', 3109, 'Amadeo.Sierra.Rincon@mailinator.com', '20/01/68', 97, 4);
INSERT INTO usuaris VALUES (2425, 'Querima', 'Amador Arriaga', 'D', '44 Canónigo Valiño', 46530, 'Querima.Amador.Arriaga@dodgit.com', '20/08/63', 1, 9);
INSERT INTO usuaris VALUES (2426, 'Quique', 'Aponte Escobedo', 'H', '57 San Andrés', 37312, 'Quique.Aponte.Escobedo@trashymail.com', '20/02/65', 86, 6);
INSERT INTO usuaris VALUES (2427, 'Montserrat', 'Alcalá Griego', 'H', '46 Rúa do Paseo', 41897, 'Montserrat.Alcala.Griego@spambob.com', '31/03/80', 80, NULL);
INSERT INTO usuaris VALUES (2428, 'Ismelda', 'Concepción Espinosa', 'D', '68 San Andrés', 37272, 'Ismelda.Concepcion.Espinosa@mailinator.com', '19/05/81', 23, NULL);
INSERT INTO usuaris VALUES (2429, 'Emelinda', 'Sánchez Núñez', 'D', '72 Avda. de la Estación', 28691, 'Emelinda.Sanchez.Nunez@pookmail.com', '13/10/52', 29, 4);
INSERT INTO usuaris VALUES (2430, 'Hidalgo', 'Luna Laboy', 'H', '47 Valadouro', 48142, 'Hidalgo.Luna.Laboy@mailinator.com', '13/09/51', 65, 12);
INSERT INTO usuaris VALUES (2431, 'Canan', 'Zayas Gutiérrez', 'H', '24 Paseo del Atlántico', 18127, 'Canan.Zayas.Gutierrez@dodgit.com', '17/11/51', 93, 7);
INSERT INTO usuaris VALUES (2432, 'Cassandra', 'Treviño Gaitán', NULL, '64 C/ Canarias', 20200, 'Cassandra.Trevino.Gaitan@spambob.com', '08/12/73', 59, 1);
INSERT INTO usuaris VALUES (2433, 'Ifigenia', 'Lugo Olmos', 'D', '40 Calle Carril de la Fuente', 13192, 'Ifigenia.Lugo.Olmos@pookmail.com', '15/03/44', 26, 6);
INSERT INTO usuaris VALUES (2434, 'Emilia', 'Ramos Tello', 'D', '76 Av. Santiago Lapuente', 50710, 'Emilia.Ramos.Tello@trashymail.com', '09/12/83', 53, NULL);
INSERT INTO usuaris VALUES (2435, 'Renaldo', 'Ayala Guillén', 'H', '62 Antonio Vázquez', 38780, 'Renaldo.Ayala.Guillen@dodgit.com', '01/03/57', 8, 4);
INSERT INTO usuaris VALUES (2436, 'Jamila', 'Henríquez Castellanos', 'D', '16 C/ Pablo Iglesias', 26315, 'Jamila.Henriquez.Castellanos@spambob.com', '01/06/49', 26, NULL);
INSERT INTO usuaris VALUES (2437, 'Duilio', 'Frías Vigil', 'H', '94 Avda. de Andalucía', 29440, 'Duilio.Frias.Vigil@pookmail.com', '04/01/48', 14, 8);
INSERT INTO usuaris VALUES (2438, 'Idelia', 'Mota Dávila', 'D', '78 Rúa de San Pedro', 37865, 'Idelia.Mota.Davila@spambob.com', '10/02/85', 77, 5);
INSERT INTO usuaris VALUES (2439, 'Branco', 'Casares Lomeli', 'H', '67 Ctra. de Fuentenueva', 28190, 'Branco.Casares.Lomeli@trashymail.com', '25/08/57', 41, NULL);
INSERT INTO usuaris VALUES (2440, 'Casimira', 'Cárdenas Gastelum', 'D', '32 Plaza Colón', 26122, 'Casimira.Cardenas.Gastelum@dodgit.com', '12/03/58', 21, 1);
INSERT INTO usuaris VALUES (2441, 'Eileen', 'Ornelas Díaz', 'D', '62 Paraguay', 3638, 'Eileen.Ornelas.Diaz@spambob.com', '07/08/43', 83, NULL);
INSERT INTO usuaris VALUES (2442, 'Dugan', 'Marcos Montalvo', 'H', '42 Puerta Nueva', 36194, 'Dugan.Marcos.Montalvo@dodgit.com', '01/10/71', 47, 11);
INSERT INTO usuaris VALUES (2443, 'Pompeo', 'Mendoza Zúñiga', 'H', '22 Avda. Rio Nalon', 33150, 'Pompeo.Mendoza.Zuniga@dodgit.com', '05/07/58', 5, 3);
INSERT INTO usuaris VALUES (2444, 'Aristóteles', 'Jáquez Bañuelos', 'H', '5 Apartado de Correos', 37455, 'Aristoteles.Jaquez.Banuelos@dodgit.com', '26/03/66', 7, 9);
INSERT INTO usuaris VALUES (2445, 'Umberto', 'Cruz Rubio', 'H', '9 Constitución', 36900, 'Umberto.Cruz.Rubio@mailinator.com', '30/08/55', 36, 4);
INSERT INTO usuaris VALUES (2446, 'Yocasta', 'Hernandes Leal', 'D', '71 Antonio Vázquez', 38640, 'Yocasta.Hernandes.Leal@trashymail.com', '12/06/53', 62, 11);
INSERT INTO usuaris VALUES (2447, 'Flaminio', 'Zúñiga Ruelas', 'H', '14 Calle Proc. San Sebastián', 12600, 'Flaminio.Zuniga.Ruelas@mailinator.com', '13/12/60', 12, 4);
INSERT INTO usuaris VALUES (2448, 'Selina', 'Cedillo Hurtado', 'D', '14 Visitación de la Encina', 37710, 'Selina.Cedillo.Hurtado@dodgit.com', '05/03/66', 94, 6);
INSERT INTO usuaris VALUES (2449, 'Beltran', 'Lomeli Delgadillo', 'H', '35 Rua da Rapina', 37470, 'Beltran.Lomeli.Delgadillo@trashymail.com', '19/02/62', 39, 2);
INSERT INTO usuaris VALUES (2450, 'Jesabel', 'Barrios Benavidez', 'D', '64 Escuadro', 46960, 'Jesabel.Barrios.Benavidez@trashymail.com', '27/08/40', 85, 3);
INSERT INTO usuaris VALUES (2451, 'Rosalie', 'Mayonga Perales', 'D', '53 Enxertos', 37541, 'Rosalie.Mayonga.Perales@trashymail.com', '13/07/66', 76, 5);
INSERT INTO usuaris VALUES (2452, 'Gina', 'Santiago Alcantar', 'D', '31 Avenida Cervantes', 48213, 'Gina.Santiago.Alcantar@mailinator.com', '28/12/69', 80, 6);
INSERT INTO usuaris VALUES (2453, 'Petruos', 'Menéndez Luján', 'H', '6 C/ Domingo Beltrán', 2240, 'Petruos.Menendez.Lujan@trashymail.com', '30/04/52', 57, 1);
INSERT INTO usuaris VALUES (2454, 'Barry', 'Jasso Alvarado', 'H', '87 Avda. Andalucía', 26134, 'Barry.Jasso.Alvarado@spambob.com', '08/07/41', 34, 7);
INSERT INTO usuaris VALUES (2455, 'Eufrasio', 'Sandoval Jáquez', 'H', '2 Antonio Vázquez', 38750, 'Eufrasio.Sandoval.Jaquez@dodgit.com', '13/03/42', 47, 5);
INSERT INTO usuaris VALUES (2456, 'Manque', 'Raya Ulloa', 'D', '78 Avendaño', 4250, 'Manque.Raya.Ulloa@dodgit.com', '14/10/41', 41, 2);
INSERT INTO usuaris VALUES (2457, 'Aimon', 'Nava Jaramillo', 'H', '83 Caño', 32814, 'Aimon.Nava.Jaramillo@pookmail.com', '29/03/57', 71, 7);
INSERT INTO usuaris VALUES (2458, 'Karin', 'Escalante Nava', 'D', '90 Reyes Católicos', 9500, 'Karin.Escalante.Nava@trashymail.com', '10/07/63', 76, 4);
INSERT INTO usuaris VALUES (2459, 'Verbena', 'Carbajal Prado', 'D', '3 Avda. de Andalucía', 29200, 'Verbena.Carbajal.Prado@dodgit.com', '13/09/82', 55, 12);
INSERT INTO usuaris VALUES (2460, 'Omero', 'Romero Cadena', 'H', '2 Padre Caro', 13730, 'Omero.Romero.Cadena@spambob.com', '14/01/74', 55, 7);
INSERT INTO usuaris VALUES (2461, 'Fiamma', 'Iglesias Comejo', 'D', '43 Visitación de la Encina', 37760, 'Fiamma.Iglesias.Comejo@dodgit.com', '22/10/49', 11, 4);
INSERT INTO usuaris VALUES (2462, 'Daryl', 'Badillo Ramos', 'H', '86 Avenida Cervantes', 48330, 'Daryl.Badillo.Ramos@spambob.com', '25/05/72', 54, 10);
INSERT INTO usuaris VALUES (2463, 'Avelino', 'Armenta Sauceda', 'H', '93 Avenida Cervantes', 48350, 'Avelino.Armenta.Sauceda@spambob.com', '07/05/76', 22, 8);
INSERT INTO usuaris VALUES (2464, 'Kusi', 'Casas Naranjo', 'D', '91 Avenida Cervantes', 48292, 'Kusi.Casas.Naranjo@trashymail.com', '18/02/44', 41, 8);
INSERT INTO usuaris VALUES (2465, 'Orly', 'Collazo Segovia', 'D', '53 Canónigo Valiño', 46210, 'Orly.Collazo.Segovia@pookmail.com', '22/01/84', 20, 7);
INSERT INTO usuaris VALUES (2466, 'Nabucodonosor', 'Orosco Calderón', 'H', '93 Avda. de la Estación', 28694, 'Nabucodonosor.Orosco.Calderon@spambob.com', '27/05/77', 79, NULL);
INSERT INTO usuaris VALUES (2467, 'Sadoth', 'Manzanares Miramontes', 'H', '74 Camiño Real', 48370, 'Sadoth.Manzanares.Miramontes@spambob.com', '26/08/56', 52, 4);
INSERT INTO usuaris VALUES (2468, 'Felisardo', 'Angulo Gutiérrez', 'H', '86 Ctra. Hornos', 26220, 'Felisardo.Angulo.Gutierrez@spambob.com', '09/07/44', 81, 10);
INSERT INTO usuaris VALUES (2469, 'Abad', 'Serrato Galvez', 'H', '77 Estrela', 40194, 'Abad.Serrato.Galvez@trashymail.com', '23/08/40', 33, 4);
INSERT INTO usuaris VALUES (2470, 'Yaguatí', 'Galván Aguirre', 'H', '51 La Fontanilla', 14270, 'Yaguati.Galvan.Aguirre@trashymail.com', '30/07/55', 37, NULL);
INSERT INTO usuaris VALUES (2471, 'Helga', 'Barrera Ramón', NULL, '61 Ctra. Hornos', 26224, 'Helga.Barrera.Ramon@trashymail.com', '26/05/81', NULL, 10);
INSERT INTO usuaris VALUES (2472, 'Gisel', 'Villalpando Nieves', 'D', '48 Caño', 33110, 'Gisel.Villalpando.Nieves@spambob.com', '13/03/42', 60, 3);
INSERT INTO usuaris VALUES (2473, 'Emigdio', 'Caldera Rivero', 'H', '7 Ctra. Villena', 34000, 'Emigdio.Caldera.Rivero@mailinator.com', '02/08/82', 92, 11);
INSERT INTO usuaris VALUES (2474, 'Leonora', 'Alicea Villalpando', 'D', '46 Carretera Cádiz-Málaga', 20737, 'Leonora.Alicea.Villalpando@pookmail.com', '28/12/44', 1, 8);
INSERT INTO usuaris VALUES (2475, 'Job', 'Carrasco Robledo', 'H', '31 Avda. Generalísimo', 31830, 'Job.Carrasco.Robledo@dodgit.com', '20/11/48', 3, 11);
INSERT INTO usuaris VALUES (2476, 'Quique', 'Olmos Valles', 'H', '27 C/ Eras', 28749, 'Quique.Olmos.Valles@mailinator.com', '21/07/84', 96, NULL);
INSERT INTO usuaris VALUES (2477, 'Sonsoles', 'Alemán Naranjo', 'D', '63 Eusebio Dávila', 41440, 'Sonsoles.Aleman.Naranjo@dodgit.com', '22/09/40', 18, 9);
INSERT INTO usuaris VALUES (2478, 'Christophe', 'Apodaca Muñiz', 'H', '35 Ctra. Bailén-Motril', 23215, 'Christophe.Apodaca.Muniz@mailinator.com', '27/09/48', 81, 8);
INSERT INTO usuaris VALUES (2479, 'Anthony', 'Cano Negrón', 'H', '93 Cádiz', 18518, 'Anthony.Cano.Negron@spambob.com', '17/02/78', 26, 10);
INSERT INTO usuaris VALUES (2480, 'Helda', 'Serrano Murillo', 'D', '65 Rúa de San Pedro', 37871, 'Helda.Serrano.Murillo@pookmail.com', '26/06/82', 47, 6);
INSERT INTO usuaris VALUES (2481, 'Madelón', 'Solís Espinosa', 'D', '95 Puerta Nueva', 36300, 'Madelon.Solis.Espinosa@mailinator.com', '09/03/78', 61, 11);
INSERT INTO usuaris VALUES (2482, 'Casandro', 'Delgadillo Ponce', 'H', '92 Puerto Lugar', 29718, 'Casandro.Delgadillo.Ponce@dodgit.com', '09/12/40', 19, 12);
INSERT INTO usuaris VALUES (2483, 'Adimar', 'Coronado Rendón', 'H', '29 C/ Señores Curas', 12123, 'Adimar.Coronado.Rendon@mailinator.com', '20/03/55', 96, 9);
INSERT INTO usuaris VALUES (2484, 'Laureano', 'Arriaga Escamilla', 'H', '51 C/ Pablo Iglesias', 26315, 'Laureano.Arriaga.Escamilla@mailinator.com', '14/11/51', 4, 6);
INSERT INTO usuaris VALUES (2485, 'Cassandre', 'Banda Arroyo', 'D', '85 Av. Santiago Lapuente', 50780, 'Cassandre.Banda.Arroyo@mailinator.com', '13/08/60', 68, 11);
INSERT INTO usuaris VALUES (2486, 'Bienvenido', 'Salas Sedillo', 'H', '20 C/ Cuevas de Ambrosio', 23712, 'Bienvenido.Salas.Sedillo@spambob.com', '24/08/50', 9, 4);
INSERT INTO usuaris VALUES (2487, 'Demeter', 'Jasso Muñoz', 'H', '5 Estrela', 38870, 'Demeter.Jasso.Munoz@spambob.com', '26/03/56', 32, 4);
INSERT INTO usuaris VALUES (2488, 'Ivana', 'Mena Lucio', 'D', '86 Ctra. Villena', 34400, 'Ivana.Mena.Lucio@mailinator.com', '17/01/65', 31, 1);
INSERT INTO usuaris VALUES (2489, 'Teodora', 'Altamirano Ybarra', 'D', '94 Rúa de San Pedro', 37797, 'Teodora.Altamirano.Ybarra@pookmail.com', '21/10/44', 22, 9);
INSERT INTO usuaris VALUES (2490, 'Khalil', 'Aguayo Rendón', 'H', '20 Ventanilla de Beas', 28189, 'Khalil.Aguayo.Rendon@trashymail.com', '04/01/44', 83, 8);
INSERT INTO usuaris VALUES (2491, 'Reyes', 'Montano Escalante', 'H', '92 Calle Proc. San Sebastián', 12599, 'Reyes.Montano.Escalante@pookmail.com', '20/04/45', 41, 8);
INSERT INTO usuaris VALUES (2492, 'Agueda', 'Hernandes Heredia', 'D', '77 Cartagena', 30540, 'Agueda.Hernandes.Heredia@pookmail.com', '08/10/67', 11, 10);
INSERT INTO usuaris VALUES (2493, 'Gus', 'Sepúlveda Almaraz', 'H', '17 El Roqueo', 15911, 'Gus.Sepulveda.Almaraz@pookmail.com', '30/10/53', 36, 1);
INSERT INTO usuaris VALUES (2494, 'Alhueche', 'Loya Carranza', 'H', '5 Quevedo', 15400, 'Alhueche.Loya.Carranza@mailinator.com', '24/10/83', 78, 6);
INSERT INTO usuaris VALUES (2495, 'Heberto', 'Barraza Maldonado', 'H', '8 C/ Manuel Iradier', 3787, 'Heberto.Barraza.Maldonado@spambob.com', '26/12/50', 7, 4);
INSERT INTO usuaris VALUES (2496, 'Ervino', 'Venegas Peres', 'H', '36 Rosa de los Vientos', 13370, 'Ervino.Venegas.Peres@pookmail.com', '19/12/79', 25, 7);
INSERT INTO usuaris VALUES (2497, 'Vitaliano', 'Matías Barrientos', 'H', '43 Avda. Generalísimo', 31630, 'Vitaliano.Matias.Barrientos@mailinator.com', '15/04/78', 40, NULL);
INSERT INTO usuaris VALUES (2498, 'Pirra', 'Galarza Fajardo', 'D', '39 Plaza Maior', 37214, 'Pirra.Galarza.Fajardo@spambob.com', '21/05/58', 73, 2);
INSERT INTO usuaris VALUES (2499, 'Bertilda', 'Razo Bernal', 'D', '95 Avda. de la Estación', 28609, 'Bertilda.Razo.Bernal@pookmail.com', '01/02/53', 17, NULL);
INSERT INTO usuaris VALUES (2500, 'Dalmacio', 'Roybal Sarabia', 'H', '95 Avendaño', 4260, 'Dalmacio.Roybal.Sarabia@mailinator.com', '09/09/72', 31, 9);
INSERT INTO usuaris VALUES (2501, 'Kurt', 'Aparicio Agosto', 'H', '67 Av. Santiago Lapuente', 50793, 'Kurt.Aparicio.Agosto@spambob.com', '14/01/75', 35, 7);
INSERT INTO usuaris VALUES (2502, 'Carmina', 'Aguirre Mercado', 'D', '35 Herrería', 18240, 'Carmina.Aguirre.Mercado@trashymail.com', '05/05/84', 76, 12);
INSERT INTO usuaris VALUES (2503, 'Leonora', 'Lozano Segovia', 'D', '38 Maestro Puig Valera', 33630, 'Leonora.Lozano.Segovia@dodgit.com', '15/02/78', 32, 6);
INSERT INTO usuaris VALUES (2504, 'Alterio', 'Huerta Ortega', 'H', '72 Carretera del Muelle', 12311, 'Alterio.Huerta.Ortega@spambob.com', '23/07/72', 62, 2);
INSERT INTO usuaris VALUES (2505, 'Narcisa', 'Ayala Hinojosa', 'D', '82 Avenida Cervantes', 48289, 'Narcisa.Ayala.Hinojosa@dodgit.com', '20/05/49', 35, 1);
INSERT INTO usuaris VALUES (2506, 'Dara', 'Rincón Rivas', 'D', '10 Rua da Rapina', 37486, 'Dara.Rincon.Rivas@dodgit.com', '18/07/62', 67, 8);
INSERT INTO usuaris VALUES (2507, 'Casandra', 'Roque Serna', 'D', '6 Estrela', 39470, 'Casandra.Roque.Serna@trashymail.com', '08/12/65', 2, NULL);
INSERT INTO usuaris VALUES (2508, 'James', 'Jurado Godoy', 'H', '41 Valadouro', 48114, 'James.Jurado.Godoy@dodgit.com', '13/08/68', 26, NULL);
INSERT INTO usuaris VALUES (2509, 'Florencia', 'Nieves Valdés', 'D', '52 Reiseñor', 45593, 'Florencia.Nieves.Valdes@dodgit.com', '24/12/59', 3, 11);
INSERT INTO usuaris VALUES (2510, 'Zofía', 'Bernal Muro', 'D', '10 La Fontanilla', 14208, 'Zofia.Bernal.Muro@spambob.com', '12/07/83', 74, 4);
INSERT INTO usuaris VALUES (2511, 'Lincoln', 'Romero Avilés', 'D', '45 Canónigo Valiño', 46290, 'Lincoln.Romero.Aviles@pookmail.com', '07/10/77', 69, 11);
INSERT INTO usuaris VALUES (2512, 'Loretta', 'Calderón Godoy', 'D', '54 Ctra. de la Puerta', 27170, 'Loretta.Calderon.Godoy@spambob.com', '16/03/42', 96, 3);
INSERT INTO usuaris VALUES (2513, 'Nidia', 'Ortiz Cotto', 'D', '6 Escuadro', 47162, 'Nidia.Ortiz.Cotto@mailinator.com', '02/07/56', 45, 8);
INSERT INTO usuaris VALUES (2514, 'Acab', 'Cantú Borrego', 'H', '57 Rosa de los Vientos', 13332, 'Acab.Cantu.Borrego@pookmail.com', '22/12/44', 77, 3);
INSERT INTO usuaris VALUES (2515, 'Mitra', 'Padrón Tejeda', 'D', '53 Avda. Los llanos', 26259, 'Mitra.Padron.Tejeda@mailinator.com', '22/06/62', 40, 6);
INSERT INTO usuaris VALUES (2516, 'Cosette', 'Razo Trujillo', 'D', '30 San Andrés', 37267, 'Cosette.Razo.Trujillo@dodgit.com', '16/05/43', 95, 5);
INSERT INTO usuaris VALUES (2517, 'Eleodoro', 'Gamez Quiroz', 'H', '76 C/ Fernández de Leceta', 3350, 'Eleodoro.Gamez.Quiroz@pookmail.com', '18/03/68', 87, 9);
INSERT INTO usuaris VALUES (2518, 'Cloris', 'Gurule Manzanares', 'D', '15 Boriñaur enparantza', 7750, 'Cloris.Gurule.Manzanares@trashymail.com', '16/01/74', 88, 5);
INSERT INTO usuaris VALUES (2519, 'Caren', 'Alemán Tello', 'D', '37 Alvaro Cunqueiro', 41250, 'Caren.Aleman.Tello@trashymail.com', '09/04/46', 29, 10);
INSERT INTO usuaris VALUES (2520, 'Malena', 'Lucero Armendáriz', 'D', '44 C/ Arana', 2410, 'Malena.Lucero.Armendariz@dodgit.com', '11/07/48', 62, 7);
INSERT INTO usuaris VALUES (2521, 'Mathías', 'Sepúlveda Mercado', 'H', '73 C/ Henan Cortes', 28960, 'Mathias.Sepulveda.Mercado@mailinator.com', '07/03/52', 72, NULL);
INSERT INTO usuaris VALUES (2522, 'Dunstan', 'Luevano Almaraz', 'H', '11 Cartagena', 30180, 'Dunstan.Luevano.Almaraz@mailinator.com', '01/10/71', 33, 6);
INSERT INTO usuaris VALUES (2523, 'Amarilla', 'Arteaga Arce', 'D', '86 Plaza de España', 15686, 'Amarilla.Arteaga.Arce@dodgit.com', '30/08/40', 67, 8);
INSERT INTO usuaris VALUES (2524, 'Ivonne', 'Armas Aguirre', 'D', '4 Reyes Católicos', 10840, 'Ivonne.Armas.Aguirre@mailinator.com', '02/12/71', 68, 1);
INSERT INTO usuaris VALUES (2525, 'Marín', 'Esparza Saldivar', NULL, '60 Crta. Cádiz-Málaga', 12230, 'Marin.Esparza.Saldivar@dodgit.com', '02/03/49', 77, 11);
INSERT INTO usuaris VALUES (2526, 'Aciscio', 'Matías Casillas', 'H', '53 C/ Fernández de Leceta', 3460, 'Aciscio.Matias.Casillas@trashymail.com', '02/12/51', 0, 11);
INSERT INTO usuaris VALUES (2527, 'Loreto', 'Bueno Soto', 'H', '95 Reiseñor', 45860, 'Loreto.Bueno.Soto@pookmail.com', '23/07/78', 28, 1);
INSERT INTO usuaris VALUES (2528, 'Eluney', 'Casárez Candelaria', 'D', '84 Estrela', 38900, 'Eluney.Casarez.Candelaria@spambob.com', '01/09/65', 89, 3);
INSERT INTO usuaris VALUES (2529, 'Mennos', 'Noriega Matos', 'H', '63 Quevedo', 15500, 'Mennos.Noriega.Matos@dodgit.com', '12/04/51', 99, 6);
INSERT INTO usuaris VALUES (2530, 'Albino', 'Mojica Carrasco', 'H', '22 Pl. Virgen Blanca', 8560, 'Albino.Mojica.Carrasco@dodgit.com', '26/04/56', 68, 4);
INSERT INTO usuaris VALUES (2531, 'Marcello', 'Gómez Escobar', NULL, '30 Apartado de Correos', 37452, 'Marcello.Gomez.Escobar@trashymail.com', '26/03/84', 79, 11);
INSERT INTO usuaris VALUES (2532, 'Neptuno', 'Pagan Salazar', NULL, '92 Ventanilla de Beas', 27770, 'Neptuno.Pagan.Salazar@spambob.com', '26/03/59', 6, 5);
INSERT INTO usuaris VALUES (2533, 'Sibila', 'Jasso Solís', 'D', '46 Reyes Católicos', 9400, 'Sibila.Jasso.Solis@spambob.com', '29/03/50', 9, 10);
INSERT INTO usuaris VALUES (2534, 'Relinda', 'Ceja Longoria', 'D', '38 C/ Angosto', 23486, 'Relinda.Ceja.Longoria@dodgit.com', '09/03/74', 12, 10);
INSERT INTO usuaris VALUES (2535, 'Florio', 'Herrera Verdugo', 'H', '52 Rua da Rapina', 37494, 'Florio.Herrera.Verdugo@pookmail.com', '09/11/43', 41, 8);
INSERT INTO usuaris VALUES (2536, 'Day', 'Roldán Ponce', 'H', '19 Rio Segura', 31490, 'Day.Roldan.Ponce@dodgit.com', '27/06/45', 35, NULL);
INSERT INTO usuaris VALUES (2537, 'Joaquin', 'Caldera Iglesias', 'H', '24 C/ Rosa de los Vientos', 11380, 'Joaquin.Caldera.Iglesias@trashymail.com', '20/12/62', 73, 6);
INSERT INTO usuaris VALUES (2538, 'Evelyn', 'Macías Flórez', 'D', '22 Caño', 32911, 'Evelyn.Macias.Florez@spambob.com', '16/02/68', 89, 8);
INSERT INTO usuaris VALUES (2539, 'Calíope', 'Quesada Regalado', 'D', '27 Socampo', 37670, 'Caliope.Quesada.Regalado@dodgit.com', '03/04/75', 16, 1);
INSERT INTO usuaris VALUES (2540, 'Boris', 'Palomino Navarro', 'H', '6 Maestro Puig Valera', 33746, 'Boris.Palomino.Navarro@dodgit.com', '28/08/53', 64, 11);
INSERT INTO usuaris VALUES (2541, 'Ilva', 'Espinosa Maestas', 'D', '24 Plazuela do Porto', 37880, 'Ilva.Espinosa.Maestas@pookmail.com', '04/03/83', 67, 3);
INSERT INTO usuaris VALUES (2542, 'Febe', 'Altamirano Almaraz', 'D', '39 C/ Benito Guinea', 8397, 'Febe.Altamirano.Almaraz@spambob.com', '19/04/41', 28, 12);
INSERT INTO usuaris VALUES (2543, 'Purificación', 'Macías Núñez', 'D', '35 Puerta Nueva', 36440, 'Purificacion.Macias.Nunez@dodgit.com', '07/03/85', 61, 9);
INSERT INTO usuaris VALUES (2544, 'Marcella', 'Luevano Batista', 'D', '83 Ctra. Villena', 34800, 'Marcella.Luevano.Batista@pookmail.com', '28/02/41', 11, 9);
INSERT INTO usuaris VALUES (2545, 'Valerie', 'Garrido Ybarra', 'D', '77 Fuente del Gallo', 15110, 'Valerie.Garrido.Ybarra@trashymail.com', '08/09/75', 14, 9);
INSERT INTO usuaris VALUES (2546, 'Numa', 'Ordóñez Cordero', 'D', '5 Reiseñor', 46137, 'Numa.Ordonez.Cordero@mailinator.com', '28/03/65', 17, 1);
INSERT INTO usuaris VALUES (2547, 'Efreín', 'Armendáriz Olivo', 'H', '73 C/ Señores Curas', 11688, 'Efrein.Armendariz.Olivo@dodgit.com', '24/04/56', 49, 4);
INSERT INTO usuaris VALUES (2548, 'Natalí', 'Huerta Padilla', 'D', '69 Comandante Izarduy', 9123, 'Natali.Huerta.Padilla@trashymail.com', '08/05/43', 76, 9);
INSERT INTO usuaris VALUES (2549, 'Remedios', 'Caraballo Briseño', 'D', '41 C/ Arana', 2638, 'Remedios.Caraballo.Briseno@mailinator.com', '12/06/65', 21, 5);
INSERT INTO usuaris VALUES (2550, 'Rhode', 'Rosas Lira', 'D', '10 Bouciña', 43790, 'Rhode.Rosas.Lira@dodgit.com', '04/10/75', 84, 2);
INSERT INTO usuaris VALUES (2551, 'Agnus', 'Rivero Medina', 'D', '10 Fuente del Gallo', 14920, 'Agnus.Rivero.Medina@spambob.com', '14/08/44', 49, 4);
INSERT INTO usuaris VALUES (2552, 'Danilo', 'Santiago Perales', 'H', '57 Avda. Andalucía', 26131, 'Danilo.Santiago.Perales@pookmail.com', '21/08/67', 6, 12);
INSERT INTO usuaris VALUES (2553, 'Urbano', 'Salazar Alonzo', 'H', '28 Urzáiz', 44700, 'Urbano.Salazar.Alonzo@dodgit.com', '20/11/57', 20, 3);
INSERT INTO usuaris VALUES (2554, 'Buenaventura', 'Granados Pacheco', 'H', '70 Cañadilla', 22234, 'Buenaventura.Granados.Pacheco@pookmail.com', '03/09/51', 68, 4);
INSERT INTO usuaris VALUES (2555, 'Venus', 'Palacios Ferrer', 'D', '74 Plazuela do Porto', 38260, 'Venus.Palacios.Ferrer@spambob.com', '21/12/72', 84, 10);
INSERT INTO usuaris VALUES (2556, 'Olympia', 'Fuentes Peres', 'D', '6 Camiño Real', 48383, 'Olympia.Fuentes.Peres@spambob.com', '02/04/73', 45, 12);
INSERT INTO usuaris VALUES (2557, 'Corina', 'Aguayo Crespo', 'D', '51 Avenida Cervantes', 48313, 'Corina.Aguayo.Crespo@spambob.com', '24/12/79', 17, 3);
INSERT INTO usuaris VALUES (2558, 'Dafna', 'Villanueva Mojica', 'D', '65 Calle Carril de la Fuente', 13200, 'Dafna.Villanueva.Mojica@spambob.com', '18/08/57', 65, NULL);
INSERT INTO usuaris VALUES (2559, 'Zair', 'Peres Zambrano', 'H', '34 C/ Canarias', 19200, 'Zair.Peres.Zambrano@spambob.com', '26/12/82', 86, 4);
INSERT INTO usuaris VALUES (2560, 'Khalil', 'Limón Colunga', 'H', '9 Calle Aduana', 1117, 'Khalil.Limon.Colunga@spambob.com', '12/12/53', 10, 11);
INSERT INTO usuaris VALUES (2561, 'Basilio', 'Sauceda Rosario', 'H', '91 Salzillo', 32690, 'Basilio.Sauceda.Rosario@trashymail.com', '03/06/69', 38, 6);
INSERT INTO usuaris VALUES (2562, 'Serxio', 'Fuentes Archuleta', 'H', '44 Av. Santiago Lapuente', 50830, 'Serxio.Fuentes.Archuleta@dodgit.com', '14/07/45', 57, 2);
INSERT INTO usuaris VALUES (2563, 'Abraham', 'Lovato Mireles', 'H', '95 C/ Libertad', 5220, 'Abraham.Lovato.Mireles@trashymail.com', '30/05/71', 98, 2);
INSERT INTO usuaris VALUES (2564, 'Hildegunda', 'Medrano Mondragón', NULL, '61 Crta. Cádiz-Málaga', 12230, 'Hildegunda.Medrano.Mondragon@trashymail.com', '29/07/70', 20, 9);
INSERT INTO usuaris VALUES (2565, 'Natanael', 'Ybarra Fuentes', 'H', '78 Alcon Molina', 31110, 'Natanael.Ybarra.Fuentes@spambob.com', '08/01/78', 26, 2);
INSERT INTO usuaris VALUES (2566, 'Yanina', 'Montalvo Casares', 'D', '69 Boriñaur enparantza', 7630, 'Yanina.Montalvo.Casares@dodgit.com', '07/01/47', 4, 8);
INSERT INTO usuaris VALUES (2567, 'Rosemary', 'Alvarado Cortés', 'D', '70 Canónigo Valiño', 46380, 'Rosemary.Alvarado.Cortes@dodgit.com', '02/07/43', 6, 7);
INSERT INTO usuaris VALUES (2568, 'Arcángel', 'Jaramillo Mondragón', 'H', '77 Av. Zumalakarregi', 3190, 'Arcangel.Jaramillo.Mondragon@trashymail.com', '02/12/41', 82, 5);
INSERT INTO usuaris VALUES (2569, 'Florinda', 'Laboy Soto', 'D', '7 C/ Pablo Iglesias', 26339, 'Florinda.Laboy.Soto@trashymail.com', '07/08/77', 35, 4);
INSERT INTO usuaris VALUES (2570, 'Medardo', 'Hidalgo Paez', 'H', '10 C/ Libertad', 5420, 'Medardo.Hidalgo.Paez@spambob.com', '11/01/42', 39, 1);
INSERT INTO usuaris VALUES (2571, 'Jessie', 'Rojas Olivera', 'D', '57 Maestro Puig Valera', 33590, 'Jessie.Rojas.Olivera@trashymail.com', '08/03/50', 36, 12);
INSERT INTO usuaris VALUES (2572, 'Jackie', 'Carbajal Ferrer', 'D', '87 José matía', 1409, 'Jackie.Carbajal.Ferrer@spambob.com', '24/10/60', 19, 4);
INSERT INTO usuaris VALUES (2573, 'Leontino', 'Arce Casas', 'H', '81 C/ Benito Guinea', 8339, 'Leontino.Arce.Casas@pookmail.com', '11/03/52', 60, 1);
INSERT INTO usuaris VALUES (2574, 'Gayane', 'Alonso Calderón', NULL, '47 Inglaterra', 18539, 'Gayane.Alonso.Calderon@trashymail.com', '23/05/69', 45, 1);
INSERT INTO usuaris VALUES (2575, 'Idelfonso', 'Parra Rojo', 'H', '25 Eusebio Dávila', 41510, 'Idelfonso.Parra.Rojo@pookmail.com', '29/12/75', 93, 1);
INSERT INTO usuaris VALUES (2576, 'Gerson', 'Mascarenas Domínquez', 'H', '43 Cádiz', 18500, 'Gerson.Mascarenas.Dominquez@dodgit.com', '30/11/60', 69, 10);
INSERT INTO usuaris VALUES (2577, 'Dalmiro', 'Godínez Bustamante', 'H', '45 Caño', 32911, 'Dalmiro.Godinez.Bustamante@spambob.com', '21/09/66', 80, NULL);
INSERT INTO usuaris VALUES (2578, 'Darlene', 'Rincón Najera', 'D', '64 Avda. de la Estación', 28660, 'Darlene.Rincon.Najera@mailinator.com', '06/09/79', 73, 5);
INSERT INTO usuaris VALUES (2579, 'Azrael', 'Ortega Comejo', 'H', '43 Avda. Generalísimo', 31830, 'Azrael.Ortega.Comejo@trashymail.com', '23/12/77', 40, 1);
INSERT INTO usuaris VALUES (2580, 'Akira', 'Rincón Irizarry', 'H', '45 Plazuela do Porto', 38350, 'Akira.Rincon.Irizarry@mailinator.com', '26/03/63', 64, 11);
INSERT INTO usuaris VALUES (2581, 'Raynaldo', 'Villagómez Velázquez', 'H', '51 C/ Señores Curas', 12159, 'Raynaldo.Villagomez.Velazquez@pookmail.com', '29/02/80', 38, 11);
INSERT INTO usuaris VALUES (2582, 'Bingham', 'Esquivel Méndez', 'H', '85 Boriñaur enparantza', 7620, 'Bingham.Esquivel.Mendez@dodgit.com', '09/11/58', 56, 7);
INSERT INTO usuaris VALUES (2583, 'Malena', 'Tello Velasco', 'D', '30 Bouciña', 43780, 'Malena.Tello.Velasco@dodgit.com', '26/04/45', 0, 2);
INSERT INTO usuaris VALUES (2584, 'Joav', 'Corona Segovia', 'H', '37 C/ Amoladera', 28813, 'Joav.Corona.Segovia@trashymail.com', '14/08/51', 58, 12);
INSERT INTO usuaris VALUES (2585, 'Abdías', 'Bernal Gallardo', 'H', '45 Cartagena', 30564, 'Abdias.Bernal.Gallardo@pookmail.com', '06/10/77', 22, 10);
INSERT INTO usuaris VALUES (2586, 'Plauto', 'Monroy Valencia', 'H', '92 Avda. Alameda Sundheim', 23000, 'Plauto.Monroy.Valencia@trashymail.com', '07/10/80', 47, 3);
INSERT INTO usuaris VALUES (2587, 'Ansaldo', 'Argüello Pedraza', 'H', '87 Bellavista', 50220, 'Ansaldo.Arguello.Pedraza@trashymail.com', '04/05/54', 49, 8);
INSERT INTO usuaris VALUES (2588, 'Speranza', 'Malave Toledo', 'D', '98 Avda. Explanada Barnuevo', 34840, 'Speranza.Malave.Toledo@dodgit.com', '29/09/83', 45, 4);
INSERT INTO usuaris VALUES (2589, 'Presentación', 'Atencio Arana', 'D', '13 C/ Angosto', 23410, 'Presentacion.Atencio.Arana@pookmail.com', '19/06/44', 53, 2);
INSERT INTO usuaris VALUES (2590, 'Celest', 'Pérez Villalpando', 'D', '10 Ctra. de la Puerta', 27200, 'Celest.Perez.Villalpando@dodgit.com', '26/03/62', 44, 11);
INSERT INTO usuaris VALUES (2591, 'Marc', 'Ibarra Ortiz', 'H', '48 Plaza Colón', 24420, 'Marc.Ibarra.Ortiz@dodgit.com', '04/12/40', 29, 6);
INSERT INTO usuaris VALUES (2592, 'Melibea', 'Laureano Acosta', 'D', '70 C/ Arana', 2640, 'Melibea.Laureano.Acosta@spambob.com', '23/12/60', 65, 7);
INSERT INTO usuaris VALUES (2593, 'Johana', 'Toledo Palomo', 'D', '24 Alcon Molina', 30880, 'Johana.Toledo.Palomo@pookmail.com', '15/02/81', 67, NULL);
INSERT INTO usuaris VALUES (2594, 'Marta', 'Esparza Saldivar', 'D', '11 C/ Andalucía', 4692, 'Marta.Esparza.Saldivar@dodgit.com', '20/02/51', 9, 12);
INSERT INTO usuaris VALUES (2595, 'Oseas', 'Valverde Granado', 'H', '35 C/ Libertad', 5100, 'Oseas.Valverde.Granado@pookmail.com', '06/01/58', 78, 7);
INSERT INTO usuaris VALUES (2596, 'Ladio', 'Sandoval Brito', 'H', '12 Rua da Rapina', 37487, 'Ladio.Sandoval.Brito@pookmail.com', '27/12/51', 80, 10);
INSERT INTO usuaris VALUES (2597, 'Illed', 'Duarte Sisneros', 'D', '66 Quevedo', 15510, 'Illed.Duarte.Sisneros@mailinator.com', '27/09/40', 37, 4);
INSERT INTO usuaris VALUES (2598, 'Malcolm', 'Cavazos Mares', 'H', '4 Maestro Puig Valera', 33795, 'Malcolm.Cavazos.Mares@dodgit.com', '20/12/78', 42, 10);
INSERT INTO usuaris VALUES (2599, 'Avelino', 'Barela Esparza', 'H', '27 C/ Señores Curas', 11680, 'Avelino.Barela.Esparza@trashymail.com', '04/03/52', 58, 10);
INSERT INTO usuaris VALUES (2600, 'Numilen', 'Guerrero Cárdenas', 'D', '52 C/ Domingo Beltrán', 2316, 'Numilen.Guerrero.Cardenas@trashymail.com', '27/03/66', 5, 11);
INSERT INTO usuaris VALUES (2601, 'Selva', 'Figueroa Quiñónez', 'D', '18 Alcon Molina', 31194, 'Selva.Figueroa.Quinonez@pookmail.com', '25/04/40', 59, NULL);
INSERT INTO usuaris VALUES (2602, 'Laurindo', 'Duarte Narváez', 'H', '39 Pza. Fuensanta', 32200, 'Laurindo.Duarte.Narvaez@dodgit.com', '26/08/63', 59, 7);
INSERT INTO usuaris VALUES (2603, 'Sein', 'Mascarenas Rivas', 'H', '85 Socampo', 37624, 'Sein.Mascarenas.Rivas@mailinator.com', '04/07/70', 43, 1);
INSERT INTO usuaris VALUES (2604, 'Olympia', 'Angulo Hidalgo', 'D', '95 Avda. Los llanos', 26260, 'Olympia.Angulo.Hidalgo@trashymail.com', '20/12/59', 75, 5);
INSERT INTO usuaris VALUES (2605, 'Clinio', 'Sotelo Cisneros', 'H', '74 Cruce Casa de Postas', 18330, 'Clinio.Sotelo.Cisneros@pookmail.com', '26/03/73', 56, 5);
INSERT INTO usuaris VALUES (2606, 'Adalgiso', 'Delgado Posada', 'H', '78 Avda. de Andalucía', 29410, 'Adalgiso.Delgado.Posada@spambob.com', '12/07/78', 72, 4);
INSERT INTO usuaris VALUES (2607, 'Giulianna', 'Arredondo Abrego', 'D', '8 Rúa Olmos', 37419, 'Giulianna.Arredondo.Abrego@mailinator.com', '06/01/85', 32, 11);
INSERT INTO usuaris VALUES (2608, 'Joyce', 'Ramón Díaz', 'D', '51 Ourense', 43420, 'Joyce.Ramon.Diaz@pookmail.com', '06/10/81', 72, 7);
INSERT INTO usuaris VALUES (2609, 'Donaldo', 'Zamudio Lozano', 'H', '49 Alvaro Cunqueiro', 41240, 'Donaldo.Zamudio.Lozano@mailinator.com', '26/04/61', 51, 12);
INSERT INTO usuaris VALUES (2610, 'Vilma', 'Zarate Rael', 'D', '79 Lamas Carbajal', 41800, 'Vilma.Zarate.Rael@pookmail.com', '02/11/45', 5, 2);
INSERT INTO usuaris VALUES (2611, 'Claudette', 'Montoya Murillo', 'D', '42 Bellavista', 49591, 'Claudette.Montoya.Murillo@spambob.com', '25/01/66', 45, 4);
INSERT INTO usuaris VALUES (2612, 'Taiana', 'Medina Chavarría', 'D', '25 Maestro Puig Valera', 33774, 'Taiana.Medina.Chavarria@mailinator.com', '16/09/55', 33, 9);
INSERT INTO usuaris VALUES (2613, 'Jocelin', 'Pabón Bermúdez', 'H', '62 Alcon Molina', 30840, 'Jocelin.Pabon.Bermudez@spambob.com', '26/05/69', 88, 6);
INSERT INTO usuaris VALUES (2614, 'Linus', 'Martínez Bahena', 'H', '47 Comandante Izarduy', 8910, 'Linus.Martinez.Bahena@spambob.com', '28/02/57', 11, 8);
INSERT INTO usuaris VALUES (2615, 'Lisa', 'Ybarra Flores', 'D', '24 C/ Angosto', 23480, 'Lisa.Ybarra.Flores@spambob.com', '09/10/50', 70, NULL);
INSERT INTO usuaris VALUES (2616, 'Goliat', 'Almonte Figueroa', 'H', '71 C/ Los Herrán', 6340, 'Goliat.Almonte.Figueroa@spambob.com', '18/09/83', 43, 1);
INSERT INTO usuaris VALUES (2617, 'Dina', 'Garica Orozco', 'D', '2 C/ Cuesta del  Álamo', 29551, 'Dina.Garica.Orozco@dodgit.com', '23/06/46', 31, 4);
INSERT INTO usuaris VALUES (2618, 'Akemi', 'Puga Escamilla', 'D', '19 Herrería', 18181, 'Akemi.Puga.Escamilla@trashymail.com', '18/09/43', 5, 11);
INSERT INTO usuaris VALUES (2619, 'Nicanor', 'Pizarro Iglesias', 'H', '24 Apartado de Correos', 37448, 'Nicanor.Pizarro.Iglesias@trashymail.com', '24/07/62', 77, 8);
INSERT INTO usuaris VALUES (2620, 'Jonah', 'Urena Lozada', 'H', '79 Escuadro', 46970, 'Jonah.Urena.Lozada@dodgit.com', '19/09/66', 49, 5);
INSERT INTO usuaris VALUES (2621, 'Marissa', 'Estrada Brito', 'D', '38 C/ Fernández de Leceta', 3400, 'Marissa.Estrada.Brito@spambob.com', '15/05/84', 23, 8);
INSERT INTO usuaris VALUES (2622, 'Irta', 'Villa Almanza', 'D', '33 Plaza Colón', 26111, 'Irta.Villa.Almanza@dodgit.com', '20/09/67', 54, 1);
INSERT INTO usuaris VALUES (2623, 'Teodolinda', 'Acosta Holguín', NULL, '99 C/ Andalucía', 4700, 'Teodolinda.Acosta.Holguin@mailinator.com', '14/09/75', 85, 12);
INSERT INTO usuaris VALUES (2624, 'Kaled', 'Guardado Ornelas', 'H', '30 Urzáiz', 43896, 'Kaled.Guardado.Ornelas@trashymail.com', '30/03/83', 13, 2);
INSERT INTO usuaris VALUES (2625, 'Kristina', 'Puente Tórrez', 'D', '8 El Roqueo', 16400, 'Kristina.Puente.Torrez@mailinator.com', '29/08/71', 99, 12);
INSERT INTO usuaris VALUES (2626, 'Casdoa', 'Alvarado Peralta', 'D', '45 Cercas Bajas', 7840, 'Casdoa.Alvarado.Peralta@dodgit.com', '15/03/64', 48, NULL);
INSERT INTO usuaris VALUES (2627, 'Gabino', 'Argüello Galvez', 'H', '87 Urzáiz', 44370, 'Gabino.Arguello.Galvez@dodgit.com', '10/01/62', 46, 5);
INSERT INTO usuaris VALUES (2628, 'Anxela', 'Ulloa Aguilar', 'D', '88 C/ Libertad', 5600, 'Anxela.Ulloa.Aguilar@mailinator.com', '01/10/43', 11, 10);
INSERT INTO usuaris VALUES (2629, 'Calfu', 'Espinosa Gonzales', 'D', '67 Atamaria', 36800, 'Calfu.Espinosa.Gonzales@mailinator.com', '12/02/85', 44, 8);
INSERT INTO usuaris VALUES (2630, 'Kurt', 'Alcaraz Armendáriz', 'H', '40 Avda. Enrique Peinador', 37150, 'Kurt.Alcaraz.Armendariz@mailinator.com', '11/12/60', 17, 7);
INSERT INTO usuaris VALUES (2631, 'Ida', 'Benavides Solorio', 'D', '71 Carretera del Muelle', 12315, 'Ida.Benavides.Solorio@mailinator.com', '29/06/81', 10, 5);
INSERT INTO usuaris VALUES (2632, 'Hipólito', 'Roybal Delgado', 'H', '52 Cercas Bajas', 8000, 'Hipolito.Roybal.Delgado@spambob.com', '20/12/42', 89, 5);
INSERT INTO usuaris VALUES (2633, 'Llanos', 'Colón Almanza', 'H', '95 Avenida Cervantes', 48250, 'Llanos.Colon.Almanza@dodgit.com', '23/05/57', 67, 8);
INSERT INTO usuaris VALUES (2634, 'Dulce', 'Barragán Viera', 'D', '68 Atamaria', 36870, 'Dulce.Barragan.Viera@dodgit.com', '09/05/73', 21, 8);
INSERT INTO usuaris VALUES (2635, 'Iñaqui', 'Lemus Quintanilla', 'H', '14 Ctra. Bailén-Motril', 23292, 'Inaqui.Lemus.Quintanilla@mailinator.com', '07/01/50', 98, 6);
INSERT INTO usuaris VALUES (2636, 'Cecile', 'Sepúlveda Alfaro', 'D', '45 Ctra. Villena', 34000, 'Cecile.Sepulveda.Alfaro@mailinator.com', '17/05/85', 79, 9);
INSERT INTO usuaris VALUES (2637, 'Bernardina', 'Griego Malave', 'D', '64 Rúa Olmos', 37339, 'Bernardina.Griego.Malave@mailinator.com', '03/09/41', 59, 12);
INSERT INTO usuaris VALUES (2638, 'Dustin', 'Abreu Tórrez', 'H', '44 Celso Emilio Ferreiro', 50540, 'Dustin.Abreu.Torrez@spambob.com', '16/10/71', 37, 9);
INSERT INTO usuaris VALUES (2639, 'Girzie', 'Alicea Cerda', 'D', '21 Rúa Olmos', 37408, 'Girzie.Alicea.Cerda@mailinator.com', '17/10/49', 6, NULL);
INSERT INTO usuaris VALUES (2640, 'Betania', 'Valles Delgado', 'D', '80 C/ Señores Curas', 11692, 'Betania.Valles.Delgado@spambob.com', '08/03/83', 6, 5);
INSERT INTO usuaris VALUES (2641, 'Roxana', 'Briones Sánchez', 'D', '18 Pascual Yunquera', 18659, 'Roxana.Briones.Sanchez@spambob.com', '04/02/80', 93, 10);
INSERT INTO usuaris VALUES (2642, 'Rocco', 'Puente Otero', 'H', '34 Paseo del Atlántico', 18132, 'Rocco.Puente.Otero@trashymail.com', '18/03/73', 89, 3);
INSERT INTO usuaris VALUES (2643, 'Abner', 'Bañuelos Castellanos', 'H', '81 Rua da Rapina', 37491, 'Abner.Banuelos.Castellanos@spambob.com', '27/07/80', 69, NULL);
INSERT INTO usuaris VALUES (2644, 'Baldwin', 'Corona Velez', 'H', '55 C/ Eras', 28721, 'Baldwin.Corona.Velez@trashymail.com', '27/12/56', 91, 11);
INSERT INTO usuaris VALUES (2645, 'Lucy', 'Mares Blanco', 'D', '88 Reiseñor', 45500, 'Lucy.Mares.Blanco@dodgit.com', '07/06/48', 29, 3);
INSERT INTO usuaris VALUES (2646, 'Ruyan', 'Ortiz Colón', 'H', '5 Ctra. Beas-Cortijos Nuevos', 26509, 'Ruyan.Ortiz.Colon@spambob.com', '27/09/76', 59, 4);
INSERT INTO usuaris VALUES (2647, 'Milva', 'Lozada Téllez', 'D', '25 Camiño Ancho', 37785, 'Milva.Lozada.Tellez@trashymail.com', '07/02/61', 74, 11);
INSERT INTO usuaris VALUES (2648, 'Wilma', 'Téllez Laboy', 'D', '40 Escuadro', 46940, 'Wilma.Tellez.Laboy@pookmail.com', '21/10/43', 29, 2);
INSERT INTO usuaris VALUES (2649, 'Columbo', 'Acosta Pérez', 'H', '4 C/ Manuel Iradier', 3792, 'Columbo.Acosta.Perez@spambob.com', '20/12/66', 86, NULL);
INSERT INTO usuaris VALUES (2650, 'Galilah', 'Peralta Alvarado', 'D', '88 Estrela', 38830, 'Galilah.Peralta.Alvarado@pookmail.com', '19/12/64', 55, 1);
INSERT INTO usuaris VALUES (2651, 'Saturno', 'Domínquez Carbajal', 'H', '83 Ctra. Beas-Cortijos Nuevos', 26375, 'Saturno.Dominquez.Carbajal@mailinator.com', '17/05/73', 58, 12);
INSERT INTO usuaris VALUES (2652, 'Pascua', 'Yáñez Gaytan', NULL, '88 Socampo', 37623, 'Pascua.Yanez.Gaytan@pookmail.com', '28/07/82', 84, 7);
INSERT INTO usuaris VALUES (2653, 'Nerio', 'Abreu Cuellar', NULL, '64 Carretera del Muelle', 12400, 'Nerio.Abreu.Cuellar@pookmail.com', '24/12/52', 64, 1);
INSERT INTO usuaris VALUES (2654, 'Gisella', 'Cabán Toro', 'D', '68 Avda. Enrique Peinador', 37187, 'Gisella.Caban.Toro@trashymail.com', '21/01/78', NULL, 4);
INSERT INTO usuaris VALUES (2655, 'Caín', 'Villalpando Ríos', 'H', '99 La Fontanilla', 14280, 'Cain.Villalpando.Rios@dodgit.com', '12/08/76', 56, 12);
INSERT INTO usuaris VALUES (2656, 'Othmaro', 'Lovato Camacho', 'H', '94 C/ Cuevas de Ambrosio', 24000, 'Othmaro.Lovato.Camacho@mailinator.com', '10/04/47', 74, 4);
INSERT INTO usuaris VALUES (2657, 'Justino', 'Luna Badillo', 'H', '70 Avda. Explanada Barnuevo', 34886, 'Justino.Luna.Badillo@spambob.com', '23/02/74', 44, NULL);
INSERT INTO usuaris VALUES (2658, 'Cecilio', 'Matos Matos', 'H', '63 C/ Domingo Beltrán', 2249, 'Cecilio.Matos.Matos@mailinator.com', '25/11/43', 39, 6);
INSERT INTO usuaris VALUES (2659, 'Florentina', 'Rosario Quesada', 'D', '24 C/ Manuel Iradier', 3778, 'Florentina.Rosario.Quesada@dodgit.com', '09/12/45', 35, NULL);
INSERT INTO usuaris VALUES (2660, 'Jerónima', 'Vasquez Carrasco', 'D', '94 Ctra. Hornos', 26225, 'Jeronima.Vasquez.Carrasco@trashymail.com', '05/06/45', 67, 11);
INSERT INTO usuaris VALUES (2661, 'Shasa', 'Chacón Cerda', 'D', '81 Paseo Junquera', 12513, 'Shasa.Chacon.Cerda@trashymail.com', '24/05/73', 76, 12);
INSERT INTO usuaris VALUES (2662, 'Edelio', 'Solorio Elizondo', 'H', '82 Avda. Los llanos', 26250, 'Edelio.Solorio.Elizondo@spambob.com', '18/06/55', 58, 2);
INSERT INTO usuaris VALUES (2663, 'Ciríaco', 'Valentín Godoy', 'H', '70 Lamas Carbajal', 41620, 'Ciriaco.Valentin.Godoy@trashymail.com', '02/11/45', 81, 4);
INSERT INTO usuaris VALUES (2664, 'Fito', 'Cintrón Olivas', 'H', '48 Caño', 32730, 'Fito.Cintron.Olivas@dodgit.com', '20/02/53', 28, 4);
INSERT INTO usuaris VALUES (2665, 'Elsira', 'Longoria Pagan', NULL, '18 Av. Zumalakarregi', 3179, 'Elsira.Longoria.Pagan@trashymail.com', '02/07/43', 90, 2);
INSERT INTO usuaris VALUES (2666, 'Yago', 'Montano Contreras', 'H', '46 C/ Libertad', 5230, 'Yago.Montano.Contreras@spambob.com', '07/07/49', 11, 12);
INSERT INTO usuaris VALUES (2667, 'Mainque', 'Nieves Alvarado', 'D', '40 Calle Proc. San Sebastián', 12609, 'Mainque.Nieves.Alvarado@spambob.com', '18/01/85', 99, NULL);
INSERT INTO usuaris VALUES (2668, 'Gerald', 'Barrera Navarrete', 'H', '85 C/ Libertad', 5450, 'Gerald.Barrera.Navarrete@dodgit.com', '08/10/83', 35, 7);
INSERT INTO usuaris VALUES (2669, 'Salvator', 'Ocasio Delgado', 'H', '1 Bouciña', 43895, 'Salvator.Ocasio.Delgado@spambob.com', '09/02/49', 76, 3);
INSERT INTO usuaris VALUES (2670, 'Isolda', 'Serrano Trejo', 'D', '6 Avda. Enrique Peinador', 37173, 'Isolda.Serrano.Trejo@mailinator.com', '13/05/80', 66, 5);
INSERT INTO usuaris VALUES (2671, 'Doria', 'Cruz Sisneros', 'D', '54 Paraguay', 3728, 'Doria.Cruz.Sisneros@trashymail.com', '01/10/61', 23, 8);
INSERT INTO usuaris VALUES (2672, 'Nasya', 'Saldivar Lozada', 'D', '86 Pascual Yunquera', 18700, 'Nasya.Saldivar.Lozada@mailinator.com', '25/12/60', 85, 7);
INSERT INTO usuaris VALUES (2673, 'Wanda', 'Ochoa Laboy', 'D', '29 Cruce Casa de Postas', 18411, 'Wanda.Ochoa.Laboy@dodgit.com', '10/10/73', 51, 4);
INSERT INTO usuaris VALUES (2674, 'Nacho', 'Ocasio Solórzano', 'H', '24 Herrería', 18240, 'Nacho.Ocasio.Solorzano@spambob.com', '05/10/74', 14, 7);
INSERT INTO usuaris VALUES (2675, 'Jack', 'Nevarez Guerra', 'H', '7 Plazuela do Porto', 37893, 'Jack.Nevarez.Guerra@pookmail.com', '26/08/50', 10, NULL);
INSERT INTO usuaris VALUES (2676, 'Zenobio', 'Quintana Rodrígez', 'H', '45 Calle Carril de la Fuente', 13260, 'Zenobio.Quintana.Rodrigez@trashymail.com', '04/02/74', 2, 1);
INSERT INTO usuaris VALUES (2677, 'Auxano', 'Partida Pedraza', 'H', '99 Celso Emilio Ferreiro', 50550, 'Auxano.Partida.Pedraza@trashymail.com', '10/06/77', 65, 3);
INSERT INTO usuaris VALUES (2678, 'Roxanne', 'Abreu Matías', 'D', '63 Av. Santiago Lapuente', 50786, 'Roxanne.Abreu.Matias@mailinator.com', '28/03/51', 51, 6);
INSERT INTO usuaris VALUES (2679, 'Alin', 'Montés Zepeda', 'D', '38 Visitación de la Encina', 37716, 'Alin.Montes.Zepeda@mailinator.com', '22/07/48', 13, 2);
INSERT INTO usuaris VALUES (2680, 'Aglae', 'Angulo Juárez', 'D', '6 Extramuros', 28440, 'Aglae.Angulo.Juarez@dodgit.com', '26/03/61', 19, 10);
INSERT INTO usuaris VALUES (2681, 'Ares', 'Gaitán Rodríguez', 'H', '1 C/ Cuevas de Ambrosio', 23740, 'Ares.Gaitan.Rodriguez@dodgit.com', '19/05/63', NULL, 5);
INSERT INTO usuaris VALUES (2682, 'Baal', 'Holguín Ponce', 'H', '78 Avda. de Andalucía', 29313, 'Baal.Holguin.Ponce@mailinator.com', '01/11/44', 79, 9);
INSERT INTO usuaris VALUES (2683, 'Gualberto', 'Delgadillo Garibay', 'H', '26 Pza. Fuensanta', 32514, 'Gualberto.Delgadillo.Garibay@dodgit.com', '02/05/82', 65, 9);
INSERT INTO usuaris VALUES (2684, 'Kristen', 'Zelaya Díaz', 'D', '15 Celso Emilio Ferreiro', 50637, 'Kristen.Zelaya.Diaz@dodgit.com', '31/12/73', 20, 6);
INSERT INTO usuaris VALUES (2685, 'Aminta', 'Rolón Parra', 'D', '72 Avda. Alameda Sundheim', 22530, 'Aminta.Rolon.Parra@mailinator.com', '10/12/64', 37, 2);
INSERT INTO usuaris VALUES (2686, 'Ludwig', 'Jiménez Parra', 'H', '57 Calle Aduana', 1208, 'Ludwig.Jimenez.Parra@trashymail.com', '18/09/84', 19, 9);
INSERT INTO usuaris VALUES (2687, 'Lisandro', 'Duarte Carreón', 'H', '73 El Roqueo', 17220, 'Lisandro.Duarte.Carreon@spambob.com', '23/02/69', 59, 10);
INSERT INTO usuaris VALUES (2688, 'Edgarda', 'Balderas Tamez', 'D', '3 Prolongacion San Sebastian', 21320, 'Edgarda.Balderas.Tamez@dodgit.com', '06/03/81', 29, 12);
INSERT INTO usuaris VALUES (2689, 'Tilo', 'Zavala Bernal', 'H', '34 Puerto Lugar', 29755, 'Tilo.Zavala.Bernal@mailinator.com', '11/07/64', 77, 11);
INSERT INTO usuaris VALUES (2690, 'Milena', 'Echevarría Casillas', 'D', '93 Reyes Católicos', 11000, 'Milena.Echevarria.Casillas@trashymail.com', '15/03/68', 25, 12);
INSERT INTO usuaris VALUES (2691, 'Edesio', 'Villanueva Marcos', 'H', '55 Padre Caro', 13580, 'Edesio.Villanueva.Marcos@dodgit.com', '24/07/85', 32, 2);
INSERT INTO usuaris VALUES (2692, 'Isaias', 'Archuleta Zamudio', 'H', '54 Enxertos', 37591, 'Isaias.Archuleta.Zamudio@mailinator.com', '08/03/40', 93, 6);
INSERT INTO usuaris VALUES (2693, 'Armen', 'Cadena Esquivel', 'H', '88 Rio Segura', 31523, 'Armen.Cadena.Esquivel@spambob.com', '31/08/47', 54, NULL);
INSERT INTO usuaris VALUES (2694, 'Maribel', 'Medina Romo', 'D', '33 C/ Domingo Beltrán', 2215, 'Maribel.Medina.Romo@trashymail.com', '11/04/62', 97, 11);
INSERT INTO usuaris VALUES (2695, 'Laila', 'Saavedra Ornelas', 'D', '78 Castelao', 48710, 'Laila.Saavedra.Ornelas@mailinator.com', '28/09/75', 15, 2);
INSERT INTO usuaris VALUES (2696, 'Grisel', 'Arana Duran', NULL, '72 Extramuros', 28390, 'Grisel.Arana.Duran@dodgit.com', '13/09/83', 68, 6);
INSERT INTO usuaris VALUES (2697, 'Armen', 'Crespo Cintrón', 'H', '71 Puerto Lugar', 29788, 'Armen.Crespo.Cintron@mailinator.com', '24/08/78', 94, NULL);
INSERT INTO usuaris VALUES (2698, 'Renau', 'Puente Tirado', 'H', '36 Socampo', 37670, 'Renau.Puente.Tirado@trashymail.com', '20/05/65', 83, 1);
INSERT INTO usuaris VALUES (2699, 'Fiorel', 'Mendoza Alonzo', 'D', '98 San Andrés', 37271, 'Fiorel.Mendoza.Alonzo@dodgit.com', '25/06/48', 15, 9);
INSERT INTO usuaris VALUES (2700, 'Carissa', 'Caraballo Quiñónez', 'D', '1 Puerta Nueva', 36130, 'Carissa.Caraballo.Quinonez@spambob.com', '21/07/68', 28, 12);
INSERT INTO usuaris VALUES (2701, 'Senan', 'Cruz Gutiérrez', 'H', '81 Camiño Ancho', 37791, 'Senan.Cruz.Gutierrez@pookmail.com', '29/12/81', 77, 6);
INSERT INTO usuaris VALUES (2702, 'Gualberto', 'Carrera Leyva', 'H', '71 Inglaterra', 18550, 'Gualberto.Carrera.Leyva@dodgit.com', '11/02/85', 32, 11);
INSERT INTO usuaris VALUES (2703, 'Clodomiro', 'Griego Espinoza', 'H', '97 Cruce Casa de Postas', 18330, 'Clodomiro.Griego.Espinoza@mailinator.com', '25/04/73', 85, NULL);
INSERT INTO usuaris VALUES (2704, 'Heber', 'Agosto Banda', 'H', '28 Paseo del Atlántico', 18100, 'Heber.Agosto.Banda@spambob.com', '18/02/53', 6, 1);
INSERT INTO usuaris VALUES (2705, 'Vesta', 'Molina Ruelas', 'D', '34 Quevedo', 15318, 'Vesta.Molina.Ruelas@mailinator.com', '22/05/52', 4, NULL);
INSERT INTO usuaris VALUES (2706, 'Ademaro', 'Rivas Maestas', 'H', '23 Salzillo', 32700, 'Ademaro.Rivas.Maestas@mailinator.com', '04/08/60', 49, 9);
INSERT INTO usuaris VALUES (2707, 'Malcon', 'Heredia Solórzano', 'H', '90 Avda. Rio Nalon', 33556, 'Malcon.Heredia.Solorzano@mailinator.com', '07/12/49', 85, 7);
INSERT INTO usuaris VALUES (2708, 'Azrael', 'Blanco Ozuna', 'H', '32 Avda. de Andalucía', 29460, 'Azrael.Blanco.Ozuna@dodgit.com', '25/07/71', 65, 7);
INSERT INTO usuaris VALUES (2709, 'Elijah', 'Salas Solorio', 'H', '84 Rúa Olmos', 37339, 'Elijah.Salas.Solorio@dodgit.com', '13/09/61', 13, 2);
INSERT INTO usuaris VALUES (2710, 'Balbino', 'Ramón Almanza', 'H', '10 C/ Fernández de Leceta', 3517, 'Balbino.Ramon.Almanza@pookmail.com', '17/05/58', 14, 3);
INSERT INTO usuaris VALUES (2711, 'Azalea', 'Mares Alvarez', 'D', '16 Reyes Católicos', 9300, 'Azalea.Mares.Alvarez@mailinator.com', '06/05/40', 77, NULL);
INSERT INTO usuaris VALUES (2712, 'Yulan', 'Villegas Prado', 'H', '77 Carretera', 14500, 'Yulan.Villegas.Prado@spambob.com', '13/09/46', 9, 4);
INSERT INTO usuaris VALUES (2713, 'Emillen', 'Arana Orozco', 'H', '5 Reyes Católicos', 9300, 'Emillen.Arana.Orozco@pookmail.com', '31/05/40', 37, 6);
INSERT INTO usuaris VALUES (2714, 'Catón', 'Fonseca Gaona', 'H', '73 Antonio Vázquez', 38530, 'Caton.Fonseca.Gaona@dodgit.com', '26/06/67', 79, 2);
INSERT INTO usuaris VALUES (2715, 'Edda', 'Covarrubias Rael', 'D', '8 C/ Henan Cortes', 29180, 'Edda.Covarrubias.Rael@pookmail.com', '03/03/66', 49, 3);
INSERT INTO usuaris VALUES (2716, 'Catón', 'Jaramillo Tirado', 'H', '55 Ctra. Villena', 34480, 'Caton.Jaramillo.Tirado@dodgit.com', '21/10/50', NULL, 11);
INSERT INTO usuaris VALUES (2717, 'Helida', 'Noriega Rodrígez', 'D', '50 Padre Caro', 13630, 'Helida.Noriega.Rodrigez@mailinator.com', '05/03/66', 24, 5);
INSERT INTO usuaris VALUES (2718, 'Ramses', 'Salcido Lucero', 'H', '14 Alvaro Cunqueiro', 40480, 'Ramses.Salcido.Lucero@mailinator.com', '11/07/55', 78, 9);
INSERT INTO usuaris VALUES (2719, 'Gaetan', 'Díaz Barreto', 'H', '32 Plazuela do Porto', 37874, 'Gaetan.Diaz.Barreto@spambob.com', '28/09/84', 82, 6);
INSERT INTO usuaris VALUES (2720, 'Reginaldo', 'Cadena Hernádez', 'H', '90 Ctra. Villena', 34210, 'Reginaldo.Cadena.Hernadez@mailinator.com', '02/07/54', 11, 6);
INSERT INTO usuaris VALUES (2721, 'Ercilia', 'Adomo Urbina', 'D', '30 Rosa de los Vientos', 13340, 'Ercilia.Adomo.Urbina@pookmail.com', '03/05/44', 11, 11);
INSERT INTO usuaris VALUES (2722, 'Karol', 'Carrasquill Gamez', 'H', '72 Escuadro', 46970, 'Karol.Carrasquill.Gamez@trashymail.com', '24/07/63', 77, 11);
INSERT INTO usuaris VALUES (2723, 'Arandu', 'Agosto Aguayo', 'D', '66 Celso Emilio Ferreiro', 50300, 'Arandu.Agosto.Aguayo@trashymail.com', NULL, 68, 1);
INSERT INTO usuaris VALUES (2724, 'Eliora', 'Rojas Ballesteros', 'D', '26 Puerto Lugar', 29770, 'Eliora.Rojas.Ballesteros@trashymail.com', '09/06/51', 62, 7);
INSERT INTO usuaris VALUES (2725, 'Aluhe', 'Monroy Alonzo', 'D', '11 C/ Canarias', 20214, 'Aluhe.Monroy.Alonzo@trashymail.com', '10/04/48', 73, 4);
INSERT INTO usuaris VALUES (2726, 'Adriana', 'Nino Carranza', 'D', '41 El Roqueo', 15930, 'Adriana.Nino.Carranza@pookmail.com', '16/05/68', 3, 5);
INSERT INTO usuaris VALUES (2727, 'Ilya', 'Villagómez Maldonado', 'D', '57 C/ Pablo Iglesias', 26315, 'Ilya.Villagomez.Maldonado@trashymail.com', '30/10/42', 7, 9);
INSERT INTO usuaris VALUES (2728, 'Senan', 'Herrera Guillén', 'H', '93 C/ Domingo Beltrán', 2300, 'Senan.Herrera.Guillen@spambob.com', '15/01/61', 84, 3);
INSERT INTO usuaris VALUES (2729, 'Maribel', 'Alicea Orta', 'D', '50 Escuadro', 47155, 'Maribel.Alicea.Orta@dodgit.com', '09/01/64', 28, 7);
INSERT INTO usuaris VALUES (2730, 'Tiburcio', 'Martínez Fonseca', 'H', '32 C/ Benito Guinea', 8310, 'Tiburcio.Martinez.Fonseca@mailinator.com', '24/08/65', 45, 12);
INSERT INTO usuaris VALUES (2731, 'Birgitta', 'Muñoz Saenz', 'D', '12 Avda. Alameda Sundheim', 22590, 'Birgitta.Munoz.Saenz@spambob.com', '21/01/56', 70, 1);
INSERT INTO usuaris VALUES (2732, 'Clea', 'Meza Coronado', 'D', '59 Plazuela do Porto', 37893, 'Clea.Meza.Coronado@pookmail.com', '01/05/66', 30, 12);
INSERT INTO usuaris VALUES (2733, 'Oda', 'Segura Quiñones', 'D', '45 Avda. Rio Nalon', 33138, 'Oda.Segura.Quinones@pookmail.com', '28/04/84', 7, NULL);
INSERT INTO usuaris VALUES (2734, 'Arebela', 'Carrillo Urías', 'D', '17 Avenida Cervantes', 48287, 'Arebela.Carrillo.Urias@trashymail.com', '30/07/69', 54, 6);
INSERT INTO usuaris VALUES (2735, 'Judas', 'Munguia Carrera', 'H', '61 Carretera', 14812, 'Judas.Munguia.Carrera@trashymail.com', '20/08/66', 0, 3);
INSERT INTO usuaris VALUES (2736, 'Julia', 'Fonseca Ojeda', 'D', '58 Bellavista', 50000, 'Julia.Fonseca.Ojeda@pookmail.com', '06/02/67', 8, 10);
INSERT INTO usuaris VALUES (2737, 'Luisa', 'Pacheco Vela', 'D', '31 Estrela', 39400, 'Luisa.Pacheco.Vela@dodgit.com', '14/02/82', 30, 8);
INSERT INTO usuaris VALUES (2738, 'Balbo', 'Marcos Mondragón', 'H', '91 Avda. Los llanos', 26288, 'Balbo.Marcos.Mondragon@pookmail.com', '15/01/59', 26, 6);
INSERT INTO usuaris VALUES (2739, 'Fani', 'Cadena Gaitán', NULL, '91 Carretera', 14620, 'Fani.Cadena.Gaitan@dodgit.com', '03/07/64', 15, 6);
INSERT INTO usuaris VALUES (2740, 'Nino', 'Garay Juárez', 'H', '16 Celso Emilio Ferreiro', 50693, 'Nino.Garay.Juarez@pookmail.com', '07/02/82', 15, 5);
INSERT INTO usuaris VALUES (2741, 'Ozana', 'Aranda Alemán', NULL, '45 C/ Canarias', 20120, 'Ozana.Aranda.Aleman@pookmail.com', '11/12/81', 6, 7);
INSERT INTO usuaris VALUES (2742, 'Danisa', 'Montenegro Bernal', 'D', '30 Atamaria', 36770, 'Danisa.Montenegro.Bernal@spambob.com', '22/08/52', 60, 1);
INSERT INTO usuaris VALUES (2743, 'Sophie', 'Rosario Sevilla', 'D', '74 Avda. Generalísimo', 31560, 'Sophie.Rosario.Sevilla@pookmail.com', '26/03/72', 90, 12);
INSERT INTO usuaris VALUES (2744, 'Sonia', 'Trejo Concepción', NULL, '87 Escuadro', 47100, 'Sonia.Trejo.Concepcion@trashymail.com', '27/04/78', 58, 1);
INSERT INTO usuaris VALUES (2745, 'Saidi', 'Miramontes Menéndez', 'D', '85 Avda. Generalísimo', 31570, 'Saidi.Miramontes.Menendez@trashymail.com', '14/12/44', 98, NULL);
INSERT INTO usuaris VALUES (2746, 'Angelines', 'Pantoja Tamez', 'D', '3 Atamaria', 36680, 'Angelines.Pantoja.Tamez@dodgit.com', '22/02/50', 61, NULL);
INSERT INTO usuaris VALUES (2747, 'Ginebra', 'Guzmán Zepeda', 'D', '91 Puerto Lugar', 29712, 'Ginebra.Guzman.Zepeda@pookmail.com', '19/04/77', 17, NULL);
INSERT INTO usuaris VALUES (2748, 'Shamara', 'Esparza Ceja', 'D', '94 Cañadilla', 22300, 'Shamara.Esparza.Ceja@trashymail.com', '05/02/56', 77, 3);
INSERT INTO usuaris VALUES (2749, 'Iliana', 'Gutiérrez Suárez', 'D', '77 Ctra. de Fuentenueva', 28212, 'Iliana.Gutierrez.Suarez@mailinator.com', '22/05/77', 22, 7);
INSERT INTO usuaris VALUES (2750, 'Andrónico', 'Gallardo Medina', 'H', '54 Antonio Vázquez', 38726, 'Andronico.Gallardo.Medina@dodgit.com', '08/11/56', 17, 5);
INSERT INTO usuaris VALUES (2751, 'Penny', 'Marrero Naranjo', 'D', '86 Rúa Olmos', 37406, 'Penny.Marrero.Naranjo@mailinator.com', '27/08/76', 17, 7);
INSERT INTO usuaris VALUES (2752, 'Melania', 'Montoya Granados', 'D', '38 Padre Caro', 13630, 'Melania.Montoya.Granados@mailinator.com', '26/11/56', 43, 10);
INSERT INTO usuaris VALUES (2753, 'Allison', 'Santillán Arenas', 'D', '75 C/ Eras', 28737, 'Allison.Santillan.Arenas@dodgit.com', '17/01/72', 33, 3);
INSERT INTO usuaris VALUES (2754, 'Hervé', 'Quintanilla Ávila', 'H', '23 Atamaria', 36637, 'Herve.Quintanilla.Avila@mailinator.com', '24/05/65', 8, 10);
INSERT INTO usuaris VALUES (2755, 'Lucrecio', 'Salazar Cuellar', NULL, '74 Plaza de España', 15840, 'Lucrecio.Salazar.Cuellar@mailinator.com', '18/12/41', 66, 4);
INSERT INTO usuaris VALUES (2756, 'Gaspard', 'Cerda Tamez', 'H', '64 Paseo del Atlántico', 18132, 'Gaspard.Cerda.Tamez@dodgit.com', '19/04/85', 84, 3);
INSERT INTO usuaris VALUES (2757, 'Escolástica', 'Gaitán Miranda', 'D', '72 Cañadilla', 22234, 'Escolastica.Gaitan.Miranda@spambob.com', '31/08/51', 91, NULL);
INSERT INTO usuaris VALUES (2758, 'Teseo', 'Olmos Gómez', 'H', '70 C/ Domingo Beltrán', 2320, 'Teseo.Olmos.Gomez@spambob.com', '24/10/55', 64, NULL);
INSERT INTO usuaris VALUES (2759, 'Ptolomeo', 'Vasquez Nevarez', 'H', '11 C/ Cuevas de Ambrosio', 23730, 'Ptolomeo.Vasquez.Nevarez@spambob.com', '11/10/46', 50, 8);
INSERT INTO usuaris VALUES (2760, 'Alejandrino', 'Alcantar Gómez', 'H', '2 Bellavista', 49610, 'Alejandrino.Alcantar.Gomez@pookmail.com', '26/10/77', 30, NULL);
INSERT INTO usuaris VALUES (2761, 'Estefania', 'Ramírez Reyna', 'D', '34 Avenida Cervantes', 48215, 'Estefania.Ramirez.Reyna@dodgit.com', '04/07/72', 21, 5);
INSERT INTO usuaris VALUES (2762, 'Adelaide', 'Guillén Vargas', 'D', '77 Castelao', 48970, 'Adelaide.Guillen.Vargas@mailinator.com', '03/10/83', 90, 3);
INSERT INTO usuaris VALUES (2763, 'Meredith', 'Esquibel Ballesteros', 'D', '99 Ctra. Beas-Cortijos Nuevos', 26376, 'Meredith.Esquibel.Ballesteros@mailinator.com', '09/08/57', 71, 7);
INSERT INTO usuaris VALUES (2764, 'Munir', 'Palacios Barrientos', 'H', '40 Ourense', 43140, 'Munir.Palacios.Barrientos@trashymail.com', '19/04/45', 33, 8);
INSERT INTO usuaris VALUES (2765, 'Lorea', 'Reynoso Varela', 'D', '64 Urzáiz', 44200, 'Lorea.Reynoso.Varela@mailinator.com', '27/02/40', 42, 7);
INSERT INTO usuaris VALUES (2766, 'Vanda', 'Pantoja Saucedo', 'D', '67 Ventanilla de Beas', 28023, 'Vanda.Pantoja.Saucedo@pookmail.com', '18/09/76', 62, 4);
INSERT INTO usuaris VALUES (2767, 'Ingmar', 'Henríquez Carmona', 'H', '78 Canónigo Valiño', 46540, 'Ingmar.Henriquez.Carmona@dodgit.com', '04/04/56', 80, 4);
INSERT INTO usuaris VALUES (2768, 'Innie', 'Bañuelos Gamez', 'D', '1 Urzáiz', 44600, 'Innie.Banuelos.Gamez@trashymail.com', '30/05/42', 61, 1);
INSERT INTO usuaris VALUES (2769, 'Laodamia', 'Archuleta Ramos', 'D', '24 San Andrés', 37257, 'Laodamia.Archuleta.Ramos@dodgit.com', '13/07/41', 13, 3);
INSERT INTO usuaris VALUES (2770, 'Eudoxio', 'Paredes Paredes', 'H', '80 C/ Amoladera', 28812, 'Eudoxio.Paredes.Paredes@pookmail.com', '07/08/46', 26, 11);
INSERT INTO usuaris VALUES (2771, 'Lorna', 'Peres Amador', 'D', '9 Cádiz', 18510, 'Lorna.Peres.Amador@pookmail.com', '07/11/79', 65, 2);
INSERT INTO usuaris VALUES (2772, 'Jairo', 'Arredondo Granado', 'H', '89 Socampo', 37621, 'Jairo.Arredondo.Granado@dodgit.com', '18/07/78', 78, 11);
INSERT INTO usuaris VALUES (2773, 'Aldano', 'Sierra Quezada', 'H', '61 Reyes Católicos', 11000, 'Aldano.Sierra.Quezada@trashymail.com', '29/04/69', 53, 11);
INSERT INTO usuaris VALUES (2774, 'Nimfa', 'Irizarry Loera', 'D', '60 Reiseñor', 45860, 'Nimfa.Irizarry.Loera@dodgit.com', '08/07/71', 14, 8);
INSERT INTO usuaris VALUES (2775, 'Marón', 'Sepúlveda Tamez', 'H', '25 Avda. Rio Nalon', 33500, 'Maron.Sepulveda.Tamez@spambob.com', '06/07/73', 54, 6);
INSERT INTO usuaris VALUES (2776, 'Miguelina', 'Espinal Galván', NULL, '26 Escuadro', 47150, 'Miguelina.Espinal.Galvan@spambob.com', '04/03/50', 49, 12);
INSERT INTO usuaris VALUES (2777, 'Carysa', 'Cabrera Posada', 'D', '87 Quevedo', 15185, 'Carysa.Cabrera.Posada@dodgit.com', '25/06/62', 58, 9);
INSERT INTO usuaris VALUES (2778, 'Laya', 'Balderas Santana', 'D', '40 Prolongacion San Sebastian', 21300, 'Laya.Balderas.Santana@dodgit.com', '15/09/70', 7, 1);
INSERT INTO usuaris VALUES (2779, 'Terpsícore', 'Orellana Quezada', 'D', '16 Rúa de San Pedro', 37792, 'Terpsicore.Orellana.Quezada@trashymail.com', '03/03/59', 93, NULL);
INSERT INTO usuaris VALUES (2780, 'Alcmena', 'Sevilla Galvez', 'D', '79 C/ Hijuela de Lojo', 20300, 'Alcmena.Sevilla.Galvez@pookmail.com', '22/10/82', 99, 11);
INSERT INTO usuaris VALUES (2781, 'Anselma', 'Valles Valencia', 'D', '52 Crta. Cádiz-Málaga', 12186, 'Anselma.Valles.Valencia@pookmail.com', '06/08/83', 49, 2);
INSERT INTO usuaris VALUES (2782, 'Alexia', 'Huerta Maestas', 'D', '89 Carretera', 14840, 'Alexia.Huerta.Maestas@spambob.com', '30/04/45', 28, 3);
INSERT INTO usuaris VALUES (2783, 'Wilfredo', 'Zavala Tello', 'H', '92 C/ Arana', 2651, 'Wilfredo.Zavala.Tello@trashymail.com', '30/07/59', 46, 12);
INSERT INTO usuaris VALUES (2784, 'Iziar', 'Zúñiga Saenz', 'D', '87 Plaza Colón', 24600, 'Iziar.Zuniga.Saenz@dodgit.com', '26/03/76', 4, 11);
INSERT INTO usuaris VALUES (2785, 'Nadine', 'Alonzo Miramontes', 'D', '61 C/ Rosa de los Vientos', 11612, 'Nadine.Alonzo.Miramontes@trashymail.com', '12/08/57', 18, 6);
INSERT INTO usuaris VALUES (2786, 'Lucero', 'Olivares Nieves', 'D', '82 C/ Andalucía', 4800, 'Lucero.Olivares.Nieves@mailinator.com', '31/01/42', 19, 9);
INSERT INTO usuaris VALUES (2787, 'Liafdag', 'Urbina Soliz', 'H', '34 C/ Los Herrán', 6120, 'Liafdag.Urbina.Soliz@mailinator.com', '07/10/78', NULL, 10);
INSERT INTO usuaris VALUES (2788, 'Menelao', 'Garica Rentería', 'H', '77 Plaza de España', 15808, 'Menelao.Garica.Renteria@dodgit.com', '13/06/53', 45, 9);
INSERT INTO usuaris VALUES (2789, 'Lastenia', 'Orellana Pantoja', 'D', '94 Rúa de San Pedro', 37820, 'Lastenia.Orellana.Pantoja@dodgit.com', '29/08/76', 99, 1);
INSERT INTO usuaris VALUES (2790, 'Ionatán', 'Castillo Armendáriz', 'H', '67 Crta. Cádiz-Málaga', 12192, 'Ionatan.Castillo.Armendariz@mailinator.com', '18/06/41', 33, 12);
INSERT INTO usuaris VALUES (2791, 'Michael', 'Rojo Sotelo', 'H', '43 C/ Señores Curas', 12150, 'Michael.Rojo.Sotelo@dodgit.com', '03/05/71', 17, 10);
INSERT INTO usuaris VALUES (2792, 'Dacia', 'Jiménez Esparza', 'D', '82 Cartagena', 30320, 'Dacia.Jimenez.Esparza@mailinator.com', '06/07/73', 53, 5);
INSERT INTO usuaris VALUES (2793, 'Joad', 'Padilla Feliciano', 'H', '51 Carretera Cádiz-Málaga', 20570, 'Joad.Padilla.Feliciano@dodgit.com', '17/10/83', 7, 12);
INSERT INTO usuaris VALUES (2794, 'Visitación', 'Gil Luna', 'D', '41 Plazuela do Porto', 38260, 'Visitacion.Gil.Luna@spambob.com', '11/05/77', 68, 2);
INSERT INTO usuaris VALUES (2795, 'Piero', 'Alonso Amador', NULL, '30 Inglaterra', 18564, 'Piero.Alonso.Amador@trashymail.com', '28/08/45', 24, NULL);
INSERT INTO usuaris VALUES (2796, 'Clorindo', 'Gómez Farías', 'H', '40 Canónigo Valiño', 46440, 'Clorindo.Gomez.Farias@trashymail.com', '25/06/46', 28, 12);
INSERT INTO usuaris VALUES (2797, 'Caetano', 'Ortega Cisneros', 'H', '68 Avda. Los llanos', 26311, 'Caetano.Ortega.Cisneros@pookmail.com', '11/05/53', 73, 8);
INSERT INTO usuaris VALUES (2798, 'Romero', 'Almaraz Calvillo', 'H', '11 Prolongacion San Sebastian', 21291, 'Romero.Almaraz.Calvillo@dodgit.com', '03/05/66', 98, 11);
INSERT INTO usuaris VALUES (2799, 'Marcella', 'Flórez Urbina', 'D', '42 Avda. Enrique Peinador', 37150, 'Marcella.Florez.Urbina@mailinator.com', '08/04/85', 17, 11);
INSERT INTO usuaris VALUES (2800, 'Hercilia', 'Toledo Valle', 'D', '27 Extramuros', 28340, 'Hercilia.Toledo.Valle@pookmail.com', '19/11/50', 47, 7);
INSERT INTO usuaris VALUES (2801, 'Angie', 'Estévez Covas', 'D', '52 Padre Caro', 13740, 'Angie.Estevez.Covas@trashymail.com', '28/12/50', 28, 12);
INSERT INTO usuaris VALUES (2802, 'Haizea', 'Bravo Macías', 'D', '68 Castelao', 48920, 'Haizea.Bravo.Macias@pookmail.com', '24/04/82', 91, 10);
INSERT INTO usuaris VALUES (2803, 'Vesta', 'Jiménez Rivas', 'D', '92 Puerto Lugar', 29719, 'Vesta.Jimenez.Rivas@trashymail.com', '20/06/67', 72, 8);
INSERT INTO usuaris VALUES (2804, 'Zina', 'Lerma Ramón', NULL, '50 C/ Domingo Beltrán', 2247, 'Zina.Lerma.Ramon@trashymail.com', '22/03/44', 18, 4);
INSERT INTO usuaris VALUES (2805, 'Merlin', 'Rivas Haro', 'D', '85 Ourense', 42200, 'Merlin.Rivas.Haro@trashymail.com', '23/06/84', 81, 4);
INSERT INTO usuaris VALUES (2806, 'Palma', 'Prado Saldana', 'D', '24 C/ Señores Curas', 12123, 'Palma.Prado.Saldana@trashymail.com', '13/09/71', 24, 3);
INSERT INTO usuaris VALUES (2807, 'Lastenia', 'Altamirano Arroyo', 'D', '97 Av. Santiago Lapuente', 50794, 'Lastenia.Altamirano.Arroyo@dodgit.com', '28/04/67', 11, 6);
INSERT INTO usuaris VALUES (2808, 'Landolf', 'Molina Marroquín', 'H', '95 Ctra. de Fuentenueva', 28230, 'Landolf.Molina.Marroquin@trashymail.com', '19/07/46', 12, 8);
INSERT INTO usuaris VALUES (2809, 'Joya', 'Vigil Girón', NULL, '47 C/ Henan Cortes', 28990, 'Joya.Vigil.Giron@trashymail.com', '05/12/55', 91, 8);
INSERT INTO usuaris VALUES (2810, 'Rufo', 'Crespo Cedillo', 'H', '81 Avda. Explanada Barnuevo', 35470, 'Rufo.Crespo.Cedillo@trashymail.com', '29/06/62', 83, 5);
INSERT INTO usuaris VALUES (2811, 'Edelweiss', 'Puga Márquez', 'D', '47 Pza. Fuensanta', 32530, 'Edelweiss.Puga.Marquez@trashymail.com', '24/02/67', 18, 7);
INSERT INTO usuaris VALUES (2812, 'Amaia', 'Armijo Méndez', 'D', '42 Avenida Cervantes', 48360, 'Amaia.Armijo.Mendez@dodgit.com', '25/07/54', 63, 3);
INSERT INTO usuaris VALUES (2813, 'Irma', 'Montoya Ulibarri', 'D', '47 Camiño Ancho', 37768, 'Irma.Montoya.Ulibarri@pookmail.com', '07/05/67', 28, 8);
INSERT INTO usuaris VALUES (2814, 'Ilona', 'Pina Cortés', 'D', '88 C/ Libertad', 6000, 'Ilona.Pina.Cortes@mailinator.com', '10/05/41', 59, 9);
INSERT INTO usuaris VALUES (2815, 'Fe', 'Juárez Leyva', 'D', '7 El Roqueo', 16600, 'Fe.Juarez.Leyva@mailinator.com', '12/08/68', 39, 6);
INSERT INTO usuaris VALUES (2816, 'Torcuato', 'Prado Téllez', 'H', '33 Avda. Los llanos', 26259, 'Torcuato.Prado.Tellez@dodgit.com', '03/07/63', 5, 1);
INSERT INTO usuaris VALUES (2817, 'Dionel', 'Sauceda Rincón', 'H', '9 C/ Señores Curas', 12127, 'Dionel.Sauceda.Rincon@pookmail.com', '23/05/60', 78, 11);
INSERT INTO usuaris VALUES (2818, 'Tecla', 'Guerrero Hernández', 'D', '81 Carretera Cádiz-Málaga', 20550, 'Tecla.Guerrero.Hernandez@pookmail.com', '05/12/71', 29, 11);
INSERT INTO usuaris VALUES (2819, 'Orestes', 'Agosto Bermúdez', 'H', '59 Eusebio Dávila', 41520, 'Orestes.Agosto.Bermudez@pookmail.com', '23/07/76', 35, 12);
INSERT INTO usuaris VALUES (2820, 'Louis', 'Verdugo Ordóñez', 'H', '1 Urzáiz', 44760, 'Louis.Verdugo.Ordonez@pookmail.com', '24/02/48', 53, 5);
INSERT INTO usuaris VALUES (2821, 'Aureo', 'Castellanos Mares', 'H', '50 Pascual Yunquera', 18659, 'Aureo.Castellanos.Mares@mailinator.com', '02/09/54', 32, 10);
INSERT INTO usuaris VALUES (2822, 'Marziabo', 'Robles Ulibarri', 'H', '5 C/ Andalucía', 4740, 'Marziabo.Robles.Ulibarri@pookmail.com', '28/02/69', 35, 5);
INSERT INTO usuaris VALUES (2823, 'Ticiano', 'Guillén Otero', 'H', '9 C/ Pablo Iglesias', 26312, 'Ticiano.Guillen.Otero@trashymail.com', '23/06/71', 94, 11);
INSERT INTO usuaris VALUES (2824, 'Mindy', 'Vigil Verdugo', 'D', '2 Avda. de Andalucía', 29410, 'Mindy.Vigil.Verdugo@mailinator.com', '09/05/45', 49, 10);
INSERT INTO usuaris VALUES (2825, 'Dylan', 'Fonseca Solorio', 'H', '93 Puerto Lugar', 29719, 'Dylan.Fonseca.Solorio@pookmail.com', '16/09/56', 21, 10);
INSERT INTO usuaris VALUES (2826, 'Naike', 'Montemayor Guzmán', 'H', '38 Rosa de los Vientos', 13328, 'Naike.Montemayor.Guzman@spambob.com', '29/08/48', 77, 10);
INSERT INTO usuaris VALUES (2827, 'Isaias', 'Baca Collazo', 'H', '12 Pascual Yunquera', 18708, 'Isaias.Baca.Collazo@pookmail.com', '05/12/81', 1, 4);
INSERT INTO usuaris VALUES (2828, 'Irupé', 'Rentería Villegas', 'D', '70 Avda. de la Estación', 28610, 'Irupe.Renteria.Villegas@pookmail.com', '13/03/65', 95, 4);
INSERT INTO usuaris VALUES (2829, 'Sabas', 'Rolón Jaimes', 'H', '53 Cañadilla', 21890, 'Sabas.Rolon.Jaimes@pookmail.com', '01/12/64', 92, 4);
INSERT INTO usuaris VALUES (2830, 'Clío', 'Cazares Vera', 'D', '2 C/ Rosa de los Vientos', 11630, 'Clio.Cazares.Vera@spambob.com', '18/12/83', 66, 12);
INSERT INTO usuaris VALUES (2831, 'Haig', 'Mota Casárez', 'H', '45 Avda. Explanada Barnuevo', 34870, 'Haig.Mota.Casarez@pookmail.com', '15/04/71', 3, 9);
INSERT INTO usuaris VALUES (2832, 'Oda', 'Archuleta Duran', NULL, '95 Avda. Generalísimo', 31540, 'Oda.Archuleta.Duran@mailinator.com', '14/11/55', 74, NULL);
INSERT INTO usuaris VALUES (2833, 'Donatela', 'Castillo Tejeda', 'D', '82 Eusebio Dávila', 41479, 'Donatela.Castillo.Tejeda@dodgit.com', '08/12/78', 30, 12);
INSERT INTO usuaris VALUES (2834, 'Radegunda', 'Farías Atencio', 'D', '33 C/ Los Herrán', 6470, 'Radegunda.Farias.Atencio@mailinator.com', '04/10/41', 83, 9);
INSERT INTO usuaris VALUES (2835, 'Thaiel', 'Ozuna Gómez', 'H', '99 C/ Hijuela de Lojo', 20400, 'Thaiel.Ozuna.Gomez@pookmail.com', '15/01/61', 10, 1);
INSERT INTO usuaris VALUES (2836, 'Dominique', 'Bañuelos Castaneda', 'D', '14 Ctra. de la Puerta', 27170, 'Dominique.Banuelos.Castaneda@spambob.com', '12/10/48', 45, 10);
INSERT INTO usuaris VALUES (2837, 'Obed', 'Peres Medina', 'D', '30 Celso Emilio Ferreiro', 50280, 'Obed.Peres.Medina@spambob.com', '12/09/57', 21, 12);
INSERT INTO usuaris VALUES (2838, 'Geranio', 'Rosas Cordova', 'D', '79 Plaza Colón', 24600, 'Geranio.Rosas.Cordova@pookmail.com', '07/11/78', 38, 1);
INSERT INTO usuaris VALUES (2839, 'Fredeswinda', 'Juárez Linares', 'D', '50 C/ Domingo Beltrán', 2220, 'Fredeswinda.Juarez.Linares@dodgit.com', '30/04/61', 53, 5);
INSERT INTO usuaris VALUES (2840, 'Sócrates', 'Arenas Echevarría', 'H', '79 Avda. Rio Nalon', 33150, 'Socrates.Arenas.Echevarria@pookmail.com', '06/05/63', 58, NULL);
INSERT INTO usuaris VALUES (2841, 'Liana', 'Soto Curiel', 'D', '48 C/ Cuesta del  Álamo', 29639, 'Liana.Soto.Curiel@spambob.com', '24/07/44', 39, 12);
INSERT INTO usuaris VALUES (2842, 'Eulogius', 'Fernández Zamora', 'H', '51 Visitación de la Encina', 37762, 'Eulogius.Fernandez.Zamora@mailinator.com', '03/08/40', 0, 6);
INSERT INTO usuaris VALUES (2843, 'Iair', 'Cerda Baez', 'H', '91 Paseo del Atlántico', 17800, 'Iair.Cerda.Baez@spambob.com', '30/11/60', 52, NULL);
INSERT INTO usuaris VALUES (2844, 'Dositeo', 'Marrero Villagómez', 'H', '30 Avda. Andalucía', 26131, 'Dositeo.Marrero.Villagomez@mailinator.com', '04/05/49', 61, 3);
INSERT INTO usuaris VALUES (2845, 'Cesario', 'Díaz Lerma', 'H', '78 Atamaria', 36830, 'Cesario.Diaz.Lerma@pookmail.com', '17/07/61', 72, 1);
INSERT INTO usuaris VALUES (2846, 'Lena', 'Nieves Molina', 'D', '70 C/ Cañada del Rosal', 21668, 'Lena.Nieves.Molina@pookmail.com', '28/07/54', 82, 10);
INSERT INTO usuaris VALUES (2847, 'Loreta', 'Sotelo Paredes', 'D', '83 Celso Emilio Ferreiro', 50410, 'Loreta.Sotelo.Paredes@dodgit.com', '25/10/65', 99, 8);
INSERT INTO usuaris VALUES (2848, 'Alesia', 'Gómez Lemus', 'D', '90 José matía', 2124, 'Alesia.Gomez.Lemus@dodgit.com', '02/08/75', 11, 11);
INSERT INTO usuaris VALUES (2849, 'Minna', 'Santillán Fonseca', 'D', '63 El Roqueo', 17240, 'Minna.Santillan.Fonseca@dodgit.com', '18/06/44', 78, 3);
INSERT INTO usuaris VALUES (2850, 'Natalie', 'Santacruz Ballesteros', 'D', '57 Bouciña', 43840, 'Natalie.Santacruz.Ballesteros@mailinator.com', '09/01/51', 66, 8);
INSERT INTO usuaris VALUES (2851, 'Brandon', 'Quintero Hernandes', 'H', '39 Avda. Rio Nalon', 33200, 'Brandon.Quintero.Hernandes@dodgit.com', '12/03/40', 30, 3);
INSERT INTO usuaris VALUES (2852, 'Aleydis', 'Navarro Briones', 'H', '52 Rua da Rapina', 37468, 'Aleydis.Navarro.Briones@dodgit.com', '05/04/73', 7, 9);
INSERT INTO usuaris VALUES (2853, 'Jocelín', 'Villa Laureano', 'D', '56 Avda. Rio Nalon', 33126, 'Jocelin.Villa.Laureano@dodgit.com', '26/08/65', 41, 12);
INSERT INTO usuaris VALUES (2854, 'Brunela', 'Alonso Gamboa', 'D', '23 Puerto Lugar', 29755, 'Brunela.Alonso.Gamboa@spambob.com', '05/07/49', 16, NULL);
INSERT INTO usuaris VALUES (2855, 'Deyanira', 'Camarillo Treviño', 'D', '18 Fuente del Gallo', 15115, 'Deyanira.Camarillo.Trevino@mailinator.com', '17/02/64', 92, NULL);
INSERT INTO usuaris VALUES (2856, 'Hartman', 'Corona Ruelas', 'H', '74 Avda. Andalucía', 26130, 'Hartman.Corona.Ruelas@dodgit.com', '19/09/76', 76, 3);
INSERT INTO usuaris VALUES (2857, 'Margaret', 'Gurule Bernal', 'D', '48 Reiseñor', 45840, 'Margaret.Gurule.Bernal@pookmail.com', '22/06/85', 95, 9);
INSERT INTO usuaris VALUES (2858, 'Crispina', 'Jasso Garibay', 'D', '55 C/ Eras', 28738, 'Crispina.Jasso.Garibay@mailinator.com', '26/09/51', 35, 12);
INSERT INTO usuaris VALUES (2859, 'Arandu', 'Parra Ruelas', 'D', '71 Avda. Rio Nalon', 33535, 'Arandu.Parra.Ruelas@mailinator.com', '01/10/56', 32, 2);
INSERT INTO usuaris VALUES (2860, 'Mijal', 'Fernández Valenzuela', 'D', '53 C/ Henan Cortes', 29194, 'Mijal.Fernandez.Valenzuela@pookmail.com', '21/05/60', 22, 11);
INSERT INTO usuaris VALUES (2861, 'Aquiles', 'Vigil Sauceda', 'H', '38 C/ Hijuela de Lojo', 20270, 'Aquiles.Vigil.Sauceda@mailinator.com', '16/09/54', 90, 6);
INSERT INTO usuaris VALUES (2862, 'Leopolda', 'Márquez Reyes', 'D', '96 Comandante Izarduy', 8800, 'Leopolda.Marquez.Reyes@dodgit.com', '13/01/78', 26, 11);
INSERT INTO usuaris VALUES (2863, 'Yunka', 'Toledo Adame', 'H', '53 Apartado de Correos', 37450, 'Yunka.Toledo.Adame@trashymail.com', '05/07/84', 99, 3);
INSERT INTO usuaris VALUES (2864, 'Katja', 'Montenegro Meléndez', 'D', '74 Ctra. de la Puerta', 27240, 'Katja.Montenegro.Melendez@spambob.com', '27/06/68', 57, 11);
INSERT INTO usuaris VALUES (2865, 'Cristhian', 'Benavides Carvajal', 'H', '67 Visitación de la Encina', 37750, 'Cristhian.Benavides.Carvajal@dodgit.com', '03/09/77', 73, 9);
INSERT INTO usuaris VALUES (2866, 'Filomana', 'Mateo Montemayor', 'D', '13 Outid de Arriba', 43596, 'Filomana.Mateo.Montemayor@trashymail.com', '15/03/54', 95, 4);
INSERT INTO usuaris VALUES (2867, 'Camelia', 'Granado Esparza', 'D', '26 C/ Señores Curas', 12161, 'Camelia.Granado.Esparza@dodgit.com', '20/01/80', 35, 8);
INSERT INTO usuaris VALUES (2868, 'Marlen', 'Gamez Carvajal', 'D', '18 C/ Los Herrán', 6120, 'Marlen.Gamez.Carvajal@trashymail.com', '04/09/55', 64, 5);
INSERT INTO usuaris VALUES (2869, 'Gregory', 'Arana Verdugo', 'D', '66 C/ Manuel Iradier', 3792, 'Gregory.Arana.Verdugo@mailinator.com', '07/12/42', 95, 10);
INSERT INTO usuaris VALUES (2870, 'Duncan', 'Cerda Ávila', 'H', '87 Socampo', 37658, 'Duncan.Cerda.Avila@dodgit.com', '14/12/75', 40, 5);
INSERT INTO usuaris VALUES (2871, 'Illcapil', 'Vargas Montemayor', 'D', '21 Rio Segura', 31360, 'Illcapil.Vargas.Montemayor@dodgit.com', '17/03/83', 73, 11);
INSERT INTO usuaris VALUES (2872, 'Michelle', 'Saucedo Bañuelos', 'D', '96 Escuadro', 46910, 'Michelle.Saucedo.Banuelos@spambob.com', '08/04/67', 48, 8);
INSERT INTO usuaris VALUES (2873, 'Lucinda', 'Guardado Zúñiga', 'D', '67 La Fontanilla', 14290, 'Lucinda.Guardado.Zuniga@trashymail.com', '26/04/83', 99, 11);
INSERT INTO usuaris VALUES (2874, 'Lucero', 'Soliz Corral', 'D', '68 Crta. Cádiz-Málaga', 12225, 'Lucero.Soliz.Corral@trashymail.com', '20/02/49', 24, 3);
INSERT INTO usuaris VALUES (2875, 'Ida', 'Serrato Jaime', 'D', '9 C/ Fernández de Leceta', 3409, 'Ida.Serrato.Jaime@spambob.com', '07/02/40', 57, 2);
INSERT INTO usuaris VALUES (2876, 'Zuleica', 'Corona Coronado', 'D', '76 Av. Santiago Lapuente', 50793, 'Zuleica.Corona.Coronado@mailinator.com', '23/04/62', 51, 2);
INSERT INTO usuaris VALUES (2877, 'Brígida', 'Acosta Arredondo', 'D', '22 Rúa de San Pedro', 37797, 'Brigida.Acosta.Arredondo@spambob.com', '24/02/64', 17, 2);
INSERT INTO usuaris VALUES (2878, 'Carlo', 'Magana Ramírez', 'H', '42 Outid de Arriba', 43500, 'Carlo.Magana.Ramirez@dodgit.com', '26/11/71', 93, 9);
INSERT INTO usuaris VALUES (2879, 'Herman', 'Muñiz Orellana', 'H', '77 Avendaño', 4470, 'Herman.Muniz.Orellana@mailinator.com', '05/06/69', 12, 12);
INSERT INTO usuaris VALUES (2880, 'Calquín', 'Laboy Guerra', 'H', '24 Carretera', 14720, 'Calquin.Laboy.Guerra@pookmail.com', '04/06/82', 94, 3);
INSERT INTO usuaris VALUES (2881, 'Lelio', 'Ramón Nieves', 'H', '16 Escuadro', 46960, 'Lelio.Ramon.Nieves@mailinator.com', '17/03/61', 13, 2);
INSERT INTO usuaris VALUES (2882, 'Olimpia', 'Hernádez Negrón', NULL, '61 Herrería', 18160, 'Olimpia.Hernadez.Negron@spambob.com', '22/01/57', 9, 10);
INSERT INTO usuaris VALUES (2883, 'Nara', 'Acuna Colunga', 'D', '97 C/ Pablo Iglesias', 26315, 'Nara.Acuna.Colunga@dodgit.com', '02/03/65', 3, 10);
INSERT INTO usuaris VALUES (2884, 'Isabel', 'Sotelo Villa', 'D', '71 Pza. Fuensanta', 32226, 'Isabel.Sotelo.Villa@spambob.com', '05/12/53', 70, 8);
INSERT INTO usuaris VALUES (2885, 'Laia', 'Arriaga Robledo', 'D', '2 El Roqueo', 17200, 'Laia.Arriaga.Robledo@trashymail.com', '10/08/51', 89, 11);
INSERT INTO usuaris VALUES (2886, 'André', 'Perea Morales', 'H', '69 C/ Rosa de los Vientos', 11648, 'Andre.Perea.Morales@mailinator.com', '01/09/85', 41, 3);
INSERT INTO usuaris VALUES (2887, 'Tiziano', 'Haro Corrales', 'H', '47 Extramuros', 28400, 'Tiziano.Haro.Corrales@spambob.com', '23/05/43', 0, 1);
INSERT INTO usuaris VALUES (2888, 'Ulrico', 'Villalobos Magana', 'H', '44 C/ Fernández de Leceta', 3380, 'Ulrico.Villalobos.Magana@pookmail.com', '06/10/69', 90, 10);
INSERT INTO usuaris VALUES (2889, 'Xena', 'Camacho Cordero', 'D', '79 Avendaño', 4500, 'Xena.Camacho.Cordero@trashymail.com', '04/11/84', 25, 4);
INSERT INTO usuaris VALUES (2890, 'Absalom', 'Aragón Terán', 'H', '78 Ctra. Hornos', 26213, 'Absalom.Aragon.Teran@spambob.com', '13/04/72', 45, 2);
INSERT INTO usuaris VALUES (2891, 'Luciana', 'Contreras Estrada', 'D', '97 Outid de Arriba', 43480, 'Luciana.Contreras.Estrada@pookmail.com', '02/01/57', 84, 4);
INSERT INTO usuaris VALUES (2892, 'Samir', 'Ruiz Acevedo', 'H', '33 Cruce Casa de Postas', 18420, 'Samir.Ruiz.Acevedo@spambob.com', '27/06/74', 15, 3);
INSERT INTO usuaris VALUES (2893, 'Damia', 'Espinoza Rodrígez', 'D', '58 Canónigo Valiño', 46210, 'Damia.Espinoza.Rodrigez@spambob.com', '28/10/61', 0, 8);
INSERT INTO usuaris VALUES (2894, 'Lahuen', 'Covas Pedraza', 'D', '25 Ourense', 43200, 'Lahuen.Covas.Pedraza@spambob.com', '25/07/55', 29, 12);
INSERT INTO usuaris VALUES (2895, 'Goyo', 'Velásquez Urrútia', 'H', '85 Ctra. Bailén-Motril', 23330, 'Goyo.Velasquez.Urrutia@spambob.com', '11/12/40', 80, 12);
INSERT INTO usuaris VALUES (2896, 'Celma', 'Barrientos Rojas', 'D', '73 Plazuela do Porto', 37892, 'Celma.Barrientos.Rojas@dodgit.com', '17/07/63', 31, 12);
INSERT INTO usuaris VALUES (2897, 'Mendel', 'Soliz Salas', 'H', '51 C/ Amoladera', 28760, 'Mendel.Soliz.Salas@pookmail.com', '28/12/81', 30, NULL);
INSERT INTO usuaris VALUES (2898, 'Lian', 'Sanches Orosco', 'H', '34 Urzáiz', 44370, 'Lian.Sanches.Orosco@mailinator.com', '19/08/66', 69, 1);
INSERT INTO usuaris VALUES (2899, 'Loreto', 'Casas Marrero', 'H', '73 Pl. Virgen Blanca', 8750, 'Loreto.Casas.Marrero@trashymail.com', '06/04/65', 73, 6);
INSERT INTO usuaris VALUES (2900, 'Kenji', 'Rosas Loya', 'H', '92 Rua da Rapina', 37487, 'Kenji.Rosas.Loya@dodgit.com', '01/05/52', 96, 6);
INSERT INTO usuaris VALUES (2901, 'Mayda', 'Arriaga Valadez', 'D', '10 Quevedo', 15256, 'Mayda.Arriaga.Valadez@spambob.com', '13/01/52', 88, 10);
INSERT INTO usuaris VALUES (2902, 'Agapita', 'Mascarenas Echevarría', 'D', '42 Reyes Católicos', 9300, 'Agapita.Mascarenas.Echevarria@trashymail.com', '28/09/58', 29, NULL);
INSERT INTO usuaris VALUES (2903, 'Rosemary', 'Cuellar Cortés', 'D', '70 Rúa do Paseo', 41820, 'Rosemary.Cuellar.Cortes@spambob.com', '01/01/64', 81, 11);
INSERT INTO usuaris VALUES (2904, 'Tiburcio', 'Sanabria Mascarenas', 'H', '79 Camiño Ancho', 37764, 'Tiburcio.Sanabria.Mascarenas@trashymail.com', '17/01/83', 26, 2);
INSERT INTO usuaris VALUES (2905, 'Mamerto', 'Romero Vasquez', 'H', '96 Escuadro', 46860, 'Mamerto.Romero.Vasquez@pookmail.com', '16/05/49', 65, 11);
INSERT INTO usuaris VALUES (2906, 'Flavia', 'Jasso Mota', 'D', '61 Pza. Fuensanta', 32530, 'Flavia.Jasso.Mota@pookmail.com', '24/11/62', 25, 1);
INSERT INTO usuaris VALUES (2907, 'Fabienne', 'Herrera Ybarra', 'D', '48 Av. Santiago Lapuente', 50770, 'Fabienne.Herrera.Ybarra@pookmail.com', '12/08/83', 39, 6);
INSERT INTO usuaris VALUES (2908, 'Mar', 'Hernandes Montoya', 'D', '17 Avendaño', 4510, 'Mar.Hernandes.Montoya@trashymail.com', '22/11/76', 12, 12);
INSERT INTO usuaris VALUES (2909, 'Eufrasio', 'Lemus Benítez', 'H', '19 C/ Los Herrán', 6700, 'Eufrasio.Lemus.Benitez@spambob.com', '09/10/74', 40, 5);
INSERT INTO usuaris VALUES (2910, 'Alice', 'Sisneros Leyva', 'D', '63 Visitación de la Encina', 37730, 'Alice.Sisneros.Leyva@mailinator.com', '12/01/78', 32, 1);
INSERT INTO usuaris VALUES (2911, 'Modesto', 'Betancourt Villa', 'H', '93 Extramuros', 28530, 'Modesto.Betancourt.Villa@pookmail.com', '02/10/83', 90, 6);
INSERT INTO usuaris VALUES (2912, 'Ilian', 'Amador Velázquez', 'D', '18 Extramuros', 28413, 'Ilian.Amador.Velazquez@dodgit.com', '27/05/83', 0, 2);
INSERT INTO usuaris VALUES (2913, 'Dulce', 'Ceballos Molina', 'D', '33 José matía', 1426, 'Dulce.Ceballos.Molina@dodgit.com', '27/02/76', 98, 1);
INSERT INTO usuaris VALUES (2914, 'Calixta', 'Salazar Rendón', NULL, '6 C/ Cañada del Rosal', 21668, 'Calixta.Salazar.Rendon@mailinator.com', '23/04/40', 52, 1);
INSERT INTO usuaris VALUES (2915, 'Borja', 'Carrera Heredia', 'H', '66 Avda. Enrique Peinador', 37187, 'Borja.Carrera.Heredia@spambob.com', '19/02/84', 52, NULL);
INSERT INTO usuaris VALUES (2916, 'Semira', 'Aguirre Montemayor', 'D', '31 Caño', 32750, 'Semira.Aguirre.Montemayor@trashymail.com', '28/04/70', 73, 6);
INSERT INTO usuaris VALUES (2917, 'Gayane', 'Zambrano Alicea', 'D', '88 C/ Eras', 28729, 'Gayane.Zambrano.Alicea@pookmail.com', '03/09/78', 51, 6);
INSERT INTO usuaris VALUES (2918, 'Ammiano', 'Caballero Chávez', 'H', '75 Constitución', 36950, 'Ammiano.Caballero.Chavez@pookmail.com', '11/01/44', 41, NULL);
INSERT INTO usuaris VALUES (2919, 'Roquelina', 'Lozada Estévez', 'D', '36 Puerto Lugar', 29753, 'Roquelina.Lozada.Estevez@mailinator.com', '25/09/73', 77, NULL);
INSERT INTO usuaris VALUES (2920, 'Eloisa', 'Ceballos Robledo', 'D', '62 Pl. Virgen Blanca', 8640, 'Eloisa.Ceballos.Robledo@spambob.com', '10/06/45', 69, 4);
INSERT INTO usuaris VALUES (2921, 'Bettina', 'Peralta Trejo', 'D', '39 Carretera Cádiz-Málaga', 20495, 'Bettina.Peralta.Trejo@mailinator.com', '01/07/70', 66, 2);
INSERT INTO usuaris VALUES (2922, 'Servio', 'Vallejo Pina', 'H', '39 Caño', 32870, 'Servio.Vallejo.Pina@trashymail.com', '16/04/48', 99, 4);
INSERT INTO usuaris VALUES (2923, 'Lázaro', 'Otero Orta', 'D', '62 Ctra. de Siles', 27377, 'Lazaro.Otero.Orta@spambob.com', '26/12/51', 72, 3);
INSERT INTO usuaris VALUES (2924, 'Agueda', 'Montoya Arredondo', 'D', '9 Boriñaur enparantza', 7440, 'Agueda.Montoya.Arredondo@dodgit.com', '16/05/83', 46, 12);
INSERT INTO usuaris VALUES (2925, 'Amadoe', 'Puente Linares', 'H', '69 Calle Carril de la Fuente', 13193, 'Amadoe.Puente.Linares@pookmail.com', '26/05/43', 96, 1);
INSERT INTO usuaris VALUES (2926, 'Mampu', 'Aguayo Nevarez', 'H', '51 Paseo Junquera', 12429, 'Mampu.Aguayo.Nevarez@mailinator.com', '08/03/56', 73, 8);
INSERT INTO usuaris VALUES (2927, 'Gilda', 'Tapia Ruelas', 'D', '9 Valadouro', 48140, 'Gilda.Tapia.Ruelas@mailinator.com', '29/09/65', 42, 7);
INSERT INTO usuaris VALUES (2928, 'Hans', 'Cantú Prieto', 'H', '74 C/ Domingo Beltrán', 2253, 'Hans.Cantu.Prieto@trashymail.com', '09/07/69', 75, 6);
INSERT INTO usuaris VALUES (2929, 'Demóstenes', 'Saldivar Hernandes', 'H', '95 Urzáiz', 45300, 'Demostenes.Saldivar.Hernandes@mailinator.com', '20/06/71', 13, 7);
INSERT INTO usuaris VALUES (2930, 'Lis', 'Paez Ponce', 'D', '13 Prolongacion San Sebastian', 21291, 'Lis.Paez.Ponce@spambob.com', '03/07/70', 26, 10);
INSERT INTO usuaris VALUES (2931, 'Crescencio', 'Jimínez Gurule', 'H', '23 Calle Proc. San Sebastián', 13100, 'Crescencio.Jiminez.Gurule@mailinator.com', '12/11/54', 67, 3);
INSERT INTO usuaris VALUES (2932, 'Mauli', 'Domínguez Dávila', 'D', '58 Cruce Casa de Postas', 18400, 'Mauli.Dominguez.Davila@pookmail.com', '09/04/48', 42, 4);
INSERT INTO usuaris VALUES (2933, 'Ailen', 'Corrales Arredondo', 'D', '28 C/ Manuel Iradier', 3814, 'Ailen.Corrales.Arredondo@trashymail.com', '03/10/69', 68, 11);
INSERT INTO usuaris VALUES (2934, 'Casandro', 'Lerma Vergara', 'H', '17 Outid de Arriba', 43740, 'Casandro.Lerma.Vergara@spambob.com', '26/11/63', 26, 7);
INSERT INTO usuaris VALUES (2935, 'Anunciación', 'López Vargas', 'D', '24 Carretera del Muelle', 12311, 'Anunciacion.Lopez.Vargas@trashymail.com', '19/12/53', 12, 1);
INSERT INTO usuaris VALUES (2936, 'Balbina', 'Alicea Loya', 'D', '46 Avda. de Andalucía', 29312, 'Balbina.Alicea.Loya@trashymail.com', '10/01/83', 59, 10);
INSERT INTO usuaris VALUES (2937, 'Arthur', 'Ballesteros Fernández', 'H', '72 Calle Carril de la Fuente', 13210, 'Arthur.Ballesteros.Fernandez@trashymail.com', '06/07/83', 8, 5);
INSERT INTO usuaris VALUES (2938, 'Cyril', 'Otero Rael', 'H', '2 C/ Canarias', 20200, 'Cyril.Otero.Rael@mailinator.com', '18/10/77', 24, 10);
INSERT INTO usuaris VALUES (2939, 'Madeleine', 'Arévalo Alcantar', 'D', '16 Avda. Enrique Peinador', 37183, 'Madeleine.Arevalo.Alcantar@pookmail.com', '22/03/47', 51, 6);
INSERT INTO usuaris VALUES (2940, 'Sean', 'Matos Cruz', 'H', '74 Pl. Virgen Blanca', 8759, 'Sean.Matos.Cruz@trashymail.com', '25/09/82', 63, 12);
INSERT INTO usuaris VALUES (2941, 'Ophelia', 'Leyva Alvarado', 'D', '50 Avda. de Andalucía', 29240, 'Ophelia.Leyva.Alvarado@dodgit.com', '27/11/54', 56, 5);
INSERT INTO usuaris VALUES (2942, 'Rogerio', 'Escalante Chapa', 'H', '85 Zumalakarregi etorbidea', 7192, 'Rogerio.Escalante.Chapa@dodgit.com', '07/05/41', 18, 8);
INSERT INTO usuaris VALUES (2943, 'Polidoro', 'Segovia Arce', 'H', '76 Herrería', 18184, 'Polidoro.Segovia.Arce@dodgit.com', '12/08/81', 75, 5);
INSERT INTO usuaris VALUES (2944, 'Igal', 'Pena Mejía', 'H', '52 C/ Fernández de Leceta', 3517, 'Igal.Pena.Mejia@mailinator.com', '20/06/43', 86, 8);
INSERT INTO usuaris VALUES (2945, 'Afrodisio', 'Ceja Miramontes', 'H', '84 Cruce Casa de Postas', 18430, 'Afrodisio.Ceja.Miramontes@mailinator.com', '08/06/40', 85, 9);
INSERT INTO usuaris VALUES (2946, 'Benon', 'Malave Cisneros', 'H', '87 Rúa do Paseo', 41927, 'Benon.Malave.Cisneros@pookmail.com', '19/02/42', 58, 6);
INSERT INTO usuaris VALUES (2947, 'Michaela', 'Zavala Alaniz', 'D', '28 Extramuros', 28411, 'Michaela.Zavala.Alaniz@mailinator.com', '30/12/65', 65, 12);
INSERT INTO usuaris VALUES (2948, 'Espartaco', 'Rangel Cuellar', NULL, '54 Camiño Ancho', 37789, 'Espartaco.Rangel.Cuellar@mailinator.com', '25/03/71', 26, 9);
INSERT INTO usuaris VALUES (2949, 'Periandro', 'Jurado Figueroa', 'H', '88 Rúa Olmos', 37330, 'Periandro.Jurado.Figueroa@mailinator.com', '28/02/52', 35, 9);
INSERT INTO usuaris VALUES (2950, 'Abdallah', 'Rivero Samaniego', 'H', '74 Urzáiz', 44360, 'Abdallah.Rivero.Samaniego@trashymail.com', '21/10/60', 23, 11);
INSERT INTO usuaris VALUES (2951, 'Rainero', 'Pedroza Peralta', 'H', '60 C/ Los Herrán', 6120, 'Rainero.Pedroza.Peralta@spambob.com', '03/09/84', 66, 1);
INSERT INTO usuaris VALUES (2952, 'Mickey', 'Saldana Vázquez', 'H', '70 Salzillo', 32692, 'Mickey.Saldana.Vazquez@dodgit.com', '11/09/70', 60, 7);
INSERT INTO usuaris VALUES (2953, 'Abaco', 'Orellana Ávalos', 'H', '27 Avda. Andalucía', 26131, 'Abaco.Orellana.Avalos@spambob.com', '04/05/81', 77, 4);
INSERT INTO usuaris VALUES (2954, 'Danilo', 'Rocha Jaramillo', 'H', '55 Pza. Fuensanta', 32356, 'Danilo.Rocha.Jaramillo@spambob.com', '13/06/58', 2, 9);
INSERT INTO usuaris VALUES (2955, 'Bautista', 'Aranda Iglesias', 'H', '61 C/ Fernández de Leceta', 3500, 'Bautista.Aranda.Iglesias@dodgit.com', '21/06/44', 44, 3);
INSERT INTO usuaris VALUES (2956, 'Evaristo', 'Camarillo Acevedo', 'H', '56 Camiño Ancho', 37791, 'Evaristo.Camarillo.Acevedo@spambob.com', '21/04/59', 77, 1);
INSERT INTO usuaris VALUES (2957, 'Natasha', 'Naranjo Atencio', 'D', '78 Cartagena', 30180, 'Natasha.Naranjo.Atencio@pookmail.com', NULL, 34, 6);
INSERT INTO usuaris VALUES (2958, 'Ludovica', 'Saucedo Garza', 'D', '35 C/ Arana', 2650, 'Ludovica.Saucedo.Garza@mailinator.com', '03/03/52', 36, 9);
INSERT INTO usuaris VALUES (2959, 'Petronio', 'Tijerina Alcaraz', 'H', '41 Cercas Bajas', 8200, 'Petronio.Tijerina.Alcaraz@mailinator.com', '31/07/84', 71, 11);
INSERT INTO usuaris VALUES (2960, 'Odila', 'Casillas Sedillo', 'D', '9 C/ Arana', 2640, 'Odila.Casillas.Sedillo@pookmail.com', '09/09/47', 13, 10);
INSERT INTO usuaris VALUES (2961, 'Rainer', 'Prieto Carreón', 'H', '22 Avda. de Andalucía', 29197, 'Rainer.Prieto.Carreon@pookmail.com', '10/01/68', 57, 7);
INSERT INTO usuaris VALUES (2962, 'Malaquías', 'Corral Merino', 'H', '97 C/ Pablo Iglesias', 26324, 'Malaquias.Corral.Merino@dodgit.com', '22/08/40', 69, 12);
INSERT INTO usuaris VALUES (2963, 'Septimo', 'Olivares Maya', 'H', '46 Herrería', 18193, 'Septimo.Olivares.Maya@dodgit.com', '04/07/49', 1, 8);
INSERT INTO usuaris VALUES (2964, 'Urbano', 'Caldera Cuellar', NULL, '9 Avda. Los llanos', 26280, 'Urbano.Caldera.Cuellar@dodgit.com', '15/01/64', 86, 4);
INSERT INTO usuaris VALUES (2965, 'Mateos', 'Sarabia Girón', 'H', '47 Ctra. Beas-Cortijos Nuevos', 26520, 'Mateos.Sarabia.Giron@spambob.com', '18/09/47', 97, 2);
INSERT INTO usuaris VALUES (2966, 'Zeeb', 'Velásquez Cardona', 'H', '2 Ctra. Bailén-Motril', 23390, 'Zeeb.Velasquez.Cardona@trashymail.com', '02/10/59', 77, 9);
INSERT INTO usuaris VALUES (2967, 'Apollo', 'Valenzuela Manzanares', 'H', '54 Calle Proc. San Sebastián', 13130, 'Apollo.Valenzuela.Manzanares@spambob.com', '08/08/65', 8, 3);
INSERT INTO usuaris VALUES (2968, 'Naike', 'Guevara Zepeda', 'H', '24 Rúa do Paseo', 41930, 'Naike.Guevara.Zepeda@spambob.com', '12/10/63', 19, 3);
INSERT INTO usuaris VALUES (2969, 'Severo', 'Jurado Arévalo', 'H', '74 Salzillo', 32620, 'Severo.Jurado.Arevalo@mailinator.com', '12/01/51', 38, 10);
INSERT INTO usuaris VALUES (2970, 'Nazar', 'Tamayo Barraza', 'H', '7 Socampo', 37656, 'Nazar.Tamayo.Barraza@pookmail.com', '25/09/66', 88, 8);
INSERT INTO usuaris VALUES (2971, 'Fulxencio', 'Méndez Viera', 'H', '8 Avda. de la Estación', 28650, 'Fulxencio.Mendez.Viera@mailinator.com', '25/09/63', 21, 1);
INSERT INTO usuaris VALUES (2972, 'Amatista', 'Montés Velez', 'D', '77 Avda. Alameda Sundheim', 22800, 'Amatista.Montes.Velez@spambob.com', '30/08/40', 81, 6);
INSERT INTO usuaris VALUES (2973, 'Leonila', 'Urena Veliz', 'D', '21 El Roqueo', 17130, 'Leonila.Urena.Veliz@pookmail.com', '26/09/55', 8, 6);
INSERT INTO usuaris VALUES (2974, 'Adelhard', 'Solorio Haro', 'H', '67 Lamas Carbajal', 41570, 'Adelhard.Solorio.Haro@mailinator.com', '24/10/76', 10, 1);
INSERT INTO usuaris VALUES (2975, 'Garibaldo', 'Olmos Barrientos', 'H', '32 Plazuela do Porto', 37893, 'Garibaldo.Olmos.Barrientos@dodgit.com', '22/01/46', 23, 11);
INSERT INTO usuaris VALUES (2976, 'Bayard', 'Najera Gil', 'H', '35 El Roqueo', 15900, 'Bayard.Najera.Gil@mailinator.com', '06/01/82', 64, 7);
INSERT INTO usuaris VALUES (2977, 'Androcles', 'Molina Viera', 'H', '23 Calle Proc. San Sebastián', 12570, 'Androcles.Molina.Viera@trashymail.com', '03/03/46', 90, 1);
INSERT INTO usuaris VALUES (2978, 'Abo', 'Collado Crespo', 'H', '81 C/ Andalucía', 4639, 'Abo.Collado.Crespo@spambob.com', '18/04/42', 98, 8);
INSERT INTO usuaris VALUES (2979, 'Dafna', 'Reyes Gamez', 'D', '39 Ourense', 42110, 'Dafna.Reyes.Gamez@spambob.com', '13/07/70', 63, 12);
INSERT INTO usuaris VALUES (2980, 'Denna', 'Naranjo Cordova', 'D', '13 C/ Los Herrán', 6700, 'Denna.Naranjo.Cordova@spambob.com', '13/05/41', 41, 12);
INSERT INTO usuaris VALUES (2981, 'Athena', 'Mena Ramírez', 'D', '46 C/ Canarias', 20100, 'Athena.Mena.Ramirez@pookmail.com', '18/09/70', 46, 5);
INSERT INTO usuaris VALUES (2982, 'Merlina', 'Munguia Sedillo', 'D', '24 Cartagena', 30560, 'Merlina.Munguia.Sedillo@mailinator.com', '27/12/43', 29, 7);
INSERT INTO usuaris VALUES (2983, 'Inaquí', 'Ulibarri Armas', 'D', '15 C/ Domingo Beltrán', 2220, 'Inaqui.Ulibarri.Armas@mailinator.com', '08/09/49', 97, 10);
INSERT INTO usuaris VALUES (2984, 'Scarlett', 'Ruiz Partida', 'D', '93 C/ Henan Cortes', 28980, 'Scarlett.Ruiz.Partida@pookmail.com', '10/12/42', 55, 10);
INSERT INTO usuaris VALUES (2985, 'Evaristo', 'Cárdenas Quezada', 'H', '25 Paraguay', 3740, 'Evaristo.Cardenas.Quezada@mailinator.com', '25/12/60', 15, 8);
INSERT INTO usuaris VALUES (2986, 'Febe', 'Leyva Cantú', 'H', '77 C/ Hijuela de Lojo', 20400, 'Febe.Leyva.Cantu@dodgit.com', '18/08/80', 69, 11);
INSERT INTO usuaris VALUES (2987, 'Viv', 'Nieto Saldivar', 'D', '28 Ventanilla de Beas', 27770, 'Viv.Nieto.Saldivar@pookmail.com', '04/05/48', 5, 2);
INSERT INTO usuaris VALUES (2988, 'Amantzi', 'Alcaraz Tijerina', 'H', '16 Cruce Casa de Postas', 18247, 'Amantzi.Alcaraz.Tijerina@mailinator.com', '25/11/72', 65, 4);
INSERT INTO usuaris VALUES (2989, 'Jordana', 'Hinojosa Chapa', 'D', '33 Ctra. Hornos', 26227, 'Jordana.Hinojosa.Chapa@mailinator.com', '05/12/44', 30, 11);
INSERT INTO usuaris VALUES (2990, 'Jannifer', 'Lugo Calvillo', 'D', '53 Av. Zumalakarregi', 3159, 'Jannifer.Lugo.Calvillo@pookmail.com', '13/03/59', 68, 12);
INSERT INTO usuaris VALUES (2991, 'Martiniano', 'Robledo Jasso', 'H', '94 Canónigo Valiño', 46260, 'Martiniano.Robledo.Jasso@pookmail.com', '18/09/70', 72, 6);
INSERT INTO usuaris VALUES (2992, 'Rancul', 'Adame Pichardo', 'H', '7 C/ Libertad', 5410, 'Rancul.Adame.Pichardo@mailinator.com', '24/07/56', 10, 2);
INSERT INTO usuaris VALUES (2993, 'Wendy', 'Varela Guardado', 'D', '29 Ctra. Bailén-Motril', 23240, 'Wendy.Varela.Guardado@mailinator.com', '25/11/67', 0, 11);
INSERT INTO usuaris VALUES (2994, 'Rogerio', 'Alonso Castillo', 'H', '45 C/ Henan Cortes', 29170, 'Rogerio.Alonso.Castillo@trashymail.com', '21/01/56', 80, 1);
INSERT INTO usuaris VALUES (2995, 'Briseida', 'Rincón Sarabia', 'D', '27 Calvo Sotelo', 47260, 'Briseida.Rincon.Sarabia@trashymail.com', '16/04/58', 13, 6);
INSERT INTO usuaris VALUES (2996, 'Crystal', 'Perea Barrios', 'D', '30 Ctra. Bailén-Motril', 23210, 'Crystal.Perea.Barrios@mailinator.com', '20/09/40', 50, 3);
INSERT INTO usuaris VALUES (2997, 'Iona', 'Leyva Palomo', 'D', '18 Rosa de los Vientos', 13345, 'Iona.Leyva.Palomo@dodgit.com', '25/10/76', 10, 9);
INSERT INTO usuaris VALUES (2998, 'Iber', 'Corona Salas', 'H', '28 Avda. Generalísimo', 31540, 'Iber.Corona.Salas@trashymail.com', '01/08/79', 66, 6);
INSERT INTO usuaris VALUES (2999, 'Troilo', 'Cordova Zamudio', 'H', '79 Rúa do Paseo', 41908, 'Troilo.Cordova.Zamudio@trashymail.com', '21/01/68', 90, 3);
INSERT INTO usuaris VALUES (3000, 'Elsira', 'Ruiz Anguiano', 'D', '54 C/ Henan Cortes', 28979, 'Elsira.Ruiz.Anguiano@mailinator.com', '25/09/44', 90, 12);
INSERT INTO usuaris VALUES (3001, 'Petronila', 'Madera Mondragón', NULL, '94 C/ Henan Cortes', 28950, 'Petronila.Madera.Mondragon@dodgit.com', '15/02/82', 45, 4);
INSERT INTO usuaris VALUES (3002, 'Lie', 'Zapata Cepeda', 'H', '97 Prolongacion San Sebastian', 21387, 'Lie.Zapata.Cepeda@pookmail.com', '03/02/67', 48, 9);
INSERT INTO usuaris VALUES (3003, 'Isadora', 'Ramírez Duarte', 'D', '83 C/ Benito Guinea', 8330, 'Isadora.Ramirez.Duarte@trashymail.com', '18/06/41', 9, NULL);
INSERT INTO usuaris VALUES (3004, 'Denis', 'Lucio Herrera', 'D', '64 Avda. de la Estación', 28595, 'Denis.Lucio.Herrera@mailinator.com', '12/04/73', 54, 5);
INSERT INTO usuaris VALUES (3005, 'Tiburcio', 'Armendáriz Gallardo', 'H', '99 Socampo', 37658, 'Tiburcio.Armendariz.Gallardo@pookmail.com', '31/12/72', 34, 7);
INSERT INTO usuaris VALUES (3006, 'Dositeo', 'Sánchez Montano', 'H', '38 Carretera Cádiz-Málaga', 20700, 'Dositeo.Sanchez.Montano@pookmail.com', '28/12/72', 37, 11);
INSERT INTO usuaris VALUES (3007, 'Herendiara', 'Quintanilla Arana', 'D', '17 C/ Henan Cortes', 28940, 'Herendiara.Quintanilla.Arana@trashymail.com', '31/10/65', 85, 9);
INSERT INTO usuaris VALUES (3008, 'Susane', 'Zepeda Montano', 'D', '35 Avendaño', 3816, 'Susane.Zepeda.Montano@spambob.com', '12/05/47', 28, 3);
INSERT INTO usuaris VALUES (3009, 'Quintilo', 'Pineda Palomino', 'H', '60 C/ Canarias', 20215, 'Quintilo.Pineda.Palomino@dodgit.com', '13/07/73', 98, 10);
INSERT INTO usuaris VALUES (3010, 'Ary', 'Alcantar Jasso', 'D', '65 Caño', 33110, 'Ary.Alcantar.Jasso@trashymail.com', '06/03/63', 22, 3);
INSERT INTO usuaris VALUES (3011, 'Arthur', 'Rosado Santana', 'H', '88 Atamaria', 36550, 'Arthur.Rosado.Santana@spambob.com', '01/08/80', 49, 2);
INSERT INTO usuaris VALUES (3012, 'Matteo', 'Velez Urena', 'H', '19 Avendaño', 3817, 'Matteo.Velez.Urena@dodgit.com', '02/06/57', 21, 5);
INSERT INTO usuaris VALUES (3013, 'Mirella', 'Fernández Vasquez', 'D', '14 C/ Cañada del Rosal', 21390, 'Mirella.Fernandez.Vasquez@dodgit.com', '18/11/59', 15, 5);
INSERT INTO usuaris VALUES (3014, 'Linus', 'Bermúdez Téllez', 'H', '40 Ventanilla de Beas', 28189, 'Linus.Bermudez.Tellez@dodgit.com', '24/10/49', 98, NULL);
INSERT INTO usuaris VALUES (3015, 'Ebe', 'Covas Olivares', 'D', '8 Ctra. Beas-Cortijos Nuevos', 26360, 'Ebe.Covas.Olivares@spambob.com', '19/10/40', 88, 7);
INSERT INTO usuaris VALUES (3016, 'Morfeo', 'Marcos Limón', 'H', '31 Comandante Izarduy', 8760, 'Morfeo.Marcos.Limon@trashymail.com', '07/10/54', 11, 3);
INSERT INTO usuaris VALUES (3017, 'Namuncurá', 'Ramón Rico', 'H', '91 Plaza de España', 15840, 'Namuncura.Ramon.Rico@mailinator.com', '27/04/75', 47, 6);
INSERT INTO usuaris VALUES (3018, 'Cuasimodo', 'Caraballo Lerma', 'H', '59 Av. Santiago Lapuente', 50794, 'Cuasimodo.Caraballo.Lerma@pookmail.com', '28/04/41', 25, 9);
INSERT INTO usuaris VALUES (3019, 'Tabitha', 'Arana Nava', 'D', '6 Bellavista', 50170, 'Tabitha.Arana.Nava@dodgit.com', '09/02/73', 1, 10);
INSERT INTO usuaris VALUES (3020, 'Olina', 'Urrútia Balderas', 'D', '24 C/ Cañada del Rosal', 21647, 'Olina.Urrutia.Balderas@spambob.com', '17/06/75', 9, 6);
INSERT INTO usuaris VALUES (3021, 'Clodovea', 'Arroyo Huerta', 'D', '64 C/ Señores Curas', 12134, 'Clodovea.Arroyo.Huerta@trashymail.com', '21/05/48', 95, 5);
INSERT INTO usuaris VALUES (3022, 'Ezequías', 'Hinojosa Pacheco', 'H', '48 Camiño Ancho', 37789, 'Ezequias.Hinojosa.Pacheco@trashymail.com', '07/06/54', 55, 9);
INSERT INTO usuaris VALUES (3023, 'Príamo', 'Pedroza Segura', 'H', '86 José matía', 2154, 'Priamo.Pedroza.Segura@spambob.com', '21/02/68', 68, 11);
INSERT INTO usuaris VALUES (3024, 'Heidy', 'Cepeda Ortiz', 'D', '73 Avda. Explanada Barnuevo', 34840, 'Heidy.Cepeda.Ortiz@trashymail.com', '18/08/58', 83, 7);
INSERT INTO usuaris VALUES (3025, 'Peregrino', 'Curiel Ulibarri', 'H', '32 Ourense', 43350, 'Peregrino.Curiel.Ulibarri@spambob.com', '04/03/63', 29, 11);
INSERT INTO usuaris VALUES (3026, 'Menandro', 'Patino Garibay', 'H', '95 Eusebio Dávila', 41440, 'Menandro.Patino.Garibay@pookmail.com', '28/04/60', 82, 6);
INSERT INTO usuaris VALUES (3027, 'Calixto', 'Delgadillo Carrión', 'H', '16 C/ Eras', 28730, 'Calixto.Delgadillo.Carrion@dodgit.com', '23/07/40', 56, NULL);
INSERT INTO usuaris VALUES (3028, 'Bridget', 'Batista Jasso', 'D', '30 Cruce Casa de Postas', 18413, 'Bridget.Batista.Jasso@spambob.com', '05/12/50', 84, 3);
INSERT INTO usuaris VALUES (3029, 'Karim', 'Ruelas Matos', 'D', '48 Escuadro', 46780, 'Karim.Ruelas.Matos@trashymail.com', '24/04/74', 32, 3);
INSERT INTO usuaris VALUES (3030, 'Clare', 'Argüello Mora', 'D', '60 C/ Cañada del Rosal', 21450, 'Clare.Arguello.Mora@mailinator.com', '18/02/46', 57, 3);
INSERT INTO usuaris VALUES (3031, 'Francis', 'Betancourt Guerra', 'H', '38 Avendaño', 3829, 'Francis.Betancourt.Guerra@dodgit.com', '26/11/54', 81, 8);
INSERT INTO usuaris VALUES (3032, 'Nolasco', 'Valentín Benavidez', 'H', '69 Avda. Alameda Sundheim', 22422, 'Nolasco.Valentin.Benavidez@pookmail.com', '03/10/44', 10, 6);
INSERT INTO usuaris VALUES (3033, 'Alcmena', 'Limón Portillo', 'D', '8 Socampo', 37640, 'Alcmena.Limon.Portillo@pookmail.com', '04/06/77', 17, 8);
INSERT INTO usuaris VALUES (3034, 'Marín', 'Valentín Rivero', 'H', '17 Padre Caro', 13680, 'Marin.Valentin.Rivero@mailinator.com', '25/07/77', 14, 2);
INSERT INTO usuaris VALUES (3035, 'Luna', 'Malave Palomino', 'D', '15 Camiño Ancho', 37766, 'Luna.Malave.Palomino@trashymail.com', '15/10/43', 19, 4);
INSERT INTO usuaris VALUES (3036, 'Solana', 'Candelaria Godínez', 'D', '18 Boriñaur enparantza', 7360, 'Solana.Candelaria.Godinez@spambob.com', '07/03/75', 98, 6);
INSERT INTO usuaris VALUES (3037, 'Adalgiso', 'Llarnas Avilés', 'H', '50 Avda. de Andalucía', 29451, 'Adalgiso.Llarnas.Aviles@trashymail.com', '30/05/83', 42, 11);
INSERT INTO usuaris VALUES (3038, 'Domitila', 'Holguín Toro', 'D', '37 Avda. Generalísimo', 31600, 'Domitila.Holguin.Toro@trashymail.com', '03/12/73', 71, 6);
INSERT INTO usuaris VALUES (3039, 'Ingmar', 'Arellano Castellanos', 'H', '32 Avda. Los llanos', 26291, 'Ingmar.Arellano.Castellanos@mailinator.com', '11/02/74', 88, 9);
INSERT INTO usuaris VALUES (3040, 'Flavio', 'Medrano Alcalá', 'H', '96 Plaza de España', 15807, 'Flavio.Medrano.Alcala@trashymail.com', '05/07/64', 11, 8);
INSERT INTO usuaris VALUES (3041, 'Yamel', 'Guardado Lebrón', NULL, '29 Puerta Nueva', 36110, 'Yamel.Guardado.Lebron@pookmail.com', '19/08/41', 33, 6);
INSERT INTO usuaris VALUES (3042, 'Doménica', 'Quintana Lugo', 'D', '16 C/ Cuevas de Ambrosio', 23620, 'Domenica.Quintana.Lugo@spambob.com', '16/06/67', 26, 9);
INSERT INTO usuaris VALUES (3043, 'Iguazel', 'Valverde Oquendo', 'D', '30 Maestro Puig Valera', 33776, 'Iguazel.Valverde.Oquendo@pookmail.com', '18/10/54', 52, 12);
INSERT INTO usuaris VALUES (3044, 'Mamerto', 'Carrasquill Carreón', 'H', '77 Visitación de la Encina', 37751, 'Mamerto.Carrasquill.Carreon@dodgit.com', '26/02/40', 54, 11);
INSERT INTO usuaris VALUES (3045, 'Lila', 'Magana Merino', 'D', '8 Calle Aduana', 1307, 'Lila.Magana.Merino@trashymail.com', '12/01/51', 32, 11);
INSERT INTO usuaris VALUES (3046, 'Librado', 'Carrera Villagómez', 'H', '68 Paseo Junquera', 12429, 'Librado.Carrera.Villagomez@pookmail.com', '29/08/40', 37, 12);
INSERT INTO usuaris VALUES (3047, 'Eufrasio', 'Romo Leyva', 'H', '95 Avenida Cervantes', 48309, 'Eufrasio.Romo.Leyva@dodgit.com', '23/09/44', 42, 10);
INSERT INTO usuaris VALUES (3048, 'Ken', 'Martínez Menéndez', 'H', '95 Ctra. Villena', 34800, 'Ken.Martinez.Menendez@dodgit.com', '12/03/61', 87, 9);
INSERT INTO usuaris VALUES (3049, 'Agnelo', 'Pérez Urrútia', 'H', '79 Cercas Bajas', 8181, 'Agnelo.Perez.Urrutia@spambob.com', '31/07/77', 44, 5);
INSERT INTO usuaris VALUES (3050, 'Gyorgy', 'Gutiérrez Escobar', NULL, '90 Cercas Bajas', 8110, 'Gyorgy.Gutierrez.Escobar@trashymail.com', '27/05/64', 19, 11);
INSERT INTO usuaris VALUES (3051, 'Catrian', 'Godínez Ramírez', 'H', '53 José matía', 1470, 'Catrian.Godinez.Ramirez@pookmail.com', '25/10/68', 75, NULL);
INSERT INTO usuaris VALUES (3052, 'Electra', 'Valentín Barragán', NULL, '7 C/ Benito Guinea', 8338, 'Electra.Valentin.Barragan@mailinator.com', '28/11/63', 67, 6);
INSERT INTO usuaris VALUES (3053, 'Inocencio', 'Chapa Murillo', 'H', '65 Bouciña', 43765, 'Inocencio.Chapa.Murillo@trashymail.com', '31/01/47', 80, 6);
INSERT INTO usuaris VALUES (3054, 'Italo', 'Leyva Saldivar', NULL, '52 Calle Proc. San Sebastián', 13100, 'Italo.Leyva.Saldivar@spambob.com', '31/10/44', 73, 10);
INSERT INTO usuaris VALUES (3055, 'Guaraci', 'Quezada Ferrer', 'D', '92 Enxertos', 37521, 'Guaraci.Quezada.Ferrer@dodgit.com', '29/06/72', 23, 8);
INSERT INTO usuaris VALUES (3056, 'Alfonsina', 'Acevedo Comejo', 'D', '60 C/ Pablo Iglesias', 26329, 'Alfonsina.Acevedo.Comejo@pookmail.com', '14/09/63', 69, 2);
INSERT INTO usuaris VALUES (3057, 'Vernón', 'Santana Verduzco', 'H', '8 Calvo Sotelo', 47320, 'Vernon.Santana.Verduzco@mailinator.com', '27/04/55', 43, NULL);
INSERT INTO usuaris VALUES (3058, 'Petronila', 'Camacho Rico', 'D', '36 Lamas Carbajal', 41670, 'Petronila.Camacho.Rico@spambob.com', '15/12/80', 96, 10);
INSERT INTO usuaris VALUES (3059, 'Gianluca', 'Tijerina Cintrón', 'H', '30 Cañadilla', 22250, 'Gianluca.Tijerina.Cintron@pookmail.com', '19/05/44', 38, 8);
INSERT INTO usuaris VALUES (3060, 'Abi', 'Banda Corrales', 'D', '6 C/ Señores Curas', 12159, 'Abi.Banda.Corrales@dodgit.com', '01/01/59', 55, 5);
INSERT INTO usuaris VALUES (3061, 'Ara', 'Abreu Delgadillo', 'D', '13 Boriñaur enparantza', 7530, 'Ara.Abreu.Delgadillo@trashymail.com', '19/08/77', 23, 12);
INSERT INTO usuaris VALUES (3062, 'Mathilde', 'Leal Roldán', NULL, '35 C/ Cuesta del  Álamo', 29532, 'Mathilde.Leal.Roldan@mailinator.com', '10/01/73', 14, 4);
INSERT INTO usuaris VALUES (3063, 'Clidia', 'Navarro Loya', 'D', '11 La Fontanilla', 14220, 'Clidia.Navarro.Loya@mailinator.com', '14/05/53', 98, 2);
INSERT INTO usuaris VALUES (3064, 'Amarilia', 'Mesa Saldivar', 'D', '67 Cañadilla', 22200, 'Amarilia.Mesa.Saldivar@trashymail.com', '05/03/55', 92, 11);
INSERT INTO usuaris VALUES (3065, 'Verne', 'Rojo Pagan', 'H', '42 Ctra. de Siles', 27520, 'Verne.Rojo.Pagan@mailinator.com', '22/06/50', 3, 8);
INSERT INTO usuaris VALUES (3066, 'Ademaro', 'León Lomeli', 'H', '67 C/ Libertad', 5260, 'Ademaro.Leon.Lomeli@dodgit.com', '26/03/67', 62, 4);
INSERT INTO usuaris VALUES (3067, 'Verona', 'Gracia Pabón', NULL, '2 Carretera del Muelle', 12310, 'Verona.Gracia.Pabon@mailinator.com', '08/09/85', 6, 7);
INSERT INTO usuaris VALUES (3068, 'Hildegunda', 'Rael Argüello', 'D', '44 Plaza Colón', 26124, 'Hildegunda.Rael.Arguello@dodgit.com', '30/12/43', 53, 4);
INSERT INTO usuaris VALUES (3069, 'Edgarda', 'Valentín Razo', 'D', '57 Paraguay', 3729, 'Edgarda.Valentin.Razo@spambob.com', '14/04/75', 22, 11);
INSERT INTO usuaris VALUES (3070, 'Doria', 'Sauceda Urena', 'D', '32 Alcon Molina', 31190, 'Doria.Sauceda.Urena@trashymail.com', '23/09/42', 31, 7);
INSERT INTO usuaris VALUES (3071, 'Aarón', 'Amador Casares', 'H', '99 Avda. Enrique Peinador', 37170, 'Aaron.Amador.Casares@trashymail.com', '18/05/84', 2, 12);
INSERT INTO usuaris VALUES (3072, 'Lair', 'Velázquez Hurtado', 'H', '98 Pza. Fuensanta', 32420, 'Lair.Velazquez.Hurtado@trashymail.com', '18/08/59', 0, 5);
INSERT INTO usuaris VALUES (3073, 'Ebo', 'Orosco Armas', 'H', '34 C/ Angosto', 23500, 'Ebo.Orosco.Armas@trashymail.com', '19/07/56', 50, 4);
INSERT INTO usuaris VALUES (3074, 'Marín', 'Coronado Díaz', 'H', '50 C/ Libertad', 5430, 'Marin.Coronado.Diaz@pookmail.com', '30/03/43', 41, 9);
INSERT INTO usuaris VALUES (3075, 'Emelina', 'Valdez Campos', 'D', '43 Reyes Católicos', 9550, 'Emelina.Valdez.Campos@trashymail.com', '08/09/59', 23, 2);
INSERT INTO usuaris VALUES (3076, 'Domínica', 'Ochoa Malave', 'D', '42 Inglaterra', 18611, 'Dominica.Ochoa.Malave@trashymail.com', '20/04/72', 82, 3);
INSERT INTO usuaris VALUES (3077, 'Evasio', 'Pelayo Gamboa', 'H', '98 C/ Fernández de Leceta', 3500, 'Evasio.Pelayo.Gamboa@trashymail.com', '21/11/41', 88, 12);
INSERT INTO usuaris VALUES (3078, 'Nasha', 'Medrano Feliciano', 'D', '75 C/ Cañada del Rosal', 21570, 'Nasha.Medrano.Feliciano@mailinator.com', '18/02/73', 7, 7);
INSERT INTO usuaris VALUES (3079, 'Melanie', 'Valenzuela Gallegos', 'D', '94 Socampo', 37671, 'Melanie.Valenzuela.Gallegos@dodgit.com', '23/09/80', 65, 7);
INSERT INTO usuaris VALUES (3080, 'Liafdag', 'Nino Coronado', 'H', '2 Inglaterra', 18540, 'Liafdag.Nino.Coronado@pookmail.com', '25/04/60', 66, 6);
INSERT INTO usuaris VALUES (3081, 'Melanie', 'Caldera Barrientos', 'D', '78 C/ Angosto', 23550, 'Melanie.Caldera.Barrientos@pookmail.com', '24/06/80', 85, 1);
INSERT INTO usuaris VALUES (3082, 'Tito', 'Griego Longoria', 'H', '69 Reyes Católicos', 9530, 'Tito.Griego.Longoria@spambob.com', '22/07/74', 42, NULL);
INSERT INTO usuaris VALUES (3083, 'Hossana', 'Camarillo Toledo', 'D', '82 Plazuela do Porto', 37893, 'Hossana.Camarillo.Toledo@pookmail.com', '24/02/75', 87, 9);
INSERT INTO usuaris VALUES (3084, 'Ilda', 'Luna Ríos', 'D', '41 Ctra. Hornos', 26220, 'Ilda.Luna.Rios@spambob.com', '05/08/54', 98, 11);
INSERT INTO usuaris VALUES (3085, 'Nayme', 'Fierro Valle', 'D', '23 Cartagena', 30611, 'Nayme.Fierro.Valle@dodgit.com', '18/03/43', 88, 3);
INSERT INTO usuaris VALUES (3086, 'Melissa', 'Salcido Jiménez', 'D', '49 Cartagena', 30540, 'Melissa.Salcido.Jimenez@spambob.com', '19/07/68', 80, 3);
INSERT INTO usuaris VALUES (3087, 'Hildegarda', 'Dueñas Cerda', 'D', '22 Rúa Olmos', 37317, 'Hildegarda.Duenas.Cerda@pookmail.com', '30/06/73', 53, 8);
INSERT INTO usuaris VALUES (3088, 'Roxanne', 'Barajas Méndez', 'D', '34 C/ Cañada del Rosal', 21591, 'Roxanne.Barajas.Mendez@dodgit.com', '17/03/79', 88, 4);
INSERT INTO usuaris VALUES (3089, 'Neyén', 'Olivárez Parra', 'H', '24 Apartado de Correos', 37448, 'Neyen.Olivarez.Parra@mailinator.com', '23/05/84', 11, 1);
INSERT INTO usuaris VALUES (3090, 'Juancruz', 'Sauceda Mora', 'H', '5 Enxertos', 37550, 'Juancruz.Sauceda.Mora@dodgit.com', '14/11/57', 45, 11);
INSERT INTO usuaris VALUES (3091, 'Vulcano', 'Concepción Nino', 'H', '42 Plaza Maior', 37210, 'Vulcano.Concepcion.Nino@trashymail.com', '18/01/49', 42, 10);
INSERT INTO usuaris VALUES (3092, 'Arcángel', 'Carrasco Mendoza', 'H', '54 Rua da Rapina', 37468, 'Arcangel.Carrasco.Mendoza@spambob.com', '30/07/61', 57, 2);
INSERT INTO usuaris VALUES (3093, 'Ermelinda', 'Morales Galván', NULL, '98 Rúa Olmos', 37410, 'Ermelinda.Morales.Galvan@pookmail.com', '26/05/53', 42, 6);
INSERT INTO usuaris VALUES (3094, 'Brandon', 'Cisneros Acuna', 'H', '49 Plazuela do Porto', 38435, 'Brandon.Cisneros.Acuna@spambob.com', '21/01/47', 48, 12);
INSERT INTO usuaris VALUES (3095, 'Ives', 'Espinal Jaramillo', 'H', '38 Salzillo', 32616, 'Ives.Espinal.Jaramillo@spambob.com', '10/02/44', 9, 5);
INSERT INTO usuaris VALUES (3096, 'Lonhard', 'Olivárez Casillas', 'H', '73 Avenida Cervantes', 48220, 'Lonhard.Olivarez.Casillas@mailinator.com', '26/12/47', 38, 4);
INSERT INTO usuaris VALUES (3097, 'Sisebuto', 'Betancourt Bahena', 'H', '92 Ctra. de la Puerta', 27250, 'Sisebuto.Betancourt.Bahena@dodgit.com', '05/06/70', 9, 8);
INSERT INTO usuaris VALUES (3098, 'Floreal', 'Mendoza Carmona', 'H', '11 C/ Henan Cortes', 28910, 'Floreal.Mendoza.Carmona@pookmail.com', '21/07/47', 73, 11);
INSERT INTO usuaris VALUES (3099, 'Rocío', 'Reyna Alcaraz', 'D', '87 Bellavista', 49620, 'Rocio.Reyna.Alcaraz@dodgit.com', '04/04/47', 92, 8);
INSERT INTO usuaris VALUES (3100, 'Víctor', 'Frías Marcos', 'H', '80 C/ Manuel Iradier', 3792, 'Victor.Frias.Marcos@spambob.com', '14/07/73', 23, 3);
INSERT INTO usuaris VALUES (3101, 'Mustafá', 'Tejeda Herrera', 'H', '14 Rua da Rapina', 37500, 'Mustafa.Tejeda.Herrera@pookmail.com', '31/03/47', 48, 3);
INSERT INTO usuaris VALUES (3102, 'Baldovino', 'Guevara Baeza', 'H', '22 Canónigo Valiño', 46540, 'Baldovino.Guevara.Baeza@dodgit.com', '24/03/70', 93, 11);
INSERT INTO usuaris VALUES (3103, 'Ezequías', 'Regalado Vargas', 'H', '57 Rúa Olmos', 37418, 'Ezequias.Regalado.Vargas@spambob.com', '31/08/46', 8, 5);
INSERT INTO usuaris VALUES (3104, 'Cristhian', 'Gaytan Estrada', 'H', '52 Rúa Olmos', 37329, 'Cristhian.Gaytan.Estrada@dodgit.com', '11/10/68', 60, 1);
INSERT INTO usuaris VALUES (3105, 'Sadoth', 'Curiel Marín', 'H', '90 Camiño Ancho', 37770, 'Sadoth.Curiel.Marin@dodgit.com', '09/03/59', 6, 1);
INSERT INTO usuaris VALUES (3106, 'Calíope', 'Bravo Alcaraz', 'D', '83 Fuente del Gallo', 14900, 'Caliope.Bravo.Alcaraz@dodgit.com', '19/09/40', 37, 11);
INSERT INTO usuaris VALUES (3107, 'Afrodisio', 'Lemus Gracia', 'H', '96 Constitución', 36880, 'Afrodisio.Lemus.Gracia@spambob.com', '22/11/66', NULL, 1);
INSERT INTO usuaris VALUES (3108, 'Cassandra', 'Escobedo Jaimes', 'D', '34 C/ Hijuela de Lojo', 20270, 'Cassandra.Escobedo.Jaimes@spambob.com', '10/09/73', 49, 11);
INSERT INTO usuaris VALUES (3109, 'Hugolina', 'Prieto Melgar', 'D', '67 Avda. de la Estación', 28597, 'Hugolina.Prieto.Melgar@dodgit.com', '30/05/57', 87, 2);
INSERT INTO usuaris VALUES (3110, 'Landerico', 'Salgado Quiñones', 'H', '95 Avda. Andalucía', 26126, 'Landerico.Salgado.Quinones@spambob.com', '22/11/57', 94, 9);
INSERT INTO usuaris VALUES (3111, 'Igone', 'Ríos Tijerina', 'D', '33 Lamas Carbajal', 41620, 'Igone.Rios.Tijerina@pookmail.com', '24/02/67', 42, 9);
INSERT INTO usuaris VALUES (3112, 'Roni', 'Roldán Herrera', 'H', '94 Apartado de Correos', 37454, 'Roni.Roldan.Herrera@pookmail.com', '07/06/67', 86, 2);
INSERT INTO usuaris VALUES (3113, 'Yoav', 'Toledo Castro', 'H', '6 Antonio Vázquez', 38789, 'Yoav.Toledo.Castro@mailinator.com', '28/09/66', 55, 1);
INSERT INTO usuaris VALUES (3114, 'Niobe', 'Callas Soto', 'D', '4 Paraguay', 3728, 'Niobe.Callas.Soto@dodgit.com', '19/12/78', 72, 10);
INSERT INTO usuaris VALUES (3115, 'Ernie', 'Garay Botello', 'H', '55 Ctra. de la Puerta', 27150, 'Ernie.Garay.Botello@dodgit.com', '22/01/72', 31, NULL);
INSERT INTO usuaris VALUES (3116, 'Joab', 'Otero Guevara', 'H', '51 C/ Los Herrán', 6100, 'Joab.Otero.Guevara@trashymail.com', '06/07/81', 19, 1);
INSERT INTO usuaris VALUES (3117, 'Gianni', 'Lozada Cordova', 'H', '77 Bouciña', 43770, 'Gianni.Lozada.Cordova@pookmail.com', '28/12/59', 9, 1);
INSERT INTO usuaris VALUES (3118, 'Anelisa', 'Cabán Rolón', NULL, '35 C/ Domingo Beltrán', 2316, 'Anelisa.Caban.Rolon@pookmail.com', '27/08/60', 20, 8);
INSERT INTO usuaris VALUES (3119, 'Andrés', 'Ortega Cadena', 'H', '40 C/ Cuesta del  Álamo', 29493, 'Andres.Ortega.Cadena@dodgit.com', '23/06/46', 65, NULL);
INSERT INTO usuaris VALUES (3120, 'Calínica', 'Carbajal Esquibel', 'D', '75 Urzáiz', 44550, 'Calinica.Carbajal.Esquibel@mailinator.com', '25/12/84', 37, 12);
INSERT INTO usuaris VALUES (3121, 'Luisina', 'Rosas Montés', 'D', '41 Plazuela do Porto', 38290, 'Luisina.Rosas.Montes@trashymail.com', '25/04/40', 57, 5);
INSERT INTO usuaris VALUES (3122, 'Casildo', 'Leal Mascarenas', 'H', '98 Avda. de Andalucía', 29195, 'Casildo.Leal.Mascarenas@pookmail.com', '18/09/65', 44, 6);
INSERT INTO usuaris VALUES (3123, 'Aramis', 'Casas Posada', 'H', '69 Prolongacion San Sebastian', 21208, 'Aramis.Casas.Posada@trashymail.com', '05/12/80', 50, 2);
INSERT INTO usuaris VALUES (3124, 'Renzo', 'Quintanilla Tamayo', 'H', '71 José matía', 1409, 'Renzo.Quintanilla.Tamayo@mailinator.com', '09/10/61', 33, 12);
INSERT INTO usuaris VALUES (3125, 'Alvina', 'Roque Olivera', 'D', '79 Bellavista', 50246, 'Alvina.Roque.Olivera@trashymail.com', '01/04/54', 29, 2);
INSERT INTO usuaris VALUES (3126, 'Alcia', 'Barraza Lebrón', NULL, '78 Plazuela do Porto', 38420, 'Alcia.Barraza.Lebron@mailinator.com', '05/12/74', 62, 6);
INSERT INTO usuaris VALUES (3127, 'Astra', 'Archuleta Villalpando', 'D', '37 C/ Manuel Iradier', 3813, 'Astra.Archuleta.Villalpando@dodgit.com', '16/03/60', 53, 7);
INSERT INTO usuaris VALUES (3128, 'Beat', 'Aguilar Zamudio', 'H', '27 Escuadro', 46850, 'Beat.Aguilar.Zamudio@spambob.com', '01/10/74', 17, 12);
INSERT INTO usuaris VALUES (3129, 'Lelia', 'Marín Rodrígez', 'D', '58 Avda. Andalucía', 26133, 'Lelia.Marin.Rodrigez@spambob.com', '23/12/81', 74, 2);
INSERT INTO usuaris VALUES (3130, 'Bab', 'Rubio Pedroza', 'D', '37 Rua da Rapina', 37470, 'Bab.Rubio.Pedroza@dodgit.com', '18/11/77', 59, 12);
INSERT INTO usuaris VALUES (3131, 'Guzmán', 'Benavidez Urbina', 'H', '87 Maestro Puig Valera', 33777, 'Guzman.Benavidez.Urbina@mailinator.com', '06/03/50', 88, 9);
INSERT INTO usuaris VALUES (3132, 'Eliora', 'Montenegro Uribe', 'D', '95 Pza. Fuensanta', 32310, 'Eliora.Montenegro.Uribe@pookmail.com', '18/04/40', 14, 7);
INSERT INTO usuaris VALUES (3133, 'Gatty', 'Castro Canales', 'D', '81 Cartagena', 30560, 'Gatty.Castro.Canales@mailinator.com', '28/01/53', 25, 4);
INSERT INTO usuaris VALUES (3134, 'Blenda', 'Ballesteros Alvarez', 'H', '12 C/ Cuevas de Ambrosio', 23750, 'Blenda.Ballesteros.Alvarez@spambob.com', '27/10/50', 62, 6);
INSERT INTO usuaris VALUES (3135, 'Vicki', 'Cortez Alanis', 'D', '83 C/ Canarias', 19200, 'Vicki.Cortez.Alanis@mailinator.com', '28/11/57', 29, 4);
INSERT INTO usuaris VALUES (3136, 'Illel', 'Espinoza Ruvalcaba', 'H', '15 Boriñaur enparantza', 7640, 'Illel.Espinoza.Ruvalcaba@trashymail.com', '09/12/80', 95, 7);
INSERT INTO usuaris VALUES (3137, 'Baudilio', 'Valle Alemán', 'H', '76 Avda. Explanada Barnuevo', 35140, 'Baudilio.Valle.Aleman@pookmail.com', '28/05/83', 69, 10);
INSERT INTO usuaris VALUES (3138, 'James', 'Najera Quintanilla', 'H', '84 Paseo del Atlántico', 18000, 'James.Najera.Quintanilla@mailinator.com', '13/03/51', 8, 11);
INSERT INTO usuaris VALUES (3139, 'Demóstenes', 'Quesada Garay', 'H', '86 Paraguay', 3740, 'Demostenes.Quesada.Garay@mailinator.com', '14/10/54', 17, 1);
INSERT INTO usuaris VALUES (3140, 'Arnulfo', 'Apodaca Herrera', 'H', '81 Reiseñor', 46191, 'Arnulfo.Apodaca.Herrera@trashymail.com', '12/04/76', 98, 4);
INSERT INTO usuaris VALUES (3141, 'Teodorico', 'Terán Matos', 'H', '21 Escuadro', 46740, 'Teodorico.Teran.Matos@dodgit.com', '31/12/82', 99, 10);
INSERT INTO usuaris VALUES (3142, 'Cirila', 'Trujillo Muñiz', 'D', '38 C/ Señores Curas', 12140, 'Cirila.Trujillo.Muniz@dodgit.com', '18/11/41', 51, 12);
INSERT INTO usuaris VALUES (3143, 'Gualtar', 'Duran Tamez', 'H', '99 El Roqueo', 16000, 'Gualtar.Duran.Tamez@dodgit.com', '22/01/68', 19, 3);
INSERT INTO usuaris VALUES (3144, 'Heldo', 'Lucero Juárez', 'H', '45 C/ Arana', 2636, 'Heldo.Lucero.Juarez@trashymail.com', '13/11/40', 86, 8);
INSERT INTO usuaris VALUES (3145, 'Atala', 'Matos Espinal', 'D', '53 Prolongacion San Sebastian', 21320, 'Atala.Matos.Espinal@mailinator.com', '28/06/45', 66, NULL);
INSERT INTO usuaris VALUES (3146, 'Peter', 'Carrera Partida', 'H', '51 C/ Henan Cortes', 28970, 'Peter.Carrera.Partida@dodgit.com', '29/01/42', NULL, 6);
INSERT INTO usuaris VALUES (3147, 'Giselda', 'Collazo Gamez', 'D', '67 Puerta Nueva', 36470, 'Giselda.Collazo.Gamez@mailinator.com', '02/12/60', 41, 11);
INSERT INTO usuaris VALUES (3148, 'Gamaliel', 'Blanco Cepeda', 'H', '92 Fuente del Gallo', 15113, 'Gamaliel.Blanco.Cepeda@dodgit.com', '19/11/59', 17, NULL);
INSERT INTO usuaris VALUES (3149, 'Ama', 'Puente Escobar', 'D', '47 Bellavista', 49510, 'Ama.Puente.Escobar@trashymail.com', '27/09/63', 21, 12);
INSERT INTO usuaris VALUES (3150, 'Birgitta', 'Gallardo Villegas', 'D', '34 Avda. Rio Nalon', 33440, 'Birgitta.Gallardo.Villegas@spambob.com', '17/06/78', 2, 8);
INSERT INTO usuaris VALUES (3151, 'Bartie', 'Casanova Nieto', 'H', '46 C/ Andalucía', 4650, 'Bartie.Casanova.Nieto@dodgit.com', '28/06/66', 84, 1);
INSERT INTO usuaris VALUES (3152, 'Nicholai', 'Viera Batista', 'H', '97 C/ Los Herrán', 6120, 'Nicholai.Viera.Batista@spambob.com', '19/01/56', 81, 7);
INSERT INTO usuaris VALUES (3153, 'Cuasimodo', 'Alcalá Orta', 'H', '51 C/ Domingo Beltrán', 2340, 'Cuasimodo.Alcala.Orta@dodgit.com', '25/07/47', 84, 12);
INSERT INTO usuaris VALUES (3154, 'Cordelia', 'Polanco Santiago', 'D', '47 Comandante Izarduy', 8980, 'Cordelia.Polanco.Santiago@spambob.com', '15/07/68', 99, 8);
INSERT INTO usuaris VALUES (3155, 'Amaia', 'Nino Ramón', NULL, '30 Calvo Sotelo', 47430, 'Amaia.Nino.Ramon@pookmail.com', '14/10/68', 69, 9);
INSERT INTO usuaris VALUES (3156, 'Tarcila', 'Ramírez Perales', 'D', '74 Avenida Cervantes', 48270, 'Tarcila.Ramirez.Perales@dodgit.com', '27/07/81', 1, 4);
INSERT INTO usuaris VALUES (3157, 'Madeleine', 'Cárdenas Prieto', 'D', '74 Av. Zumalakarregi', 3316, 'Madeleine.Cardenas.Prieto@mailinator.com', '30/10/63', 89, 12);
INSERT INTO usuaris VALUES (3158, 'Nunila', 'Puente Baeza', 'D', '75 Avda. Rio Nalon', 33510, 'Nunila.Puente.Baeza@mailinator.com', '19/04/76', 73, 9);
INSERT INTO usuaris VALUES (3159, 'Giorgio', 'Peralta Corrales', 'H', '21 Pl. Virgen Blanca', 8540, 'Giorgio.Peralta.Corrales@spambob.com', '31/12/55', 93, 8);
INSERT INTO usuaris VALUES (3160, 'Andrómeda', 'Torres Montenegro', 'D', '62 Apartado de Correos', 37455, 'Andromeda.Torres.Montenegro@trashymail.com', '16/06/70', 72, 9);
INSERT INTO usuaris VALUES (3161, 'Fulk', 'Roybal Valles', 'H', '54 C/ Libertad', 5310, 'Fulk.Roybal.Valles@spambob.com', '26/03/49', 44, 8);
INSERT INTO usuaris VALUES (3162, 'Cristo', 'Valenzuela Herrera', 'H', '83 Ventanilla de Beas', 28150, 'Cristo.Valenzuela.Herrera@mailinator.com', '04/02/77', 34, 12);
INSERT INTO usuaris VALUES (3163, 'Orión', 'Bahena Cano', 'H', '86 Alvaro Cunqueiro', 40470, 'Orion.Bahena.Cano@pookmail.com', '16/03/67', 59, 7);
INSERT INTO usuaris VALUES (3164, 'Cadmo', 'Holguín Romero', 'H', '25 Eusebio Dávila', 41310, 'Cadmo.Holguin.Romero@pookmail.com', '10/06/56', 96, 12);
INSERT INTO usuaris VALUES (3165, 'Mustafá', 'Abrego Meléndez', 'H', '95 C/ Pablo Iglesias', 26329, 'Mustafa.Abrego.Melendez@pookmail.com', '18/12/72', 98, 10);
INSERT INTO usuaris VALUES (3166, 'Ambroise', 'Gaytan Solano', 'H', '95 Reiseñor', 46160, 'Ambroise.Gaytan.Solano@trashymail.com', '21/07/82', 10, 5);
INSERT INTO usuaris VALUES (3167, 'Jordana', 'Solís Delgadillo', 'D', '70 C/ Amoladera', 28792, 'Jordana.Solis.Delgadillo@mailinator.com', '25/01/54', 98, 5);
INSERT INTO usuaris VALUES (3168, 'Idelfonso', 'Castaneda Sedillo', 'H', '25 Crta. Cádiz-Málaga', 12184, 'Idelfonso.Castaneda.Sedillo@trashymail.com', '02/03/48', 88, 2);
INSERT INTO usuaris VALUES (3169, 'Quintín', 'Alarcón Gaona', 'H', '3 Inglaterra', 18650, 'Quintin.Alarcon.Gaona@trashymail.com', '09/05/42', 81, 9);
INSERT INTO usuaris VALUES (3170, 'Marilyn', 'Luján Chacón', NULL, '33 C/ Cañada del Rosal', 21550, 'Marilyn.Lujan.Chacon@mailinator.com', '24/10/62', 15, 1);
INSERT INTO usuaris VALUES (3171, 'Teo', 'Olivera Mejía', 'H', '25 C/ Manuel Iradier', 3812, 'Teo.Olivera.Mejia@pookmail.com', '01/04/75', 7, 3);
INSERT INTO usuaris VALUES (3172, 'Celinda', 'Huerta Badillo', 'D', '28 Ctra. de la Puerta', 27000, 'Celinda.Huerta.Badillo@mailinator.com', '28/09/54', 70, 10);
INSERT INTO usuaris VALUES (3173, 'Gioseppina', 'Vargas Nava', 'D', '14 Ctra. de Fuentenueva', 28190, 'Gioseppina.Vargas.Nava@trashymail.com', '09/12/74', 64, 3);
INSERT INTO usuaris VALUES (3174, 'Verena', 'Iglesias Tovar', 'D', '97 C/ Los Herrán', 6120, 'Verena.Iglesias.Tovar@pookmail.com', '29/05/79', 89, 10);
INSERT INTO usuaris VALUES (3175, 'Nazareno', 'Montero Anguiano', 'H', '21 Enxertos', 37522, 'Nazareno.Montero.Anguiano@dodgit.com', '07/06/83', 97, 10);
INSERT INTO usuaris VALUES (3176, 'Lesmes', 'Terán Briseño', 'D', '4 C/ Henan Cortes', 28991, 'Lesmes.Teran.Briseno@mailinator.com', '22/02/55', 16, 7);
INSERT INTO usuaris VALUES (3177, 'Karim', 'Zúñiga Gracia', 'H', '33 José matía', 2150, 'Karim.Zuniga.Gracia@mailinator.com', '21/10/41', 39, 9);
INSERT INTO usuaris VALUES (3178, 'Einar', 'Adame Olivárez', 'H', '14 Celso Emilio Ferreiro', 50298, 'Einar.Adame.Olivarez@mailinator.com', '20/11/45', 15, 5);
INSERT INTO usuaris VALUES (3179, 'Candela', 'Alcaraz Girón', NULL, '34 Cartagena', 30550, 'Candela.Alcaraz.Giron@mailinator.com', '12/01/84', 88, 1);
INSERT INTO usuaris VALUES (3180, 'Leticia', 'Ocasio Nieves', 'D', '17 Avda. de la Estación', 28680, 'Leticia.Ocasio.Nieves@spambob.com', '24/03/66', 34, 8);
INSERT INTO usuaris VALUES (3181, 'Donna', 'Escamilla Guardado', 'D', '36 Prolongacion San Sebastian', 21210, 'Donna.Escamilla.Guardado@spambob.com', '08/03/69', 35, 11);
INSERT INTO usuaris VALUES (3182, 'Auxiliadora', 'Porras Angulo', 'D', '91 Avda. Los llanos', 26230, 'Auxiliadora.Porras.Angulo@trashymail.com', '27/02/47', 7, 6);
INSERT INTO usuaris VALUES (3183, 'Amilcar', 'Pantoja Toro', 'H', '62 Boriñaur enparantza', 7750, 'Amilcar.Pantoja.Toro@pookmail.com', '24/03/58', 82, 1);
INSERT INTO usuaris VALUES (3184, 'Guiomar', 'Saucedo Alcalá', 'D', '12 Calle Aduana', 1200, 'Guiomar.Saucedo.Alcala@pookmail.com', '21/07/64', 30, 12);
INSERT INTO usuaris VALUES (3185, 'Alcmena', 'Pabón Peres', 'D', '78 Rúa do Paseo', 41808, 'Alcmena.Pabon.Peres@spambob.com', '09/11/74', 65, 5);
INSERT INTO usuaris VALUES (3186, 'Pace', 'Rodarte Cordero', 'H', '78 Avda. Explanada Barnuevo', 35290, 'Pace.Rodarte.Cordero@spambob.com', '25/06/46', 61, 6);
INSERT INTO usuaris VALUES (3187, 'Astrid', 'Barajas Calvillo', 'D', '29 Socampo', 37658, 'Astrid.Barajas.Calvillo@pookmail.com', '14/01/51', 35, 2);
INSERT INTO usuaris VALUES (3188, 'Mia', 'Alarcón Aragón', NULL, '96 Calvo Sotelo', 47610, 'Mia.Alarcon.Aragon@trashymail.com', '23/03/84', 50, 11);
INSERT INTO usuaris VALUES (3189, 'Oderico', 'Palomo Porras', 'H', '7 C/ Cañada del Rosal', 21640, 'Oderico.Palomo.Porras@pookmail.com', '18/11/47', 48, 1);
INSERT INTO usuaris VALUES (3190, 'Aicardo', 'Matías Razo', 'H', '73 Lamas Carbajal', 41710, 'Aicardo.Matias.Razo@spambob.com', '02/09/51', 28, NULL);
INSERT INTO usuaris VALUES (3191, 'Androcles', 'Limón Veliz', 'H', '10 Puerta Nueva', 35637, 'Androcles.Limon.Veliz@mailinator.com', '08/12/82', 38, 2);
INSERT INTO usuaris VALUES (3192, 'Elí', 'Cordero Casillas', 'D', '38 Reiseñor', 46191, 'Eli.Cordero.Casillas@pookmail.com', '30/01/54', NULL, 3);
INSERT INTO usuaris VALUES (3193, 'Kemberley', 'Banda Suárez', 'D', '14 Calle Aduana', 1208, 'Kemberley.Banda.Suarez@trashymail.com', '08/08/82', 29, 5);
INSERT INTO usuaris VALUES (3194, 'Telémaco', 'Ortega Morales', 'H', '29 Avda. Los llanos', 26228, 'Telemaco.Ortega.Morales@trashymail.com', '29/12/53', 76, 8);
INSERT INTO usuaris VALUES (3195, 'Zunilda', 'Fuentes Escamilla', 'D', '95 Inglaterra', 18614, 'Zunilda.Fuentes.Escamilla@dodgit.com', '09/06/46', 67, 7);
INSERT INTO usuaris VALUES (3196, 'Joann', 'Tovar Guardado', 'D', '10 José matía', 2141, 'Joann.Tovar.Guardado@pookmail.com', '05/12/41', 93, 1);
INSERT INTO usuaris VALUES (3197, 'Filomana', 'Valencia Henríquez', 'D', '44 Bouciña', 43791, 'Filomana.Valencia.Henriquez@spambob.com', '05/04/61', 40, 12);
INSERT INTO usuaris VALUES (3198, 'Ion', 'Ortega Alarcón', 'H', '48 Ourense', 43140, 'Ion.Ortega.Alarcon@spambob.com', '26/04/50', 21, 9);
INSERT INTO usuaris VALUES (3199, 'Cristian', 'Contreras Estévez', 'H', '2 Alcon Molina', 31192, 'Cristian.Contreras.Estevez@dodgit.com', '15/04/67', 5, 11);
INSERT INTO usuaris VALUES (3200, 'Delta', 'Zelaya Verdugo', 'D', '16 José matía', 2100, 'Delta.Zelaya.Verdugo@pookmail.com', '03/12/41', 18, 1);
INSERT INTO usuaris VALUES (3201, 'Aicardo', 'Camarillo Sepúlveda', 'H', '11 Constitución', 37129, 'Aicardo.Camarillo.Sepulveda@mailinator.com', '25/11/50', 15, 6);
INSERT INTO usuaris VALUES (3202, 'Alana', 'Jasso Quintero', 'D', '54 C/ Angosto', 23480, 'Alana.Jasso.Quintero@spambob.com', '15/10/40', 87, 4);
INSERT INTO usuaris VALUES (3203, 'Palixena', 'Delgadillo Gaitán', NULL, '22 Rio Segura', 31390, 'Palixena.Delgadillo.Gaitan@pookmail.com', '11/02/43', 96, 10);
INSERT INTO usuaris VALUES (3204, 'Marcelina', 'Garza Lovato', 'D', '92 Avda. Los llanos', 26291, 'Marcelina.Garza.Lovato@dodgit.com', '01/11/64', 36, 6);
INSERT INTO usuaris VALUES (3205, 'Zenobio', 'Montano Briones', 'H', '98 Calvo Sotelo', 47310, 'Zenobio.Montano.Briones@pookmail.com', '26/09/57', 37, 1);
INSERT INTO usuaris VALUES (3206, 'Ercilia', 'Velásquez Fernández', 'D', '50 C/ Domingo Beltrán', 2246, 'Ercilia.Velasquez.Fernandez@dodgit.com', '11/12/63', 9, 7);
INSERT INTO usuaris VALUES (3207, 'Nélida', 'Negrete Cerda', 'D', '23 Plaza de España', 15637, 'Nelida.Negrete.Cerda@dodgit.com', '12/06/64', 22, 1);
INSERT INTO usuaris VALUES (3208, 'Siglinda', 'Uribe Orozco', 'D', '15 Cartagena', 30611, 'Siglinda.Uribe.Orozco@spambob.com', '19/12/79', 16, 6);
INSERT INTO usuaris VALUES (3209, 'Aimon', 'Tirado Cotto', 'H', '96 Puerto Lugar', 29715, 'Aimon.Tirado.Cotto@dodgit.com', '02/12/85', 44, NULL);
INSERT INTO usuaris VALUES (3210, 'Longinos', 'Sanabria Montoya', 'H', '10 Avda. Generalísimo', 31590, 'Longinos.Sanabria.Montoya@pookmail.com', NULL, 17, 3);
INSERT INTO usuaris VALUES (3211, 'Alaia', 'Ayala Valdez', 'D', '73 C/ Cuevas de Ambrosio', 23710, 'Alaia.Ayala.Valdez@trashymail.com', '22/07/82', 58, 7);
INSERT INTO usuaris VALUES (3212, 'Adalgisa', 'Girón Tijerina', 'D', '43 Avda. Enrique Peinador', 37180, 'Adalgisa.Giron.Tijerina@pookmail.com', '24/10/56', 31, 6);
INSERT INTO usuaris VALUES (3213, 'Nuri', 'Zavala Nava', 'H', '46 Zumalakarregi etorbidea', 7200, 'Nuri.Zavala.Nava@pookmail.com', '21/07/63', NULL, 4);
INSERT INTO usuaris VALUES (3214, 'Escipion', 'Valadez Balderas', 'H', '33 Avda. Enrique Peinador', 37170, 'Escipion.Valadez.Balderas@mailinator.com', '10/01/64', 24, 9);
INSERT INTO usuaris VALUES (3215, 'Balbo', 'Jiménez Domínquez', 'H', '82 Calle Proc. San Sebastián', 13100, 'Balbo.Jimenez.Dominquez@pookmail.com', '18/04/42', 69, NULL);
INSERT INTO usuaris VALUES (3216, 'Saba', 'Pedroza Ruvalcaba', 'D', '22 C/ Cuesta del  Álamo', 29620, 'Saba.Pedroza.Ruvalcaba@pookmail.com', '22/07/70', 42, 6);
INSERT INTO usuaris VALUES (3217, 'Jose', 'Rodrígez García', 'H', '96 Avda. Andalucía', 26134, 'Jose.Rodrigez.Garcia@trashymail.com', '28/03/72', 30, 6);
INSERT INTO usuaris VALUES (3218, 'Bona', 'Zamora Meza', 'D', '43 Ctra. de Siles', 27346, 'Bona.Zamora.Meza@trashymail.com', '27/11/50', 53, 11);
INSERT INTO usuaris VALUES (3219, 'Yoconda', 'Mateo Rincón', NULL, '70 Avenida Cervantes', 48330, 'Yoconda.Mateo.Rincon@mailinator.com', '05/09/60', 0, 4);
INSERT INTO usuaris VALUES (3220, 'Tulio', 'Escalante Árias', 'H', '79 Inglaterra', 18520, 'Tulio.Escalante.Arias@spambob.com', '25/08/56', 31, 1);
INSERT INTO usuaris VALUES (3221, 'Abad', 'Espinoza Galvez', 'H', '73 Rosa de los Vientos', 13370, 'Abad.Espinoza.Galvez@spambob.com', '23/05/60', 49, 10);
INSERT INTO usuaris VALUES (3222, 'Torcuato', 'Gaitán Salcedo', 'H', '15 Rua da Rapina', 37483, 'Torcuato.Gaitan.Salcedo@trashymail.com', '05/08/66', 11, 10);
INSERT INTO usuaris VALUES (3223, 'Rhode', 'Benavidez Colón', NULL, '67 El Roqueo', 17200, 'Rhode.Benavidez.Colon@trashymail.com', '18/02/68', 57, 5);
INSERT INTO usuaris VALUES (3224, 'Ismenia', 'Ávila Mascarenas', 'D', '19 Constitución', 37000, 'Ismenia.Avila.Mascarenas@spambob.com', '13/07/56', 68, 11);
INSERT INTO usuaris VALUES (3225, 'Iara', 'Castro Puente', 'D', '55 Puerto Lugar', 29710, 'Iara.Castro.Puente@spambob.com', '30/10/54', 64, NULL);
INSERT INTO usuaris VALUES (3226, 'Carina', 'Vanegas Vasquez', 'D', '64 Canónigo Valiño', 46290, 'Carina.Vanegas.Vasquez@spambob.com', '25/08/58', 50, 8);
INSERT INTO usuaris VALUES (3227, 'Cameron', 'Jasso Zúñiga', 'H', '66 Apartado de Correos', 37456, 'Cameron.Jasso.Zuniga@mailinator.com', '30/07/68', 53, 12);
INSERT INTO usuaris VALUES (3228, 'Dulce', 'Badillo Acosta', 'D', '70 Plaza de España', 15818, 'Dulce.Badillo.Acosta@dodgit.com', '17/06/85', 11, 8);
INSERT INTO usuaris VALUES (3229, 'Telmo', 'Reynoso Urbina', 'H', '32 Ourense', 43420, 'Telmo.Reynoso.Urbina@spambob.com', '29/09/43', 85, 11);
INSERT INTO usuaris VALUES (3230, 'Loreto', 'Archuleta Estévez', 'H', '6 Enxertos', 37522, 'Loreto.Archuleta.Estevez@pookmail.com', '04/01/51', 38, 5);
INSERT INTO usuaris VALUES (3231, 'Alexandra', 'Banda Zepeda', 'D', '58 Carretera Cádiz-Málaga', 20809, 'Alexandra.Banda.Zepeda@pookmail.com', '18/02/79', 7, 4);
INSERT INTO usuaris VALUES (3232, 'Bab', 'Iglesias Gracia', 'D', '9 Avendaño', 4140, 'Bab.Iglesias.Gracia@trashymail.com', '27/03/62', 90, 6);
INSERT INTO usuaris VALUES (3233, 'Ladio', 'Sanabria Ortega', 'H', '38 Canónigo Valiño', 46260, 'Ladio.Sanabria.Ortega@spambob.com', '24/01/48', 88, 10);
INSERT INTO usuaris VALUES (3234, 'Helene', 'Villagómez Cisneros', 'D', '58 Extramuros', 28430, 'Helene.Villagomez.Cisneros@spambob.com', '21/03/40', 78, 6);
INSERT INTO usuaris VALUES (3235, 'Everardo', 'Zaragoza Guajardo', 'H', '37 C/ Eras', 28737, 'Everardo.Zaragoza.Guajardo@pookmail.com', '05/08/73', 17, 4);
INSERT INTO usuaris VALUES (3236, 'Teodor', 'Cardona Heredia', 'H', '96 Alvaro Cunqueiro', 41130, 'Teodor.Cardona.Heredia@dodgit.com', '24/05/85', 36, 2);
INSERT INTO usuaris VALUES (3237, 'Sahara', 'Fernández Sanches', 'D', '59 Alcon Molina', 31140, 'Sahara.Fernandez.Sanches@pookmail.com', '10/07/70', 48, 12);
INSERT INTO usuaris VALUES (3238, 'Gad', 'Casas Peres', 'H', '76 Urzáiz', 44360, 'Gad.Casas.Peres@trashymail.com', '17/11/50', 91, 10);
INSERT INTO usuaris VALUES (3239, 'Magda', 'Galván Carranza', 'D', '79 Carretera del Muelle', 12413, 'Magda.Galvan.Carranza@pookmail.com', '11/05/76', 38, 4);
INSERT INTO usuaris VALUES (3240, 'Saulo', 'Armijo Santacruz', 'H', '68 Pza. Fuensanta', 32232, 'Saulo.Armijo.Santacruz@spambob.com', '11/06/59', 92, 9);
INSERT INTO usuaris VALUES (3241, 'Calígula', 'Pantoja Cotto', 'H', '45 Ctra. de Fuentenueva', 28200, 'Caligula.Pantoja.Cotto@pookmail.com', '26/06/80', 0, 8);
INSERT INTO usuaris VALUES (3242, 'Laurelino', 'Baez Girón', 'H', '67 C/ Domingo Beltrán', 2316, 'Laurelino.Baez.Giron@mailinator.com', '22/06/79', 93, 8);
INSERT INTO usuaris VALUES (3243, 'Emeterio', 'Armas Cantú', 'H', '87 Zumalakarregi etorbidea', 7100, 'Emeterio.Armas.Cantu@trashymail.com', '13/08/70', 99, 11);
INSERT INTO usuaris VALUES (3244, 'Amiel', 'Vázquez Aranda', 'H', '45 Rosa de los Vientos', 13380, 'Amiel.Vazquez.Aranda@trashymail.com', '22/10/77', 51, 10);
INSERT INTO usuaris VALUES (3245, 'Rinaldo', 'Espinosa Jimínez', 'H', '5 Ctra. Villena', 33840, 'Rinaldo.Espinosa.Jiminez@pookmail.com', '06/08/77', 67, 11);
INSERT INTO usuaris VALUES (3246, 'Emperatriz', 'Ordóñez Regalado', 'D', '82 Rúa Olmos', 37337, 'Emperatriz.Ordonez.Regalado@trashymail.com', '19/09/70', 60, 6);
INSERT INTO usuaris VALUES (3247, 'Melibeo', 'Alcalá Castellanos', 'H', '74 Estrela', 40194, 'Melibeo.Alcala.Castellanos@dodgit.com', '31/05/42', 76, 2);
INSERT INTO usuaris VALUES (3248, 'Nélida', 'Cabán Jimínez', 'D', '52 Camiño Ancho', 37762, 'Nelida.Caban.Jiminez@spambob.com', '04/07/59', 30, 3);
INSERT INTO usuaris VALUES (3249, 'Karla', 'Coronado Tórrez', 'D', '87 Pl. Virgen Blanca', 8720, 'Karla.Coronado.Torrez@dodgit.com', '18/11/54', 71, 11);
INSERT INTO usuaris VALUES (3250, 'Vin', 'Roldán Villagómez', 'H', '11 Extramuros', 28460, 'Vin.Roldan.Villagomez@trashymail.com', '03/07/51', 32, 9);
INSERT INTO usuaris VALUES (3251, 'Mijail', 'Galarza Márquez', 'H', '47 Avda. de Andalucía', 29327, 'Mijail.Galarza.Marquez@spambob.com', '23/01/63', 34, 11);
INSERT INTO usuaris VALUES (3252, 'Oriol', 'Orta Naranjo', 'H', '30 Avda. Generalísimo', 31570, 'Oriol.Orta.Naranjo@mailinator.com', '11/03/52', 29, 10);
INSERT INTO usuaris VALUES (3253, 'Florentino', 'Archuleta Maestas', 'H', '33 Comandante Izarduy', 8970, 'Florentino.Archuleta.Maestas@trashymail.com', '01/08/64', 60, 6);
INSERT INTO usuaris VALUES (3254, 'Ingrid', 'Quintanilla Ramos', 'D', '96 Alvaro Cunqueiro', 40250, 'Ingrid.Quintanilla.Ramos@trashymail.com', '24/12/41', 48, 6);
INSERT INTO usuaris VALUES (3255, 'Arandú', 'Arroyo Ordóñez', 'H', '95 C/ Libertad', 5310, 'Arandu.Arroyo.Ordonez@dodgit.com', '20/06/76', 70, 11);
INSERT INTO usuaris VALUES (3256, 'Alphonse', 'Caldera Agosto', 'H', '10 Camiño Ancho', 37766, 'Alphonse.Caldera.Agosto@trashymail.com', '01/12/53', 5, 8);
INSERT INTO usuaris VALUES (3257, 'Olivia', 'Peralta Garay', 'D', '72 Camiño Real', 48508, 'Olivia.Peralta.Garay@dodgit.com', '16/10/56', 13, 3);
INSERT INTO usuaris VALUES (3258, 'Yago', 'Galvez Madrid', 'H', '25 Cañadilla', 21710, 'Yago.Galvez.Madrid@spambob.com', '13/01/49', 40, 10);
INSERT INTO usuaris VALUES (3259, 'Leneo', 'Malave Venegas', 'H', '64 Rio Segura', 31320, 'Leneo.Malave.Venegas@spambob.com', '09/10/72', 61, 5);
INSERT INTO usuaris VALUES (3260, 'Aidé', 'Gutiérrez Gaona', 'D', '7 C/ Los Herrán', 6490, 'Aide.Gutierrez.Gaona@pookmail.com', '07/06/51', 52, 3);
INSERT INTO usuaris VALUES (3261, 'Sasha', 'Armendáriz Velasco', 'D', '31 Crta. Cádiz-Málaga', 12184, 'Sasha.Armendariz.Velasco@pookmail.com', '26/09/76', 23, 5);
INSERT INTO usuaris VALUES (3262, 'Eufrasio', 'Valdés Pabón', 'H', '71 Apartado de Correos', 37456, 'Eufrasio.Valdes.Pabon@spambob.com', '16/07/82', 26, 12);
INSERT INTO usuaris VALUES (3263, 'Nabil', 'Salazar Ayala', 'H', '23 Visitación de la Encina', 37762, 'Nabil.Salazar.Ayala@mailinator.com', '14/10/76', 5, 6);
INSERT INTO usuaris VALUES (3264, 'Andrónico', 'Jáquez Concepción', 'H', '76 Maestro Puig Valera', 33720, 'Andronico.Jaquez.Concepcion@mailinator.com', '10/07/75', 11, 5);
INSERT INTO usuaris VALUES (3265, 'Favian', 'Zayas Briones', 'H', '35 Cañadilla', 21891, 'Favian.Zayas.Briones@mailinator.com', '18/06/66', 61, 2);
INSERT INTO usuaris VALUES (3266, 'Nedar', 'Trejo Limón', 'H', '13 C/ Cuevas de Ambrosio', 23611, 'Nedar.Trejo.Limon@trashymail.com', '08/05/65', 68, 8);
INSERT INTO usuaris VALUES (3267, 'Carol', 'Reynoso Archuleta', 'D', '15 Ourense', 42300, 'Carol.Reynoso.Archuleta@pookmail.com', '08/08/71', 48, 12);
INSERT INTO usuaris VALUES (3268, 'Conrad', 'Cerda Archuleta', 'H', '20 Pl. Virgen Blanca', 8440, 'Conrad.Cerda.Archuleta@pookmail.com', '15/04/66', 64, 5);
INSERT INTO usuaris VALUES (3269, 'Alen', 'Delgado Salcido', 'H', '84 Rúa Olmos', 37320, 'Alen.Delgado.Salcido@spambob.com', '05/03/83', 51, 8);
INSERT INTO usuaris VALUES (3270, 'Dativa', 'Urrútia Riojas', 'D', '36 Extramuros', 28560, 'Dativa.Urrutia.Riojas@trashymail.com', '23/04/67', 33, NULL);
INSERT INTO usuaris VALUES (3271, 'Traful', 'Rincón Sandoval', 'H', '34 Avenida Cervantes', 48289, 'Traful.Rincon.Sandoval@spambob.com', '05/11/69', 0, 10);
INSERT INTO usuaris VALUES (3272, 'Escolástica', 'Hernádez Rodrígez', 'D', '7 Puerta Nueva', 36440, 'Escolastica.Hernadez.Rodrigez@trashymail.com', '01/10/41', 96, 8);
INSERT INTO usuaris VALUES (3273, 'Florentina', 'Mireles Sotelo', 'D', '54 Prolongacion San Sebastian', 21340, 'Florentina.Mireles.Sotelo@pookmail.com', '13/04/70', 32, 2);
INSERT INTO usuaris VALUES (3274, 'Zemira', 'Longoria Quezada', 'D', '86 Avda. Rio Nalon', 33126, 'Zemira.Longoria.Quezada@dodgit.com', '01/02/45', 3, NULL);
INSERT INTO usuaris VALUES (3275, 'Liberato', 'Rodríguez Narváez', 'H', '11 Avda. Generalísimo', 32137, 'Liberato.Rodriguez.Narvaez@pookmail.com', '19/11/71', 71, 8);
INSERT INTO usuaris VALUES (3276, 'Danila', 'Pedroza Rendón', NULL, '76 C/ Angosto', 23528, 'Danila.Pedroza.Rendon@mailinator.com', '22/02/59', 75, 5);
INSERT INTO usuaris VALUES (3277, 'Natal', 'Peralta Heredia', 'H', '20 Prolongacion San Sebastian', 21292, 'Natal.Peralta.Heredia@spambob.com', '16/09/77', 30, 6);
INSERT INTO usuaris VALUES (3278, 'Leo', 'Farías Correa', 'H', '73 Crta. Cádiz-Málaga', 12183, 'Leo.Farias.Correa@trashymail.com', '19/08/55', 36, 10);
INSERT INTO usuaris VALUES (3279, 'Georgina', 'Garza Pulido', 'D', '54 Valadouro', 48144, 'Georgina.Garza.Pulido@mailinator.com', '07/09/71', 1, 9);
INSERT INTO usuaris VALUES (3280, 'Custodio', 'Adomo Núñez', 'H', '54 Inglaterra', 18566, 'Custodio.Adomo.Nunez@trashymail.com', '02/10/62', 35, 8);
INSERT INTO usuaris VALUES (3281, 'Kevin', 'Arenas Loera', 'H', '3 Alvaro Cunqueiro', 41110, 'Kevin.Arenas.Loera@spambob.com', '24/03/40', 54, 2);
INSERT INTO usuaris VALUES (3282, 'Moira', 'Salinas Baeza', 'D', '12 Reiseñor', 45880, 'Moira.Salinas.Baeza@mailinator.com', '23/03/56', 84, 10);
INSERT INTO usuaris VALUES (3283, 'Wanda', 'Árias Esquibel', 'D', '59 Cartagena', 30620, 'Wanda.Arias.Esquibel@spambob.com', '15/01/75', 29, 8);
INSERT INTO usuaris VALUES (3284, 'Adalrico', 'Vanegas Vega', 'H', '87 Maestro Puig Valera', 33760, 'Adalrico.Vanegas.Vega@spambob.com', '18/12/58', 31, 12);
INSERT INTO usuaris VALUES (3285, 'Nils', 'Quintanilla Rosas', 'H', '84 C/ Andalucía', 4640, 'Nils.Quintanilla.Rosas@mailinator.com', '30/12/51', 11, 6);
INSERT INTO usuaris VALUES (3286, 'Yvette', 'Vargas Barragán', NULL, '71 C/ Angosto', 23487, 'Yvette.Vargas.Barragan@pookmail.com', '22/04/44', 83, 12);
INSERT INTO usuaris VALUES (3287, 'Perpetuo', 'Villa Delgado', 'H', '80 C/ Los Herrán', 6230, 'Perpetuo.Villa.Delgado@trashymail.com', '16/09/56', 5, 9);
INSERT INTO usuaris VALUES (3288, 'Vespasiano', 'Pabón Campos', 'H', '5 Ctra. de Siles', 27430, 'Vespasiano.Pabon.Campos@dodgit.com', '12/06/54', NULL, 9);
INSERT INTO usuaris VALUES (3289, 'Dafne', 'Morales Salcido', 'D', '47 Escuadro', 47193, 'Dafne.Morales.Salcido@dodgit.com', '02/02/78', 52, 12);
INSERT INTO usuaris VALUES (3290, 'Oto', 'Granado Gaytan', 'H', '97 Ctra. Hornos', 26211, 'Oto.Granado.Gaytan@pookmail.com', '10/08/60', 96, 5);
INSERT INTO usuaris VALUES (3291, 'Teodelina', 'Garica Márquez', 'D', '28 C/ Canarias', 20130, 'Teodelina.Garica.Marquez@spambob.com', '02/01/77', 7, 10);
INSERT INTO usuaris VALUES (3292, 'Alice', 'Murillo Saucedo', 'D', '42 Avda. de Andalucía', 29328, 'Alice.Murillo.Saucedo@pookmail.com', '25/11/72', 56, 8);
INSERT INTO usuaris VALUES (3293, 'Bertrán', 'Galindo Argüello', 'H', '7 Av. Zumalakarregi', 3310, 'Bertran.Galindo.Arguello@dodgit.com', '08/06/48', 66, NULL);
INSERT INTO usuaris VALUES (3294, 'Itatay', 'Luján Rolón', NULL, '98 Ctra. de Fuentenueva', 28295, 'Itatay.Lujan.Rolon@trashymail.com', '25/04/77', 20, 11);
INSERT INTO usuaris VALUES (3295, 'Ashley', 'Ríos Solano', 'D', '38 Ctra. Hornos', 26223, 'Ashley.Rios.Solano@pookmail.com', '04/11/49', 37, 3);
INSERT INTO usuaris VALUES (3296, 'Domenec', 'Pina Elizondo', 'H', '88 Socampo', 37692, 'Domenec.Pina.Elizondo@spambob.com', '02/04/85', 69, 1);
INSERT INTO usuaris VALUES (3297, 'Karim', 'Ceja Sanches', 'H', '48 Avda. Alameda Sundheim', 22400, 'Karim.Ceja.Sanches@mailinator.com', '02/06/41', 71, NULL);
INSERT INTO usuaris VALUES (3298, 'Analía', 'Zaragoza Garay', 'D', '88 Valadouro', 48143, 'Analia.Zaragoza.Garay@spambob.com', '06/07/42', 61, 2);
INSERT INTO usuaris VALUES (3299, 'Maha', 'Gallardo Canales', 'D', '56 C/ Angosto', 23568, 'Maha.Gallardo.Canales@trashymail.com', '06/09/73', 51, 8);
INSERT INTO usuaris VALUES (3300, 'Badomero', 'Vallejo Luevano', 'H', '37 C/ Cañada del Rosal', 21610, 'Badomero.Vallejo.Luevano@pookmail.com', '14/05/50', 1, 5);
INSERT INTO usuaris VALUES (3301, 'Francesca', 'Cárdenas Bustos', 'D', '90 C/ Hijuela de Lojo', 20270, 'Francesca.Cardenas.Bustos@mailinator.com', '19/04/85', 28, 10);
INSERT INTO usuaris VALUES (3302, 'Remedios', 'Orellana Olivera', 'D', '96 Comandante Izarduy', 9210, 'Remedios.Orellana.Olivera@trashymail.com', '07/01/65', 14, 6);
INSERT INTO usuaris VALUES (3303, 'Romilda', 'Griego Carmona', 'D', '45 Carretera Cádiz-Málaga', 20570, 'Romilda.Griego.Carmona@dodgit.com', '13/02/48', 51, 6);
INSERT INTO usuaris VALUES (3304, 'Reuquén', 'Osorio Madera', 'H', '6 Carretera Cádiz-Málaga', 20737, 'Reuquen.Osorio.Madera@trashymail.com', '23/05/75', 14, 9);
INSERT INTO usuaris VALUES (3305, 'Pompilio', 'Barrios Zapata', 'H', '55 Ourense', 42157, 'Pompilio.Barrios.Zapata@pookmail.com', '10/10/43', 97, 9);
INSERT INTO usuaris VALUES (3306, 'Ginette', 'Paredes Montemayor', 'D', '40 Camiño Ancho', 37777, 'Ginette.Paredes.Montemayor@mailinator.com', '06/09/41', 23, 3);
INSERT INTO usuaris VALUES (3307, 'Erberto', 'Ferrer Padrón', 'H', '98 Pza. Fuensanta', 32420, 'Erberto.Ferrer.Padron@pookmail.com', '26/02/77', 81, 6);
INSERT INTO usuaris VALUES (3308, 'Baudilia', 'Villalpando Ortiz', 'D', '76 C/ Andalucía', 4750, 'Baudilia.Villalpando.Ortiz@pookmail.com', '14/03/53', 50, 11);
INSERT INTO usuaris VALUES (3309, 'Sereno', 'Miranda Guerra', 'H', '18 Paraguay', 3680, 'Sereno.Miranda.Guerra@dodgit.com', '19/02/67', 62, 9);
INSERT INTO usuaris VALUES (3310, 'Polidora', 'Velázquez Menéndez', 'D', '44 Rio Segura', 31520, 'Polidora.Velazquez.Menendez@pookmail.com', '26/10/40', 22, 12);
INSERT INTO usuaris VALUES (3311, 'Jezabel', 'Quintero Hurtado', 'D', '58 Celso Emilio Ferreiro', 50670, 'Jezabel.Quintero.Hurtado@spambob.com', '19/03/67', 94, 1);
INSERT INTO usuaris VALUES (3312, 'Mael', 'Olvera Ledesma', 'H', '17 Cartagena', 30170, 'Mael.Olvera.Ledesma@pookmail.com', '15/07/65', 42, 4);
INSERT INTO usuaris VALUES (3313, 'Dagoberto', 'Alcaraz Alva', 'H', '58 Ctra. de Fuentenueva', 28250, 'Dagoberto.Alcaraz.Alva@dodgit.com', '21/07/69', 7, 1);
INSERT INTO usuaris VALUES (3314, 'Violeta', 'Esquivel Elizondo', 'D', '59 Bellavista', 50246, 'Violeta.Esquivel.Elizondo@trashymail.com', '08/05/57', 76, 3);
INSERT INTO usuaris VALUES (3315, 'Querubina', 'Urías Rivera', 'D', '15 Rio Segura', 31400, 'Querubina.Urias.Rivera@dodgit.com', '09/01/83', 26, NULL);
INSERT INTO usuaris VALUES (3316, 'Kemal', 'Cervantes Cano', 'H', '63 Calle Aduana', 1300, 'Kemal.Cervantes.Cano@mailinator.com', '07/04/50', 82, 8);
INSERT INTO usuaris VALUES (3317, 'Alhueche', 'Cerda Muro', 'H', '75 Av. Santiago Lapuente', 50730, 'Alhueche.Cerda.Muro@mailinator.com', '27/12/47', 15, 9);
INSERT INTO usuaris VALUES (3318, 'Narellla', 'Garica Quintanilla', 'D', '29 C/ Canarias', 20115, 'Narellla.Garica.Quintanilla@spambob.com', '16/06/68', 51, 3);
INSERT INTO usuaris VALUES (3319, 'Jeannette', 'Rosado Velázquez', 'D', '91 Paseo Junquera', 12510, 'Jeannette.Rosado.Velazquez@pookmail.com', '02/04/83', 48, 1);
INSERT INTO usuaris VALUES (3320, 'Inca', 'Barreto Cedillo', 'H', '77 C/ Cuevas de Ambrosio', 23650, 'Inca.Barreto.Cedillo@mailinator.com', '06/01/81', 59, 2);
INSERT INTO usuaris VALUES (3321, 'Gordon', 'Espinosa Ledesma', 'H', '70 Puerto Lugar', 29750, 'Gordon.Espinosa.Ledesma@dodgit.com', '15/05/76', 9, 11);
INSERT INTO usuaris VALUES (3322, 'Valencia', 'Valentín Laureano', 'D', '72 José matía', 2110, 'Valencia.Valentin.Laureano@mailinator.com', '06/10/60', 80, 4);
INSERT INTO usuaris VALUES (3323, 'Husai', 'Navarro Olivera', 'H', '10 Herrería', 18200, 'Husai.Navarro.Olivera@pookmail.com', '25/01/43', 33, NULL);
INSERT INTO usuaris VALUES (3324, 'Anías', 'Sosa Zúñiga', 'H', '63 Paseo Junquera', 12449, 'Anias.Sosa.Zuniga@trashymail.com', '30/09/80', 40, 11);
INSERT INTO usuaris VALUES (3325, 'Parmenio', 'Amador Ferrer', NULL, '26 Maestro Puig Valera', 33630, 'Parmenio.Amador.Ferrer@trashymail.com', '24/12/81', 83, 4);
INSERT INTO usuaris VALUES (3326, 'Bayard', 'Camacho Elizondo', 'H', '36 C/ Manuel Iradier', 3790, 'Bayard.Camacho.Elizondo@spambob.com', '03/02/53', 96, 11);
INSERT INTO usuaris VALUES (3327, 'Rancul', 'Baca Rojo', 'H', '20 C/ Amoladera', 28800, 'Rancul.Baca.Rojo@dodgit.com', '06/07/73', 9, 4);
INSERT INTO usuaris VALUES (3328, 'Araceli', 'Olivera Frías', 'D', '75 C/ Fernández de Leceta', 3348, 'Araceli.Olivera.Frias@mailinator.com', '09/05/75', 86, 10);
INSERT INTO usuaris VALUES (3329, 'Manases', 'Sánchez Quezada', 'H', '17 Avendaño', 4280, 'Manases.Sanchez.Quezada@dodgit.com', '09/11/50', 82, 2);
INSERT INTO usuaris VALUES (3330, 'Archer', 'Covas Reynoso', 'H', '92 Alcon Molina', 31243, 'Archer.Covas.Reynoso@pookmail.com', '29/11/59', 40, 1);
INSERT INTO usuaris VALUES (3331, 'Jeremy', 'Lomeli Aragón', 'H', '18 Visitación de la Encina', 37749, 'Jeremy.Lomeli.Aragon@dodgit.com', '03/12/46', 11, 2);
INSERT INTO usuaris VALUES (3332, 'Adalbaro', 'Velez Venegas', 'H', '5 Cruce Casa de Postas', 18260, 'Adalbaro.Velez.Venegas@spambob.com', '06/11/65', 16, 11);
INSERT INTO usuaris VALUES (3333, 'Fritz', 'Collado Segovia', 'H', '34 C/ Pablo Iglesias', 26321, 'Fritz.Collado.Segovia@mailinator.com', '13/04/40', 79, 6);
INSERT INTO usuaris VALUES (3334, 'Carmelita', 'Cerda Parra', 'D', '25 Avda. Enrique Peinador', 37187, 'Carmelita.Cerda.Parra@spambob.com', '07/05/55', 15, 1);
INSERT INTO usuaris VALUES (3335, 'Gelasio', 'Castaneda Orellana', 'H', '84 Crta. Cádiz-Málaga', 12186, 'Gelasio.Castaneda.Orellana@pookmail.com', '09/03/60', 27, 10);
INSERT INTO usuaris VALUES (3336, 'Faust', 'Colunga Estrada', 'H', '88 Avenida Cervantes', 48269, 'Faust.Colunga.Estrada@dodgit.com', '30/06/44', 81, 12);
INSERT INTO usuaris VALUES (3337, 'Brenda', 'Espinosa Ochoa', 'D', '99 Antonio Vázquez', 38500, 'Brenda.Espinosa.Ochoa@dodgit.com', '20/03/80', 30, 4);
INSERT INTO usuaris VALUES (3338, 'Rosenda', 'Pina Espinoza', 'D', '87 Calvo Sotelo', 47410, 'Rosenda.Pina.Espinoza@pookmail.com', '09/07/61', 96, 5);
INSERT INTO usuaris VALUES (3339, 'Uciel', 'Verdugo Guillén', NULL, '57 Socampo', 37610, 'Uciel.Verdugo.Guillen@dodgit.com', '03/01/51', 40, 1);
INSERT INTO usuaris VALUES (3340, 'Basileo', 'Osorio Miramontes', 'H', '95 Avda. Explanada Barnuevo', 35290, 'Basileo.Osorio.Miramontes@pookmail.com', '25/11/59', 10, 12);
INSERT INTO usuaris VALUES (3341, 'Tehuel', 'Benítez Aranda', 'H', '18 Padre Caro', 13593, 'Tehuel.Benitez.Aranda@trashymail.com', '05/04/59', 6, 11);
INSERT INTO usuaris VALUES (3342, 'Livio', 'López Irizarry', 'H', '92 Avendaño', 3816, 'Livio.Lopez.Irizarry@mailinator.com', '14/04/63', 99, 6);
INSERT INTO usuaris VALUES (3343, 'Dennis', 'Sierra Frías', 'H', '75 Avda. Los llanos', 26311, 'Dennis.Sierra.Frias@pookmail.com', '11/09/72', 91, 8);
INSERT INTO usuaris VALUES (3344, 'Jacqueline', 'Paez Collado', 'D', '35 Avendaño', 4140, 'Jacqueline.Paez.Collado@trashymail.com', '01/01/79', 90, NULL);
INSERT INTO usuaris VALUES (3345, 'Geremías', 'Santacruz Villareal', 'H', '18 Ctra. de Siles', 27630, 'Geremias.Santacruz.Villareal@pookmail.com', '16/04/72', 52, 10);
INSERT INTO usuaris VALUES (3346, 'Periandro', 'Sotelo Orta', 'H', '17 Avda. Enrique Peinador', 37187, 'Periandro.Sotelo.Orta@trashymail.com', '11/06/58', 7, 5);
INSERT INTO usuaris VALUES (3347, 'Numas', 'Sauceda Medrano', 'D', '2 Quevedo', 15189, 'Numas.Sauceda.Medrano@pookmail.com', '13/09/64', 47, 1);
INSERT INTO usuaris VALUES (3348, 'Huilen', 'Escobar Arellano', 'D', '72 Avenida Cervantes', 48260, 'Huilen.Escobar.Arellano@spambob.com', '08/08/82', 49, 7);
INSERT INTO usuaris VALUES (3349, 'Landolfo', 'Casillas Ortiz', 'H', '51 Plaza de España', 15808, 'Landolfo.Casillas.Ortiz@trashymail.com', '22/10/82', 77, 8);
INSERT INTO usuaris VALUES (3350, 'Froilán', 'Espino Guardado', 'H', '94 C/ Cuevas de Ambrosio', 23700, 'Froilan.Espino.Guardado@mailinator.com', '07/10/62', 45, 9);
INSERT INTO usuaris VALUES (3351, 'Damaris', 'Ballesteros Olivares', 'D', '62 Pl. Virgen Blanca', 8759, 'Damaris.Ballesteros.Olivares@dodgit.com', '11/09/47', 3, 6);
INSERT INTO usuaris VALUES (3352, 'Maud', 'Vega Godoy', 'D', '5 Eusebio Dávila', 41540, 'Maud.Vega.Godoy@dodgit.com', '19/07/78', 87, 11);
INSERT INTO usuaris VALUES (3353, 'Alvin', 'Ontiveros Correa', 'H', '7 Padre Caro', 13600, 'Alvin.Ontiveros.Correa@dodgit.com', '07/05/80', 95, 7);
INSERT INTO usuaris VALUES (3354, 'Lisbet', 'Ocampo Badillo', 'D', '4 Calle Aduana', 1117, 'Lisbet.Ocampo.Badillo@spambob.com', '23/10/45', 17, 7);
INSERT INTO usuaris VALUES (3355, 'Gilda', 'Rivas Acevedo', 'D', '42 Eusebio Dávila', 41340, 'Gilda.Rivas.Acevedo@pookmail.com', '16/09/50', 25, 11);
INSERT INTO usuaris VALUES (3356, 'Sotero', 'Garay Peralta', 'H', '65 Camiño Real', 48480, 'Sotero.Garay.Peralta@pookmail.com', '26/01/76', 97, 6);
INSERT INTO usuaris VALUES (3357, 'Ivany', 'Abrego Reynoso', 'H', '64 Plazuela do Porto', 37893, 'Ivany.Abrego.Reynoso@mailinator.com', '31/05/70', 10, 11);
INSERT INTO usuaris VALUES (3358, 'Raiquen', 'Ponce Duarte', 'H', '42 Calvo Sotelo', 47270, 'Raiquen.Ponce.Duarte@mailinator.com', '27/04/45', 86, 9);
INSERT INTO usuaris VALUES (3359, 'Peer', 'Fernández Godoy', 'H', '44 Escuadro', 46910, 'Peer.Fernandez.Godoy@trashymail.com', '06/06/83', 76, 11);
INSERT INTO usuaris VALUES (3360, 'Karla', 'Muñiz Malave', 'D', '96 Rosa de los Vientos', 13391, 'Karla.Muniz.Malave@pookmail.com', '14/02/85', 30, 6);
INSERT INTO usuaris VALUES (3361, 'Emilian', 'Puga Solano', 'H', '49 Paseo del Atlántico', 18131, 'Emilian.Puga.Solano@pookmail.com', '23/04/54', 39, 9);
INSERT INTO usuaris VALUES (3362, 'Macrina', 'Lozada Villalobos', 'D', '94 C/ Arana', 2651, 'Macrina.Lozada.Villalobos@pookmail.com', '20/08/79', 43, 6);
INSERT INTO usuaris VALUES (3363, 'Nubia', 'Abeyta Montanez', 'D', '46 C/ Manuel Iradier', 3794, 'Nubia.Abeyta.Montanez@mailinator.com', '30/01/60', 89, 10);
INSERT INTO usuaris VALUES (3364, 'Lincoln', 'Rentería Zamudio', 'D', '94 Salzillo', 32618, 'Lincoln.Renteria.Zamudio@dodgit.com', '21/11/63', 71, 5);
INSERT INTO usuaris VALUES (3365, 'Licas', 'Bravo Sanabria', 'H', '13 Plaza Maior', 37208, 'Licas.Bravo.Sanabria@dodgit.com', '30/11/68', 68, 3);
INSERT INTO usuaris VALUES (3366, 'Heber', 'Gonzales Navarrete', 'H', '65 Cruce Casa de Postas', 18310, 'Heber.Gonzales.Navarrete@spambob.com', '26/11/49', 54, 11);
INSERT INTO usuaris VALUES (3367, 'Alcibíades', 'Jasso Tello', 'H', '93 Herrería', 18190, 'Alcibiades.Jasso.Tello@spambob.com', '08/06/50', 55, 9);
INSERT INTO usuaris VALUES (3368, 'Lavinia', 'Aponte Alonzo', 'D', '24 Ctra. Bailén-Motril', 23220, 'Lavinia.Aponte.Alonzo@spambob.com', '11/07/81', 0, 1);
INSERT INTO usuaris VALUES (3369, 'Pichi', 'Aguayo Saavedra', 'H', '50 C/ Libertad', 5450, 'Pichi.Aguayo.Saavedra@trashymail.com', '07/11/47', 27, 1);
INSERT INTO usuaris VALUES (3370, 'Vanna', 'Villaseñor Lerma', 'D', '81 Calle Aduana', 1211, 'Vanna.Villasenor.Lerma@trashymail.com', '27/03/76', 53, 9);
INSERT INTO usuaris VALUES (3371, 'Jaden', 'Ceja Caballero', 'D', '70 Bouciña', 43790, 'Jaden.Ceja.Caballero@dodgit.com', '07/12/41', 1, 12);
INSERT INTO usuaris VALUES (3372, 'Livino', 'Ramírez Rojo', 'H', '11 Paraguay', 3600, 'Livino.Ramirez.Rojo@spambob.com', '07/04/58', 58, 10);
INSERT INTO usuaris VALUES (3373, 'Dionel', 'Aragón Velez', 'H', '79 Plaza Maior', 37191, 'Dionel.Aragon.Velez@dodgit.com', '17/01/65', 25, NULL);
INSERT INTO usuaris VALUES (3374, 'Romilda', 'Mercado Gracia', 'D', '89 C/ Andalucía', 4810, 'Romilda.Mercado.Gracia@trashymail.com', '07/01/72', 62, 3);
INSERT INTO usuaris VALUES (3375, 'Wendy', 'Roybal Correa', 'D', '36 Visitación de la Encina', 37724, 'Wendy.Roybal.Correa@pookmail.com', '30/03/68', 4, 10);
INSERT INTO usuaris VALUES (3376, 'Emperatriz', 'Escalante Pina', 'D', '29 Rua da Rapina', 37469, 'Emperatriz.Escalante.Pina@dodgit.com', '04/03/50', 86, 12);
INSERT INTO usuaris VALUES (3377, 'Hipólito', 'Monroy Estévez', 'H', '29 Plaza de España', 15700, 'Hipolito.Monroy.Estevez@trashymail.com', '13/12/56', 5, 8);
INSERT INTO usuaris VALUES (3378, 'Ludovico', 'Aparicio Griego', 'H', '23 Avda. Explanada Barnuevo', 34880, 'Ludovico.Aparicio.Griego@dodgit.com', '18/05/54', 42, 8);
INSERT INTO usuaris VALUES (3379, 'Cristhian', 'Ramos Haro', 'H', '58 C/ Canarias', 20159, 'Cristhian.Ramos.Haro@trashymail.com', '31/08/58', 21, 10);
INSERT INTO usuaris VALUES (3380, 'Mercy', 'Torres Gaitán', NULL, '52 Rosa de los Vientos', 13412, 'Mercy.Torres.Gaitan@spambob.com', '05/01/62', 26, 4);
INSERT INTO usuaris VALUES (3381, 'Tea', 'Concepción Rangel', 'D', '5 Herrería', 18170, 'Tea.Concepcion.Rangel@mailinator.com', '26/09/82', 51, 6);
INSERT INTO usuaris VALUES (3382, 'Eliú', 'Aparicio Calvillo', 'D', '2 Socampo', 37659, 'Eliu.Aparicio.Calvillo@trashymail.com', '27/06/68', 44, 6);
INSERT INTO usuaris VALUES (3383, 'Ilona', 'Sarabia Apodaca', 'D', '4 Paseo del Atlántico', 18120, 'Ilona.Sarabia.Apodaca@trashymail.com', '05/09/43', 49, 10);
INSERT INTO usuaris VALUES (3384, 'Isaldina', 'Arévalo Castellanos', 'D', '50 C/ Amoladera', 28818, 'Isaldina.Arevalo.Castellanos@spambob.com', '04/11/49', 4, 3);
INSERT INTO usuaris VALUES (3385, 'Kay', 'Quintero Nevarez', 'D', '76 San Andrés', 37250, 'Kay.Quintero.Nevarez@dodgit.com', '01/01/63', 93, 8);
INSERT INTO usuaris VALUES (3386, 'Venus', 'Lomeli Adomo', 'D', '40 José matía', 1427, 'Venus.Lomeli.Adomo@spambob.com', '27/06/58', 75, 9);
INSERT INTO usuaris VALUES (3387, 'Canan', 'Abeyta Ferrer', NULL, '5 Rúa de San Pedro', 37871, 'Canan.Abeyta.Ferrer@spambob.com', '22/03/81', 85, 9);
INSERT INTO usuaris VALUES (3388, 'Hector', 'Oquendo Flórez', 'H', '12 San Andrés', 37272, 'Hector.Oquendo.Florez@spambob.com', '12/03/45', 84, 2);
INSERT INTO usuaris VALUES (3389, 'Clarisa', 'Salcedo Alanis', 'D', '17 C/ Andalucía', 4600, 'Clarisa.Salcedo.Alanis@trashymail.com', '18/01/43', 72, 3);
INSERT INTO usuaris VALUES (3390, 'Arquímedes', 'Campos Gómez', 'H', '78 C/ Los Herrán', 6100, 'Arquimedes.Campos.Gomez@trashymail.com', '27/07/59', 56, 10);
INSERT INTO usuaris VALUES (3391, 'Leonilda', 'Barajas Leyva', 'D', '6 Celso Emilio Ferreiro', 50270, 'Leonilda.Barajas.Leyva@pookmail.com', '26/07/44', 64, 2);
INSERT INTO usuaris VALUES (3392, 'Cassandre', 'Regalado Cardona', 'D', '92 C/ Amoladera', 28815, 'Cassandre.Regalado.Cardona@pookmail.com', '01/06/83', 98, 11);
INSERT INTO usuaris VALUES (3393, 'Monique', 'Anguiano Romo', 'D', '77 Rosa de los Vientos', 13345, 'Monique.Anguiano.Romo@trashymail.com', '14/12/42', 27, 5);
INSERT INTO usuaris VALUES (3394, 'Clementino', 'Arreola Velázquez', 'H', '70 Puerto Lugar', 29718, 'Clementino.Arreola.Velazquez@pookmail.com', '22/07/45', 98, 9);
INSERT INTO usuaris VALUES (3395, 'Carpo', 'Bermúdez Arana', 'H', '98 C/ Los Herrán', 6420, 'Carpo.Bermudez.Arana@dodgit.com', '25/09/80', 79, 10);
INSERT INTO usuaris VALUES (3396, 'Adair', 'Barrera Longoria', 'H', '93 C/ Rosa de los Vientos', 11560, 'Adair.Barrera.Longoria@mailinator.com', '11/03/58', 36, 9);
INSERT INTO usuaris VALUES (3397, 'Aarón', 'Maya Orosco', 'H', '9 Constitución', 36994, 'Aaron.Maya.Orosco@trashymail.com', '25/06/82', 75, NULL);
INSERT INTO usuaris VALUES (3398, 'Cleopatra', 'Guerra Godínez', 'D', '87 Calvo Sotelo', 47196, 'Cleopatra.Guerra.Godinez@spambob.com', '22/07/68', 96, 7);
INSERT INTO usuaris VALUES (3399, 'Nais', 'Carmona Otero', 'D', '92 Calvo Sotelo', 48000, 'Nais.Carmona.Otero@spambob.com', '21/03/57', 45, 9);
INSERT INTO usuaris VALUES (3400, 'Brandon', 'Árias León', 'H', '65 Eusebio Dávila', 41530, 'Brandon.Arias.Leon@mailinator.com', '21/04/80', 39, 9);
INSERT INTO usuaris VALUES (3401, 'Melchior', 'Iglesias Bravo', 'H', '30 La Fontanilla', 14430, 'Melchior.Iglesias.Bravo@trashymail.com', '22/03/66', 31, 7);
INSERT INTO usuaris VALUES (3402, 'Canela', 'Mora Baca', 'D', '8 Avda. Los llanos', 26291, 'Canela.Mora.Baca@mailinator.com', '20/10/65', 33, 6);
INSERT INTO usuaris VALUES (3403, 'Tancredo', 'Núñez Muñoz', 'H', '48 Avda. Los llanos', 26257, 'Tancredo.Nunez.Munoz@mailinator.com', '09/02/60', 38, 11);
INSERT INTO usuaris VALUES (3404, 'Emiliano', 'Arana Alonso', 'H', '7 C/ Benito Guinea', 8390, 'Emiliano.Arana.Alonso@dodgit.com', '09/12/62', 33, 3);
INSERT INTO usuaris VALUES (3405, 'Akira', 'Corral Medina', 'H', '3 C/ Hijuela de Lojo', 20248, 'Akira.Corral.Medina@pookmail.com', '29/07/50', 81, 6);
INSERT INTO usuaris VALUES (3406, 'Floreal', 'Zarate Alvarez', 'H', '82 Visitación de la Encina', 37714, 'Floreal.Zarate.Alvarez@dodgit.com', '24/01/85', 20, 7);
INSERT INTO usuaris VALUES (3407, 'Leocadia', 'Coronado Tamayo', 'D', '4 Atamaria', 36740, 'Leocadia.Coronado.Tamayo@trashymail.com', '09/08/78', 21, 5);
INSERT INTO usuaris VALUES (3408, 'Toni', 'Tamayo Delgadillo', 'H', '62 Plaza Colón', 24300, 'Toni.Tamayo.Delgadillo@trashymail.com', '22/10/79', 71, 3);
INSERT INTO usuaris VALUES (3409, 'Melchior', 'Macías Candelaria', 'H', '12 Ventanilla de Beas', 27880, 'Melchior.Macias.Candelaria@dodgit.com', '17/05/81', 6, 2);
INSERT INTO usuaris VALUES (3410, 'Gerson', 'Gracia Farías', 'H', '86 Avda. Los llanos', 26258, 'Gerson.Gracia.Farias@pookmail.com', '29/03/80', 68, 12);
INSERT INTO usuaris VALUES (3411, 'Lola', 'Zúñiga Collado', 'D', '98 Ventanilla de Beas', 28100, 'Lola.Zuniga.Collado@pookmail.com', '12/03/73', 74, 11);
INSERT INTO usuaris VALUES (3412, 'Laila', 'Montez Valladares', 'D', '72 C/ Domingo Beltrán', 2214, 'Laila.Montez.Valladares@trashymail.com', '08/07/55', 24, 1);
INSERT INTO usuaris VALUES (3413, 'Aminta', 'Zavala Aponte', 'D', '67 Pza. Fuensanta', 32300, 'Aminta.Zavala.Aponte@dodgit.com', '25/01/53', 15, 10);
INSERT INTO usuaris VALUES (3414, 'Eleonor', 'Angulo Meza', 'D', '97 C/ Andalucía', 4650, 'Eleonor.Angulo.Meza@dodgit.com', '02/03/78', 76, 6);
INSERT INTO usuaris VALUES (3415, 'Gildo', 'Marroquín Lugo', 'H', '83 Prolongacion San Sebastian', 21230, 'Gildo.Marroquin.Lugo@pookmail.com', '03/12/48', 53, 6);
INSERT INTO usuaris VALUES (3416, 'Nazarena', 'Cruz Rodrígez', 'D', '32 José matía', 2162, 'Nazarena.Cruz.Rodrigez@trashymail.com', '15/01/42', 67, 6);
INSERT INTO usuaris VALUES (3417, 'Juvenal', 'Galvez Arana', 'H', '46 Atamaria', 36645, 'Juvenal.Galvez.Arana@mailinator.com', '16/09/80', 98, 3);
INSERT INTO usuaris VALUES (3418, 'Quique', 'Borrego Salazar', NULL, '86 Ventanilla de Beas', 27780, 'Quique.Borrego.Salazar@spambob.com', '14/04/67', 25, 2);
INSERT INTO usuaris VALUES (3419, 'Laya', 'Prieto Dávila', 'D', '74 C/ Pablo Iglesias', 26321, 'Laya.Prieto.Davila@trashymail.com', '18/05/85', 95, 11);
INSERT INTO usuaris VALUES (3420, 'Tania', 'Figueroa Acuna', 'D', '20 Pl. Virgen Blanca', 8530, 'Tania.Figueroa.Acuna@pookmail.com', '17/02/42', 59, 4);
INSERT INTO usuaris VALUES (3421, 'Galatea', 'Linares Vázquez', 'D', '55 Avda. Explanada Barnuevo', 35530, 'Galatea.Linares.Vazquez@trashymail.com', '01/08/57', 15, 1);
INSERT INTO usuaris VALUES (3422, 'Rodas', 'Velasco Reynoso', 'H', '30 C/ Los Herrán', 6340, 'Rodas.Velasco.Reynoso@dodgit.com', '04/04/65', 78, 5);
INSERT INTO usuaris VALUES (3423, 'Clemencia', 'Nieves González', 'D', '63 Avda. Enrique Peinador', 37160, 'Clemencia.Nieves.Gonzalez@trashymail.com', '08/07/74', NULL, 12);
INSERT INTO usuaris VALUES (3424, 'Len', 'Saavedra Negrete', 'H', '83 Inglaterra', 18570, 'Len.Saavedra.Negrete@spambob.com', '29/04/49', 20, 1);
INSERT INTO usuaris VALUES (3425, 'Peer', 'Rangel Colón', 'H', '78 Reiseñor', 45700, 'Peer.Rangel.Colon@trashymail.com', '25/01/69', 81, 6);
INSERT INTO usuaris VALUES (3426, 'Sadoc', 'Mora Arteaga', 'H', '68 Avenida Cervantes', 48314, 'Sadoc.Mora.Arteaga@dodgit.com', '24/06/40', 71, 2);
INSERT INTO usuaris VALUES (3427, 'Juanjo', 'Vigil Hernández', 'H', '27 C/ Canarias', 19000, 'Juanjo.Vigil.Hernandez@dodgit.com', '07/01/85', 18, 12);
INSERT INTO usuaris VALUES (3428, 'Emilian', 'Lara Baca', 'H', '25 C/ Cuevas de Ambrosio', 23620, 'Emilian.Lara.Baca@mailinator.com', '18/01/48', 26, NULL);
INSERT INTO usuaris VALUES (3429, 'Aniceto', 'Quiñones Ruelas', 'H', '72 Avda. Los llanos', 26311, 'Aniceto.Quinones.Ruelas@trashymail.com', '11/05/62', 53, 7);
INSERT INTO usuaris VALUES (3430, 'Saturio', 'Garibay Ávila', 'H', '40 Constitución', 37129, 'Saturio.Garibay.Avila@trashymail.com', '21/01/69', 62, 10);
INSERT INTO usuaris VALUES (3431, 'Inaxio', 'Farías Concepción', 'H', '72 San Andrés', 37249, 'Inaxio.Farias.Concepcion@dodgit.com', '24/09/76', 85, 2);
INSERT INTO usuaris VALUES (3432, 'Audrey', 'Lerma Aparicio', 'D', '41 C/ Angosto', 23540, 'Audrey.Lerma.Aparicio@mailinator.com', '17/04/63', 77, 5);
INSERT INTO usuaris VALUES (3433, 'Dejanira', 'Casas Gutiérrez', 'D', '44 Boriñaur enparantza', 7760, 'Dejanira.Casas.Gutierrez@dodgit.com', '11/03/77', 63, 5);
INSERT INTO usuaris VALUES (3434, 'Werner', 'Ramírez Ybarra', 'H', '38 Socampo', 37656, 'Werner.Ramirez.Ybarra@dodgit.com', '25/09/62', 11, 3);
INSERT INTO usuaris VALUES (3435, 'Olivia', 'Marín Romero', 'D', '68 C/ Eras', 28737, 'Olivia.Marin.Romero@trashymail.com', '02/03/82', 39, 8);
INSERT INTO usuaris VALUES (3436, 'Oriol', 'Gastelum Castaneda', 'H', '51 C/ Cañada del Rosal', 21590, 'Oriol.Gastelum.Castaneda@trashymail.com', '22/01/83', 8, 12);
INSERT INTO usuaris VALUES (3437, 'Angelo', 'Benavidez Baeza', 'H', '2 C/ Rosa de los Vientos', 11648, 'Angelo.Benavidez.Baeza@pookmail.com', '06/12/60', 42, 11);
INSERT INTO usuaris VALUES (3438, 'Pascualina', 'Urías Sierra', 'D', '67 Cádiz', 18470, 'Pascualina.Urias.Sierra@pookmail.com', '18/08/76', 77, 12);
INSERT INTO usuaris VALUES (3439, 'Espartaco', 'Gaytan Zelaya', 'H', '49 Bouciña', 43786, 'Espartaco.Gaytan.Zelaya@trashymail.com', '08/07/46', 56, 9);
INSERT INTO usuaris VALUES (3440, 'Cayo', 'Casanova Alcantar', NULL, '87 Lamas Carbajal', 41750, 'Cayo.Casanova.Alcantar@pookmail.com', '16/08/43', 49, 3);
INSERT INTO usuaris VALUES (3441, 'Isis', 'Lemus Ávalos', 'D', '37 Alcon Molina', 30850, 'Isis.Lemus.Avalos@mailinator.com', '24/01/54', 76, 11);
INSERT INTO usuaris VALUES (3442, 'Toshi', 'Adomo Henríquez', 'H', '49 Fuente del Gallo', 14930, 'Toshi.Adomo.Henriquez@spambob.com', '23/03/43', 87, 8);
INSERT INTO usuaris VALUES (3443, 'Filemón', 'Mayonga Olvera', 'H', '42 Antonio Vázquez', 38712, 'Filemon.Mayonga.Olvera@mailinator.com', '03/01/80', 40, 2);
INSERT INTO usuaris VALUES (3444, 'Juventina', 'Salcedo Duarte', 'D', '39 Atamaria', 36590, 'Juventina.Salcedo.Duarte@pookmail.com', '22/09/47', 89, 11);
INSERT INTO usuaris VALUES (3445, 'Arnulfo', 'Prado Nieves', 'H', '28 Crta. Cádiz-Málaga', 12222, 'Arnulfo.Prado.Nieves@dodgit.com', '23/09/67', 96, 5);
INSERT INTO usuaris VALUES (3446, 'Elisa', 'Montalvo Guevara', 'D', '50 C/ Cuevas de Ambrosio', 23770, 'Elisa.Montalvo.Guevara@pookmail.com', '15/11/74', 85, 8);
INSERT INTO usuaris VALUES (3447, 'Michelle', 'Navarro Lara', 'D', '34 Camiño Ancho', 37785, 'Michelle.Navarro.Lara@spambob.com', '29/10/46', 44, NULL);
INSERT INTO usuaris VALUES (3448, 'Marziabo', 'Laureano Alfaro', 'H', '8 Estrela', 39740, 'Marziabo.Laureano.Alfaro@spambob.com', '01/11/85', 42, 3);
INSERT INTO usuaris VALUES (3449, 'Laureana', 'Echevarría Posada', 'D', '45 Rúa do Paseo', 41880, 'Laureana.Echevarria.Posada@trashymail.com', '17/10/77', 34, 3);
INSERT INTO usuaris VALUES (3450, 'Mailin', 'Cadena Olvera', 'D', '99 Rúa de San Pedro', 37830, 'Mailin.Cadena.Olvera@spambob.com', '19/01/59', 19, 12);
INSERT INTO usuaris VALUES (3451, 'Argimiro', 'Carrasquill Arriaga', 'H', '40 Celso Emilio Ferreiro', 50290, 'Argimiro.Carrasquill.Arriaga@dodgit.com', '20/03/59', 46, 5);
INSERT INTO usuaris VALUES (3452, 'Alec', 'Negrón Baez', 'H', '88 Cádiz', 18512, 'Alec.Negron.Baez@trashymail.com', '06/11/74', 96, 7);
INSERT INTO usuaris VALUES (3453, 'Mariu', 'Leal Casárez', 'D', '10 Carretera', 14740, 'Mariu.Leal.Casarez@dodgit.com', '19/08/55', 28, 8);
INSERT INTO usuaris VALUES (3454, 'Clímene', 'Pelayo Valdez', 'H', '51 C/ Andalucía', 4600, 'Climene.Pelayo.Valdez@pookmail.com', '09/09/54', 51, 6);
INSERT INTO usuaris VALUES (3455, 'Shirly', 'Samaniego Alva', 'D', '93 C/ Benito Guinea', 8260, 'Shirly.Samaniego.Alva@dodgit.com', '15/05/71', 56, 12);
INSERT INTO usuaris VALUES (3456, 'Adena', 'Díaz Sepúlveda', 'D', '68 C/ Libertad', 5600, 'Adena.Diaz.Sepulveda@mailinator.com', '09/05/53', 82, 2);
INSERT INTO usuaris VALUES (3457, 'Bart', 'Velázquez Roque', 'H', '27 Cádiz', 18516, 'Bart.Velazquez.Roque@dodgit.com', '24/06/56', 28, 9);
INSERT INTO usuaris VALUES (3458, 'Veronique', 'Cabán Juárez', 'D', '40 Calvo Sotelo', 47600, 'Veronique.Caban.Juarez@dodgit.com', '14/05/57', 22, NULL);
INSERT INTO usuaris VALUES (3459, 'Kirian', 'Esquibel Olvera', 'H', '47 Rúa Olmos', 37319, 'Kirian.Esquibel.Olvera@pookmail.com', '09/02/78', 76, 10);
INSERT INTO usuaris VALUES (3460, 'Ottón', 'Guardado Pelayo', 'H', '92 Puerta Nueva', 36500, 'Otton.Guardado.Pelayo@spambob.com', '18/09/44', 61, NULL);
INSERT INTO usuaris VALUES (3461, 'Balduino', 'Hidalgo Lozano', 'H', '83 Carretera', 14620, 'Balduino.Hidalgo.Lozano@trashymail.com', '05/11/85', 30, 1);
INSERT INTO usuaris VALUES (3462, 'Natan', 'Villaseñor Rosas', 'H', '2 Comandante Izarduy', 8830, 'Natan.Villasenor.Rosas@pookmail.com', NULL, 12, 1);
INSERT INTO usuaris VALUES (3463, 'Adair', 'Alfaro Cepeda', 'H', '57 C/ Canarias', 20150, 'Adair.Alfaro.Cepeda@pookmail.com', '08/05/74', 7, 10);
INSERT INTO usuaris VALUES (3464, 'Cuyén', 'Alarcón Caballero', 'H', '8 C/ Angosto', 23477, 'Cuyen.Alarcon.Caballero@pookmail.com', '18/08/62', 76, 11);
INSERT INTO usuaris VALUES (3465, 'Ronan', 'Zambrano Abrego', 'H', '77 Ventanilla de Beas', 27773, 'Ronan.Zambrano.Abrego@spambob.com', '28/12/64', 63, 7);
INSERT INTO usuaris VALUES (3466, 'Publia', 'Roque Leiva', 'D', '3 Puerto Lugar', 29718, 'Publia.Roque.Leiva@spambob.com', '26/05/83', 77, 11);
INSERT INTO usuaris VALUES (3467, 'Alana', 'Apodaca Castro', 'D', '93 Herrería', 18191, 'Alana.Apodaca.Castro@spambob.com', '29/05/52', 5, 6);
INSERT INTO usuaris VALUES (3468, 'Beda', 'Cotto Rivas', 'H', '45 Enxertos', 37590, 'Beda.Cotto.Rivas@dodgit.com', '11/10/47', 89, 2);
INSERT INTO usuaris VALUES (3469, 'Esmirna', 'Leal Granado', 'D', '43 El Roqueo', 16630, 'Esmirna.Leal.Granado@spambob.com', '21/12/40', 76, 8);
INSERT INTO usuaris VALUES (3470, 'Noelino', 'Cervantes Lomeli', 'H', '12 Carretera del Muelle', 12410, 'Noelino.Cervantes.Lomeli@spambob.com', '25/05/56', 10, 9);
INSERT INTO usuaris VALUES (3471, 'Fidelia', 'Salinas Márquez', 'D', '43 Salzillo', 32630, 'Fidelia.Salinas.Marquez@pookmail.com', '23/04/58', 51, 1);
INSERT INTO usuaris VALUES (3472, 'Giunia', 'Mejía Casares', 'D', '98 Cruce Casa de Postas', 18311, 'Giunia.Mejia.Casares@trashymail.com', '06/07/59', 42, 10);
INSERT INTO usuaris VALUES (3473, 'Numas', 'Maestas Rubio', 'D', '44 Avda. Enrique Peinador', 37183, 'Numas.Maestas.Rubio@pookmail.com', '15/02/52', 75, 11);
INSERT INTO usuaris VALUES (3474, 'Glenda', 'Arellano Cepeda', 'D', '74 Plazuela do Porto', 37874, 'Glenda.Arellano.Cepeda@pookmail.com', '30/05/64', 33, 10);
INSERT INTO usuaris VALUES (3475, 'Evelina', 'Palacios Heredia', 'D', '41 La Fontanilla', 14410, 'Evelina.Palacios.Heredia@trashymail.com', '19/11/78', 26, 4);
INSERT INTO usuaris VALUES (3476, 'Melitona', 'Jaime Montés', 'D', '29 Avda. de la Estación', 28694, 'Melitona.Jaime.Montes@dodgit.com', '12/12/84', 10, 10);
INSERT INTO usuaris VALUES (3477, 'Adalbert', 'Chavarría Murillo', 'H', '50 Eusebio Dávila', 41388, 'Adalbert.Chavarria.Murillo@dodgit.com', '20/11/43', 3, 11);
INSERT INTO usuaris VALUES (3478, 'Amaya', 'Olivárez Padilla', 'D', '73 Ourense', 42360, 'Amaya.Olivarez.Padilla@spambob.com', '03/02/65', 3, 5);
INSERT INTO usuaris VALUES (3479, 'Dacia', 'Barraza Montano', 'D', '58 Ctra. de Fuentenueva', 28330, 'Dacia.Barraza.Montano@dodgit.com', '05/09/73', 85, 3);
INSERT INTO usuaris VALUES (3480, 'Abo', 'Martínez Salinas', 'H', '35 Quevedo', 15185, 'Abo.Martinez.Salinas@dodgit.com', '06/04/47', 9, 11);
INSERT INTO usuaris VALUES (3481, 'Ives', 'Gutiérrez Almonte', 'H', '86 Quevedo', 15400, 'Ives.Gutierrez.Almonte@pookmail.com', '08/11/46', 80, 7);
INSERT INTO usuaris VALUES (3482, 'Mary', 'Covas Zúñiga', 'D', '25 Inglaterra', 18612, 'Mary.Covas.Zuniga@spambob.com', '30/01/62', 56, 7);
INSERT INTO usuaris VALUES (3483, 'Ratrudis', 'Curiel Villaseñor', 'D', '79 C/ Amoladera', 28820, 'Ratrudis.Curiel.Villasenor@pookmail.com', '26/07/79', 44, 7);
INSERT INTO usuaris VALUES (3484, 'Etelvina', 'Guillén Terrazas', 'D', '38 Valadouro', 48150, 'Etelvina.Guillen.Terrazas@spambob.com', '08/12/61', 80, 2);
INSERT INTO usuaris VALUES (3485, 'Custodio', 'Maestas Nava', 'H', '30 Ctra. Villena', 34000, 'Custodio.Maestas.Nava@spambob.com', '22/08/63', 78, 7);
INSERT INTO usuaris VALUES (3486, 'Numa', 'Lerma Aguayo', 'D', '42 Urzáiz', 45300, 'Numa.Lerma.Aguayo@dodgit.com', '04/06/65', 87, 2);
INSERT INTO usuaris VALUES (3487, 'Giancarlo', 'Escobedo Maestas', 'H', '2 C/ Pablo Iglesias', 26330, 'Giancarlo.Escobedo.Maestas@spambob.com', '05/09/64', 37, 8);
INSERT INTO usuaris VALUES (3488, 'Melchior', 'Luna Saucedo', 'H', '16 Avda. de la Estación', 28580, 'Melchior.Luna.Saucedo@trashymail.com', '19/09/49', 52, 10);
INSERT INTO usuaris VALUES (3489, 'Onofre', 'Baeza Domínguez', 'H', '36 Rúa de San Pedro', 37840, 'Onofre.Baeza.Dominguez@trashymail.com', '16/08/70', 77, 11);
INSERT INTO usuaris VALUES (3490, 'Nicholas', 'Caballero Pichardo', 'H', '12 Rúa Olmos', 37320, 'Nicholas.Caballero.Pichardo@trashymail.com', '28/08/49', 70, 7);
INSERT INTO usuaris VALUES (3491, 'Cañumil', 'Franco Espinal', 'H', '5 Extramuros', 28390, 'Canumil.Franco.Espinal@mailinator.com', '08/01/83', 69, 12);
INSERT INTO usuaris VALUES (3492, 'Leoncia', 'Melgar Figueroa', 'D', '8 Bouciña', 43786, 'Leoncia.Melgar.Figueroa@pookmail.com', '02/06/54', 71, 1);
INSERT INTO usuaris VALUES (3493, 'Próspero', 'Tirado Aguilera', 'H', '78 San Andrés', 37310, 'Prospero.Tirado.Aguilera@spambob.com', '20/10/65', NULL, 6);
INSERT INTO usuaris VALUES (3494, 'Abby', 'Madera Vera', 'D', '16 Avenida Cervantes', 48310, 'Abby.Madera.Vera@trashymail.com', '04/05/76', 65, 5);
INSERT INTO usuaris VALUES (3495, 'Neftalí', 'Escobedo Ledesma', 'D', '65 C/ Domingo Beltrán', 2311, 'Neftali.Escobedo.Ledesma@pookmail.com', '01/08/49', 82, 6);
INSERT INTO usuaris VALUES (3496, 'Ticiano', 'Limón Nieves', 'H', '69 Cañadilla', 22300, 'Ticiano.Limon.Nieves@pookmail.com', '17/07/49', 50, 4);
INSERT INTO usuaris VALUES (3497, 'Elbio', 'Montanez Guardado', 'H', '53 C/ Pablo Iglesias', 26325, 'Elbio.Montanez.Guardado@dodgit.com', '20/10/72', 20, 3);
INSERT INTO usuaris VALUES (3498, 'Amaya', 'Barreto Murillo', 'D', '24 Ctra. Bailén-Motril', 23266, 'Amaya.Barreto.Murillo@pookmail.com', '08/10/56', 63, 1);
INSERT INTO usuaris VALUES (3499, 'Ulla', 'Luján Rivas', 'D', '37 C/ Rosa de los Vientos', 11350, 'Ulla.Lujan.Rivas@trashymail.com', '24/06/81', 6, 8);
INSERT INTO usuaris VALUES (3500, 'Argento', 'Corona Chávez', 'H', '36 Estrela', 39000, 'Argento.Corona.Chavez@pookmail.com', '08/09/77', 71, 1);
INSERT INTO usuaris VALUES (3501, 'Pirra', 'Robles Colunga', 'D', '31 Calvo Sotelo', 47195, 'Pirra.Robles.Colunga@spambob.com', '14/07/56', 84, 5);
INSERT INTO usuaris VALUES (3502, 'Ornella', 'Robles Santillán', NULL, '79 C/ Los Herrán', 6450, 'Ornella.Robles.Santillan@dodgit.com', '26/02/74', 39, 7);
INSERT INTO usuaris VALUES (3503, 'Priscila', 'Angulo Loera', 'D', '75 Paraguay', 3668, 'Priscila.Angulo.Loera@dodgit.com', '19/06/62', 87, 5);
INSERT INTO usuaris VALUES (3504, 'Alem', 'Vasquez Madrigal', 'H', '95 Cartagena', 30611, 'Alem.Vasquez.Madrigal@dodgit.com', '04/07/56', 16, 6);
INSERT INTO usuaris VALUES (3505, 'Georgina', 'Espinosa Merino', 'D', '29 Bellavista', 50180, 'Georgina.Espinosa.Merino@spambob.com', '27/09/63', 8, 8);
INSERT INTO usuaris VALUES (3506, 'Eladia', 'Madera Serna', 'D', '44 Ctra. Beas-Cortijos Nuevos', 26370, 'Eladia.Madera.Serna@pookmail.com', '15/01/44', 5, 8);
INSERT INTO usuaris VALUES (3507, 'Taciano', 'Mota Vera', 'H', '72 C/ Cuesta del  Álamo', 29492, 'Taciano.Mota.Vera@dodgit.com', '03/09/55', 37, 10);
INSERT INTO usuaris VALUES (3508, 'Cornelio', 'Peres Casares', 'H', '25 Avda. Explanada Barnuevo', 35300, 'Cornelio.Peres.Casares@mailinator.com', '13/07/46', 38, 2);
INSERT INTO usuaris VALUES (3509, 'Absalón', 'Galvez Urrútia', 'H', '9 Ctra. de la Puerta', 26587, 'Absalon.Galvez.Urrutia@mailinator.com', '07/12/58', 42, 8);
INSERT INTO usuaris VALUES (3510, 'Engracia', 'Pedraza Olivárez', 'D', '32 San Andrés', 37257, 'Engracia.Pedraza.Olivarez@dodgit.com', '25/01/62', 66, 12);
INSERT INTO usuaris VALUES (3511, 'Petruos', 'Saenz Lemus', 'H', '97 Apartado de Correos', 37439, 'Petruos.Saenz.Lemus@pookmail.com', '21/09/40', 61, 11);
INSERT INTO usuaris VALUES (3512, 'Amarilia', 'Velázquez Fonseca', 'D', '64 Canónigo Valiño', 46290, 'Amarilia.Velazquez.Fonseca@spambob.com', '27/09/77', 4, 6);
INSERT INTO usuaris VALUES (3513, 'Clío', 'Verduzco Lugo', 'D', '12 C/ Los Herrán', 6810, 'Clio.Verduzco.Lugo@dodgit.com', '24/05/79', 39, NULL);
INSERT INTO usuaris VALUES (3514, 'Adelmo', 'Bustos Godínez', 'H', '84 Pl. Virgen Blanca', 8500, 'Adelmo.Bustos.Godinez@trashymail.com', '20/12/82', 80, 1);
INSERT INTO usuaris VALUES (3515, 'Mar', 'Guzmán Segovia', 'D', '76 Enxertos', 37516, 'Mar.Guzman.Segovia@mailinator.com', '03/01/48', 29, 9);
INSERT INTO usuaris VALUES (3516, 'Claribel', 'López Uribe', 'D', '65 Calle Aduana', 1118, 'Claribel.Lopez.Uribe@pookmail.com', '11/10/66', 78, 12);
INSERT INTO usuaris VALUES (3517, 'Cecilio', 'Corral Anaya', 'H', '37 Av. Santiago Lapuente', 50780, 'Cecilio.Corral.Anaya@dodgit.com', '21/04/64', 56, 8);
INSERT INTO usuaris VALUES (3518, 'Adulfo', 'Velásquez Palomino', 'H', '39 Alcon Molina', 31195, 'Adulfo.Velasquez.Palomino@spambob.com', '20/01/77', 68, 11);
INSERT INTO usuaris VALUES (3519, 'Elpidia', 'Najera Valdez', 'D', '90 Bouciña', 43830, 'Elpidia.Najera.Valdez@dodgit.com', '12/08/57', 62, 5);
INSERT INTO usuaris VALUES (3520, 'Gualterio', 'Ríos Toro', 'H', '63 Estrela', 39500, 'Gualterio.Rios.Toro@mailinator.com', '07/02/71', 77, 3);
INSERT INTO usuaris VALUES (3521, 'Partenia', 'Rolón Rosario', 'D', '45 Ctra. Hornos', 26226, 'Partenia.Rolon.Rosario@trashymail.com', '30/04/85', 45, 5);
INSERT INTO usuaris VALUES (3522, 'Damia', 'Cadena Zayas', 'D', '14 C/ Angosto', 23392, 'Damia.Cadena.Zayas@pookmail.com', '07/09/55', 2, 6);
INSERT INTO usuaris VALUES (3523, 'Crisólogo', 'Miranda Varela', 'H', '2 Quevedo', 15189, 'Crisologo.Miranda.Varela@spambob.com', '17/12/68', 75, 12);
INSERT INTO usuaris VALUES (3524, 'Ilanit', 'Carreón Alejandro', 'D', '44 Av. Zumalakarregi', 3170, 'Ilanit.Carreon.Alejandro@pookmail.com', '28/07/53', 52, 5);
INSERT INTO usuaris VALUES (3525, 'Sophe', 'Maestas Alvarez', 'D', '85 Pza. Fuensanta', 32456, 'Sophe.Maestas.Alvarez@mailinator.com', '24/05/42', 44, 11);
INSERT INTO usuaris VALUES (3526, 'Giancarla', 'Beltrán Solano', 'D', '62 C/ Amoladera', 28813, 'Giancarla.Beltran.Solano@mailinator.com', '17/12/70', 20, 5);
INSERT INTO usuaris VALUES (3527, 'Bautista', 'Agosto Munguia', 'H', '56 Caño', 32824, 'Bautista.Agosto.Munguia@spambob.com', '25/03/72', 25, 8);
INSERT INTO usuaris VALUES (3528, 'Suyai', 'Valdez Mondragón', 'H', '86 Calle Carril de la Fuente', 13179, 'Suyai.Valdez.Mondragon@spambob.com', '05/01/70', 8, 3);
INSERT INTO usuaris VALUES (3529, 'Andrés', 'Lara Cadena', 'H', '95 C/ Rosa de los Vientos', 11200, 'Andres.Lara.Cadena@dodgit.com', '28/12/54', 79, 12);
INSERT INTO usuaris VALUES (3530, 'Morris', 'Callas Velásquez', 'H', '30 Maestro Puig Valera', 33686, 'Morris.Callas.Velasquez@mailinator.com', '24/02/80', 84, 5);
INSERT INTO usuaris VALUES (3531, 'Alanis', 'Fajardo Sotelo', 'H', '51 C/ Henan Cortes', 29180, 'Alanis.Fajardo.Sotelo@mailinator.com', '18/03/65', 66, 11);
INSERT INTO usuaris VALUES (3532, 'Antígona', 'Aguayo Regalado', 'D', '68 C/ Andalucía', 4610, 'Antigona.Aguayo.Regalado@trashymail.com', '09/11/83', 65, 2);
INSERT INTO usuaris VALUES (3533, 'Dédalo', 'Quiroz Alaniz', 'H', '5 C/ Angosto', 23591, 'Dedalo.Quiroz.Alaniz@mailinator.com', '05/11/70', 76, 3);
INSERT INTO usuaris VALUES (3534, 'Isachar', 'Gómez Lira', 'H', '30 Atamaria', 36660, 'Isachar.Gomez.Lira@dodgit.com', '15/02/82', 24, 3);
INSERT INTO usuaris VALUES (3535, 'Jean', 'Colunga Gamboa', 'H', '80 Calvo Sotelo', 47270, 'Jean.Colunga.Gamboa@spambob.com', '05/07/77', 81, 11);
INSERT INTO usuaris VALUES (3536, 'Zite', 'Gastelum Concepción', NULL, '40 Plaza de España', 15808, 'Zite.Gastelum.Concepcion@trashymail.com', '12/04/74', 96, 1);
INSERT INTO usuaris VALUES (3537, 'Noel', 'Arreola Vera', 'D', '99 Pza. Fuensanta', 32455, 'Noel.Arreola.Vera@spambob.com', '10/11/56', 41, 8);
INSERT INTO usuaris VALUES (3538, 'Lisardo', 'Almaraz Ponce', 'H', '87 C/ Cañada del Rosal', 21560, 'Lisardo.Almaraz.Ponce@trashymail.com', '23/07/82', 38, 10);
INSERT INTO usuaris VALUES (3539, 'Habrilia', 'Cardona Gil', 'D', '28 Atamaria', 36870, 'Habrilia.Cardona.Gil@pookmail.com', '04/09/55', 45, 6);
INSERT INTO usuaris VALUES (3540, 'Melani', 'Urena González', 'D', '39 Outid de Arriba', 43530, 'Melani.Urena.Gonzalez@mailinator.com', '03/11/74', 18, NULL);
INSERT INTO usuaris VALUES (3541, 'Leo', 'Mireles Cruz', 'H', '90 Avda. Andalucía', 26134, 'Leo.Mireles.Cruz@mailinator.com', '12/07/57', 88, 3);
INSERT INTO usuaris VALUES (3542, 'Cecilia', 'Escamilla Castro', 'D', '59 Avda. de Andalucía', 29370, 'Cecilia.Escamilla.Castro@spambob.com', '15/11/45', 63, 12);
INSERT INTO usuaris VALUES (3543, 'Cuyen', 'González Escamilla', 'D', '76 Rua da Rapina', 37485, 'Cuyen.Gonzalez.Escamilla@trashymail.com', '29/04/76', 73, 11);
INSERT INTO usuaris VALUES (3544, 'Marc', 'Abeyta Puga', 'H', '56 C/ Canarias', 20100, 'Marc.Abeyta.Puga@spambob.com', '18/06/81', 2, 6);
INSERT INTO usuaris VALUES (3545, 'Noel', 'Olivas Polanco', 'D', '9 José matía', 1426, 'Noel.Olivas.Polanco@trashymail.com', '05/10/84', 81, 11);
INSERT INTO usuaris VALUES (3546, 'Matteo', 'Zamudio Razo', 'H', '30 Cartagena', 30320, 'Matteo.Zamudio.Razo@mailinator.com', '07/03/69', 39, NULL);
INSERT INTO usuaris VALUES (3547, 'Atanasio', 'Samaniego Nieto', 'H', '28 Av. Zumalakarregi', 3179, 'Atanasio.Samaniego.Nieto@trashymail.com', '21/01/74', 82, 4);
INSERT INTO usuaris VALUES (3548, 'Anaxagoras', 'Zúñiga Partida', 'H', '30 Socampo', 37621, 'Anaxagoras.Zuniga.Partida@mailinator.com', '30/08/47', 96, 11);
INSERT INTO usuaris VALUES (3549, 'Ilve', 'Olivárez Covas', 'D', '30 C/ Cuevas de Ambrosio', 23711, 'Ilve.Olivarez.Covas@pookmail.com', '16/10/40', 75, 9);
INSERT INTO usuaris VALUES (3550, 'Aron', 'Marroquín Peres', 'H', '7 Constitución', 36880, 'Aron.Marroquin.Peres@spambob.com', '22/11/79', 34, 10);
INSERT INTO usuaris VALUES (3551, 'Anahid', 'Cadena Beltrán', NULL, '25 Pl. Virgen Blanca', 8530, 'Anahid.Cadena.Beltran@mailinator.com', '13/10/46', 43, 6);
INSERT INTO usuaris VALUES (3552, 'Elí', 'Domínguez Roybal', 'D', '90 Pascual Yunquera', 18659, 'Eli.Dominguez.Roybal@trashymail.com', '05/01/62', 48, 1);
INSERT INTO usuaris VALUES (3553, 'Norberta', 'Cordero Cortés', 'D', '85 Pza. Fuensanta', 32411, 'Norberta.Cordero.Cortes@spambob.com', '16/06/84', 42, 12);
INSERT INTO usuaris VALUES (3554, 'Auristela', 'Melgar Segura', 'D', '67 Socampo', 37638, 'Auristela.Melgar.Segura@pookmail.com', '13/02/76', 37, 2);
INSERT INTO usuaris VALUES (3555, 'Vladimir', 'Arenas Macías', 'H', '79 El Roqueo', 16000, 'Vladimir.Arenas.Macias@spambob.com', '30/01/64', 85, 8);
INSERT INTO usuaris VALUES (3556, 'Senan', 'Ojeda Hernandes', 'H', '64 C/ Pablo Iglesias', 26350, 'Senan.Ojeda.Hernandes@pookmail.com', '07/05/73', 44, 4);
INSERT INTO usuaris VALUES (3557, 'Herminda', 'Aponte Alejandro', 'D', '19 Avda. de Andalucía', 29380, 'Herminda.Aponte.Alejandro@pookmail.com', '18/09/63', 82, 9);
INSERT INTO usuaris VALUES (3558, 'Elal', 'Figueroa Varela', 'D', '13 Avenida Cervantes', 48311, 'Elal.Figueroa.Varela@mailinator.com', '28/02/80', 47, 7);
INSERT INTO usuaris VALUES (3559, 'Heloísa', 'Tirado Villanueva', 'D', '83 Avda. Explanada Barnuevo', 35360, 'Heloisa.Tirado.Villanueva@trashymail.com', '26/04/78', 93, 2);
INSERT INTO usuaris VALUES (3560, 'Baldovino', 'Domínguez Rojo', 'H', '17 Plaza Maior', 37217, 'Baldovino.Dominguez.Rojo@trashymail.com', '08/01/61', 17, 6);
INSERT INTO usuaris VALUES (3561, 'Fermín', 'Borrego Rosario', 'H', '45 Rúa Olmos', 37350, 'Fermin.Borrego.Rosario@pookmail.com', '17/02/78', 14, 6);
INSERT INTO usuaris VALUES (3562, 'Fabricia', 'Ceballos Rendón', NULL, '20 Paraguay', 3638, 'Fabricia.Ceballos.Rendon@spambob.com', '23/03/60', 20, NULL);
INSERT INTO usuaris VALUES (3563, 'Fulk', 'Alejandro Toledo', 'H', '29 Avda. Los llanos', 26257, 'Fulk.Alejandro.Toledo@spambob.com', '16/01/82', 96, 5);
INSERT INTO usuaris VALUES (3564, 'Maricel', 'Valdés Carrillo', 'D', '39 Enxertos', 37522, 'Maricel.Valdes.Carrillo@pookmail.com', '14/02/41', 78, 9);
INSERT INTO usuaris VALUES (3565, 'Leonel', 'Pedroza Llarnas', 'H', '32 C/ Hijuela de Lojo', 20260, 'Leonel.Pedroza.Llarnas@dodgit.com', '28/09/84', 8, 6);
INSERT INTO usuaris VALUES (3566, 'Cala', 'Betancourt Casas', 'D', '86 C/ Fernández de Leceta', 3380, 'Cala.Betancourt.Casas@mailinator.com', '22/08/42', 15, 2);
INSERT INTO usuaris VALUES (3567, 'Koko', 'Fajardo Velázquez', 'H', '60 Eusebio Dávila', 41388, 'Koko.Fajardo.Velazquez@spambob.com', '15/03/57', 17, 3);
INSERT INTO usuaris VALUES (3568, 'Toni', 'Flores Tijerina', 'H', '93 Avda. Andalucía', 26134, 'Toni.Flores.Tijerina@dodgit.com', '07/05/57', 4, 8);
INSERT INTO usuaris VALUES (3569, 'Ageo', 'Alva Zepeda', 'H', '48 Enxertos', 37515, 'Ageo.Alva.Zepeda@mailinator.com', '16/03/64', 39, 4);
INSERT INTO usuaris VALUES (3570, 'Alissa', 'Otero Aguayo', 'D', '40 C/ Amoladera', 28770, 'Alissa.Otero.Aguayo@dodgit.com', '16/08/63', 79, 7);
INSERT INTO usuaris VALUES (3571, 'Egidio', 'Sánchez Rodrígez', 'H', '94 Cádiz', 18518, 'Egidio.Sanchez.Rodrigez@trashymail.com', '30/01/59', 29, 9);
INSERT INTO usuaris VALUES (3572, 'Floriana', 'Zelaya Burgos', 'D', '80 Camiño Real', 48630, 'Floriana.Zelaya.Burgos@pookmail.com', '19/10/68', 17, 10);
INSERT INTO usuaris VALUES (3573, 'Arapey', 'Borrego Godoy', 'H', '89 Cruce Casa de Postas', 18330, 'Arapey.Borrego.Godoy@spambob.com', '20/12/71', 48, 1);
INSERT INTO usuaris VALUES (3574, 'Plinio', 'Figueroa Trujillo', 'H', '85 Pza. Fuensanta', 32356, 'Plinio.Figueroa.Trujillo@trashymail.com', '25/02/42', 82, 12);
INSERT INTO usuaris VALUES (3575, 'Ursulina', 'Nieves Venegas', 'D', '93 Ctra. de Fuentenueva', 28194, 'Ursulina.Nieves.Venegas@spambob.com', '05/10/43', 65, 4);
INSERT INTO usuaris VALUES (3576, 'Achill', 'Moreno Armas', 'H', '76 Salzillo', 32616, 'Achill.Moreno.Armas@spambob.com', '21/06/76', 40, 10);
INSERT INTO usuaris VALUES (3577, 'Mila', 'Crespo Callas', 'D', '19 José matía', 2152, 'Mila.Crespo.Callas@dodgit.com', '31/07/74', 69, 4);
INSERT INTO usuaris VALUES (3578, 'Nominanda', 'Osorio Montero', 'D', '65 Rúa Olmos', 37337, 'Nominanda.Osorio.Montero@pookmail.com', '22/01/77', 17, 7);
INSERT INTO usuaris VALUES (3579, 'Kapriel', 'Longoria Casárez', 'D', '62 Carretera del Muelle', 12410, 'Kapriel.Longoria.Casarez@mailinator.com', '30/10/54', 78, 8);
INSERT INTO usuaris VALUES (3580, 'Grisel', 'Montoya Montano', 'D', '95 Ventanilla de Beas', 28110, 'Grisel.Montoya.Montano@spambob.com', '05/03/54', 72, 7);
INSERT INTO usuaris VALUES (3581, 'Sean', 'Ocampo Pantoja', 'H', '41 Paseo Junquera', 12526, 'Sean.Ocampo.Pantoja@trashymail.com', '15/02/53', 94, 10);
INSERT INTO usuaris VALUES (3582, 'Omer', 'Heredia Pagan', 'H', '28 Reiseñor', 45710, 'Omer.Heredia.Pagan@spambob.com', '04/08/53', 81, 6);
INSERT INTO usuaris VALUES (3583, 'Curcio', 'Villaseñor Heredia', 'H', '10 Caño', 33120, 'Curcio.Villasenor.Heredia@mailinator.com', '04/06/72', 89, 11);
INSERT INTO usuaris VALUES (3584, 'Candy', 'Herrera Quiñónez', 'D', '67 Camiño Real', 48498, 'Candy.Herrera.Quinonez@trashymail.com', '11/08/44', 89, 11);
INSERT INTO usuaris VALUES (3585, 'Sagar', 'Toledo Baeza', 'H', '21 Plazuela do Porto', 37882, 'Sagar.Toledo.Baeza@mailinator.com', '25/02/54', 81, 1);
INSERT INTO usuaris VALUES (3586, 'Gastón', 'Mercado Saucedo', 'H', '96 C/ Hijuela de Lojo', 20491, 'Gaston.Mercado.Saucedo@dodgit.com', '28/03/47', 84, 3);
INSERT INTO usuaris VALUES (3587, 'Aucan', 'Espinoza Sierra', 'D', '85 Avda. Alameda Sundheim', 22430, 'Aucan.Espinoza.Sierra@mailinator.com', '16/03/47', 32, 12);
INSERT INTO usuaris VALUES (3588, 'Livino', 'Malave Valdés', 'H', '59 Pza. Fuensanta', 32420, 'Livino.Malave.Valdes@trashymail.com', '25/04/43', 43, 2);
INSERT INTO usuaris VALUES (3589, 'Crispina', 'Arroyo Toledo', 'D', '33 Ctra. Villena', 34310, 'Crispina.Arroyo.Toledo@trashymail.com', '08/08/72', 13, 4);
INSERT INTO usuaris VALUES (3590, 'Marilina', 'Perea Santana', 'D', '21 Ventanilla de Beas', 27740, 'Marilina.Perea.Santana@spambob.com', '23/10/80', 76, 11);
INSERT INTO usuaris VALUES (3591, 'Ludwig', 'Luján Díaz', 'H', '30 Rua da Rapina', 37486, 'Ludwig.Lujan.Diaz@pookmail.com', '13/07/43', 92, 6);
INSERT INTO usuaris VALUES (3592, 'Nicéforo', 'Gastelum Esquivel', 'H', '65 C/ Eras', 28738, 'Niceforo.Gastelum.Esquivel@pookmail.com', '25/03/81', 19, 8);
INSERT INTO usuaris VALUES (3593, 'Evodia', 'Laureano Villaseñor', 'D', '80 Alvaro Cunqueiro', 40200, 'Evodia.Laureano.Villasenor@pookmail.com', '03/01/45', 16, 2);
INSERT INTO usuaris VALUES (3594, 'Zelmira', 'Montero Lara', 'D', '32 C/ Canarias', 20214, 'Zelmira.Montero.Lara@spambob.com', '03/10/65', 71, 2);
INSERT INTO usuaris VALUES (3595, 'Nicholas', 'Corona Pena', 'H', '9 C/ Manuel Iradier', 3811, 'Nicholas.Corona.Pena@mailinator.com', '23/11/47', 74, 11);
INSERT INTO usuaris VALUES (3596, 'Leonard', 'Villanueva Suárez', 'H', '70 Padre Caro', 13600, 'Leonard.Villanueva.Suarez@dodgit.com', '09/11/63', 98, 7);
INSERT INTO usuaris VALUES (3597, 'Maira', 'Zamora Nava', 'D', '80 Rúa Olmos', 37317, 'Maira.Zamora.Nava@trashymail.com', '05/02/55', 69, 9);
INSERT INTO usuaris VALUES (3598, 'Solana', 'Guevara Tijerina', 'D', '29 Urzáiz', 45470, 'Solana.Guevara.Tijerina@trashymail.com', '01/05/77', 62, 7);
INSERT INTO usuaris VALUES (3599, 'Amérigo', 'Mateo Ozuna', 'H', '81 Avda. Enrique Peinador', 37180, 'Amerigo.Mateo.Ozuna@mailinator.com', '05/10/46', 31, 10);
INSERT INTO usuaris VALUES (3600, 'Domitila', 'Otero Osorio', 'D', '30 C/ Cuesta del  Álamo', 29470, 'Domitila.Otero.Osorio@pookmail.com', '14/06/75', 78, 5);
INSERT INTO usuaris VALUES (3601, 'Jerry', 'Ruiz Casares', 'H', '14 Rúa Olmos', 37337, 'Jerry.Ruiz.Casares@pookmail.com', '26/04/69', 20, 11);
INSERT INTO usuaris VALUES (3602, 'Astor', 'Amador Palacios', 'H', '83 C/ Manuel Iradier', 3812, 'Astor.Amador.Palacios@mailinator.com', '21/03/48', 70, NULL);
INSERT INTO usuaris VALUES (3603, 'Exaltación', 'Quiñones Guillén', NULL, '35 C/ Cañada del Rosal', 21550, 'Exaltacion.Quinones.Guillen@trashymail.com', '31/10/82', 19, 7);
INSERT INTO usuaris VALUES (3604, 'Birgitta', 'Zelaya Berrios', 'D', '82 C/ Manuel Iradier', 3794, 'Birgitta.Zelaya.Berrios@spambob.com', '14/04/53', 4, 12);
INSERT INTO usuaris VALUES (3605, 'Nayra', 'Lomeli Sotelo', 'D', '90 José matía', 2124, 'Nayra.Lomeli.Sotelo@pookmail.com', '25/10/42', 4, 3);
INSERT INTO usuaris VALUES (3606, 'Niranjana', 'Feliciano Pedroza', 'D', '70 Paseo del Atlántico', 17257, 'Niranjana.Feliciano.Pedroza@dodgit.com', '13/12/82', 52, NULL);
INSERT INTO usuaris VALUES (3607, 'Onelia', 'Menchaca Casares', 'D', '33 Ctra. Bailén-Motril', 23260, 'Onelia.Menchaca.Casares@spambob.com', '04/08/81', 66, 6);
INSERT INTO usuaris VALUES (3608, 'Manzur', 'Tamayo Mares', 'H', '97 Avda. Los llanos', 26228, 'Manzur.Tamayo.Mares@trashymail.com', '01/06/76', 21, 8);
INSERT INTO usuaris VALUES (3609, 'Giancarla', 'Chacón Garica', 'D', '5 Avda. Explanada Barnuevo', 35530, 'Giancarla.Chacon.Garica@spambob.com', '06/12/68', 50, 9);
INSERT INTO usuaris VALUES (3610, 'Edelma', 'Vigil Mateo', 'D', '19 Bellavista', 50100, 'Edelma.Vigil.Mateo@dodgit.com', '01/10/69', 93, 1);
INSERT INTO usuaris VALUES (3611, 'Sotero', 'Melgar Garza', 'H', '2 Reyes Católicos', 10900, 'Sotero.Melgar.Garza@spambob.com', '16/05/70', 90, 7);
INSERT INTO usuaris VALUES (3612, 'Juventino', 'Archuleta Cuellar', NULL, '78 Rosa de los Vientos', 13427, 'Juventino.Archuleta.Cuellar@pookmail.com', '04/09/67', 60, 11);
INSERT INTO usuaris VALUES (3613, 'Clodomiro', 'Quezada Garica', 'H', '51 Prolongacion San Sebastian', 21350, 'Clodomiro.Quezada.Garica@spambob.com', '06/09/65', 53, 10);
INSERT INTO usuaris VALUES (3614, 'Genara', 'Ornelas Domínguez', 'D', '41 Carretera Cádiz-Málaga', 20808, 'Genara.Ornelas.Dominguez@spambob.com', '06/01/45', 70, 7);
INSERT INTO usuaris VALUES (3615, 'Manfredo', 'Camacho Ocasio', 'H', '6 C/ Eras', 28755, 'Manfredo.Camacho.Ocasio@dodgit.com', '07/08/65', 98, 8);
INSERT INTO usuaris VALUES (3616, 'Nazaret', 'Muñoz Zamora', 'H', '20 Enxertos', 37516, 'Nazaret.Munoz.Zamora@dodgit.com', '24/07/79', 58, NULL);
INSERT INTO usuaris VALUES (3617, 'Amalio', 'Cabán Sierra', 'H', '26 Rosa de los Vientos', 13370, 'Amalio.Caban.Sierra@pookmail.com', '28/09/79', 34, 11);
INSERT INTO usuaris VALUES (3618, 'Tarcila', 'Beltrán Arce', 'D', '33 Padre Caro', 13630, 'Tarcila.Beltran.Arce@pookmail.com', '09/09/68', 32, 2);
INSERT INTO usuaris VALUES (3619, 'Catrian', 'Macías Olivárez', 'H', '24 Outid de Arriba', 43700, 'Catrian.Macias.Olivarez@pookmail.com', '24/04/77', 45, 5);
INSERT INTO usuaris VALUES (3620, 'Martino', 'Anaya Tapia', 'H', '26 Bouciña', 43894, 'Martino.Anaya.Tapia@trashymail.com', '09/07/61', 70, 9);
INSERT INTO usuaris VALUES (3621, 'Ivan', 'Marcos Cervántez', 'H', '24 Plazuela do Porto', 37900, 'Ivan.Marcos.Cervantez@pookmail.com', '04/05/62', 72, 7);
INSERT INTO usuaris VALUES (3622, 'Eyén', 'Santana Alba', 'D', '18 Calle Proc. San Sebastián', 13114, 'Eyen.Santana.Alba@pookmail.com', '06/10/42', 1, 12);
INSERT INTO usuaris VALUES (3623, 'Yrko', 'Longoria Fuentes', 'H', '23 Valadouro', 48114, 'Yrko.Longoria.Fuentes@spambob.com', '04/06/79', 94, 10);
INSERT INTO usuaris VALUES (3624, 'Elda', 'Guevara Crespo', 'D', '37 Plaza Maior', 37193, 'Elda.Guevara.Crespo@pookmail.com', '08/08/66', 19, 9);
INSERT INTO usuaris VALUES (3625, 'Jezabel', 'Peres Orellana', 'D', '55 C/ Pablo Iglesias', 26315, 'Jezabel.Peres.Orellana@dodgit.com', '10/08/72', 89, 1);
INSERT INTO usuaris VALUES (3626, 'Alfonsa', 'Pacheco Cotto', 'D', '45 Extramuros', 28450, 'Alfonsa.Pacheco.Cotto@mailinator.com', '03/08/53', 61, 2);
INSERT INTO usuaris VALUES (3627, 'Eliezer', 'Madrid Vázquez', 'H', '71 Calle Proc. San Sebastián', 13117, 'Eliezer.Madrid.Vazquez@mailinator.com', '29/07/83', 1, 1);
INSERT INTO usuaris VALUES (3628, 'Gail', 'Fuentes Colón', NULL, '88 El Roqueo', 17190, 'Gail.Fuentes.Colon@spambob.com', '05/06/62', 29, 7);
INSERT INTO usuaris VALUES (3629, 'Gladys', 'Carrera Armijo', 'D', '85 Rio Segura', 31320, 'Gladys.Carrera.Armijo@trashymail.com', '17/03/77', 17, 7);
INSERT INTO usuaris VALUES (3630, 'Spiro', 'Marrero Barragán', 'H', '4 Ctra. Villena', 33900, 'Spiro.Marrero.Barragan@spambob.com', '07/04/81', 56, 5);
INSERT INTO usuaris VALUES (3631, 'Ilva', 'Vanegas Amador', 'D', '99 Avda. de la Estación', 28595, 'Ilva.Vanegas.Amador@trashymail.com', '20/01/53', 88, 7);
INSERT INTO usuaris VALUES (3632, 'Inalén', 'Terrazas Corrales', 'D', '39 Reiseñor', 46120, 'Inalen.Terrazas.Corrales@dodgit.com', '12/01/52', 98, 3);
INSERT INTO usuaris VALUES (3633, 'Lucila', 'Ceballos Ruvalcaba', 'D', '2 Avda. Explanada Barnuevo', 35470, 'Lucila.Ceballos.Ruvalcaba@pookmail.com', '28/04/77', 85, 1);
INSERT INTO usuaris VALUES (3634, 'Lorenza', 'Arreola Solórzano', 'D', '98 Calle Proc. San Sebastián', 12596, 'Lorenza.Arreola.Solorzano@spambob.com', '07/04/50', 24, 2);
INSERT INTO usuaris VALUES (3635, 'Francesca', 'Feliciano Benavides', 'D', '7 Puerta Nueva', 36000, 'Francesca.Feliciano.Benavides@pookmail.com', '17/04/84', 85, 12);
INSERT INTO usuaris VALUES (3636, 'Maximino', 'Terán Betancourt', 'H', '87 La Fontanilla', 14410, 'Maximino.Teran.Betancourt@dodgit.com', '04/07/46', 85, 12);
INSERT INTO usuaris VALUES (3637, 'Sadoc', 'Vargas Nevarez', 'H', '36 Boriñaur enparantza', 7749, 'Sadoc.Vargas.Nevarez@pookmail.com', '07/04/70', 33, 1);
INSERT INTO usuaris VALUES (3638, 'Otilia', 'Loera Barrios', 'D', '52 Apartado de Correos', 37420, 'Otilia.Loera.Barrios@trashymail.com', '31/12/65', 78, 12);
INSERT INTO usuaris VALUES (3639, 'Rosicler', 'Serna Girón', NULL, '67 Avda. Andalucía', 26133, 'Rosicler.Serna.Giron@pookmail.com', '10/09/85', 15, 3);
INSERT INTO usuaris VALUES (3640, 'Joseph', 'Treviño Alcalá', 'H', '24 Rúa de San Pedro', 37820, 'Joseph.Trevino.Alcala@trashymail.com', '07/02/55', 21, 6);
INSERT INTO usuaris VALUES (3641, 'Pirro', 'Caballero Centeno', 'H', '32 C/ Pablo Iglesias', 26321, 'Pirro.Caballero.Centeno@mailinator.com', '26/10/64', 82, 10);
INSERT INTO usuaris VALUES (3642, 'Abner', 'Carrillo Gurule', 'H', '72 Ventanilla de Beas', 27860, 'Abner.Carrillo.Gurule@pookmail.com', '01/03/80', 35, 9);
INSERT INTO usuaris VALUES (3643, 'Ezequías', 'Negrón Madrigal', 'H', '47 Rúa Olmos', 37400, 'Ezequias.Negron.Madrigal@spambob.com', '11/01/54', 69, 1);
INSERT INTO usuaris VALUES (3644, 'Aron', 'Romo Alarcón', 'H', '81 C/ Manuel Iradier', 3789, 'Aron.Romo.Alarcon@trashymail.com', '06/05/79', 37, 3);
INSERT INTO usuaris VALUES (3645, 'Geraldo', 'Pizarro Caraballo', 'H', '74 Visitación de la Encina', 37727, 'Geraldo.Pizarro.Caraballo@trashymail.com', '28/10/40', 0, 6);
INSERT INTO usuaris VALUES (3646, 'Pío', 'Varela Loya', 'H', '64 Avda. Rio Nalon', 33180, 'Pio.Varela.Loya@dodgit.com', '21/02/49', 5, 7);
INSERT INTO usuaris VALUES (3647, 'Primitiva', 'Segovia Abeyta', 'D', '62 Alvaro Cunqueiro', 40480, 'Primitiva.Segovia.Abeyta@dodgit.com', '02/03/47', 35, 11);
INSERT INTO usuaris VALUES (3648, 'Lalita', 'Archuleta Archuleta', 'D', '23 Puerta Nueva', 35630, 'Lalita.Archuleta.Archuleta@dodgit.com', '11/08/52', NULL, 11);
INSERT INTO usuaris VALUES (3649, 'Zara', 'Zapata Montemayor', 'D', '57 C/ Cuevas de Ambrosio', 24193, 'Zara.Zapata.Montemayor@pookmail.com', '11/08/48', 62, 3);
INSERT INTO usuaris VALUES (3650, 'Jenifer', 'Malave Santana', 'D', '8 Valadouro', 48100, 'Jenifer.Malave.Santana@spambob.com', '13/07/60', 1, 5);
INSERT INTO usuaris VALUES (3651, 'Haroldo', 'Chacón Sierra', 'H', '62 Maestro Puig Valera', 33820, 'Haroldo.Chacon.Sierra@pookmail.com', '29/01/42', 54, 2);
INSERT INTO usuaris VALUES (3652, 'Alanis', 'Quintanilla Elizondo', 'H', '87 Constitución', 36980, 'Alanis.Quintanilla.Elizondo@mailinator.com', '30/04/43', 64, 9);
INSERT INTO usuaris VALUES (3653, 'Matilde', 'Mota Carrera', 'D', '16 Puerta Nueva', 35572, 'Matilde.Mota.Carrera@pookmail.com', '05/04/77', 28, 3);
INSERT INTO usuaris VALUES (3654, 'Pompilio', 'Luján Ulloa', 'H', '29 C/ Andalucía', 4838, 'Pompilio.Lujan.Ulloa@spambob.com', '21/11/67', 47, 4);
INSERT INTO usuaris VALUES (3655, 'Herminda', 'Canales Acuna', 'D', '38 Cañadilla', 21668, 'Herminda.Canales.Acuna@pookmail.com', '19/07/48', 12, NULL);
INSERT INTO usuaris VALUES (3656, 'Baruj', 'Altamirano Granados', 'H', '52 C/ Henan Cortes', 29194, 'Baruj.Altamirano.Granados@spambob.com', '13/10/47', 64, 12);
INSERT INTO usuaris VALUES (3657, 'Consolación', 'Limón Caraballo', 'D', '35 Plaza Maior', 37214, 'Consolacion.Limon.Caraballo@mailinator.com', '02/01/48', 11, 1);
INSERT INTO usuaris VALUES (3658, 'Anisio', 'Garza Vaca', 'H', '73 C/ Canarias', 19000, 'Anisio.Garza.Vaca@spambob.com', '23/05/41', 35, 8);
INSERT INTO usuaris VALUES (3659, 'Dion', 'Rojo Rascón', 'H', '80 Plaza de España', 15808, 'Dion.Rojo.Rascon@dodgit.com', '11/01/67', 30, 9);
INSERT INTO usuaris VALUES (3660, 'Aylin', 'Venegas Cantú', 'D', '76 Calle Proc. San Sebastián', 12578, 'Aylin.Venegas.Cantu@spambob.com', '09/05/62', 31, 4);
INSERT INTO usuaris VALUES (3661, 'Quirina', 'Gonzales Rodarte', 'D', '38 Antonio Vázquez', 38720, 'Quirina.Gonzales.Rodarte@dodgit.com', '02/01/77', 54, 4);
INSERT INTO usuaris VALUES (3662, 'Emna', 'Echevarría Barreto', 'D', '49 Bellavista', 49700, 'Emna.Echevarria.Barreto@pookmail.com', '19/09/47', 11, 1);
INSERT INTO usuaris VALUES (3663, 'Clea', 'Villagómez Bermúdez', 'D', '81 Comandante Izarduy', 8780, 'Clea.Villagomez.Bermudez@trashymail.com', '15/12/70', 29, 2);
INSERT INTO usuaris VALUES (3664, 'Araxi', 'Henríquez Arenas', 'D', '49 C/ Eras', 28723, 'Araxi.Henriquez.Arenas@spambob.com', '05/07/44', 20, NULL);
INSERT INTO usuaris VALUES (3665, 'Anahí', 'Carreón Argüello', 'D', '55 Constitución', 36960, 'Anahi.Carreon.Arguello@dodgit.com', '13/02/61', 50, 12);
INSERT INTO usuaris VALUES (3666, 'Augusto', 'Robledo Castro', 'H', '94 Plaza Maior', 37219, 'Augusto.Robledo.Castro@dodgit.com', '17/02/46', 86, 1);
INSERT INTO usuaris VALUES (3667, 'Gerónimo', 'Rojas Ramírez', 'H', '74 C/ Pablo Iglesias', 26312, 'Geronimo.Rojas.Ramirez@dodgit.com', '02/03/55', 64, 10);
INSERT INTO usuaris VALUES (3668, 'Zaqueo', 'Trejo Terán', 'H', '72 C/ Arana', 2611, 'Zaqueo.Trejo.Teran@spambob.com', '30/10/82', 25, 8);
INSERT INTO usuaris VALUES (3669, 'Nereu', 'Rico Aguilar', NULL, '68 Carretera', 14815, 'Nereu.Rico.Aguilar@spambob.com', '05/03/46', 27, NULL);
INSERT INTO usuaris VALUES (3670, 'Ahmed', 'Martínez Godínez', 'H', '66 C/ Angosto', 23440, 'Ahmed.Martinez.Godinez@trashymail.com', '13/01/40', 34, 6);
INSERT INTO usuaris VALUES (3671, 'Tancredo', 'Cervantes Cadena', 'H', '84 Crta. Cádiz-Málaga', 12230, 'Tancredo.Cervantes.Cadena@dodgit.com', '10/10/66', 32, 3);
INSERT INTO usuaris VALUES (3672, 'Elio', 'Sevilla Santana', 'H', '2 Castelao', 49000, 'Elio.Sevilla.Santana@spambob.com', '19/03/71', 48, 6);
INSERT INTO usuaris VALUES (3673, 'Amantzi', 'Apodaca Ybarra', 'H', '6 Avda. Rio Nalon', 33200, 'Amantzi.Apodaca.Ybarra@spambob.com', '13/01/74', 58, 9);
INSERT INTO usuaris VALUES (3674, 'Victorio', 'Domínquez Ybarra', 'H', '7 C/ Rosa de los Vientos', 11370, 'Victorio.Dominquez.Ybarra@dodgit.com', '28/12/70', 84, 8);
INSERT INTO usuaris VALUES (3675, 'Perfecto', 'Tamayo Roldán', 'H', '75 Rúa Olmos', 37419, 'Perfecto.Tamayo.Roldan@mailinator.com', '18/01/59', 58, 5);
INSERT INTO usuaris VALUES (3676, 'Milba', 'Esparza Zambrano', 'D', '90 Padre Caro', 13750, 'Milba.Esparza.Zambrano@trashymail.com', '11/03/51', 97, 10);
INSERT INTO usuaris VALUES (3677, 'Magda', 'Cabrera Valencia', 'D', '43 Camiño Real', 48381, 'Magda.Cabrera.Valencia@pookmail.com', '12/09/84', 96, 12);
INSERT INTO usuaris VALUES (3678, 'Palma', 'Dueñas Calvillo', 'D', '6 Estrela', 39700, 'Palma.Duenas.Calvillo@trashymail.com', '06/03/83', 46, 4);
INSERT INTO usuaris VALUES (3679, 'Jasmine', 'Loera Soto', 'D', '43 Ventanilla de Beas', 27850, 'Jasmine.Loera.Soto@dodgit.com', '19/09/67', 36, 10);
INSERT INTO usuaris VALUES (3680, 'Gastón', 'Guerrero Zamora', 'H', '17 Rua da Rapina', 37487, 'Gaston.Guerrero.Zamora@trashymail.com', '22/11/76', 36, 9);
INSERT INTO usuaris VALUES (3681, 'Metran', 'Vera Henríquez', 'H', '75 Salzillo', 32702, 'Metran.Vera.Henriquez@trashymail.com', '07/04/41', 19, 11);
INSERT INTO usuaris VALUES (3682, 'Donardo', 'Contreras Chávez', 'H', '34 Av. Zumalakarregi', 2690, 'Donardo.Contreras.Chavez@pookmail.com', '19/01/60', 11, 11);
INSERT INTO usuaris VALUES (3683, 'Madison', 'Ybarra Farías', 'H', '76 Avda. Andalucía', 26135, 'Madison.Ybarra.Farias@mailinator.com', '13/07/71', 72, 11);
INSERT INTO usuaris VALUES (3684, 'Heidi', 'Bernal Amador', 'D', '37 Avda. Alameda Sundheim', 23110, 'Heidi.Bernal.Amador@mailinator.com', '14/12/79', 74, 10);
INSERT INTO usuaris VALUES (3685, 'Gaspard', 'Rolón Franco', 'H', '86 El Roqueo', 15873, 'Gaspard.Rolon.Franco@spambob.com', '11/01/66', 65, 12);
INSERT INTO usuaris VALUES (3686, 'Eliane', 'Tamayo Ortega', 'D', '84 Puerto Lugar', 29788, 'Eliane.Tamayo.Ortega@trashymail.com', '04/08/56', 48, 5);
INSERT INTO usuaris VALUES (3687, 'Cintio', 'Vázquez Pena', 'H', '78 C/ Cuevas de Ambrosio', 23740, 'Cintio.Vazquez.Pena@trashymail.com', '18/12/65', 75, 10);
INSERT INTO usuaris VALUES (3688, 'Ivan', 'Atencio Orellana', 'H', '86 Maestro Puig Valera', 33760, 'Ivan.Atencio.Orellana@spambob.com', '27/05/53', 60, 3);
INSERT INTO usuaris VALUES (3689, 'Benicio', 'Marroquín Soria', 'H', '17 Cruce Casa de Postas', 18416, 'Benicio.Marroquin.Soria@spambob.com', '17/09/78', NULL, NULL);
INSERT INTO usuaris VALUES (3690, 'Collipal', 'Bonilla Otero', 'D', '36 Ctra. de Siles', 27560, 'Collipal.Bonilla.Otero@mailinator.com', '04/09/78', 17, 12);
INSERT INTO usuaris VALUES (3691, 'Gamal', 'Montoya Tapia', 'H', '57 Paraguay', 3688, 'Gamal.Montoya.Tapia@spambob.com', '09/12/64', 91, 1);
INSERT INTO usuaris VALUES (3692, 'Alvina', 'Malave Ontiveros', 'D', '96 Cádiz', 18518, 'Alvina.Malave.Ontiveros@spambob.com', '01/07/42', 14, 2);
INSERT INTO usuaris VALUES (3693, 'Landerico', 'Toledo Madera', 'H', '57 Puerta Nueva', 35600, 'Landerico.Toledo.Madera@mailinator.com', '01/09/65', 58, 1);
INSERT INTO usuaris VALUES (3694, 'Cumelén', 'Negrón Terrazas', 'D', '81 C/ Eras', 28739, 'Cumelen.Negron.Terrazas@spambob.com', '10/07/71', 44, 3);
INSERT INTO usuaris VALUES (3695, 'Julieta', 'Díaz Cárdenas', 'D', '71 Ctra. Bailén-Motril', 23270, 'Julieta.Diaz.Cardenas@dodgit.com', '26/12/66', 4, 12);
INSERT INTO usuaris VALUES (3696, 'Leoncio', 'Suárez Serna', 'H', '5 Alvaro Cunqueiro', 40520, 'Leoncio.Suarez.Serna@pookmail.com', '29/09/48', 85, 9);
INSERT INTO usuaris VALUES (3697, 'Jesualdo', 'Ybarra Corona', 'H', '38 Cádiz', 18513, 'Jesualdo.Ybarra.Corona@trashymail.com', '16/05/67', 0, 7);
INSERT INTO usuaris VALUES (3698, 'Desdémona', 'Montenegro Raya', 'D', '32 Castelao', 49150, 'Desdemona.Montenegro.Raya@trashymail.com', '04/12/46', 80, 12);
INSERT INTO usuaris VALUES (3699, 'Begga', 'Esparza Yáñez', 'D', '28 Ctra. de Siles', 27320, 'Begga.Esparza.Yanez@trashymail.com', '29/04/68', 39, 2);
INSERT INTO usuaris VALUES (3700, 'Zofía', 'Galindo Raya', 'D', '51 Avda. Rio Nalon', 33200, 'Zofia.Galindo.Raya@spambob.com', '12/11/55', 83, 8);
INSERT INTO usuaris VALUES (3701, 'Dídimo', 'Tirado Ávalos', 'H', '8 Rúa Olmos', 37329, 'Didimo.Tirado.Avalos@dodgit.com', '15/04/60', 6, 7);
INSERT INTO usuaris VALUES (3702, 'Nasya', 'Serrano Elizondo', 'D', '23 Extramuros', 28359, 'Nasya.Serrano.Elizondo@pookmail.com', '21/09/81', 51, NULL);
INSERT INTO usuaris VALUES (3703, 'Judit', 'Orellana Caballero', 'D', '8 Cañadilla', 21820, 'Judit.Orellana.Caballero@trashymail.com', '27/11/45', 76, 3);
INSERT INTO usuaris VALUES (3704, 'Manases', 'Melgar Covarrubias', 'H', '71 San Andrés', 37246, 'Manases.Melgar.Covarrubias@mailinator.com', '17/10/49', 60, 3);
INSERT INTO usuaris VALUES (3705, 'Jade', 'Serna Arévalo', 'D', '3 Ctra. Beas-Cortijos Nuevos', 26540, 'Jade.Serna.Arevalo@dodgit.com', '08/07/60', 87, 9);
INSERT INTO usuaris VALUES (3706, 'Jova', 'Lozada Flores', 'D', '20 Herrería', 18179, 'Jova.Lozada.Flores@spambob.com', '28/06/53', 93, 11);
INSERT INTO usuaris VALUES (3707, 'Segundo', 'Tello Barela', 'H', '44 Apartado de Correos', 37428, 'Segundo.Tello.Barela@dodgit.com', '27/08/56', 99, 11);
INSERT INTO usuaris VALUES (3708, 'Michel', 'Urías Angulo', 'H', '23 Socampo', 37660, 'Michel.Urias.Angulo@dodgit.com', '04/02/49', 55, 7);
INSERT INTO usuaris VALUES (3709, 'Macario', 'Rodríguez Urena', 'H', '50 Rua da Rapina', 37485, 'Macario.Rodriguez.Urena@spambob.com', '26/08/58', 64, 3);
INSERT INTO usuaris VALUES (3710, 'Niranjana', 'Salazar Cazares', 'D', '77 C/ Amoladera', 28814, 'Niranjana.Salazar.Cazares@spambob.com', '18/01/53', 17, 11);
INSERT INTO usuaris VALUES (3711, 'Casimira', 'Núñez Gastelum', 'D', '64 Paraguay', 3600, 'Casimira.Nunez.Gastelum@spambob.com', '13/06/55', 30, 6);
INSERT INTO usuaris VALUES (3712, 'Aracely', 'Badillo Orellana', 'D', '83 San Andrés', 37251, 'Aracely.Badillo.Orellana@mailinator.com', '10/01/85', 57, 6);
INSERT INTO usuaris VALUES (3713, 'Yamile', 'Madera Ulibarri', 'D', '47 Padre Caro', 13760, 'Yamile.Madera.Ulibarri@trashymail.com', '14/09/78', 1, 10);
INSERT INTO usuaris VALUES (3714, 'Edna', 'Olivo Benítez', 'D', '54 Rosa de los Vientos', 13343, 'Edna.Olivo.Benitez@dodgit.com', '03/11/50', 55, 1);
INSERT INTO usuaris VALUES (3715, 'Pierina', 'Padilla Ponce', 'D', '36 Avenida Cervantes', 48250, 'Pierina.Padilla.Ponce@dodgit.com', '27/10/74', 0, 8);
INSERT INTO usuaris VALUES (3716, 'Gus', 'Berrios Escalante', 'H', '54 Camiño Ancho', 37791, 'Gus.Berrios.Escalante@spambob.com', '19/08/64', 58, 12);
INSERT INTO usuaris VALUES (3717, 'Marlon', 'Narváez Galindo', 'H', '57 Calle Aduana', 1206, 'Marlon.Narvaez.Galindo@trashymail.com', '19/04/65', 65, 1);
INSERT INTO usuaris VALUES (3718, 'Laureano', 'Leiva Lozada', 'H', '40 C/ Manuel Iradier', 3811, 'Laureano.Leiva.Lozada@dodgit.com', '23/08/57', 88, NULL);
INSERT INTO usuaris VALUES (3719, 'Tobías', 'Coronado Grijalva', 'H', '48 Socampo', 37623, 'Tobias.Coronado.Grijalva@mailinator.com', '31/07/50', 36, 5);
INSERT INTO usuaris VALUES (3720, 'Jesus', 'Montenegro Solorio', 'H', '62 Alvaro Cunqueiro', 41220, 'Jesus.Montenegro.Solorio@pookmail.com', '03/02/74', 8, 6);
INSERT INTO usuaris VALUES (3721, 'Janoc', 'Narváez Fonseca', 'H', '88 Caño', 32840, 'Janoc.Narvaez.Fonseca@trashymail.com', '13/02/83', 15, 10);
INSERT INTO usuaris VALUES (3722, 'Berta', 'Bañuelos Pérez', 'D', '79 Celso Emilio Ferreiro', 50520, 'Berta.Banuelos.Perez@trashymail.com', '10/12/43', 89, 8);
INSERT INTO usuaris VALUES (3723, 'Aniria', 'Miranda Carvajal', 'D', '37 C/ Cañada del Rosal', 21640, 'Aniria.Miranda.Carvajal@trashymail.com', '27/10/62', 63, 5);
INSERT INTO usuaris VALUES (3724, 'Iriel', 'Mireles Pineda', 'D', '43 Plazuela do Porto', 38260, 'Iriel.Mireles.Pineda@spambob.com', '24/08/67', 45, 5);
INSERT INTO usuaris VALUES (3725, 'Pancracia', 'Lucio Guzmán', NULL, '47 Canónigo Valiño', 46230, 'Pancracia.Lucio.Guzman@mailinator.com', '28/04/74', 66, 9);
INSERT INTO usuaris VALUES (3726, 'Ibi', 'Rendón Vergara', 'D', '43 C/ Angosto', 23393, 'Ibi.Rendon.Vergara@dodgit.com', '17/02/73', 61, 7);
INSERT INTO usuaris VALUES (3727, 'Desirée', 'Juárez Barragán', NULL, '97 Carretera', 14510, 'Desiree.Juarez.Barragan@mailinator.com', '17/01/49', 61, 11);
INSERT INTO usuaris VALUES (3728, 'Nabila', 'Aguilar Arredondo', 'D', '81 Zumalakarregi etorbidea', 7240, 'Nabila.Aguilar.Arredondo@trashymail.com', '22/05/60', 36, 5);
INSERT INTO usuaris VALUES (3729, 'Thaiel', 'Franco Enríquez', 'H', '91 Calle Aduana', 1220, 'Thaiel.Franco.Enriquez@spambob.com', '08/05/68', 62, NULL);
INSERT INTO usuaris VALUES (3730, 'Iriel', 'Beltrán Ocasio', 'D', '23 Rio Segura', 31490, 'Iriel.Beltran.Ocasio@pookmail.com', '08/02/72', 20, 11);
INSERT INTO usuaris VALUES (3731, 'Publio', 'Zapata Bustos', 'H', '49 Plazuela do Porto', 38436, 'Publio.Zapata.Bustos@trashymail.com', '20/05/63', 10, 1);
INSERT INTO usuaris VALUES (3732, 'Isidre', 'Pacheco Lerma', 'H', '53 Celso Emilio Ferreiro', 50641, 'Isidre.Pacheco.Lerma@spambob.com', '07/03/43', 22, 1);
INSERT INTO usuaris VALUES (3733, 'Donatela', 'Calvillo Echevarría', 'D', '30 Atamaria', 36780, 'Donatela.Calvillo.Echevarria@mailinator.com', '01/01/55', 47, 12);
INSERT INTO usuaris VALUES (3734, 'Juancruz', 'Salinas Santana', 'H', '49 Reyes Católicos', 9560, 'Juancruz.Salinas.Santana@dodgit.com', '04/09/72', 80, 9);
INSERT INTO usuaris VALUES (3735, 'Cyril', 'Venegas Rentería', 'H', '25 Caño', 32730, 'Cyril.Venegas.Renteria@spambob.com', '08/04/65', 47, 8);
INSERT INTO usuaris VALUES (3736, 'Augustin', 'Valladares Carrera', 'H', '5 Avenida Cervantes', 48215, 'Augustin.Valladares.Carrera@spambob.com', '05/11/49', 77, 8);
INSERT INTO usuaris VALUES (3737, 'Aleida', 'Cadena Benavidez', 'D', '2 Socampo', 37638, 'Aleida.Cadena.Benavidez@trashymail.com', '08/05/45', 62, 11);
INSERT INTO usuaris VALUES (3738, 'Griselda', 'Loera Mateo', 'D', '72 Ctra. Hornos', 26216, 'Griselda.Loera.Mateo@pookmail.com', '17/02/61', 14, 2);
INSERT INTO usuaris VALUES (3739, 'Perfecto', 'Casas Mata', 'H', '84 C/ Fernández de Leceta', 3500, 'Perfecto.Casas.Mata@pookmail.com', '18/03/60', 81, 5);
INSERT INTO usuaris VALUES (3740, 'Prilidiano', 'Limón Solano', 'H', '30 C/ Henan Cortes', 29194, 'Prilidiano.Limon.Solano@spambob.com', '08/05/83', 17, 5);
INSERT INTO usuaris VALUES (3741, 'Fito', 'Cordova Anguiano', 'H', '98 Cercas Bajas', 8192, 'Fito.Cordova.Anguiano@spambob.com', '01/08/71', 43, 3);
INSERT INTO usuaris VALUES (3742, 'Ercilia', 'Jaramillo Vela', 'D', '81 C/ Eras', 28754, 'Ercilia.Jaramillo.Vela@dodgit.com', '24/11/67', 28, NULL);
INSERT INTO usuaris VALUES (3743, 'Aristides', 'Mota Collazo', 'H', '26 Canónigo Valiño', 46470, 'Aristides.Mota.Collazo@dodgit.com', '25/09/49', 89, 10);
INSERT INTO usuaris VALUES (3744, 'Inca', 'Fernández Barreto', 'H', '42 C/ Angosto', 23486, 'Inca.Fernandez.Barreto@trashymail.com', '27/12/74', 75, 12);
INSERT INTO usuaris VALUES (3745, 'Anisio', 'Rael Olmos', 'H', '78 Cruce Casa de Postas', 18327, 'Anisio.Rael.Olmos@dodgit.com', '19/01/47', 87, NULL);
INSERT INTO usuaris VALUES (3746, 'Ane', 'Verdugo Espinoza', 'D', '14 Apartado de Correos', 37451, 'Ane.Verdugo.Espinoza@dodgit.com', '16/07/59', 94, 7);
INSERT INTO usuaris VALUES (3747, 'Tania', 'Cantú Ozuna', 'D', '21 Ctra. Hornos', 26227, 'Tania.Cantu.Ozuna@mailinator.com', '06/02/42', 32, 1);
INSERT INTO usuaris VALUES (3748, 'Maureen', 'Madera Puga', 'D', '74 Avda. de la Estación', 28570, 'Maureen.Madera.Puga@pookmail.com', '03/03/48', 88, 12);
INSERT INTO usuaris VALUES (3749, 'Fritz', 'Montoya Colunga', 'H', '37 Pza. Fuensanta', 32356, 'Fritz.Montoya.Colunga@spambob.com', '17/03/72', 20, 11);
INSERT INTO usuaris VALUES (3750, 'Lalita', 'Calderón Bonilla', 'D', '73 Avendaño', 4240, 'Lalita.Calderon.Bonilla@pookmail.com', '13/06/72', 81, 10);
INSERT INTO usuaris VALUES (3751, 'Nehemias', 'Grijalva Carrero', 'H', '60 C/ Benito Guinea', 8320, 'Nehemias.Grijalva.Carrero@spambob.com', '12/10/65', 59, 4);
INSERT INTO usuaris VALUES (3752, 'Ondina', 'Angulo Tello', 'D', '54 Avda. Enrique Peinador', 37181, 'Ondina.Angulo.Tello@mailinator.com', '09/05/85', 49, 4);
INSERT INTO usuaris VALUES (3753, 'Jaasiel', 'Bustamante Raya', 'H', '17 Ctra. de Fuentenueva', 28190, 'Jaasiel.Bustamante.Raya@pookmail.com', '15/08/60', 17, 9);
INSERT INTO usuaris VALUES (3754, 'Nerio', 'Casárez Olivares', 'H', '90 Antonio Vázquez', 38500, 'Nerio.Casarez.Olivares@spambob.com', '19/12/44', 1, 4);
INSERT INTO usuaris VALUES (3755, 'Yamal', 'Zavala Olivas', 'H', '51 Zumalakarregi etorbidea', 7300, 'Yamal.Zavala.Olivas@mailinator.com', '21/04/45', 58, 1);
INSERT INTO usuaris VALUES (3756, 'Cirinea', 'Alanis Toro', 'D', '16 Antonio Vázquez', 38789, 'Cirinea.Alanis.Toro@dodgit.com', '24/05/57', 40, 4);
INSERT INTO usuaris VALUES (3757, 'Alfred', 'Noriega Sanches', 'H', '4 Plaza Colón', 25000, 'Alfred.Noriega.Sanches@dodgit.com', '09/02/44', 66, 12);
INSERT INTO usuaris VALUES (3758, 'Zacarías', 'Ibarra Muro', 'H', '79 Inglaterra', 18564, 'Zacarias.Ibarra.Muro@dodgit.com', '12/07/66', 88, 4);
INSERT INTO usuaris VALUES (3759, 'Maku', 'Mondragón Chavarría', 'D', '79 Paseo Junquera', 12480, 'Maku.Mondragon.Chavarria@pookmail.com', '12/06/72', 39, 5);
INSERT INTO usuaris VALUES (3760, 'Leandra', 'Macías Narváez', 'D', '37 Crta. Cádiz-Málaga', 12230, 'Leandra.Macias.Narvaez@spambob.com', '25/11/66', 23, 1);
INSERT INTO usuaris VALUES (3761, 'Manque', 'Ceballos Aparicio', 'D', '68 Urzáiz', 44380, 'Manque.Ceballos.Aparicio@dodgit.com', '13/05/66', 62, 1);
INSERT INTO usuaris VALUES (3762, 'Dídimo', 'Laboy Duarte', 'H', '59 San Andrés', 37257, 'Didimo.Laboy.Duarte@dodgit.com', '02/10/75', 41, 3);
INSERT INTO usuaris VALUES (3763, 'Cleofas', 'Tafoya Mora', 'H', '32 C/ Hijuela de Lojo', 20260, 'Cleofas.Tafoya.Mora@dodgit.com', '19/05/67', 99, NULL);
INSERT INTO usuaris VALUES (3764, 'Morela', 'Ortiz Hidalgo', 'D', '89 Plazuela do Porto', 37891, 'Morela.Ortiz.Hidalgo@dodgit.com', '10/07/41', 4, 2);
INSERT INTO usuaris VALUES (3765, 'Pichi', 'Madrid Acosta', 'H', '84 C/ Cuevas de Ambrosio', 23770, 'Pichi.Madrid.Acosta@spambob.com', '20/02/77', 60, 6);
INSERT INTO usuaris VALUES (3766, 'Niobe', 'Paredes Terrazas', 'D', '17 Avda. Los llanos', 26311, 'Niobe.Paredes.Terrazas@mailinator.com', '07/05/62', 60, 8);
INSERT INTO usuaris VALUES (3767, 'Hadrian', 'Bueno Bustamante', 'H', '29 C/ Pablo Iglesias', 26315, 'Hadrian.Bueno.Bustamante@mailinator.com', '24/12/84', 59, 5);
INSERT INTO usuaris VALUES (3768, 'Shulinen', 'Jaramillo Tijerina', 'D', '6 Avda. Enrique Peinador', 37170, 'Shulinen.Jaramillo.Tijerina@spambob.com', '11/03/46', 99, NULL);
INSERT INTO usuaris VALUES (3769, 'Bela', 'Callas Arellano', 'D', '63 Plazuela do Porto', 38000, 'Bela.Callas.Arellano@pookmail.com', '21/01/46', 85, 7);
INSERT INTO usuaris VALUES (3770, 'Saidi', 'Solórzano Cano', 'D', '83 Carretera del Muelle', 12320, 'Saidi.Solorzano.Cano@dodgit.com', '20/06/62', 17, 2);
INSERT INTO usuaris VALUES (3771, 'Jaqueline', 'Aguilar Tamez', 'D', '79 Rúa de San Pedro', 37797, 'Jaqueline.Aguilar.Tamez@dodgit.com', '19/09/40', 54, 1);
INSERT INTO usuaris VALUES (3772, 'Urania', 'Solís Saldivar', 'D', '49 Caño', 33110, 'Urania.Solis.Saldivar@mailinator.com', '28/11/66', 32, 4);
INSERT INTO usuaris VALUES (3773, 'Tibor', 'Arreola Galindo', 'H', '8 Calle Proc. San Sebastián', 12589, 'Tibor.Arreola.Galindo@mailinator.com', '19/05/54', 60, 2);
INSERT INTO usuaris VALUES (3774, 'Lucina', 'Calvillo Nino', 'D', '24 Boriñaur enparantza', 7500, 'Lucina.Calvillo.Nino@spambob.com', '09/06/64', 98, 8);
INSERT INTO usuaris VALUES (3775, 'Otniel', 'Aguilar Vela', 'H', '15 Ctra. Hornos', 26213, 'Otniel.Aguilar.Vela@mailinator.com', '15/06/53', 49, NULL);
INSERT INTO usuaris VALUES (3776, 'Vinicio', 'Velásquez Covas', 'H', '13 Enxertos', 37600, 'Vinicio.Velasquez.Covas@spambob.com', '23/01/66', 99, 1);
INSERT INTO usuaris VALUES (3777, 'AmINTOr', 'Luján Franco', 'H', '62 Av. Santiago Lapuente', 52000, 'AmINTOr.Lujan.Franco@spambob.com', '29/06/78', 2, 7);
INSERT INTO usuaris VALUES (3778, 'Goyo', 'Roque Llarnas', 'H', '71 Plazuela do Porto', 38200, 'Goyo.Roque.Llarnas@dodgit.com', '01/01/40', 46, 10);
INSERT INTO usuaris VALUES (3779, 'Cinty', 'Santiago Alemán', NULL, '10 C/ Pablo Iglesias', 26338, 'Cinty.Santiago.Aleman@trashymail.com', '14/08/66', 11, 8);
INSERT INTO usuaris VALUES (3780, 'Iva', 'Segovia Tejeda', 'D', '24 Comandante Izarduy', 9110, 'Iva.Segovia.Tejeda@mailinator.com', '22/11/78', 39, 11);
INSERT INTO usuaris VALUES (3781, 'Tais', 'Quintanilla Calderón', NULL, '91 Avda. Rio Nalon', 33126, 'Tais.Quintanilla.Calderon@dodgit.com', '25/11/79', 95, 11);
INSERT INTO usuaris VALUES (3782, 'Fergus', 'Estrada Franco', 'H', '55 Castelao', 49000, 'Fergus.Estrada.Franco@trashymail.com', '04/07/69', 44, 9);
INSERT INTO usuaris VALUES (3783, 'Zemira', 'Saenz Santana', 'D', '12 C/ Angosto', 23500, 'Zemira.Saenz.Santana@mailinator.com', '06/07/42', 8, 5);
INSERT INTO usuaris VALUES (3784, 'Luisana', 'Manzanares Negrete', 'D', '47 Escuadro', 46910, 'Luisana.Manzanares.Negrete@mailinator.com', '21/12/65', 73, 11);
INSERT INTO usuaris VALUES (3785, 'Henoch', 'Puga Jaramillo', 'H', '85 Caño', 33000, 'Henoch.Puga.Jaramillo@dodgit.com', '21/04/59', 62, 12);
INSERT INTO usuaris VALUES (3786, 'Castalia', 'Esquibel Leyva', 'D', '63 Alvaro Cunqueiro', 40200, 'Castalia.Esquibel.Leyva@spambob.com', '05/07/74', 45, 9);
INSERT INTO usuaris VALUES (3787, 'Abra', 'Leiva Carranza', 'D', '93 Maestro Puig Valera', 33820, 'Abra.Leiva.Carranza@trashymail.com', '02/04/42', 23, NULL);
INSERT INTO usuaris VALUES (3788, 'Moira', 'Escobar Hernandes', 'D', '9 Avendaño', 4240, 'Moira.Escobar.Hernandes@trashymail.com', '03/01/63', 38, 12);
INSERT INTO usuaris VALUES (3789, 'Valente', 'Nazario Naranjo', 'H', '93 Plaza Maior', 37219, 'Valente.Nazario.Naranjo@mailinator.com', '04/03/43', 97, 12);
INSERT INTO usuaris VALUES (3790, 'Saba', 'Fonseca Santillán', NULL, '65 Avendaño', 4250, 'Saba.Fonseca.Santillan@trashymail.com', '19/06/60', 89, 4);
INSERT INTO usuaris VALUES (3791, 'Fabiano', 'García Fuentes', 'H', '65 Avda. Andalucía', 26135, 'Fabiano.Garcia.Fuentes@trashymail.com', '06/09/84', 0, 2);
INSERT INTO usuaris VALUES (3792, 'Ursulina', 'Polanco Olivas', 'D', '74 Padre Caro', 13680, 'Ursulina.Polanco.Olivas@pookmail.com', '06/08/44', 56, 7);
INSERT INTO usuaris VALUES (3793, 'Jessenia', 'Leyva Vargas', 'D', '49 Plaza Maior', 37188, 'Jessenia.Leyva.Vargas@pookmail.com', '23/08/57', 71, 1);
INSERT INTO usuaris VALUES (3794, 'Theo', 'Serrano Lebrón', 'H', '38 Av. Zumalakarregi', 3158, 'Theo.Serrano.Lebron@spambob.com', '02/06/65', 97, 7);
INSERT INTO usuaris VALUES (3795, 'Tadeo', 'Fajardo Casas', 'H', '28 C/ Benito Guinea', 8400, 'Tadeo.Fajardo.Casas@pookmail.com', '30/12/57', 43, NULL);
INSERT INTO usuaris VALUES (3796, 'Sonia', 'Tapia Marroquín', NULL, '11 Valadouro', 48140, 'Sonia.Tapia.Marroquin@spambob.com', '06/12/67', 56, 7);
INSERT INTO usuaris VALUES (3797, 'Rayen', 'Ibarra Casares', 'H', '15 Cádiz', 18512, 'Rayen.Ibarra.Casares@mailinator.com', '02/04/85', 69, 11);
INSERT INTO usuaris VALUES (3798, 'Venancio', 'Manzanares Leyva', 'H', '35 Bellavista', 49510, 'Venancio.Manzanares.Leyva@trashymail.com', '28/03/53', 69, 5);
INSERT INTO usuaris VALUES (3799, 'Joya', 'Morales Zaragoza', 'D', '98 Outid de Arriba', 43580, 'Joya.Morales.Zaragoza@pookmail.com', '17/04/66', 16, 9);
INSERT INTO usuaris VALUES (3800, 'Nilda', 'Jimínez Fuentes', 'D', '94 José matía', 2151, 'Nilda.Jiminez.Fuentes@spambob.com', '13/04/49', 74, 6);
INSERT INTO usuaris VALUES (3801, 'Liduvina', 'Armijo Feliciano', 'D', '57 Av. Zumalakarregi', 3190, 'Liduvina.Armijo.Feliciano@trashymail.com', '25/06/69', 27, 10);
INSERT INTO usuaris VALUES (3802, 'Liafdag', 'Soria Meraz', 'H', '17 Avda. Explanada Barnuevo', 34840, 'Liafdag.Soria.Meraz@mailinator.com', '22/10/66', 26, 1);
INSERT INTO usuaris VALUES (3803, 'Baldo', 'Rosales Godínez', 'H', '85 Quevedo', 15250, 'Baldo.Rosales.Godinez@trashymail.com', '17/12/63', 33, 7);
INSERT INTO usuaris VALUES (3804, 'Ena', 'Baeza Luevano', 'D', '97 Castelao', 49150, 'Ena.Baeza.Luevano@spambob.com', '22/04/55', 26, 10);
INSERT INTO usuaris VALUES (3805, 'Yanquiman', 'Sisneros Irizarry', 'H', '18 Zumalakarregi etorbidea', 7315, 'Yanquiman.Sisneros.Irizarry@spambob.com', NULL, 85, 3);
INSERT INTO usuaris VALUES (3806, 'Rosemary', 'Espinoza Pelayo', 'D', '61 C/ Cuesta del  Álamo', 29639, 'Rosemary.Espinoza.Pelayo@pookmail.com', '17/07/62', 71, 4);
INSERT INTO usuaris VALUES (3807, 'Hermione', 'Pina Balderas', 'D', '50 Rúa do Paseo', 41900, 'Hermione.Pina.Balderas@trashymail.com', '19/03/81', 50, 2);
INSERT INTO usuaris VALUES (3808, 'Anicet', 'Santacruz Segura', 'H', '94 C/ Los Herrán', 6920, 'Anicet.Santacruz.Segura@pookmail.com', '03/10/60', 16, 5);
INSERT INTO usuaris VALUES (3809, 'Antia', 'Montenegro Téllez', 'D', '55 C/ Eras', 28723, 'Antia.Montenegro.Tellez@mailinator.com', '19/04/63', 70, 12);
INSERT INTO usuaris VALUES (3810, 'Itatay', 'Pichardo Mercado', 'D', '97 Estrela', 39740, 'Itatay.Pichardo.Mercado@spambob.com', '26/05/50', 24, 5);
INSERT INTO usuaris VALUES (3811, 'Yunka', 'Barraza Prieto', 'H', '88 C/ Cuevas de Ambrosio', 23670, 'Yunka.Barraza.Prieto@pookmail.com', '04/10/60', 65, 3);
INSERT INTO usuaris VALUES (3812, 'Ariel', 'Aranda Alcantar', NULL, '48 Avda. Alameda Sundheim', 22510, 'Ariel.Aranda.Alcantar@trashymail.com', '13/10/48', 52, 6);
INSERT INTO usuaris VALUES (3813, 'Ghita', 'Alanis Palomo', 'D', '3 Urzáiz', 44400, 'Ghita.Alanis.Palomo@spambob.com', '13/06/83', 58, 4);
INSERT INTO usuaris VALUES (3814, 'Partenia', 'Galindo Maestas', 'D', '23 Avendaño', 3829, 'Partenia.Galindo.Maestas@spambob.com', '11/09/68', 64, 12);
INSERT INTO usuaris VALUES (3815, 'Anahí', 'Mora Abeyta', 'D', '24 Eusebio Dávila', 41550, 'Anahi.Mora.Abeyta@dodgit.com', '04/11/43', 82, 6);
INSERT INTO usuaris VALUES (3816, 'Electra', 'Granado Benavides', 'D', '31 Puerta Nueva', 36430, 'Electra.Granado.Benavides@spambob.com', '07/05/64', 3, 2);
INSERT INTO usuaris VALUES (3817, 'Lucila', 'Castro Pina', 'D', '60 Castelao', 48880, 'Lucila.Castro.Pina@dodgit.com', '06/08/48', 7, 6);
INSERT INTO usuaris VALUES (3818, 'Isaldina', 'Galván Curiel', 'D', '81 Ctra. Bailén-Motril', 23250, 'Isaldina.Galvan.Curiel@pookmail.com', '09/10/80', 8, 10);
INSERT INTO usuaris VALUES (3819, 'Seneca', 'Riojas Mares', 'H', '38 Plaza Colón', 26122, 'Seneca.Riojas.Mares@dodgit.com', '16/09/62', 67, 3);
INSERT INTO usuaris VALUES (3820, 'Chalten', 'Mayonga Corona', 'H', '95 Reiseñor', 45510, 'Chalten.Mayonga.Corona@spambob.com', '11/07/77', 12, 12);
INSERT INTO usuaris VALUES (3821, 'Melusina', 'Gurule Romo', 'D', '37 Extramuros', 28530, 'Melusina.Gurule.Romo@spambob.com', '26/10/63', 90, 11);
INSERT INTO usuaris VALUES (3822, 'Indira', 'Toro Espinosa', 'D', '64 C/ Libertad', 5216, 'Indira.Toro.Espinosa@spambob.com', '01/01/63', 36, 6);
INSERT INTO usuaris VALUES (3823, 'Teófano', 'Valdés Villareal', 'H', '59 Avda. Los llanos', 26291, 'Teofano.Valdes.Villareal@dodgit.com', '15/04/77', 32, 2);
INSERT INTO usuaris VALUES (3824, 'Valentine', 'Vázquez Puente', 'D', '30 Avda. Explanada Barnuevo', 34886, 'Valentine.Vazquez.Puente@dodgit.com', '22/10/42', NULL, 5);
INSERT INTO usuaris VALUES (3825, 'Micael', 'Molina Razo', 'H', '39 Ctra. Bailén-Motril', 23213, 'Micael.Molina.Razo@trashymail.com', '13/11/61', 16, 11);
INSERT INTO usuaris VALUES (3826, 'Eliana', 'Nevarez Medrano', 'D', '16 Avda. de Andalucía', 29360, 'Eliana.Nevarez.Medrano@mailinator.com', '11/02/61', 29, 9);
INSERT INTO usuaris VALUES (3827, 'Anolfo', 'Corrales Portillo', 'H', '30 Rua da Rapina', 37486, 'Anolfo.Corrales.Portillo@spambob.com', '16/02/60', 60, 4);
INSERT INTO usuaris VALUES (3828, 'Engracia', 'Apodaca Avilés', 'D', '26 Paraguay', 3668, 'Engracia.Apodaca.Aviles@trashymail.com', '26/03/53', 99, NULL);
INSERT INTO usuaris VALUES (3829, 'Zunilda', 'Rico Montero', 'D', '54 El Roqueo', 17190, 'Zunilda.Rico.Montero@mailinator.com', '17/04/41', 79, 4);
INSERT INTO usuaris VALUES (3830, 'Vitaliano', 'Ontiveros Zúñiga', 'H', '20 C/ Amoladera', 28864, 'Vitaliano.Ontiveros.Zuniga@mailinator.com', '26/01/65', 80, 2);
INSERT INTO usuaris VALUES (3831, 'Francesco', 'Montés Pedroza', 'H', '19 Plazuela do Porto', 37891, 'Francesco.Montes.Pedroza@trashymail.com', '20/11/78', 67, 3);
INSERT INTO usuaris VALUES (3832, 'Zair', 'Rodrígez Orta', 'H', '12 Herrería', 18192, 'Zair.Rodrigez.Orta@trashymail.com', '27/06/73', 6, 5);
INSERT INTO usuaris VALUES (3833, 'Saba', 'Leiva Macías', 'D', '18 Avda. Rio Nalon', 33344, 'Saba.Leiva.Macias@dodgit.com', '31/01/78', NULL, 1);
INSERT INTO usuaris VALUES (3834, 'Leonila', 'Tello Alvarez', 'D', '71 Avda. Los llanos', 26280, 'Leonila.Tello.Alvarez@trashymail.com', '10/02/45', 36, 3);
INSERT INTO usuaris VALUES (3835, 'Meulen', 'Ontiveros Lucio', 'D', '26 Lamas Carbajal', 41749, 'Meulen.Ontiveros.Lucio@trashymail.com', '03/11/72', 90, 4);
INSERT INTO usuaris VALUES (3836, 'Libe', 'Armas Sanches', 'D', '8 Avda. de la Estación', 28649, 'Libe.Armas.Sanches@trashymail.com', '26/02/62', 57, 2);
INSERT INTO usuaris VALUES (3837, 'Arcadio', 'Alonzo Negrete', 'H', '86 Cañadilla', 21710, 'Arcadio.Alonzo.Negrete@trashymail.com', '07/08/42', 98, 11);
INSERT INTO usuaris VALUES (3838, 'Grizel', 'Dueñas Lebrón', NULL, '92 Paraguay', 3579, 'Grizel.Duenas.Lebron@mailinator.com', '23/06/65', 26, 7);
INSERT INTO usuaris VALUES (3839, 'Cesarión', 'Malave Gaitán', 'H', '84 Quevedo', 15293, 'Cesarion.Malave.Gaitan@trashymail.com', '01/12/63', 99, 6);
INSERT INTO usuaris VALUES (3840, 'Romelio', 'Robles Ruiz', 'H', '46 Socampo', 37650, 'Romelio.Robles.Ruiz@pookmail.com', '01/04/64', 42, 9);
INSERT INTO usuaris VALUES (3841, 'Cecilio', 'Huerta Soria', 'H', '46 Reyes Católicos', 9530, 'Cecilio.Huerta.Soria@pookmail.com', '19/08/84', 71, 3);
INSERT INTO usuaris VALUES (3842, 'Bernabé', 'Madera Negrete', 'H', '7 Celso Emilio Ferreiro', 50340, 'Bernabe.Madera.Negrete@trashymail.com', '11/01/43', 98, 1);
INSERT INTO usuaris VALUES (3843, 'Mirari', 'Carrera Paez', 'D', '38 Puerta Nueva', 36470, 'Mirari.Carrera.Paez@dodgit.com', '12/03/66', 4, 3);
INSERT INTO usuaris VALUES (3844, 'Blanca', 'Murillo Saldivar', 'D', '37 Comandante Izarduy', 8810, 'Blanca.Murillo.Saldivar@mailinator.com', '09/05/41', 83, 3);
INSERT INTO usuaris VALUES (3845, 'Edipo', 'Cordero Peralta', 'H', '22 Avda. Los llanos', 26257, 'Edipo.Cordero.Peralta@spambob.com', '29/04/78', 48, 4);
INSERT INTO usuaris VALUES (3846, 'Absalom', 'Gonzales Ledesma', 'H', '41 Visitación de la Encina', 37727, 'Absalom.Gonzales.Ledesma@spambob.com', '22/02/59', 42, 5);
INSERT INTO usuaris VALUES (3847, 'Fulk', 'Anaya Garza', 'H', '17 Maestro Puig Valera', 33558, 'Fulk.Anaya.Garza@pookmail.com', '03/05/76', 77, 2);
INSERT INTO usuaris VALUES (3848, 'Benigno', 'Morales Laureano', 'H', '44 Inglaterra', 18656, 'Benigno.Morales.Laureano@dodgit.com', '21/02/47', 74, 12);
INSERT INTO usuaris VALUES (3849, 'Beatrice', 'Díaz Alarcón', NULL, '71 Plaza Maior', 37210, 'Beatrice.Diaz.Alarcon@trashymail.com', '28/01/85', 46, 1);
INSERT INTO usuaris VALUES (3850, 'Randolfo', 'Carrasco Alva', 'H', '7 Rúa Olmos', 37337, 'Randolfo.Carrasco.Alva@pookmail.com', '27/06/67', 82, 2);
INSERT INTO usuaris VALUES (3851, 'Maud', 'Mateo Baez', 'D', '78 Salzillo', 32620, 'Maud.Mateo.Baez@trashymail.com', '30/09/63', 93, 7);
INSERT INTO usuaris VALUES (3852, 'Enoc', 'Valverde Galván', 'H', '70 Plaza Maior', 37209, 'Enoc.Valverde.Galvan@pookmail.com', '14/10/71', 19, 8);
INSERT INTO usuaris VALUES (3853, 'Pimpinela', 'Garrido Hernández', 'D', '79 Ctra. de Siles', 27560, 'Pimpinela.Garrido.Hernandez@mailinator.com', '17/07/51', 79, NULL);
INSERT INTO usuaris VALUES (3854, 'Frederick', 'Saavedra Montemayor', NULL, '57 Padre Caro', 13591, 'Frederick.Saavedra.Montemayor@spambob.com', '02/08/57', 47, 2);
INSERT INTO usuaris VALUES (3855, 'Hobart', 'Rubio Castaneda', 'H', '93 Urzáiz', 44600, 'Hobart.Rubio.Castaneda@trashymail.com', '20/09/71', 84, 1);
INSERT INTO usuaris VALUES (3856, 'Hércules', 'Nieves Sánchez', 'H', '14 Ctra. Villena', 33900, 'Hercules.Nieves.Sanchez@pookmail.com', '15/11/54', 88, 5);
INSERT INTO usuaris VALUES (3857, 'Débora', 'Zamudio Saucedo', 'D', '56 Pl. Virgen Blanca', 8480, 'Debora.Zamudio.Saucedo@spambob.com', '22/06/78', 77, NULL);
INSERT INTO usuaris VALUES (3858, 'Mafalda', 'Urrútia Carbajal', 'D', '6 Avda. de la Estación', 28630, 'Mafalda.Urrutia.Carbajal@spambob.com', '06/03/83', 81, 3);
INSERT INTO usuaris VALUES (3859, 'Júpiter', 'Colunga Nevarez', 'H', '85 Avda. Los llanos', 26250, 'Jupiter.Colunga.Nevarez@pookmail.com', '04/11/48', 97, 1);
INSERT INTO usuaris VALUES (3860, 'Cindy', 'Llarnas Mares', 'D', '85 Caño', 32760, 'Cindy.Llarnas.Mares@mailinator.com', '15/04/85', 34, 6);
INSERT INTO usuaris VALUES (3861, 'Columbo', 'Muñoz Saldana', 'H', '18 Paraguay', 3578, 'Columbo.Munoz.Saldana@pookmail.com', '22/03/73', 78, 4);
INSERT INTO usuaris VALUES (3862, 'Adulfo', 'Murillo Zayas', 'H', '74 C/ Señores Curas', 11680, 'Adulfo.Murillo.Zayas@trashymail.com', '03/12/42', 89, 1);
INSERT INTO usuaris VALUES (3863, 'Chalten', 'Guardado Jaimes', 'H', '65 Carretera', 14812, 'Chalten.Guardado.Jaimes@pookmail.com', '09/02/75', 36, 10);
INSERT INTO usuaris VALUES (3864, 'Ascensión', 'Hurtado Sisneros', 'D', '44 Cañadilla', 21880, 'Ascension.Hurtado.Sisneros@pookmail.com', '25/06/80', 21, 7);
INSERT INTO usuaris VALUES (3865, 'Gaspar', 'Agosto Argüello', 'H', '95 Urzáiz', 45100, 'Gaspar.Agosto.Arguello@trashymail.com', '25/05/46', 88, 10);
INSERT INTO usuaris VALUES (3866, 'Plinio', 'Espinoza Benavidez', 'H', '11 C/ Hijuela de Lojo', 20268, 'Plinio.Espinoza.Benavidez@spambob.com', '21/05/78', 28, 4);
INSERT INTO usuaris VALUES (3867, 'Tránsito', 'Benítez Jimínez', 'D', '46 Carretera', 14546, 'Transito.Benitez.Jiminez@spambob.com', '28/01/59', 49, 8);
INSERT INTO usuaris VALUES (3868, 'Monserrat', 'Marín Arteaga', 'H', '2 Eusebio Dávila', 41450, 'Monserrat.Marin.Arteaga@mailinator.com', '26/10/79', 25, 6);
INSERT INTO usuaris VALUES (3869, 'Tulia', 'Pedroza Garibay', 'D', '22 Camiño Real', 48381, 'Tulia.Pedroza.Garibay@mailinator.com', '04/10/46', 7, 12);
INSERT INTO usuaris VALUES (3870, 'Elsira', 'Valle Linares', 'D', '75 Crta. Cádiz-Málaga', 12191, 'Elsira.Valle.Linares@pookmail.com', '05/09/45', 1, 8);
INSERT INTO usuaris VALUES (3871, 'Cleto', 'Valles Garibay', 'H', '61 Ctra. Villena', 33993, 'Cleto.Valles.Garibay@trashymail.com', '29/05/77', 98, 4);
INSERT INTO usuaris VALUES (3872, 'Agripino', 'Lozano Hernádez', 'H', '99 Zumalakarregi etorbidea', 7192, 'Agripino.Lozano.Hernadez@spambob.com', '03/02/43', 78, 3);
INSERT INTO usuaris VALUES (3873, 'Jasper', 'Abrego Villegas', 'H', '82 Visitación de la Encina', 37751, 'Jasper.Abrego.Villegas@spambob.com', '08/01/69', 34, NULL);
INSERT INTO usuaris VALUES (3874, 'Amaro', 'Valencia Aguayo', 'H', '73 Castelao', 48980, 'Amaro.Valencia.Aguayo@trashymail.com', '30/01/62', 62, 12);
INSERT INTO usuaris VALUES (3875, 'Ariadne', 'Cerda Negrete', 'D', '31 Ourense', 43420, 'Ariadne.Cerda.Negrete@pookmail.com', '16/12/85', 22, 5);
INSERT INTO usuaris VALUES (3876, 'Cuyén', 'Monroy Salas', 'H', '39 Calle Proc. San Sebastián', 13100, 'Cuyen.Monroy.Salas@trashymail.com', '06/11/51', 62, 5);
INSERT INTO usuaris VALUES (3877, 'Emanuel', 'Pantoja Madrigal', 'H', '65 C/ Henan Cortes', 28930, 'Emanuel.Pantoja.Madrigal@dodgit.com', '15/05/40', 7, 2);
INSERT INTO usuaris VALUES (3878, 'Ione', 'Saldivar Gallardo', 'H', '76 Plazuela do Porto', 38380, 'Ione.Saldivar.Gallardo@mailinator.com', '30/09/40', 43, 10);
INSERT INTO usuaris VALUES (3879, 'Covadonga', 'Jurado Quiroz', 'D', '59 C/ Angosto', 23450, 'Covadonga.Jurado.Quiroz@dodgit.com', '16/11/54', 52, 10);
INSERT INTO usuaris VALUES (3880, 'Eliú', 'Chapa Padrón', NULL, '3 Avda. Enrique Peinador', 37181, 'Eliu.Chapa.Padron@pookmail.com', '09/06/42', 90, 11);
INSERT INTO usuaris VALUES (3881, 'Othello', 'Vela Juárez', 'H', '29 Ctra. de la Puerta', 26586, 'Othello.Vela.Juarez@dodgit.com', '20/10/45', 86, 6);
INSERT INTO usuaris VALUES (3882, 'Ares', 'Viera Valadez', 'H', '27 Constitución', 36950, 'Ares.Viera.Valadez@pookmail.com', '07/06/59', 12, 1);
INSERT INTO usuaris VALUES (3883, 'Benny', 'Soto Mascarenas', 'H', '41 Camiño Ancho', 37767, 'Benny.Soto.Mascarenas@mailinator.com', '09/10/65', 87, 6);
INSERT INTO usuaris VALUES (3884, 'América', 'Baeza Regalado', 'D', '87 Socampo', 37607, 'America.Baeza.Regalado@trashymail.com', '20/09/69', 68, 11);
INSERT INTO usuaris VALUES (3885, 'Aciscio', 'Cárdenas Lerma', 'H', '11 C/ Cañada del Rosal', 21668, 'Aciscio.Cardenas.Lerma@dodgit.com', '23/12/85', 48, 1);
INSERT INTO usuaris VALUES (3886, 'Hanna', 'Lugo Acosta', 'D', '24 Plaza Colón', 26121, 'Hanna.Lugo.Acosta@dodgit.com', '01/12/62', 66, 5);
INSERT INTO usuaris VALUES (3887, 'Bertrán', 'Cisneros Trejo', 'H', '1 Avda. de la Estación', 28650, 'Bertran.Cisneros.Trejo@dodgit.com', '27/11/79', 60, 4);
INSERT INTO usuaris VALUES (3888, 'Day', 'Sauceda Ledesma', 'H', '23 C/ Señores Curas', 12140, 'Day.Sauceda.Ledesma@pookmail.com', '19/06/60', 57, 2);
INSERT INTO usuaris VALUES (3889, 'Silverio', 'Toledo Campos', 'H', '44 C/ Andalucía', 4560, 'Silverio.Toledo.Campos@dodgit.com', '24/07/48', 77, 5);
INSERT INTO usuaris VALUES (3890, 'Rosinda', 'Vargas Cerda', 'D', '96 Rosa de los Vientos', 13391, 'Rosinda.Vargas.Cerda@mailinator.com', '21/02/85', 52, 10);
INSERT INTO usuaris VALUES (3891, 'Miren', 'Macías Lomeli', 'D', '38 Pascual Yunquera', 18870, 'Miren.Macias.Lomeli@dodgit.com', '23/08/57', 6, 4);
INSERT INTO usuaris VALUES (3892, 'Jovanna', 'Vasquez Partida', 'D', '48 Boriñaur enparantza', 7580, 'Jovanna.Vasquez.Partida@spambob.com', '10/10/53', 32, 2);
INSERT INTO usuaris VALUES (3893, 'Nilce', 'Salinas Arteaga', 'D', '77 Avda. Enrique Peinador', 37181, 'Nilce.Salinas.Arteaga@mailinator.com', '24/10/45', 14, 4);
INSERT INTO usuaris VALUES (3894, 'Daila', 'Zamora Reyes', 'D', '11 Escuadro', 47155, 'Daila.Zamora.Reyes@spambob.com', '25/06/68', 45, 4);
INSERT INTO usuaris VALUES (3895, 'Josías', 'Villaseñor Castellanos', 'H', '43 Paraguay', 3670, 'Josias.Villasenor.Castellanos@mailinator.com', '03/04/49', 57, 1);
INSERT INTO usuaris VALUES (3896, 'Arlet', 'Rosario Ávalos', 'H', '54 Calle Proc. San Sebastián', 12599, 'Arlet.Rosario.Avalos@dodgit.com', '07/01/72', 17, 12);
INSERT INTO usuaris VALUES (3897, 'Benilda', 'Angulo Ojeda', 'D', '84 Avda. de la Estación', 28597, 'Benilda.Angulo.Ojeda@pookmail.com', '17/09/67', 75, 10);
INSERT INTO usuaris VALUES (3898, 'Ñambi', 'Marrero Carrillo', 'D', '89 Calle Carril de la Fuente', 13195, 'Nambi.Marrero.Carrillo@pookmail.com', '20/11/61', 46, 6);
INSERT INTO usuaris VALUES (3899, 'Crispo', 'Lara Curiel', 'H', '1 Atamaria', 36680, 'Crispo.Lara.Curiel@dodgit.com', '01/06/74', 89, 10);
INSERT INTO usuaris VALUES (3900, 'Karl', 'Robles Marroquín', 'H', '33 Bellavista', 50220, 'Karl.Robles.Marroquin@pookmail.com', '02/12/80', 89, 7);
INSERT INTO usuaris VALUES (3901, 'Cayo', 'Peres Montero', 'H', '65 Avda. Los llanos', 26292, 'Cayo.Peres.Montero@pookmail.com', '05/09/48', 51, 10);
INSERT INTO usuaris VALUES (3902, 'Yoshi', 'Otero Pineda', 'H', '2 Ctra. de Fuentenueva', 28296, 'Yoshi.Otero.Pineda@mailinator.com', '07/09/70', 81, 10);
INSERT INTO usuaris VALUES (3903, 'Ansaldo', 'Garza Gallardo', 'H', '95 Ctra. de Siles', 27377, 'Ansaldo.Garza.Gallardo@dodgit.com', '11/11/47', 0, 9);
INSERT INTO usuaris VALUES (3904, 'Leuco', 'Muro Oquendo', 'H', '64 Plaza Colón', 26124, 'Leuco.Muro.Oquendo@spambob.com', '08/03/59', 65, 1);
INSERT INTO usuaris VALUES (3905, 'Iael', 'Lira Guillén', NULL, '55 Herrería', 18190, 'Iael.Lira.Guillen@spambob.com', '26/12/48', 53, 11);
INSERT INTO usuaris VALUES (3906, 'Augustus', 'Perea Marroquín', 'H', '99 Reyes Católicos', 9250, 'Augustus.Perea.Marroquin@trashymail.com', '29/01/54', 24, 10);
INSERT INTO usuaris VALUES (3907, 'Cesarión', 'Bermúdez Posada', 'H', '93 Socampo', 37691, 'Cesarion.Bermudez.Posada@pookmail.com', '07/03/56', NULL, 10);
INSERT INTO usuaris VALUES (3908, 'Fredel', 'Carrasco Vergara', 'D', '17 Av. Santiago Lapuente', 50786, 'Fredel.Carrasco.Vergara@trashymail.com', '10/08/82', 37, 1);
INSERT INTO usuaris VALUES (3909, 'Panbil', 'Aranda Menchaca', 'H', '59 Paseo Junquera', 12447, 'Panbil.Aranda.Menchaca@pookmail.com', '11/12/59', 1, 9);
INSERT INTO usuaris VALUES (3910, 'Olmo', 'Haro Quiñónez', 'H', '36 Plaza de España', 15619, 'Olmo.Haro.Quinonez@mailinator.com', '20/04/41', 32, 5);
INSERT INTO usuaris VALUES (3911, 'Constance', 'Negrón Echevarría', 'D', '40 C/ Benito Guinea', 8380, 'Constance.Negron.Echevarria@trashymail.com', '12/04/49', 49, 12);
INSERT INTO usuaris VALUES (3912, 'Christine', 'Bañuelos Zarate', 'D', '79 C/ Canarias', 20180, 'Christine.Banuelos.Zarate@trashymail.com', '06/05/41', 11, 6);
INSERT INTO usuaris VALUES (3913, 'Kira', 'Rael Toro', 'D', '27 Alcon Molina', 30840, 'Kira.Rael.Toro@trashymail.com', '19/07/73', 63, 9);
INSERT INTO usuaris VALUES (3914, 'Caren', 'Rubio Covas', 'D', '75 Paseo Junquera', 12469, 'Caren.Rubio.Covas@mailinator.com', '06/03/64', 72, 10);
INSERT INTO usuaris VALUES (3915, 'Jenara', 'Sauceda Bernal', 'D', '63 Av. Santiago Lapuente', 50780, 'Jenara.Sauceda.Bernal@trashymail.com', '23/04/84', 21, 11);
INSERT INTO usuaris VALUES (3916, 'Larissa', 'Saldana Medina', 'D', '67 San Andrés', 37251, 'Larissa.Saldana.Medina@pookmail.com', '02/10/55', 79, 11);
INSERT INTO usuaris VALUES (3917, 'Melibea', 'León Angulo', 'D', '9 Ctra. Bailén-Motril', 23292, 'Melibea.Leon.Angulo@pookmail.com', '20/01/56', 53, NULL);
INSERT INTO usuaris VALUES (3918, 'Wilmer', 'Batista Lebrón', 'H', '52 Prolongacion San Sebastian', 21320, 'Wilmer.Batista.Lebron@spambob.com', '06/03/42', 66, 1);
INSERT INTO usuaris VALUES (3919, 'Favian', 'Muro Esquivel', 'H', '49 C/ Libertad', 5410, 'Favian.Muro.Esquivel@pookmail.com', '20/05/67', 98, 5);
INSERT INTO usuaris VALUES (3920, 'Bennie', 'Méndez Veliz', 'H', '98 Alcon Molina', 30740, 'Bennie.Mendez.Veliz@dodgit.com', '23/11/51', 15, 10);
INSERT INTO usuaris VALUES (3921, 'Cupido', 'Aranda Medrano', 'H', '5 Inglaterra', 18658, 'Cupido.Aranda.Medrano@dodgit.com', '12/09/51', 9, 1);
INSERT INTO usuaris VALUES (3922, 'Merced', 'Esquivel Carrasquill', 'D', '92 C/ Angosto', 23470, 'Merced.Esquivel.Carrasquill@spambob.com', '24/02/60', 24, 11);
INSERT INTO usuaris VALUES (3923, 'Elisa', 'Covarrubias Collado', 'D', '75 Calle Carril de la Fuente', 13326, 'Elisa.Covarrubias.Collado@trashymail.com', '22/07/68', 49, NULL);
INSERT INTO usuaris VALUES (3924, 'Semarias', 'Villa Trejo', 'H', '65 Valadouro', 48140, 'Semarias.Villa.Trejo@dodgit.com', '20/10/51', 70, 9);
INSERT INTO usuaris VALUES (3925, 'Lara', 'Roldán Grijalva', 'D', '28 C/ Domingo Beltrán', 2220, 'Lara.Roldan.Grijalva@trashymail.com', '08/04/64', 40, 1);
INSERT INTO usuaris VALUES (3926, 'Lev', 'Árias Luján', 'H', '55 Reiseñor', 45593, 'Lev.Arias.Lujan@mailinator.com', '14/05/53', 54, 6);
INSERT INTO usuaris VALUES (3927, 'Licerio', 'Castillo Noriega', 'H', '83 Avda. Los llanos', 26291, 'Licerio.Castillo.Noriega@mailinator.com', '21/07/44', 15, 9);
INSERT INTO usuaris VALUES (3928, 'Itaete', 'Martínez Gonzales', 'H', '8 Calvo Sotelo', 47420, 'Itaete.Martinez.Gonzales@pookmail.com', '28/08/52', 6, 10);
INSERT INTO usuaris VALUES (3929, 'Radegunda', 'Zapata Ayala', 'D', '40 El Roqueo', 15885, 'Radegunda.Zapata.Ayala@pookmail.com', '15/06/64', NULL, 3);
INSERT INTO usuaris VALUES (3930, 'Balduino', 'Guzmán Balderas', 'H', '49 C/ Señores Curas', 12162, 'Balduino.Guzman.Balderas@mailinator.com', '18/10/63', 54, 3);
INSERT INTO usuaris VALUES (3931, 'Monique', 'Guerra Caraballo', 'D', '29 Escuadro', 47193, 'Monique.Guerra.Caraballo@trashymail.com', '21/06/51', 21, 3);
INSERT INTO usuaris VALUES (3932, 'Ettiene', 'Cervántez Terrazas', 'H', '38 C/ Libertad', 5450, 'Ettiene.Cervantez.Terrazas@dodgit.com', '17/06/44', 17, 4);
INSERT INTO usuaris VALUES (3933, 'Tais', 'Mares Olivares', 'D', '16 Socampo', 37619, 'Tais.Mares.Olivares@pookmail.com', '30/04/51', 2, 9);
INSERT INTO usuaris VALUES (3934, 'Orson', 'Tovar Montemayor', NULL, '18 Avda. Andalucía', 26190, 'Orson.Tovar.Montemayor@dodgit.com', '15/11/53', 26, 6);
INSERT INTO usuaris VALUES (3935, 'Janet', 'Salcido Marroquín', NULL, '27 C/ Hijuela de Lojo', 20248, 'Janet.Salcido.Marroquin@pookmail.com', '25/10/67', 37, 1);
INSERT INTO usuaris VALUES (3936, 'Mireille', 'Zapata Escobedo', 'D', '2 Canónigo Valiño', 46370, 'Mireille.Zapata.Escobedo@dodgit.com', '09/07/64', 17, 12);
INSERT INTO usuaris VALUES (3937, 'Procopio', 'Leal Muro', 'H', '87 C/ Eras', 28755, 'Procopio.Leal.Muro@pookmail.com', '28/09/57', 87, 12);
INSERT INTO usuaris VALUES (3938, 'Sahara', 'Camarillo Vanegas', 'D', '74 Avda. Enrique Peinador', 37171, 'Sahara.Camarillo.Vanegas@pookmail.com', '07/05/67', 29, 10);
INSERT INTO usuaris VALUES (3939, 'Augustus', 'Rolón Roybal', 'H', '21 Estrela', 38820, 'Augustus.Rolon.Roybal@spambob.com', '03/11/65', 4, 8);
INSERT INTO usuaris VALUES (3940, 'Nehuén', 'Jasso Sierra', 'H', '39 Ctra. Villena', 34190, 'Nehuen.Jasso.Sierra@dodgit.com', '25/02/79', 16, 11);
INSERT INTO usuaris VALUES (3941, 'Ticiana', 'Negrón Rendón', NULL, '80 Paseo del Atlántico', 17257, 'Ticiana.Negron.Rendon@spambob.com', '14/09/56', 73, 7);
INSERT INTO usuaris VALUES (3942, 'Salvatore', 'Sánchez Viera', 'H', '14 Avda. Generalísimo', 32137, 'Salvatore.Sanchez.Viera@dodgit.com', '05/09/70', 24, 9);
INSERT INTO usuaris VALUES (3943, 'Constancio', 'Saldana Ceballos', 'H', '80 Ctra. Beas-Cortijos Nuevos', 26513, 'Constancio.Saldana.Ceballos@trashymail.com', '18/10/61', 3, 12);
INSERT INTO usuaris VALUES (3944, 'Emma', 'Leal Arteaga', 'D', '26 Padre Caro', 13700, 'Emma.Leal.Arteaga@mailinator.com', '24/03/76', 44, 7);
INSERT INTO usuaris VALUES (3945, 'Electra', 'Armenta Candelaria', 'D', '90 Carretera', 14550, 'Electra.Armenta.Candelaria@mailinator.com', '08/07/62', 82, 12);
INSERT INTO usuaris VALUES (3946, 'Melibea', 'Carrera Alva', 'D', '78 Enxertos', 37555, 'Melibea.Carrera.Alva@trashymail.com', '29/04/71', 8, 7);
INSERT INTO usuaris VALUES (3947, 'Cala', 'Holguín Alicea', 'D', '70 Cádiz', 18439, 'Cala.Holguin.Alicea@pookmail.com', '20/03/81', 13, NULL);
INSERT INTO usuaris VALUES (3948, 'Alfeo', 'Ponce Domínquez', 'H', '73 Avda. Enrique Peinador', 37184, 'Alfeo.Ponce.Dominquez@mailinator.com', '09/07/85', 18, 1);
INSERT INTO usuaris VALUES (3949, 'Elizabeth', 'Magana Jaramillo', 'D', '4 Carretera Cádiz-Málaga', 20730, 'Elizabeth.Magana.Jaramillo@dodgit.com', '19/10/55', 2, 5);
INSERT INTO usuaris VALUES (3950, 'Narellla', 'Cantú Jasso', 'D', '28 Rúa de San Pedro', 37795, 'Narellla.Cantu.Jasso@trashymail.com', '10/02/56', 18, 6);
INSERT INTO usuaris VALUES (3951, 'Wanda', 'Leyva Llarnas', 'D', '3 Alcon Molina', 30870, 'Wanda.Leyva.Llarnas@spambob.com', '26/10/83', 53, 11);
INSERT INTO usuaris VALUES (3952, 'Kristopher', 'Centeno López', 'H', '19 C/ Eras', 28729, 'Kristopher.Centeno.Lopez@trashymail.com', '20/01/42', 72, 11);
INSERT INTO usuaris VALUES (3953, 'Panbil', 'Barreto Banda', 'H', '53 Valadouro', 48112, 'Panbil.Barreto.Banda@mailinator.com', '11/10/81', 12, 5);
INSERT INTO usuaris VALUES (3954, 'Baruj', 'Iglesias Bonilla', 'H', '93 Castelao', 48990, 'Baruj.Iglesias.Bonilla@dodgit.com', '31/05/46', 81, NULL);
INSERT INTO usuaris VALUES (3955, 'Giovanna', 'Chávez Hidalgo', 'D', '34 Calvo Sotelo', 47230, 'Giovanna.Chavez.Hidalgo@dodgit.com', '29/03/75', 56, 9);
INSERT INTO usuaris VALUES (3956, 'Shirley', 'Hinojosa Calvillo', 'D', '62 Crta. Cádiz-Málaga', 12191, 'Shirley.Hinojosa.Calvillo@spambob.com', '28/07/41', 75, 7);
INSERT INTO usuaris VALUES (3957, 'Misael', 'Fernández Garay', 'H', '9 C/ Eras', 28749, 'Misael.Fernandez.Garay@spambob.com', '26/02/40', 73, 12);
INSERT INTO usuaris VALUES (3958, 'Roque', 'Carrasco Domínquez', 'H', '97 Ctra. de la Puerta', 27150, 'Roque.Carrasco.Dominquez@trashymail.com', '27/08/54', 11, 4);
INSERT INTO usuaris VALUES (3959, 'Macedonio', 'Pantoja Mercado', 'H', '21 Boriñaur enparantza', 7420, 'Macedonio.Pantoja.Mercado@trashymail.com', '01/10/80', 32, 9);
INSERT INTO usuaris VALUES (3960, 'Vittorio', 'Sosa Olivo', 'H', '70 C/ Arana', 2410, 'Vittorio.Sosa.Olivo@spambob.com', '10/03/68', 23, NULL);
INSERT INTO usuaris VALUES (3961, 'Eleonor', 'Haro Alicea', 'D', '31 Pza. Fuensanta', 32411, 'Eleonor.Haro.Alicea@mailinator.com', '12/05/85', 18, 1);
INSERT INTO usuaris VALUES (3962, 'Suyay', 'Tejeda Meraz', 'D', '92 Calle Aduana', 1138, 'Suyay.Tejeda.Meraz@spambob.com', '15/07/75', 20, 4);
INSERT INTO usuaris VALUES (3963, 'Dalmazio', 'Murillo Ybarra', 'H', '31 Maestro Puig Valera', 33720, 'Dalmazio.Murillo.Ybarra@spambob.com', '29/01/44', 59, 2);
INSERT INTO usuaris VALUES (3964, 'Eustasio', 'Carrasquill Ybarra', 'H', '80 Cañadilla', 22270, 'Eustasio.Carrasquill.Ybarra@pookmail.com', '29/01/52', 58, 9);
INSERT INTO usuaris VALUES (3965, 'Menna', 'Cantú Rosado', 'D', '93 Avda. de la Estación', 28596, 'Menna.Cantu.Rosado@trashymail.com', '05/03/55', 64, 8);
INSERT INTO usuaris VALUES (3966, 'Hada', 'Almaraz Orosco', 'D', '12 Reiseñor', 46160, 'Hada.Almaraz.Orosco@mailinator.com', '17/04/47', 79, 3);
INSERT INTO usuaris VALUES (3967, 'Claus', 'Espinosa Ibarra', 'H', '25 Camiño Real', 48395, 'Claus.Espinosa.Ibarra@spambob.com', '12/03/44', 78, 11);
INSERT INTO usuaris VALUES (3968, 'Eusebia', 'Covas Orozco', 'D', '17 Bellavista', 50230, 'Eusebia.Covas.Orozco@trashymail.com', '31/08/73', 1, 11);
INSERT INTO usuaris VALUES (3969, 'Sinesio', 'Casanova Montalvo', 'H', '13 Herrería', 18197, 'Sinesio.Casanova.Montalvo@spambob.com', '09/09/81', 57, 8);
INSERT INTO usuaris VALUES (3970, 'Procopio', 'Otero Rivero', 'H', '54 Calvo Sotelo', 47195, 'Procopio.Otero.Rivero@pookmail.com', '09/01/55', 87, 2);
INSERT INTO usuaris VALUES (3971, 'Nydia', 'Guerrero Romo', 'D', '53 Rua da Rapina', 37480, 'Nydia.Guerrero.Romo@trashymail.com', '07/02/47', 55, 6);
INSERT INTO usuaris VALUES (3972, 'Eleonora', 'Puga Rosado', 'D', '18 Valadouro', 48145, 'Eleonora.Puga.Rosado@mailinator.com', '20/11/75', 49, 7);
INSERT INTO usuaris VALUES (3973, 'Tea', 'Gaitán Marrero', 'D', '92 Rúa Olmos', 37400, 'Tea.Gaitan.Marrero@mailinator.com', '06/06/52', 64, 12);
INSERT INTO usuaris VALUES (3974, 'Raphael', 'López Olivares', 'H', '80 Avenida Cervantes', 48311, 'Raphael.Lopez.Olivares@spambob.com', '04/09/58', 68, 1);
INSERT INTO usuaris VALUES (3975, 'Lutgarda', 'Arellano Saavedra', 'D', '56 Alvaro Cunqueiro', 41220, 'Lutgarda.Arellano.Saavedra@dodgit.com', '17/05/49', 84, 11);
INSERT INTO usuaris VALUES (3976, 'Nilo', 'Delgadillo Loera', 'H', '29 Av. Zumalakarregi', 3190, 'Nilo.Delgadillo.Loera@mailinator.com', '17/04/78', 29, 5);
INSERT INTO usuaris VALUES (3977, 'Ofelia', 'Collado Rojas', 'D', '39 Calle Proc. San Sebastián', 13108, 'Ofelia.Collado.Rojas@mailinator.com', '26/07/85', 89, 10);
INSERT INTO usuaris VALUES (3978, 'Licinio', 'Briseño Dávila', 'H', '32 Maestro Puig Valera', 33570, 'Licinio.Briseno.Davila@spambob.com', '29/03/78', 64, 1);
INSERT INTO usuaris VALUES (3979, 'Fidelio', 'Abeyta Tijerina', 'H', '63 Avda. Generalísimo', 31797, 'Fidelio.Abeyta.Tijerina@dodgit.com', '12/08/78', 60, 8);
INSERT INTO usuaris VALUES (3980, 'Mathilda', 'Corrales Ulibarri', 'D', '42 Alvaro Cunqueiro', 41111, 'Mathilda.Corrales.Ulibarri@mailinator.com', '11/03/63', 18, 1);
INSERT INTO usuaris VALUES (3981, 'Seraphin', 'Navarrete Palomo', 'H', '61 Calle Proc. San Sebastián', 13110, 'Seraphin.Navarrete.Palomo@pookmail.com', '08/12/62', 3, 7);
INSERT INTO usuaris VALUES (3982, 'Rudolf', 'Pedraza Escalante', 'H', '69 Ctra. de Siles', 27340, 'Rudolf.Pedraza.Escalante@spambob.com', '18/04/55', 19, 2);
INSERT INTO usuaris VALUES (3983, 'Emelia', 'Sevilla Juárez', 'D', '9 Atamaria', 36770, 'Emelia.Sevilla.Juarez@pookmail.com', '21/04/63', 52, 7);
INSERT INTO usuaris VALUES (3984, 'Archibaldo', 'Hurtado Riojas', 'H', '88 Eusebio Dávila', 41500, 'Archibaldo.Hurtado.Riojas@dodgit.com', '30/10/71', 47, 11);
INSERT INTO usuaris VALUES (3985, 'Silvana', 'Madrigal Olivas', 'D', '45 Eusebio Dávila', 41530, 'Silvana.Madrigal.Olivas@pookmail.com', '13/12/78', 20, 6);
INSERT INTO usuaris VALUES (3986, 'Babs', 'Rocha Soliz', 'D', '35 Ctra. de la Puerta', 27240, 'Babs.Rocha.Soliz@spambob.com', '12/08/43', 76, 1);
INSERT INTO usuaris VALUES (3987, 'Loris', 'Zambrano Polanco', 'D', '17 Fuente del Gallo', 15124, 'Loris.Zambrano.Polanco@pookmail.com', '13/01/64', 78, 2);
INSERT INTO usuaris VALUES (3988, 'Atila', 'Acevedo Ordóñez', 'H', '86 Bouciña', 43830, 'Atila.Acevedo.Ordonez@trashymail.com', '20/04/67', 18, 1);
INSERT INTO usuaris VALUES (3989, 'Inalén', 'Feliciano Cazares', 'D', '28 Castelao', 49100, 'Inalen.Feliciano.Cazares@pookmail.com', '19/05/47', 82, 12);
INSERT INTO usuaris VALUES (3990, 'Isberga', 'Soto Irizarry', 'D', '85 Salzillo', 32570, 'Isberga.Soto.Irizarry@spambob.com', '05/07/74', 71, 4);
INSERT INTO usuaris VALUES (3991, 'Sereno', 'Barreto Ceja', 'H', '72 Plaza de España', 15683, 'Sereno.Barreto.Ceja@dodgit.com', '25/01/47', 37, 10);
INSERT INTO usuaris VALUES (3992, 'Adelmaro', 'Gutiérrez Galarza', 'H', '63 C/ Hijuela de Lojo', 20490, 'Adelmaro.Gutierrez.Galarza@trashymail.com', '16/02/76', 3, 8);
INSERT INTO usuaris VALUES (3993, 'Pelegrino', 'García Castaneda', 'H', '33 Rosa de los Vientos', 13411, 'Pelegrino.Garcia.Castaneda@pookmail.com', '03/10/85', 32, 8);
INSERT INTO usuaris VALUES (3994, 'Pascualina', 'Alonzo Casárez', 'D', '44 Pl. Virgen Blanca', 8500, 'Pascualina.Alonzo.Casarez@pookmail.com', '13/03/68', 21, 10);
INSERT INTO usuaris VALUES (3995, 'Ceferino', 'Badillo Marín', 'H', '66 Reiseñor', 45860, 'Ceferino.Badillo.Marin@pookmail.com', '18/01/80', 90, 8);
INSERT INTO usuaris VALUES (3996, 'Adelaida', 'Aparicio Cintrón', NULL, '17 Canónigo Valiño', 46700, 'Adelaida.Aparicio.Cintron@dodgit.com', '31/10/41', 91, NULL);
INSERT INTO usuaris VALUES (3997, 'Enon', 'Garza Mata', 'H', '52 Visitación de la Encina', 37762, 'Enon.Garza.Mata@dodgit.com', '16/02/57', 88, 7);
INSERT INTO usuaris VALUES (3998, 'Austín', 'Villa Irizarry', 'H', '56 Boriñaur enparantza', 7420, 'Austin.Villa.Irizarry@trashymail.com', '25/11/68', 57, 1);
INSERT INTO usuaris VALUES (3999, 'Estefania', 'Olivares Jaime', 'D', '92 Bellavista', 49622, 'Estefania.Olivares.Jaime@mailinator.com', '22/02/83', 54, NULL);
INSERT INTO usuaris VALUES (4000, 'Albertina', 'Torres Correa', 'D', '56 Ourense', 43144, 'Albertina.Torres.Correa@spambob.com', '06/04/71', 50, 12);
INSERT INTO usuaris VALUES (4001, 'Meinard', 'Ontiveros Montalvo', 'H', '38 Canónigo Valiño', 46540, 'Meinard.Ontiveros.Montalvo@pookmail.com', '09/08/71', 93, 12);
INSERT INTO usuaris VALUES (4002, 'Alano', 'Apodaca Ocasio', 'H', '35 Alvaro Cunqueiro', 40360, 'Alano.Apodaca.Ocasio@mailinator.com', '31/03/50', 53, NULL);
INSERT INTO usuaris VALUES (4003, 'Takara', 'Urías Marrero', 'D', '79 Ctra. Bailén-Motril', 23330, 'Takara.Urias.Marrero@pookmail.com', '22/03/51', 59, 8);
INSERT INTO usuaris VALUES (4004, 'Erik', 'Rangel Pina', 'H', '29 Avda. Alameda Sundheim', 23110, 'Erik.Rangel.Pina@pookmail.com', '07/01/42', 12, 2);
INSERT INTO usuaris VALUES (4005, 'Lucila', 'Bravo Amador', 'D', '52 Puerta Nueva', 36416, 'Lucila.Bravo.Amador@trashymail.com', '08/10/72', 29, 1);
INSERT INTO usuaris VALUES (4006, 'Eliora', 'Bernal Aguilar', 'D', '9 Rio Segura', 31380, 'Eliora.Bernal.Aguilar@mailinator.com', '17/04/51', 34, 8);
INSERT INTO usuaris VALUES (4007, 'Desirée', 'Acuna Morales', 'D', '35 Constitución', 37129, 'Desiree.Acuna.Morales@dodgit.com', '24/06/82', 16, 7);
INSERT INTO usuaris VALUES (4008, 'Adair', 'Martínez Muro', 'H', '95 C/ Cañada del Rosal', 21660, 'Adair.Martinez.Muro@mailinator.com', '08/11/46', 74, 2);
INSERT INTO usuaris VALUES (4009, 'Edita', 'Salgado Guajardo', 'D', '49 C/ Henan Cortes', 28940, 'Edita.Salgado.Guajardo@trashymail.com', '12/03/64', 71, 6);
INSERT INTO usuaris VALUES (4010, 'Angie', 'Sanabria Morales', 'D', '33 Ctra. Villena', 34440, 'Angie.Sanabria.Morales@pookmail.com', '21/08/75', 24, 5);
INSERT INTO usuaris VALUES (4011, 'Angelo', 'Muñoz Rojo', 'H', '66 Lamas Carbajal', 41569, 'Angelo.Munoz.Rojo@mailinator.com', '22/04/44', 37, 1);
INSERT INTO usuaris VALUES (4012, 'Líbano', 'Ortiz Saucedo', 'H', '40 Pascual Yunquera', 18816, 'Libano.Ortiz.Saucedo@spambob.com', '20/07/50', 82, 1);
INSERT INTO usuaris VALUES (4013, 'Misky', 'Yáñez Berrios', 'D', '28 Calle Proc. San Sebastián', 12549, 'Misky.Yanez.Berrios@spambob.com', '06/09/46', 69, 7);
INSERT INTO usuaris VALUES (4014, 'Tiziana', 'Segura Villalobos', 'D', '10 Avenida Cervantes', 48289, 'Tiziana.Segura.Villalobos@mailinator.com', '26/07/85', 23, 3);
INSERT INTO usuaris VALUES (4015, 'Noelio', 'Aponte Barrientos', 'H', '64 Escuadro', 46930, 'Noelio.Aponte.Barrientos@pookmail.com', '04/01/85', 76, 9);
INSERT INTO usuaris VALUES (4016, 'Fermín', 'Ceja Velázquez', 'H', '59 Cartagena', 30360, 'Fermin.Ceja.Velazquez@dodgit.com', '01/06/78', 58, 8);
INSERT INTO usuaris VALUES (4017, 'Idelina', 'Alicea Barrientos', 'D', '85 Paseo del Atlántico', 17244, 'Idelina.Alicea.Barrientos@pookmail.com', '27/12/68', 16, 8);
INSERT INTO usuaris VALUES (4018, 'Angus', 'Roybal Arévalo', 'H', '21 Avda. Explanada Barnuevo', 35300, 'Angus.Roybal.Arevalo@spambob.com', '25/01/59', 7, 5);
INSERT INTO usuaris VALUES (4019, 'Louis', 'Abreu Lugo', 'H', '37 Avda. Enrique Peinador', 37148, 'Louis.Abreu.Lugo@pookmail.com', '04/05/81', 14, 1);
INSERT INTO usuaris VALUES (4020, 'Nicholai', 'Fierro Pedroza', 'H', '31 Extramuros', 28430, 'Nicholai.Fierro.Pedroza@mailinator.com', '30/11/46', 40, 6);
INSERT INTO usuaris VALUES (4021, 'Gianira', 'Godínez Romero', 'D', '65 C/ Angosto', 23591, 'Gianira.Godinez.Romero@pookmail.com', '31/05/54', 20, 5);
INSERT INTO usuaris VALUES (4022, 'Maciela', 'Cadena Vázquez', 'D', '17 Plaza Colón', 26100, 'Maciela.Cadena.Vazquez@trashymail.com', '30/03/77', 17, 9);
INSERT INTO usuaris VALUES (4023, 'Delfín', 'Guzmán Rivera', 'H', '73 Pascual Yunquera', 18660, 'Delfin.Guzman.Rivera@mailinator.com', '21/12/76', 51, 12);
INSERT INTO usuaris VALUES (4024, 'Ariadna', 'Mascarenas Rincón', NULL, '32 Escuadro', 46860, 'Ariadna.Mascarenas.Rincon@trashymail.com', '28/12/79', 19, 12);
INSERT INTO usuaris VALUES (4025, 'Sempronio', 'Pedraza Meraz', 'H', '30 Enxertos', 37512, 'Sempronio.Pedraza.Meraz@trashymail.com', '20/02/83', 38, NULL);
INSERT INTO usuaris VALUES (4026, 'Baldo', 'Pena Guerrero', 'H', '83 Canónigo Valiño', 46470, 'Baldo.Pena.Guerrero@mailinator.com', '18/08/80', 49, 1);
INSERT INTO usuaris VALUES (4027, 'Gaudencio', 'Méndez Ríos', 'H', '59 Cádiz', 18510, 'Gaudencio.Mendez.Rios@mailinator.com', '04/10/62', 59, 6);
INSERT INTO usuaris VALUES (4028, 'Ibar', 'Zayas Rubio', 'H', '39 Eusebio Dávila', 41380, 'Ibar.Zayas.Rubio@pookmail.com', '15/02/85', 37, 11);
INSERT INTO usuaris VALUES (4029, 'Elijah', 'Aragón Betancourt', 'H', '40 Paseo Junquera', 12470, 'Elijah.Aragon.Betancourt@trashymail.com', '26/12/67', 48, 4);
INSERT INTO usuaris VALUES (4030, 'Vital', 'Abrego Gaitán', 'H', '71 Plaza Maior', 37191, 'Vital.Abrego.Gaitan@spambob.com', '29/07/81', 54, 8);
INSERT INTO usuaris VALUES (4031, 'Casta', 'Alvarado Benavidez', 'D', '67 Socampo', 37658, 'Casta.Alvarado.Benavidez@mailinator.com', '05/08/61', 92, 2);
INSERT INTO usuaris VALUES (4032, 'Periandro', 'Matos Sisneros', 'H', '10 Rosa de los Vientos', 13413, 'Periandro.Matos.Sisneros@mailinator.com', '12/02/58', 36, 10);
INSERT INTO usuaris VALUES (4033, 'Kelly', 'Santacruz Rosado', 'D', '19 Pl. Virgen Blanca', 8480, 'Kelly.Santacruz.Rosado@spambob.com', '16/12/75', 59, 12);
INSERT INTO usuaris VALUES (4034, 'Zelmira', 'Serrano Villalobos', 'D', '63 Rua da Rapina', 37468, 'Zelmira.Serrano.Villalobos@trashymail.com', '03/12/50', 87, 9);
INSERT INTO usuaris VALUES (4035, 'Licio', 'Núñez Negrón', 'H', '18 Avda. de Andalucía', 29450, 'Licio.Nunez.Negron@dodgit.com', '13/02/60', 74, 5);
INSERT INTO usuaris VALUES (4036, 'Tecla', 'Henríquez Rico', 'D', '91 Avda. Alameda Sundheim', 23130, 'Tecla.Henriquez.Rico@spambob.com', '19/01/41', 25, 11);
INSERT INTO usuaris VALUES (4037, 'Jael', 'Laboy Castaneda', 'H', '56 C/ Hijuela de Lojo', 20491, 'Jael.Laboy.Castaneda@trashymail.com', '05/02/53', 40, 7);
INSERT INTO usuaris VALUES (4038, 'Herodes', 'Hidalgo Salcedo', 'H', '26 Calle Aduana', 1240, 'Herodes.Hidalgo.Salcedo@trashymail.com', '15/01/84', 66, 5);
INSERT INTO usuaris VALUES (4039, 'Yamal', 'Méndez Salinas', 'H', '49 Lamas Carbajal', 41800, 'Yamal.Mendez.Salinas@dodgit.com', '24/06/57', 54, 2);
INSERT INTO usuaris VALUES (4040, 'Bertoldo', 'Espinal Márquez', 'H', '89 Ctra. de Fuentenueva', 28293, 'Bertoldo.Espinal.Marquez@pookmail.com', '14/11/54', 33, 10);
INSERT INTO usuaris VALUES (4041, 'Miles', 'Anguiano Galarza', 'H', '95 Avda. Alameda Sundheim', 22520, 'Miles.Anguiano.Galarza@dodgit.com', '21/10/77', 66, 11);
INSERT INTO usuaris VALUES (4042, 'Lily', 'Caballero Sevilla', 'D', '10 C/ Señores Curas', 11688, 'Lily.Caballero.Sevilla@mailinator.com', '20/11/49', 69, 1);
INSERT INTO usuaris VALUES (4043, 'Karem', 'Fajardo Beltrán', NULL, '82 Paseo del Atlántico', 17257, 'Karem.Fajardo.Beltran@mailinator.com', '28/03/70', 51, 1);
INSERT INTO usuaris VALUES (4044, 'Donaldo', 'Montez Melgar', NULL, '39 Carretera Cádiz-Málaga', 21000, 'Donaldo.Montez.Melgar@mailinator.com', '20/12/76', 43, 10);
INSERT INTO usuaris VALUES (4045, 'Jonas', 'Montero Callas', 'H', '85 Avda. Explanada Barnuevo', 35530, 'Jonas.Montero.Callas@dodgit.com', NULL, 37, 8);
INSERT INTO usuaris VALUES (4046, 'Stella', 'Pina Armas', 'D', '85 Ctra. Bailén-Motril', 23191, 'Stella.Pina.Armas@spambob.com', '30/10/72', 89, 2);
INSERT INTO usuaris VALUES (4047, 'Heráclito', 'Sisneros Zúñiga', 'H', '30 Puerto Lugar', 29712, 'Heraclito.Sisneros.Zuniga@dodgit.com', '09/04/52', 6, 8);
INSERT INTO usuaris VALUES (4048, 'Vita', 'Negrón Rincón', NULL, '34 C/ Libertad', 5216, 'Vita.Negron.Rincon@mailinator.com', '14/01/56', 5, 8);
INSERT INTO usuaris VALUES (4049, 'Audomaro', 'Leiva Tamayo', 'H', '45 C/ Eras', 28738, 'Audomaro.Leiva.Tamayo@mailinator.com', '26/05/57', 62, NULL);
INSERT INTO usuaris VALUES (4050, 'Solana', 'García Girón', NULL, '43 C/ Los Herrán', 6700, 'Solana.Garcia.Giron@trashymail.com', '12/06/80', 94, 2);
INSERT INTO usuaris VALUES (4051, 'Getulio', 'Sanabria Alonso', 'H', '80 Urzáiz', 44100, 'Getulio.Sanabria.Alonso@trashymail.com', '07/06/67', 80, 9);
INSERT INTO usuaris VALUES (4052, 'Isaias', 'Velez Loya', 'H', '21 Rua da Rapina', 37491, 'Isaias.Velez.Loya@spambob.com', '16/01/62', 67, 12);
INSERT INTO usuaris VALUES (4053, 'Candy', 'Montés Cortés', 'D', '76 Rosa de los Vientos', 13420, 'Candy.Montes.Cortes@pookmail.com', '28/11/62', 56, 9);
INSERT INTO usuaris VALUES (4054, 'Lutero', 'Salcido Saucedo', 'H', '82 C/ Cañada del Rosal', 21647, 'Lutero.Salcido.Saucedo@dodgit.com', '15/04/45', 31, 11);
INSERT INTO usuaris VALUES (4055, 'Natalio', 'Lovato Velasco', 'H', '64 Estrela', 38911, 'Natalio.Lovato.Velasco@spambob.com', '03/05/47', 56, 7);
INSERT INTO usuaris VALUES (4056, 'Elia', 'Serrato Solórzano', 'D', '98 Rúa do Paseo', 41960, 'Elia.Serrato.Solorzano@mailinator.com', '24/02/41', 54, 7);
INSERT INTO usuaris VALUES (4057, 'Generoso', 'Montés Dueñas', 'H', '18 Maestro Puig Valera', 33700, 'Generoso.Montes.Duenas@spambob.com', '21/07/45', 20, 3);
INSERT INTO usuaris VALUES (4058, 'Beverly', 'Ceballos Casárez', 'D', '18 Celso Emilio Ferreiro', 50400, 'Beverly.Ceballos.Casarez@pookmail.com', '19/03/73', 31, 3);
INSERT INTO usuaris VALUES (4059, 'Kapriel', 'Gallardo Zamudio', 'D', '48 Extramuros', 28350, 'Kapriel.Gallardo.Zamudio@mailinator.com', '28/06/52', 92, NULL);
INSERT INTO usuaris VALUES (4060, 'Generoso', 'Cintrón Vega', 'H', '4 Alcon Molina', 31210, 'Generoso.Cintron.Vega@pookmail.com', '10/08/78', 73, 7);
INSERT INTO usuaris VALUES (4061, 'Luciana', 'Jimínez Rodarte', 'D', '44 Avda. de la Estación', 28596, 'Luciana.Jiminez.Rodarte@trashymail.com', '22/01/78', 46, NULL);
INSERT INTO usuaris VALUES (4062, 'Orígenes', 'Puente Haro', 'H', '65 Comandante Izarduy', 8820, 'Origenes.Puente.Haro@spambob.com', '03/05/84', 37, 6);
INSERT INTO usuaris VALUES (4063, 'Maud', 'Zapata Arroyo', 'D', '79 C/ Manuel Iradier', 3811, 'Maud.Zapata.Arroyo@pookmail.com', '09/04/40', 27, NULL);
INSERT INTO usuaris VALUES (4064, 'Guzmán', 'Solano Salcido', 'H', '49 Avda. de la Estación', 28595, 'Guzman.Solano.Salcido@spambob.com', '16/03/78', 89, 7);
INSERT INTO usuaris VALUES (4065, 'Miren', 'Feliciano Tirado', 'D', '46 C/ Señores Curas', 11650, 'Miren.Feliciano.Tirado@spambob.com', '18/01/77', 38, 6);
INSERT INTO usuaris VALUES (4066, 'Denisa', 'Terrazas Rubio', 'D', '18 Puerto Lugar', 29690, 'Denisa.Terrazas.Rubio@pookmail.com', '11/08/80', 39, 4);
INSERT INTO usuaris VALUES (4067, 'Rómula', 'Reséndez Toro', 'D', '16 Plaza de España', 15686, 'Romula.Resendez.Toro@mailinator.com', '20/08/48', 87, 5);
INSERT INTO usuaris VALUES (4068, 'Chalten', 'Munguia Pedraza', 'H', '43 C/ Domingo Beltrán', 2220, 'Chalten.Munguia.Pedraza@trashymail.com', '08/08/49', 34, 7);
INSERT INTO usuaris VALUES (4069, 'Milca', 'Fuentes Bueno', 'D', '82 Avda. Explanada Barnuevo', 35217, 'Milca.Fuentes.Bueno@spambob.com', '22/12/47', 63, 5);
INSERT INTO usuaris VALUES (4070, 'Nerida', 'Duarte Valdés', 'D', '23 Camiño Real', 48530, 'Nerida.Duarte.Valdes@spambob.com', '08/09/44', 82, 12);
INSERT INTO usuaris VALUES (4071, 'Agatón', 'Partida Arana', 'H', '63 Bouciña', 43781, 'Agaton.Partida.Arana@dodgit.com', '13/05/80', 1, NULL);
INSERT INTO usuaris VALUES (4072, 'Makenna', 'Chavarría Chacón', NULL, '98 Extramuros', 28510, 'Makenna.Chavarria.Chacon@trashymail.com', '13/12/45', 29, 8);
INSERT INTO usuaris VALUES (4073, 'Vesta', 'Verduzco Medrano', 'D', '78 Eusebio Dávila', 41530, 'Vesta.Verduzco.Medrano@dodgit.com', '31/08/60', 57, 12);
INSERT INTO usuaris VALUES (4074, 'Amal', 'Colunga Escobedo', 'D', '98 Estrela', 39738, 'Amal.Colunga.Escobedo@mailinator.com', '31/10/54', 84, 8);
INSERT INTO usuaris VALUES (4075, 'Edgar', 'Abeyta Mateo', 'H', '59 Calle Proc. San Sebastián', 13100, 'Edgar.Abeyta.Mateo@trashymail.com', '05/07/60', 85, 10);
INSERT INTO usuaris VALUES (4076, 'Obdulio', 'Benavidez Zaragoza', 'H', '16 Puerto Lugar', 29712, 'Obdulio.Benavidez.Zaragoza@pookmail.com', '05/12/83', 6, 6);
INSERT INTO usuaris VALUES (4077, 'Laviana', 'Sanches Garza', 'D', '95 Celso Emilio Ferreiro', 50410, 'Laviana.Sanches.Garza@trashymail.com', '04/08/77', 5, 9);
INSERT INTO usuaris VALUES (4078, 'Andy', 'Santillán Frías', 'H', '26 C/ Angosto', 23528, 'Andy.Santillan.Frias@pookmail.com', '13/03/68', 22, 7);
INSERT INTO usuaris VALUES (4079, 'Cono', 'Alanis Lomeli', 'H', '49 El Roqueo', 15920, 'Cono.Alanis.Lomeli@dodgit.com', '13/02/72', 71, 3);
INSERT INTO usuaris VALUES (4080, 'Aracely', 'Mascarenas Najera', 'D', '58 Ventanilla de Beas', 27765, 'Aracely.Mascarenas.Najera@dodgit.com', '09/12/66', 49, 7);
INSERT INTO usuaris VALUES (4081, 'Naimid', 'Marín Centeno', 'D', '48 Prolongacion San Sebastian', 21350, 'Naimid.Marin.Centeno@pookmail.com', '29/01/43', 4, 1);
INSERT INTO usuaris VALUES (4082, 'Bruna', 'Macías Acosta', 'D', '46 Constitución', 36872, 'Bruna.Macias.Acosta@mailinator.com', '01/05/48', 36, 11);
INSERT INTO usuaris VALUES (4083, 'Ubaldo', 'Lozano Vasquez', 'H', '15 Herrería', 18210, 'Ubaldo.Lozano.Vasquez@dodgit.com', '13/01/61', 4, 6);
INSERT INTO usuaris VALUES (4084, 'Macaria', 'Montenegro Cedillo', 'D', '4 C/ Los Herrán', 6300, 'Macaria.Montenegro.Cedillo@dodgit.com', '07/11/68', 31, 10);
INSERT INTO usuaris VALUES (4085, 'Saba', 'Montoya Meza', 'D', '92 Avda. Explanada Barnuevo', 34870, 'Saba.Montoya.Meza@mailinator.com', '21/06/40', 74, 8);
INSERT INTO usuaris VALUES (4086, 'Arán', 'Torres Quezada', 'H', '4 C/ Benito Guinea', 8392, 'Aran.Torres.Quezada@spambob.com', '21/03/48', 30, 6);
INSERT INTO usuaris VALUES (4087, 'Aniano', 'Tafoya Ceballos', 'H', '17 Bouciña', 43790, 'Aniano.Tafoya.Ceballos@pookmail.com', '02/11/57', 69, 2);
INSERT INTO usuaris VALUES (4088, 'Justin', 'Ríos Ortiz', 'H', '3 Celso Emilio Ferreiro', 50280, 'Justin.Rios.Ortiz@pookmail.com', '25/03/75', 58, 11);
INSERT INTO usuaris VALUES (4089, 'Tubau', 'Villaseñor Valenzuela', 'H', '88 Enxertos', 37554, 'Tubau.Villasenor.Valenzuela@pookmail.com', '31/07/48', 44, 7);
INSERT INTO usuaris VALUES (4090, 'Nelson', 'Valles Melgar', NULL, '86 Valadouro', 48120, 'Nelson.Valles.Melgar@mailinator.com', '11/12/85', 55, 8);
INSERT INTO usuaris VALUES (4091, 'Rocco', 'Barrios Ferrer', NULL, '66 Cercas Bajas', 8186, 'Rocco.Barrios.Ferrer@pookmail.com', '03/03/43', 46, 2);
INSERT INTO usuaris VALUES (4092, 'Amarilis', 'Briseño Lucio', 'D', '31 El Roqueo', 15885, 'Amarilis.Briseno.Lucio@mailinator.com', '05/01/44', 39, 5);
INSERT INTO usuaris VALUES (4093, 'Licas', 'Preciado Vázquez', 'H', '31 Rio Segura', 31440, 'Licas.Preciado.Vazquez@pookmail.com', '06/03/80', 64, 9);
INSERT INTO usuaris VALUES (4094, 'Fredeswinda', 'Saavedra Verdugo', 'D', '99 Constitución', 36994, 'Fredeswinda.Saavedra.Verdugo@pookmail.com', '27/01/61', 66, 10);
INSERT INTO usuaris VALUES (4095, 'Melitona', 'Rubio Maestas', 'D', '76 Outid de Arriba', 43720, 'Melitona.Rubio.Maestas@spambob.com', '02/08/66', 74, NULL);
INSERT INTO usuaris VALUES (4096, 'Septimio', 'Montez Sarabia', 'H', '68 Escuadro', 46910, 'Septimio.Montez.Sarabia@spambob.com', '21/03/83', 45, NULL);
INSERT INTO usuaris VALUES (4097, 'Adalvino', 'Bonilla Armenta', 'H', '87 Crta. Cádiz-Málaga', 12225, 'Adalvino.Bonilla.Armenta@spambob.com', '19/10/73', 61, NULL);
INSERT INTO usuaris VALUES (4098, 'Olivia', 'Uribe Negrón', NULL, '90 C/ Henan Cortes', 29170, 'Olivia.Uribe.Negron@pookmail.com', '18/09/40', 70, 3);
INSERT INTO usuaris VALUES (4099, 'Adelio', 'Murillo Maestas', 'H', '68 C/ Cuevas de Ambrosio', 24191, 'Adelio.Murillo.Maestas@trashymail.com', '27/02/85', 82, 2);
INSERT INTO usuaris VALUES (4100, 'Adena', 'Villagómez Galarza', 'D', '63 Pl. Virgen Blanca', 8700, 'Adena.Villagomez.Galarza@spambob.com', '22/09/60', 53, 9);
INSERT INTO usuaris VALUES (4101, 'Halima', 'Cintrón Soliz', 'D', '60 Extramuros', 28410, 'Halima.Cintron.Soliz@mailinator.com', '11/04/82', 68, 8);
INSERT INTO usuaris VALUES (4102, 'Adelino', 'Villareal Márquez', 'H', '62 Fuente del Gallo', 15000, 'Adelino.Villareal.Marquez@trashymail.com', '23/03/69', 9, 9);
INSERT INTO usuaris VALUES (4103, 'Mirtha', 'Ávalos Alfaro', 'D', '29 Extramuros', 28515, 'Mirtha.Avalos.Alfaro@pookmail.com', '02/04/49', 87, 12);
INSERT INTO usuaris VALUES (4104, 'Ales', 'Ojeda Vasquez', 'H', '33 C/ Manuel Iradier', 3787, 'Ales.Ojeda.Vasquez@spambob.com', '29/09/59', 63, 1);
INSERT INTO usuaris VALUES (4105, 'Belinda', 'Cantú Cordova', 'D', '20 Reiseñor', 46137, 'Belinda.Cantu.Cordova@mailinator.com', '11/02/45', 46, 4);
INSERT INTO usuaris VALUES (4106, 'Abbi', 'Rolón Alonzo', 'D', '7 Rio Segura', 31300, 'Abbi.Rolon.Alonzo@dodgit.com', '27/07/69', 76, 9);
INSERT INTO usuaris VALUES (4107, 'Brenda', 'Lucio Ledesma', 'D', '18 C/ Rosa de los Vientos', 11630, 'Brenda.Lucio.Ledesma@dodgit.com', '06/04/66', 78, 3);
INSERT INTO usuaris VALUES (4108, 'Albana', 'Armenta Villa', 'D', '79 C/ Eras', 28723, 'Albana.Armenta.Villa@pookmail.com', '22/10/64', 67, 6);
INSERT INTO usuaris VALUES (4109, 'Altea', 'Esquivel Agosto', 'D', '47 C/ Benito Guinea', 8310, 'Altea.Esquivel.Agosto@dodgit.com', '29/06/64', 27, 4);
INSERT INTO usuaris VALUES (4110, 'Heloísa', 'Terán Ordóñez', 'D', '51 Enxertos', 37607, 'Heloisa.Teran.Ordonez@pookmail.com', '27/03/58', 81, 5);
INSERT INTO usuaris VALUES (4111, 'Maitane', 'Saldana Bustamante', 'D', '77 Cádiz', 18452, 'Maitane.Saldana.Bustamante@trashymail.com', '03/11/83', NULL, 8);
INSERT INTO usuaris VALUES (4112, 'Daryl', 'Vanegas Cardona', 'H', '8 Paseo Junquera', 12428, 'Daryl.Vanegas.Cardona@mailinator.com', '08/05/52', 21, NULL);
INSERT INTO usuaris VALUES (4113, 'Michele', 'Ponce Briones', 'H', '31 C/ Manuel Iradier', 3812, 'Michele.Ponce.Briones@spambob.com', '12/12/69', 75, 5);
INSERT INTO usuaris VALUES (4114, 'Yulan', 'Escamilla Almanza', 'H', '62 Prolongacion San Sebastian', 21387, 'Yulan.Escamilla.Almanza@spambob.com', '30/08/69', 12, 10);
INSERT INTO usuaris VALUES (4115, 'Otelo', 'Núñez Padrón', 'H', '16 Carretera del Muelle', 12330, 'Otelo.Nunez.Padron@dodgit.com', '07/03/48', 50, 6);
INSERT INTO usuaris VALUES (4116, 'Edelio', 'Oquendo Granados', 'H', '20 Cañadilla', 22160, 'Edelio.Oquendo.Granados@mailinator.com', '04/02/64', 27, 4);
INSERT INTO usuaris VALUES (4117, 'Beat', 'Baez Roque', 'H', '66 C/ Rosa de los Vientos', 11560, 'Beat.Baez.Roque@mailinator.com', '01/06/41', 87, 5);
INSERT INTO usuaris VALUES (4118, 'Erakil', 'Adomo Noriega', 'H', '98 C/ Fernández de Leceta', 3440, 'Erakil.Adomo.Noriega@dodgit.com', '02/07/61', 15, 3);
INSERT INTO usuaris VALUES (4119, 'Mamerto', 'Abeyta Adame', 'H', '41 Paseo Junquera', 12460, 'Mamerto.Abeyta.Adame@trashymail.com', '14/03/45', 93, 5);
INSERT INTO usuaris VALUES (4120, 'Ricarda', 'Lucero Quintanilla', 'D', '69 Carretera del Muelle', 12300, 'Ricarda.Lucero.Quintanilla@dodgit.com', '11/12/66', 11, 12);
INSERT INTO usuaris VALUES (4121, 'Alaide', 'Olivas Corona', 'D', '55 Avda. Enrique Peinador', 37181, 'Alaide.Olivas.Corona@dodgit.com', '08/09/51', 76, 6);
INSERT INTO usuaris VALUES (4122, 'Helda', 'Cedillo Fonseca', 'D', '88 Bellavista', 50171, 'Helda.Cedillo.Fonseca@mailinator.com', '29/11/60', 32, 11);
INSERT INTO usuaris VALUES (4123, 'Urías', 'Arreola Grijalva', 'H', '22 Eusebio Dávila', 41420, 'Urias.Arreola.Grijalva@mailinator.com', '01/05/67', 35, 4);
INSERT INTO usuaris VALUES (4124, 'Britanic', 'León Guillén', 'H', '35 Carretera del Muelle', 12231, 'Britanic.Leon.Guillen@trashymail.com', '13/01/67', 73, 3);
INSERT INTO usuaris VALUES (4125, 'Heber', 'Almaraz Tapia', 'H', '84 Plaza Colón', 24420, 'Heber.Almaraz.Tapia@trashymail.com', '13/12/47', 96, NULL);
INSERT INTO usuaris VALUES (4126, 'Sultana', 'Ríos Madrid', 'D', '14 Zumalakarregi etorbidea', 7330, 'Sultana.Rios.Madrid@mailinator.com', '13/04/55', 6, 4);
INSERT INTO usuaris VALUES (4127, 'Roni', 'Atencio Carrasco', 'H', '32 C/ Rosa de los Vientos', 11610, 'Roni.Atencio.Carrasco@trashymail.com', '18/02/52', 12, 4);
INSERT INTO usuaris VALUES (4128, 'Enric', 'Alonso Jaime', 'H', '51 Avda. Enrique Peinador', 37181, 'Enric.Alonso.Jaime@pookmail.com', '24/04/54', 96, 3);
INSERT INTO usuaris VALUES (4129, 'Alana', 'Urbina Paz', 'D', '64 Carretera', 14510, 'Alana.Urbina.Paz@trashymail.com', '16/04/80', 50, 12);
INSERT INTO usuaris VALUES (4130, 'Ligio', 'Almanza Montez', 'H', '1 Avendaño', 3820, 'Ligio.Almanza.Montez@pookmail.com', '20/08/85', 13, 6);
INSERT INTO usuaris VALUES (4131, 'Marjorie', 'Guerrero Gaona', 'D', '39 Boriñaur enparantza', 7740, 'Marjorie.Guerrero.Gaona@pookmail.com', '14/12/42', 6, 3);
INSERT INTO usuaris VALUES (4132, 'Piera', 'Serrato Pulido', 'D', '14 Avda. Explanada Barnuevo', 35290, 'Piera.Serrato.Pulido@trashymail.com', '30/11/41', 60, 1);
INSERT INTO usuaris VALUES (4133, 'Ofelia', 'Olivo Ordóñez', 'D', '97 Puerta Nueva', 36500, 'Ofelia.Olivo.Ordonez@pookmail.com', '04/09/79', 82, 2);
INSERT INTO usuaris VALUES (4134, 'Ariadna', 'Riojas Maya', 'D', '86 C/ Angosto', 23410, 'Ariadna.Riojas.Maya@spambob.com', '23/12/54', 74, 9);
INSERT INTO usuaris VALUES (4135, 'Ellis', 'Griego Mejía', 'H', '36 Ctra. de Siles', 27630, 'Ellis.Griego.Mejia@mailinator.com', '05/04/80', 85, 1);
INSERT INTO usuaris VALUES (4136, 'Theodor', 'Pantoja Aguilera', 'H', '41 Constitución', 36880, 'Theodor.Pantoja.Aguilera@pookmail.com', '25/05/77', 68, 11);
INSERT INTO usuaris VALUES (4137, 'Jackie', 'Reynoso Ávila', 'D', '55 Cádiz', 18452, 'Jackie.Reynoso.Avila@pookmail.com', '12/12/54', 63, 1);
INSERT INTO usuaris VALUES (4138, 'Esdras', 'Gaona Burgos', 'H', '72 Cercas Bajas', 7840, 'Esdras.Gaona.Burgos@mailinator.com', '30/07/73', 76, 7);
INSERT INTO usuaris VALUES (4139, 'Ibero', 'Covarrubias Oquendo', 'H', '97 Visitación de la Encina', 37724, 'Ibero.Covarrubias.Oquendo@dodgit.com', '06/07/47', 78, 4);
INSERT INTO usuaris VALUES (4140, 'Lionela', 'Maestas Cerda', 'D', '89 Rúa Olmos', 37317, 'Lionela.Maestas.Cerda@trashymail.com', '02/07/53', 94, 3);
INSERT INTO usuaris VALUES (4141, 'Fabian', 'Mayonga Lozano', 'H', '12 Cañadilla', 21870, 'Fabian.Mayonga.Lozano@mailinator.com', '29/04/49', 93, 8);
INSERT INTO usuaris VALUES (4142, 'Anelida', 'Carranza Estrada', 'D', '85 Pascual Yunquera', 18820, 'Anelida.Carranza.Estrada@dodgit.com', '16/08/52', 97, 12);
INSERT INTO usuaris VALUES (4143, 'Medea', 'Acosta Padilla', 'D', '63 Paraguay', 3700, 'Medea.Acosta.Padilla@trashymail.com', '11/10/62', 6, 10);
INSERT INTO usuaris VALUES (4144, 'Celerino', 'Chacón Monroy', 'H', '38 Apartado de Correos', 37455, 'Celerino.Chacon.Monroy@pookmail.com', '29/03/61', 46, 9);
INSERT INTO usuaris VALUES (4145, 'Alphonse', 'Serrano Alfaro', 'H', '5 C/ Hijuela de Lojo', 20240, 'Alphonse.Serrano.Alfaro@spambob.com', '20/07/61', 23, 1);
INSERT INTO usuaris VALUES (4146, 'Mennos', 'Caraballo Sevilla', 'H', '30 Puerto Lugar', 29717, 'Mennos.Caraballo.Sevilla@spambob.com', '10/02/44', 23, 7);
INSERT INTO usuaris VALUES (4147, 'Nacho', 'Sarabia Olivárez', 'H', '31 La Fontanilla', 14240, 'Nacho.Sarabia.Olivarez@trashymail.com', '24/02/71', 56, 5);
INSERT INTO usuaris VALUES (4148, 'Metran', 'Jaime Abrego', 'H', '88 Avda. de la Estación', 28694, 'Metran.Jaime.Abrego@trashymail.com', '16/02/75', 39, 9);
INSERT INTO usuaris VALUES (4149, 'Alira', 'Castro Anguiano', 'D', '52 Zumalakarregi etorbidea', 7179, 'Alira.Castro.Anguiano@spambob.com', '27/04/85', 50, 8);
INSERT INTO usuaris VALUES (4150, 'Louis', 'Peralta Tafoya', 'H', '51 Rosa de los Vientos', 13391, 'Louis.Peralta.Tafoya@mailinator.com', NULL, 44, 10);
INSERT INTO usuaris VALUES (4151, 'Princesa', 'Saucedo Arce', 'D', '27 Camiño Real', 48630, 'Princesa.Saucedo.Arce@pookmail.com', '24/07/83', 92, 9);
INSERT INTO usuaris VALUES (4152, 'Prantxes', 'Nieto Zambrano', 'H', '27 Cañadilla', 21740, 'Prantxes.Nieto.Zambrano@trashymail.com', '18/06/76', 85, 8);
INSERT INTO usuaris VALUES (4153, 'Marilda', 'Bustamante Loera', 'D', '99 Avda. Andalucía', 26148, 'Marilda.Bustamante.Loera@trashymail.com', '26/10/71', 72, 10);
INSERT INTO usuaris VALUES (4154, 'Pirro', 'Aguilera Alonso', 'H', '98 El Roqueo', 16630, 'Pirro.Aguilera.Alonso@pookmail.com', '17/08/68', 5, 1);
INSERT INTO usuaris VALUES (4155, 'Donardo', 'Huerta Arreola', 'H', '69 Rúa do Paseo', 41808, 'Donardo.Huerta.Arreola@dodgit.com', '28/11/79', 7, 9);
INSERT INTO usuaris VALUES (4156, 'Erardo', 'Casanova Núñez', 'H', '48 Comandante Izarduy', 8780, 'Erardo.Casanova.Nunez@spambob.com', '05/02/52', 67, 12);
INSERT INTO usuaris VALUES (4157, 'Gregor', 'Mota Sepúlveda', 'H', '2 Avda. de Andalucía', 29350, 'Gregor.Mota.Sepulveda@spambob.com', '16/07/85', 31, 9);
INSERT INTO usuaris VALUES (4158, 'Petronio', 'Carbajal Tamez', 'H', '68 Ctra. Villena', 33826, 'Petronio.Carbajal.Tamez@dodgit.com', '04/12/82', 30, NULL);
INSERT INTO usuaris VALUES (4159, 'Elijah', 'Carrasquill Madrigal', 'H', '61 C/ Rosa de los Vientos', 11630, 'Elijah.Carrasquill.Madrigal@spambob.com', '27/09/58', 1, NULL);
INSERT INTO usuaris VALUES (4160, 'Heraldo', 'Mota Terán', 'H', '81 Rúa de San Pedro', 37791, 'Heraldo.Mota.Teran@mailinator.com', '11/03/61', 53, 5);
INSERT INTO usuaris VALUES (4161, 'Amarilia', 'Rosario Arroyo', 'D', '46 Rúa Olmos', 37339, 'Amarilia.Rosario.Arroyo@pookmail.com', '19/09/81', 49, 12);
INSERT INTO usuaris VALUES (4162, 'Ronald', 'Murillo Vasquez', 'H', '90 Paseo Junquera', 12429, 'Ronald.Murillo.Vasquez@spambob.com', '23/03/53', 4, 7);
INSERT INTO usuaris VALUES (4163, 'Hans', 'Rascón Ramos', 'H', '61 Ctra. Bailén-Motril', 23300, 'Hans.Rascon.Ramos@dodgit.com', '25/04/64', 57, 7);
INSERT INTO usuaris VALUES (4164, 'Sylvius', 'Llarnas Tijerina', 'H', '29 Zumalakarregi etorbidea', 7320, 'Sylvius.Llarnas.Tijerina@dodgit.com', '20/02/49', 41, 1);
INSERT INTO usuaris VALUES (4165, 'Jocelin', 'Escobedo Polanco', 'H', '75 Cruce Casa de Postas', 18413, 'Jocelin.Escobedo.Polanco@mailinator.com', '20/09/50', 6, 4);
INSERT INTO usuaris VALUES (4166, 'Niceto', 'Mares Comejo', 'H', '19 Urzáiz', 43896, 'Niceto.Mares.Comejo@mailinator.com', '01/04/57', 55, 3);
INSERT INTO usuaris VALUES (4167, 'Wendy', 'Ayala Porras', 'D', '49 Carretera Cádiz-Málaga', 20800, 'Wendy.Ayala.Porras@mailinator.com', '20/07/59', 58, 12);
INSERT INTO usuaris VALUES (4168, 'Daisy', 'Gaitán Mena', 'D', '72 C/ Rosa de los Vientos', 11560, 'Daisy.Gaitan.Mena@pookmail.com', '27/01/45', 98, 9);
INSERT INTO usuaris VALUES (4169, 'Casto', 'Medina Olivo', 'H', '58 Socampo', 37619, 'Casto.Medina.Olivo@spambob.com', '28/12/57', 41, 8);
INSERT INTO usuaris VALUES (4170, 'Emilse', 'Canales Hurtado', 'D', '51 Av. Zumalakarregi', 3187, 'Emilse.Canales.Hurtado@trashymail.com', '15/06/60', 1, 6);
INSERT INTO usuaris VALUES (4171, 'Sulamita', 'Oquendo Ulibarri', 'D', '83 Estrela', 39538, 'Sulamita.Oquendo.Ulibarri@mailinator.com', '11/12/75', 45, 12);
INSERT INTO usuaris VALUES (4172, 'Viridiana', 'Muñoz Salcedo', 'D', '66 Plaza Colón', 26111, 'Viridiana.Munoz.Salcedo@dodgit.com', '06/09/64', 72, 1);
INSERT INTO usuaris VALUES (4173, 'Karl', 'Peres Pacheco', 'H', '15 Inglaterra', 18564, 'Karl.Peres.Pacheco@spambob.com', '17/05/48', 48, 6);
INSERT INTO usuaris VALUES (4174, 'Zelmar', 'Rivera Preciado', 'H', '96 José matía', 2152, 'Zelmar.Rivera.Preciado@pookmail.com', '27/07/83', 95, 2);
INSERT INTO usuaris VALUES (4175, 'Zarina', 'Flórez Baeza', 'D', '78 C/ Manuel Iradier', 3811, 'Zarina.Florez.Baeza@spambob.com', '02/07/66', 58, 7);
INSERT INTO usuaris VALUES (4176, 'Lena', 'Valentín Cárdenas', 'D', '22 Carretera del Muelle', 12415, 'Lena.Valentin.Cardenas@trashymail.com', '13/06/52', 95, 4);
INSERT INTO usuaris VALUES (4177, 'Julian', 'Sarabia Alfaro', 'H', '16 C/ Hijuela de Lojo', 20248, 'Julian.Sarabia.Alfaro@pookmail.com', '14/03/44', 27, 11);
INSERT INTO usuaris VALUES (4178, 'Seraphin', 'Arredondo Comejo', 'H', '82 Cartagena', 30430, 'Seraphin.Arredondo.Comejo@mailinator.com', '10/09/40', 64, 12);
INSERT INTO usuaris VALUES (4179, 'Kristopher', 'Concepción Preciado', 'H', '94 Cañadilla', 21700, 'Kristopher.Concepcion.Preciado@spambob.com', '24/12/52', 97, 1);
INSERT INTO usuaris VALUES (4180, 'Rosmari', 'Meza Rangel', 'D', '16 Inglaterra', 18538, 'Rosmari.Meza.Rangel@pookmail.com', '12/10/83', 15, 2);
INSERT INTO usuaris VALUES (4181, 'Leonilda', 'Trujillo Otero', 'D', '26 Avda. Rio Nalon', 33150, 'Leonilda.Trujillo.Otero@pookmail.com', '01/02/74', 8, 10);
INSERT INTO usuaris VALUES (4182, 'Guido', 'Barrios Alvarez', 'H', '29 Rio Segura', 31523, 'Guido.Barrios.Alvarez@mailinator.com', '08/09/53', 5, 1);
INSERT INTO usuaris VALUES (4183, 'Melito', 'Echevarría Gamez', 'H', '3 Carretera', 14700, 'Melito.Echevarria.Gamez@mailinator.com', '01/04/64', 66, 12);
INSERT INTO usuaris VALUES (4184, 'Cloe', 'Mota Trejo', 'D', '73 Calle Proc. San Sebastián', 12593, 'Cloe.Mota.Trejo@pookmail.com', '08/07/67', 61, 3);
INSERT INTO usuaris VALUES (4185, 'Calanit', 'Patino Abeyta', 'D', '14 C/ Domingo Beltrán', 2215, 'Calanit.Patino.Abeyta@trashymail.com', '28/01/83', 3, NULL);
INSERT INTO usuaris VALUES (4186, 'Priscilla', 'Escobar Santiago', 'D', '25 Escuadro', 46910, 'Priscilla.Escobar.Santiago@dodgit.com', '15/07/80', 40, 11);
INSERT INTO usuaris VALUES (4187, 'Mariangela', 'Alva Batista', 'D', '18 C/ Rosa de los Vientos', 11200, 'Mariangela.Alva.Batista@mailinator.com', '13/04/46', NULL, NULL);
INSERT INTO usuaris VALUES (4188, 'Salustio', 'Argüello Cárdenas', 'H', '41 Salzillo', 32620, 'Salustio.Arguello.Cardenas@dodgit.com', '01/09/54', 2, NULL);
INSERT INTO usuaris VALUES (4189, 'Scarlett', 'Nazario Fernández', 'D', '43 Outid de Arriba', 43713, 'Scarlett.Nazario.Fernandez@trashymail.com', '26/11/40', 56, 5);
INSERT INTO usuaris VALUES (4190, 'Nabucodonosor', 'Robles Alcalá', 'H', '47 La Fontanilla', 14300, 'Nabucodonosor.Robles.Alcala@mailinator.com', '23/03/80', 7, 7);
INSERT INTO usuaris VALUES (4191, 'Cathy', 'Calvillo Colón', NULL, '52 Avendaño', 4250, 'Cathy.Calvillo.Colon@dodgit.com', '13/07/74', 92, 8);
INSERT INTO usuaris VALUES (4192, 'Selva', 'Urbina Garica', 'D', '15 Canónigo Valiño', 46470, 'Selva.Urbina.Garica@trashymail.com', '08/09/84', 55, 7);
INSERT INTO usuaris VALUES (4193, 'Marianne', 'Montés Fajardo', 'D', '39 C/ Fernández de Leceta', 3369, 'Marianne.Montes.Fajardo@spambob.com', '28/08/56', 74, 3);
INSERT INTO usuaris VALUES (4194, 'Douglas', 'Cárdenas Rangel', 'H', '28 Calle Aduana', 1307, 'Douglas.Cardenas.Rangel@mailinator.com', '03/12/40', 1, 7);
INSERT INTO usuaris VALUES (4195, 'Amarilis', 'Orta Regalado', 'D', '1 Paseo Junquera', 12440, 'Amarilis.Orta.Regalado@dodgit.com', '19/08/58', 1, 8);
INSERT INTO usuaris VALUES (4196, 'Gabriele', 'Valentín Arredondo', 'D', '3 Valadouro', 48114, 'Gabriele.Valentin.Arredondo@trashymail.com', '18/11/70', 35, 3);
INSERT INTO usuaris VALUES (4197, 'Horaz', 'Trejo Carrero', 'H', '16 Rúa Olmos', 37409, 'Horaz.Trejo.Carrero@trashymail.com', '22/06/66', 78, NULL);
INSERT INTO usuaris VALUES (4198, 'Isaldina', 'Jáquez Valenzuela', 'D', '25 Herrería', 18170, 'Isaldina.Jaquez.Valenzuela@mailinator.com', '14/05/70', 62, 8);
INSERT INTO usuaris VALUES (4199, 'Eneida', 'Colunga Marroquín', NULL, '1 C/ Canarias', 20150, 'Eneida.Colunga.Marroquin@spambob.com', '15/03/50', 55, NULL);
INSERT INTO usuaris VALUES (4200, 'Licio', 'Orellana Marroquín', 'H', '22 El Roqueo', 15865, 'Licio.Orellana.Marroquin@spambob.com', '20/04/75', 51, 7);
INSERT INTO usuaris VALUES (4201, 'Arcelia', 'Camarillo Sarabia', 'D', '81 Pl. Virgen Blanca', 8500, 'Arcelia.Camarillo.Sarabia@mailinator.com', '14/07/68', 74, 1);
INSERT INTO usuaris VALUES (4202, 'Anibal', 'Ojeda Nieves', 'H', '48 Valadouro', 48191, 'Anibal.Ojeda.Nieves@pookmail.com', '20/11/41', 44, NULL);
INSERT INTO usuaris VALUES (4203, 'Bela', 'Cortez Zamudio', 'D', '28 Carretera del Muelle', 12413, 'Bela.Cortez.Zamudio@pookmail.com', '11/01/76', 28, 4);
INSERT INTO usuaris VALUES (4204, 'Servando', 'Argüello Ordóñez', 'H', '8 Ctra. Hornos', 26226, 'Servando.Arguello.Ordonez@trashymail.com', '17/01/61', 87, 5);
INSERT INTO usuaris VALUES (4205, 'Tesira', 'Argüello Reyes', 'D', '49 Ctra. Beas-Cortijos Nuevos', 26372, 'Tesira.Arguello.Reyes@dodgit.com', '11/07/85', 76, 2);
INSERT INTO usuaris VALUES (4206, 'Luperco', 'Velázquez Hidalgo', 'H', '76 Plaza de España', 15683, 'Luperco.Velazquez.Hidalgo@pookmail.com', '05/04/74', 1, NULL);
INSERT INTO usuaris VALUES (4207, 'Hemilce', 'Pina Galván', NULL, '48 Rosa de los Vientos', 13412, 'Hemilce.Pina.Galvan@spambob.com', '06/05/47', 99, 7);
INSERT INTO usuaris VALUES (4208, 'Georgia', 'Delgadillo Quezada', 'D', '91 C/ Fernández de Leceta', 3518, 'Georgia.Delgadillo.Quezada@spambob.com', '05/07/50', 10, 12);
INSERT INTO usuaris VALUES (4209, 'Astor', 'Espinoza Rascón', 'H', '96 Prolongacion San Sebastian', 21270, 'Astor.Espinoza.Rascon@mailinator.com', '25/08/77', 49, 8);
INSERT INTO usuaris VALUES (4210, 'Iñaqui', 'Guerrero Quintana', 'H', '24 Avda. de Andalucía', 29210, 'Inaqui.Guerrero.Quintana@trashymail.com', '26/07/52', 79, 6);
INSERT INTO usuaris VALUES (4211, 'Fariol', 'Almaraz Quintana', 'H', '2 Cádiz', 18512, 'Fariol.Almaraz.Quintana@mailinator.com', '05/10/49', 12, NULL);
INSERT INTO usuaris VALUES (4212, 'Rosinda', 'Calderón Villagómez', 'D', '52 Calle Carril de la Fuente', 13260, 'Rosinda.Calderon.Villagomez@dodgit.com', '31/10/47', 72, 12);
INSERT INTO usuaris VALUES (4213, 'Anelina', 'Pabón Galindo', 'D', '85 C/ Los Herrán', 6380, 'Anelina.Pabon.Galindo@dodgit.com', '27/05/56', 84, 10);
INSERT INTO usuaris VALUES (4214, 'Lisandra', 'Jiménez Carmona', 'D', '33 Avda. de Andalucía', 29370, 'Lisandra.Jimenez.Carmona@dodgit.com', '27/07/77', 78, 3);
INSERT INTO usuaris VALUES (4215, 'Publio', 'Munguia Jasso', 'H', '65 C/ Eras', 28751, 'Publio.Munguia.Jasso@trashymail.com', '14/11/64', 49, NULL);
INSERT INTO usuaris VALUES (4216, 'Morgana', 'Fernández Paez', 'D', '80 Carretera Cádiz-Málaga', 20530, 'Morgana.Fernandez.Paez@mailinator.com', '15/05/61', 18, 1);
INSERT INTO usuaris VALUES (4217, 'Maggie', 'Covarrubias Fajardo', 'D', '74 Plaza Colón', 26111, 'Maggie.Covarrubias.Fajardo@mailinator.com', '26/05/58', 71, 2);
INSERT INTO usuaris VALUES (4218, 'Godfred', 'Segura Cazares', 'H', '43 Cartagena', 30170, 'Godfred.Segura.Cazares@pookmail.com', '13/11/53', 54, 6);
INSERT INTO usuaris VALUES (4219, 'Arquímedes', 'Saavedra Armendáriz', 'H', '57 C/ Rosa de los Vientos', 11610, 'Arquimedes.Saavedra.Armendariz@spambob.com', '27/05/74', 89, 4);
INSERT INTO usuaris VALUES (4220, 'Melecio', 'Lozano Roque', 'H', '32 C/ Cuesta del  Álamo', 29551, 'Melecio.Lozano.Roque@mailinator.com', '13/12/59', NULL, 2);
INSERT INTO usuaris VALUES (4221, 'Antenor', 'Concepción Verdugo', 'H', '87 Outid de Arriba', 43570, 'Antenor.Concepcion.Verdugo@pookmail.com', '23/01/52', 89, 10);
INSERT INTO usuaris VALUES (4222, 'Adelardo', 'Espinosa Santillán', 'H', '58 Calle Aduana', 1118, 'Adelardo.Espinosa.Santillan@trashymail.com', '03/07/46', 65, 4);
INSERT INTO usuaris VALUES (4223, 'Umberto', 'Otero Comejo', 'H', '65 C/ Los Herrán', 6300, 'Umberto.Otero.Comejo@pookmail.com', '15/07/67', 73, 11);
INSERT INTO usuaris VALUES (4224, 'Dana', 'Domínquez Espinoza', 'D', '80 Plazuela do Porto', 38400, 'Dana.Dominquez.Espinoza@mailinator.com', '24/10/48', 3, 3);
INSERT INTO usuaris VALUES (4225, 'Dédalo', 'Partida Flórez', 'H', '20 Ctra. Bailén-Motril', 23220, 'Dedalo.Partida.Florez@spambob.com', '25/01/63', 10, 3);
INSERT INTO usuaris VALUES (4226, 'Fiamma', 'Lucio Parra', 'D', '44 C/ Henan Cortes', 29160, 'Fiamma.Lucio.Parra@spambob.com', '06/12/66', 62, 10);
INSERT INTO usuaris VALUES (4227, 'Fermín', 'Delgadillo Mayonga', 'H', '91 Carretera', 14490, 'Fermin.Delgadillo.Mayonga@pookmail.com', '26/11/54', 41, 4);
INSERT INTO usuaris VALUES (4228, 'Peregrino', 'Alejandro Hernádez', 'H', '77 Ctra. de Fuentenueva', 28191, 'Peregrino.Alejandro.Hernadez@mailinator.com', '07/08/74', 45, 10);
INSERT INTO usuaris VALUES (4229, 'Haziel', 'Ybarra Lozano', 'H', '30 C/ Rosa de los Vientos', 11200, 'Haziel.Ybarra.Lozano@dodgit.com', '08/03/62', 65, 3);
INSERT INTO usuaris VALUES (4230, 'Celerino', 'Santacruz Benavides', 'H', '54 Camiño Real', 48383, 'Celerino.Santacruz.Benavides@pookmail.com', '09/10/75', 31, NULL);
INSERT INTO usuaris VALUES (4231, 'Elpidia', 'Echevarría Solórzano', 'D', '93 Alvaro Cunqueiro', 41210, 'Elpidia.Echevarria.Solorzano@dodgit.com', '22/04/59', 71, 12);
INSERT INTO usuaris VALUES (4232, 'Jesusa', 'Molina Maldonado', 'D', '61 C/ Cañada del Rosal', 21630, 'Jesusa.Molina.Maldonado@mailinator.com', '17/09/82', 86, 3);
INSERT INTO usuaris VALUES (4233, 'Jamila', 'Casas Rivas', 'D', '68 El Roqueo', 17220, 'Jamila.Casas.Rivas@pookmail.com', '14/02/44', 55, 8);
INSERT INTO usuaris VALUES (4234, 'Montana', 'Marroquín Limón', NULL, '42 Boriñaur enparantza', 7640, 'Montana.Marroquin.Limon@mailinator.com', '11/08/69', 80, 12);
INSERT INTO usuaris VALUES (4235, 'Adelma', 'Navarro Carrasco', 'D', '31 Avda. Rio Nalon', 33424, 'Adelma.Navarro.Carrasco@mailinator.com', '04/12/67', 17, 8);
INSERT INTO usuaris VALUES (4236, 'Waltruda', 'Rendón Aguayo', 'D', '92 Prolongacion San Sebastian', 21380, 'Waltruda.Rendon.Aguayo@dodgit.com', '23/07/72', 56, 11);
INSERT INTO usuaris VALUES (4237, 'Brígida', 'Tovar Pedroza', 'D', '12 C/ Cuevas de Ambrosio', 23712, 'Brigida.Tovar.Pedroza@dodgit.com', '03/08/50', 76, 8);
INSERT INTO usuaris VALUES (4238, 'Yakue', 'Saldana Franco', 'H', '29 Camiño Real', 48640, 'Yakue.Saldana.Franco@spambob.com', '05/06/80', 60, 4);
INSERT INTO usuaris VALUES (4239, 'Iñaqui', 'Sevilla Urías', 'H', '88 Outid de Arriba', 43596, 'Inaqui.Sevilla.Urias@mailinator.com', '20/09/70', 51, 10);
INSERT INTO usuaris VALUES (4240, 'Hilde', 'Corona Hinojosa', 'D', '5 Urzáiz', 43896, 'Hilde.Corona.Hinojosa@mailinator.com', '10/08/54', 80, 7);
INSERT INTO usuaris VALUES (4241, 'Sylvia', 'Venegas Apodaca', 'D', '65 Visitación de la Encina', 37727, 'Sylvia.Venegas.Apodaca@dodgit.com', '28/12/47', 83, 6);
INSERT INTO usuaris VALUES (4242, 'Konrad', 'Guerra Preciado', 'H', '53 Estrela', 39500, 'Konrad.Guerra.Preciado@pookmail.com', '07/01/55', 59, NULL);
INSERT INTO usuaris VALUES (4243, 'Yanquiman', 'Tapia Alicea', 'H', '79 Plaza de España', 15820, 'Yanquiman.Tapia.Alicea@trashymail.com', '08/01/63', 50, 7);
INSERT INTO usuaris VALUES (4244, 'Ebony', 'Cortez Mireles', 'D', '72 Pza. Fuensanta', 32500, 'Ebony.Cortez.Mireles@trashymail.com', '24/12/50', 7, 2);
INSERT INTO usuaris VALUES (4245, 'Iverna', 'Ojeda Carrión', NULL, '33 Ctra. de Siles', 27520, 'Iverna.Ojeda.Carrion@spambob.com', '29/07/71', 99, 2);
INSERT INTO usuaris VALUES (4246, 'Basil', 'Zavala Chapa', 'H', '99 Antonio Vázquez', 38700, 'Basil.Zavala.Chapa@mailinator.com', '13/08/69', 58, 4);
INSERT INTO usuaris VALUES (4247, 'Bru', 'Henríquez Sarabia', 'H', '74 Alvaro Cunqueiro', 41140, 'Bru.Henriquez.Sarabia@spambob.com', '22/10/63', 67, 5);
INSERT INTO usuaris VALUES (4248, 'Arianna', 'Baeza Luján', NULL, '91 Pza. Fuensanta', 32356, 'Arianna.Baeza.Lujan@spambob.com', '19/07/57', 98, 9);
INSERT INTO usuaris VALUES (4249, 'Vicky', 'Pedroza Casares', 'D', '48 Puerta Nueva', 36500, 'Vicky.Pedroza.Casares@mailinator.com', '25/06/43', 18, 12);
INSERT INTO usuaris VALUES (4250, 'Leandre', 'Bermúdez Carrero', 'H', '91 San Andrés', 37254, 'Leandre.Bermudez.Carrero@trashymail.com', '30/05/79', 78, 9);
INSERT INTO usuaris VALUES (4251, 'Carmine', 'Aparicio Parra', 'D', '62 Bellavista', 50230, 'Carmine.Aparicio.Parra@trashymail.com', '21/09/60', 37, 3);
INSERT INTO usuaris VALUES (4252, 'Ibi', 'Lara Collazo', 'D', '65 Estrela', 39694, 'Ibi.Lara.Collazo@trashymail.com', '05/04/72', 74, 2);
INSERT INTO usuaris VALUES (4253, 'Napoleón', 'Almaraz Alba', 'H', '84 C/ Pablo Iglesias', 26326, 'Napoleon.Almaraz.Alba@spambob.com', '24/06/41', 24, 10);
INSERT INTO usuaris VALUES (4254, 'Naim', 'Covarrubias Rocha', 'H', '72 Plazuela do Porto', 38000, 'Naim.Covarrubias.Rocha@dodgit.com', '20/12/48', 39, 1);
INSERT INTO usuaris VALUES (4255, 'Luke', 'Carrión Dávila', 'H', '76 Avda. Generalísimo', 32137, 'Luke.Carrion.Davila@dodgit.com', '09/12/81', 73, 4);
INSERT INTO usuaris VALUES (4256, 'Boreas', 'González Puente', 'H', '34 Calle Carril de la Fuente', 13170, 'Boreas.Gonzalez.Puente@trashymail.com', '17/08/83', 6, NULL);
INSERT INTO usuaris VALUES (4257, 'Helda', 'Mesa Arévalo', 'D', '28 Constitución', 37100, 'Helda.Mesa.Arevalo@spambob.com', '29/06/85', 15, 1);
INSERT INTO usuaris VALUES (4258, 'Iris', 'Valdivia Rael', 'D', '21 Padre Caro', 13660, 'Iris.Valdivia.Rael@trashymail.com', '14/02/72', 73, 6);
INSERT INTO usuaris VALUES (4259, 'Nuria', 'Anguiano Ybarra', 'D', '60 Carretera del Muelle', 12311, 'Nuria.Anguiano.Ybarra@pookmail.com', '08/08/59', 19, 3);
INSERT INTO usuaris VALUES (4260, 'Edco', 'Lucero Luevano', 'H', '74 Carretera Cádiz-Málaga', 20495, 'Edco.Lucero.Luevano@spambob.com', '26/08/67', 29, 2);
INSERT INTO usuaris VALUES (4261, 'Erakil', 'Banda Covarrubias', 'H', '80 Reyes Católicos', 10000, 'Erakil.Banda.Covarrubias@mailinator.com', '23/03/61', 87, 11);
INSERT INTO usuaris VALUES (4262, 'Grizel', 'Muro Linares', 'D', '17 Escuadro', 46830, 'Grizel.Muro.Linares@dodgit.com', '09/12/77', 20, 10);
INSERT INTO usuaris VALUES (4263, 'Júpiter', 'Orellana Rojas', 'H', '79 Ctra. de Siles', 27373, 'Jupiter.Orellana.Rojas@pookmail.com', '09/07/41', 33, 6);
INSERT INTO usuaris VALUES (4264, 'Madonna', 'Casas Najera', 'D', '79 Canónigo Valiño', 46230, 'Madonna.Casas.Najera@mailinator.com', '01/08/61', 98, 3);
INSERT INTO usuaris VALUES (4265, 'Melisa', 'Salcedo Cruz', 'D', '79 Carretera', 14530, 'Melisa.Salcedo.Cruz@dodgit.com', '06/08/70', 74, NULL);
INSERT INTO usuaris VALUES (4266, 'Amalio', 'Urías Chavarría', 'H', '9 Calvo Sotelo', 47600, 'Amalio.Urias.Chavarria@mailinator.com', '13/11/72', 59, 4);
INSERT INTO usuaris VALUES (4267, 'Tarquino', 'Olivárez Colón', 'H', '28 Ctra. Bailén-Motril', 23191, 'Tarquino.Olivarez.Colon@dodgit.com', '12/07/44', 75, 10);
INSERT INTO usuaris VALUES (4268, 'Margalit', 'Rocha Grijalva', 'D', '21 Calvo Sotelo', 47196, 'Margalit.Rocha.Grijalva@spambob.com', '02/01/67', 54, 8);
INSERT INTO usuaris VALUES (4269, 'Iliana', 'Montanez Partida', 'D', '73 C/ Señores Curas', 11680, 'Iliana.Montanez.Partida@pookmail.com', '29/10/79', 79, 6);
INSERT INTO usuaris VALUES (4270, 'Abigaíl', 'Luján Alcalá', 'D', '60 Rúa Olmos', 37409, 'Abigail.Lujan.Alcala@trashymail.com', '12/09/47', 24, NULL);
INSERT INTO usuaris VALUES (4271, 'Didio', 'Hernádez Nevarez', 'H', '89 Carretera Cádiz-Málaga', 20560, 'Didio.Hernadez.Nevarez@trashymail.com', '08/12/69', 60, 12);
INSERT INTO usuaris VALUES (4272, 'Salomé', 'Casanova Ibarra', 'D', '6 Av. Zumalakarregi', 3158, 'Salome.Casanova.Ibarra@mailinator.com', '13/09/78', 52, 12);
INSERT INTO usuaris VALUES (4273, 'Joshua', 'Alemán Alanis', 'H', '72 C/ Libertad', 5270, 'Joshua.Aleman.Alanis@spambob.com', '21/10/60', 19, 6);
INSERT INTO usuaris VALUES (4274, 'Kaled', 'Ordóñez Serrano', 'H', '85 Ctra. Beas-Cortijos Nuevos', 26525, 'Kaled.Ordonez.Serrano@dodgit.com', '17/02/85', 8, 12);
INSERT INTO usuaris VALUES (4275, 'Jocelyn', 'Granado Esparza', 'D', '21 Carretera', 14740, 'Jocelyn.Granado.Esparza@mailinator.com', '14/01/65', 62, 6);
INSERT INTO usuaris VALUES (4276, 'Amadoe', 'Hurtado Aguilar', NULL, '24 Plazuela do Porto', 38350, 'Amadoe.Hurtado.Aguilar@spambob.com', '13/12/57', 79, 9);
INSERT INTO usuaris VALUES (4277, 'Eliazar', 'Carbajal Mireles', 'H', '66 Rúa Olmos', 37337, 'Eliazar.Carbajal.Mireles@pookmail.com', '16/07/46', 62, 8);
INSERT INTO usuaris VALUES (4278, 'Joanes', 'Uribe Holguín', 'H', '96 Avda. Andalucía', 26133, 'Joanes.Uribe.Holguin@spambob.com', '10/01/45', 75, 6);
INSERT INTO usuaris VALUES (4279, 'Sisebuto', 'Frías Henríquez', 'H', '44 Ctra. Beas-Cortijos Nuevos', 26532, 'Sisebuto.Frias.Henriquez@trashymail.com', '28/02/62', 25, 3);
INSERT INTO usuaris VALUES (4280, 'Eliora', 'Griego Navarrete', 'D', '36 C/ Cuesta del  Álamo', 29500, 'Eliora.Griego.Navarrete@spambob.com', '10/03/49', 36, NULL);
INSERT INTO usuaris VALUES (4281, 'Mijael', 'Escobedo Arriaga', 'H', '38 Av. Zumalakarregi', 2691, 'Mijael.Escobedo.Arriaga@dodgit.com', '10/05/48', 68, 9);
INSERT INTO usuaris VALUES (4282, 'Ailen', 'Ávalos Pena', 'D', '1 La Fontanilla', 14450, 'Ailen.Avalos.Pena@trashymail.com', '23/12/48', 78, 7);
INSERT INTO usuaris VALUES (4283, 'Rosalina', 'Zaragoza Bañuelos', 'D', '15 Avda. Enrique Peinador', 37150, 'Rosalina.Zaragoza.Banuelos@mailinator.com', '02/09/75', 16, 7);
INSERT INTO usuaris VALUES (4284, 'Ronda', 'Ulloa Cardona', 'D', '87 Crta. Cádiz-Málaga', 12222, 'Ronda.Ulloa.Cardona@dodgit.com', '21/01/58', 33, 5);
INSERT INTO usuaris VALUES (4285, 'Arabela', 'Nava Limón', NULL, '93 Salzillo', 32700, 'Arabela.Nava.Limon@spambob.com', '30/07/48', 23, 4);
INSERT INTO usuaris VALUES (4286, 'Libna', 'Pagan Medina', 'D', '21 Rua da Rapina', 37495, 'Libna.Pagan.Medina@trashymail.com', '20/02/80', 26, 5);
INSERT INTO usuaris VALUES (4287, 'Benedicta', 'Toro Rojas', 'D', '96 Ctra. de Fuentenueva', 28280, 'Benedicta.Toro.Rojas@dodgit.com', '01/09/84', 86, 6);
INSERT INTO usuaris VALUES (4288, 'Constance', 'Calderón Arredondo', 'D', '43 Cercas Bajas', 8220, 'Constance.Calderon.Arredondo@spambob.com', '21/12/60', 11, 7);
INSERT INTO usuaris VALUES (4289, 'Leonilda', 'Haro Mata', 'D', '72 Bouciña', 43784, 'Leonilda.Haro.Mata@mailinator.com', '08/07/82', 0, 6);
INSERT INTO usuaris VALUES (4290, 'Bonifacia', 'Rojo Rodrígez', 'D', '70 Puerto Lugar', 29780, 'Bonifacia.Rojo.Rodrigez@trashymail.com', '05/11/63', 20, 7);
INSERT INTO usuaris VALUES (4291, 'Louis', 'Ocampo Domínquez', 'H', '50 Cercas Bajas', 8186, 'Louis.Ocampo.Dominquez@trashymail.com', '31/05/41', 94, 7);
INSERT INTO usuaris VALUES (4292, 'Nuri', 'Cazares Maldonado', 'H', '22 C/ Cuevas de Ambrosio', 23730, 'Nuri.Cazares.Maldonado@spambob.com', '11/06/45', 53, 10);
INSERT INTO usuaris VALUES (4293, 'Leocadio', 'Segovia Contreras', 'H', '31 C/ Cuesta del  Álamo', 29650, 'Leocadio.Segovia.Contreras@dodgit.com', '24/05/59', 9, 5);
INSERT INTO usuaris VALUES (4294, 'Arquímedes', 'Velázquez Correa', 'H', '9 Cercas Bajas', 8190, 'Arquimedes.Velazquez.Correa@dodgit.com', '21/11/71', 14, 3);
INSERT INTO usuaris VALUES (4295, 'Valdemar', 'Curiel Castellanos', 'H', '19 Avda. Alameda Sundheim', 22430, 'Valdemar.Curiel.Castellanos@pookmail.com', '03/10/57', 10, 4);
INSERT INTO usuaris VALUES (4296, 'Nilton', 'Peres Colunga', 'H', '6 Alvaro Cunqueiro', 40480, 'Nilton.Peres.Colunga@pookmail.com', '27/05/58', 34, 10);
INSERT INTO usuaris VALUES (4297, 'Amaru', 'Bustamante Borrego', 'H', '33 C/ Cuevas de Ambrosio', 23790, 'Amaru.Bustamante.Borrego@trashymail.com', '04/09/67', 43, 7);
INSERT INTO usuaris VALUES (4298, 'Ernesta', 'Garay Rendón', NULL, '43 Extramuros', 28529, 'Ernesta.Garay.Rendon@trashymail.com', '24/03/75', 7, 3);
INSERT INTO usuaris VALUES (4299, 'Kirios', 'Mares Alba', 'H', '34 Avda. de la Estación', 28630, 'Kirios.Mares.Alba@spambob.com', '21/05/73', 63, 12);
INSERT INTO usuaris VALUES (4300, 'Ciríaco', 'Reynoso García', 'H', '61 Inglaterra', 18565, 'Ciriaco.Reynoso.Garcia@dodgit.com', '06/06/55', 13, NULL);
INSERT INTO usuaris VALUES (4301, 'Reina', 'Espinal Zaragoza', 'D', '93 C/ Pablo Iglesias', 26325, 'Reina.Espinal.Zaragoza@mailinator.com', '05/04/50', 40, 11);
INSERT INTO usuaris VALUES (4302, 'Rudolf', 'Méndez Palomino', 'H', '51 Ourense', 42330, 'Rudolf.Mendez.Palomino@mailinator.com', '21/04/54', 63, 9);
INSERT INTO usuaris VALUES (4303, 'Netanel', 'Figueroa Alaniz', 'H', '39 Avda. Generalísimo', 31797, 'Netanel.Figueroa.Alaniz@spambob.com', '05/11/63', 47, 3);
INSERT INTO usuaris VALUES (4304, 'Leandra', 'Valladares Castaneda', 'D', '46 Caño', 32812, 'Leandra.Valladares.Castaneda@pookmail.com', '24/01/74', 15, 7);
INSERT INTO usuaris VALUES (4305, 'James', 'González Porras', 'H', '89 Plaza de España', 15830, 'James.Gonzalez.Porras@mailinator.com', '27/11/53', 85, 2);
INSERT INTO usuaris VALUES (4306, 'Illed', 'Esquibel Urrútia', 'D', '23 Inglaterra', 18640, 'Illed.Esquibel.Urrutia@trashymail.com', NULL, 69, 8);
INSERT INTO usuaris VALUES (4307, 'Iziar', 'Fajardo Heredia', 'D', '21 Padre Caro', 13620, 'Iziar.Fajardo.Heredia@mailinator.com', '27/03/79', 37, 7);
INSERT INTO usuaris VALUES (4308, 'Heliena', 'Corrales Benítez', 'D', '37 Paseo Junquera', 12449, 'Heliena.Corrales.Benitez@spambob.com', '02/03/46', 47, 11);
INSERT INTO usuaris VALUES (4309, 'Casio', 'Olivares Herrera', 'H', '9 Ctra. de Siles', 27620, 'Casio.Olivares.Herrera@mailinator.com', '26/01/79', 10, 11);
INSERT INTO usuaris VALUES (4310, 'Fabrizio', 'Rascón Tijerina', 'H', '60 Enxertos', 37512, 'Fabrizio.Rascon.Tijerina@pookmail.com', '18/07/65', NULL, 1);
INSERT INTO usuaris VALUES (4311, 'Daira', 'Segovia Lerma', 'D', '50 C/ Pablo Iglesias', 26315, 'Daira.Segovia.Lerma@dodgit.com', '30/06/55', 22, 11);
INSERT INTO usuaris VALUES (4312, 'Lahuen', 'Sanabria Gracia', 'D', '75 Eusebio Dávila', 41320, 'Lahuen.Sanabria.Gracia@dodgit.com', '28/07/82', 85, 8);
INSERT INTO usuaris VALUES (4313, 'Saustin', 'Ulibarri Coronado', 'H', '96 Antonio Vázquez', 38640, 'Saustin.Ulibarri.Coronado@pookmail.com', '31/12/51', 42, NULL);
INSERT INTO usuaris VALUES (4314, 'Liber', 'Becerra Mares', 'H', '10 Cercas Bajas', 8190, 'Liber.Becerra.Mares@trashymail.com', '08/07/76', 48, 5);
INSERT INTO usuaris VALUES (4315, 'Adelaide', 'Zavala Sepúlveda', 'D', '78 Rúa Olmos', 37408, 'Adelaide.Zavala.Sepulveda@pookmail.com', '23/03/80', 94, 9);
INSERT INTO usuaris VALUES (4316, 'Alethia', 'Jimínez Saucedo', 'D', '65 Escuadro', 46920, 'Alethia.Jiminez.Saucedo@dodgit.com', '22/10/65', 39, 9);
INSERT INTO usuaris VALUES (4317, 'Maxelinda', 'Salgado Corral', 'D', '42 Lamas Carbajal', 41800, 'Maxelinda.Salgado.Corral@mailinator.com', '23/10/66', 22, 9);
INSERT INTO usuaris VALUES (4318, 'Monique', 'Mayonga Nino', 'D', '60 Rio Segura', 31523, 'Monique.Mayonga.Nino@pookmail.com', '16/03/42', 12, 1);
INSERT INTO usuaris VALUES (4319, 'Tetis', 'Perales Mora', 'D', '67 Apartado de Correos', 37449, 'Tetis.Perales.Mora@mailinator.com', '01/11/68', 72, 4);
INSERT INTO usuaris VALUES (4320, 'Dositeo', 'Magana Espinoza', 'H', '97 Carretera Cádiz-Málaga', 20870, 'Dositeo.Magana.Espinoza@pookmail.com', '01/08/40', 64, 3);
INSERT INTO usuaris VALUES (4321, 'Serxio', 'Corral Orellana', 'H', '82 Boriñaur enparantza', 7700, 'Serxio.Corral.Orellana@mailinator.com', '03/09/74', 69, 1);
INSERT INTO usuaris VALUES (4322, 'Recaredo', 'Salinas Solorio', 'H', '22 Estrela', 39300, 'Recaredo.Salinas.Solorio@pookmail.com', '05/06/71', 71, 4);
INSERT INTO usuaris VALUES (4323, 'Nuria', 'Gaona Gaytan', NULL, '91 Outid de Arriba', 43520, 'Nuria.Gaona.Gaytan@trashymail.com', '10/03/80', 94, 2);
INSERT INTO usuaris VALUES (4324, 'Grazian', 'Lemus Ávalos', 'H', '68 Castelao', 48840, 'Grazian.Lemus.Avalos@dodgit.com', '21/12/79', 91, 7);
INSERT INTO usuaris VALUES (4325, 'Malcom', 'Muro Correa', 'H', '43 C/ Arana', 2440, 'Malcom.Muro.Correa@trashymail.com', '20/07/57', 21, 12);
INSERT INTO usuaris VALUES (4326, 'Clotilde', 'Alvarez Valdivia', 'D', '73 Avda. Enrique Peinador', 37170, 'Clotilde.Alvarez.Valdivia@mailinator.com', '26/08/77', 89, 9);
INSERT INTO usuaris VALUES (4327, 'Lucero', 'Quintana Colunga', 'D', '93 Outid de Arriba', 43519, 'Lucero.Quintana.Colunga@pookmail.com', '07/11/60', 1, 10);
INSERT INTO usuaris VALUES (4328, 'Obdulio', 'Tirado Cordova', 'H', '79 Ctra. Villena', 34300, 'Obdulio.Tirado.Cordova@spambob.com', '07/10/60', 35, 2);
INSERT INTO usuaris VALUES (4329, 'Sabine', 'Villaseñor Perales', 'D', '74 Avda. de la Estación', 28710, 'Sabine.Villasenor.Perales@trashymail.com', '03/02/69', 52, 4);
INSERT INTO usuaris VALUES (4330, 'Aron', 'Granados Quintero', 'H', '51 Puerta Nueva', 35570, 'Aron.Granados.Quintero@mailinator.com', '12/07/44', 68, NULL);
INSERT INTO usuaris VALUES (4331, 'Raguel', 'Villalobos Cardona', 'H', '68 Av. Zumalakarregi', 2692, 'Raguel.Villalobos.Cardona@spambob.com', '28/01/57', 54, 11);
INSERT INTO usuaris VALUES (4332, 'Muredac', 'Barraza Cortez', 'H', '81 Outid de Arriba', 43716, 'Muredac.Barraza.Cortez@trashymail.com', '27/12/43', 25, 2);
INSERT INTO usuaris VALUES (4333, 'Hector', 'Vergara Navarrete', 'H', '86 Eusebio Dávila', 41400, 'Hector.Vergara.Navarrete@trashymail.com', '03/04/61', 9, 8);
INSERT INTO usuaris VALUES (4334, 'Favia', 'Villagómez Quiñónez', 'D', '97 C/ Cañada del Rosal', 21640, 'Favia.Villagomez.Quinonez@pookmail.com', '14/05/79', 29, 6);
INSERT INTO usuaris VALUES (4335, 'Moira', 'Figueroa Alanis', 'D', '34 Bouciña', 43894, 'Moira.Figueroa.Alanis@dodgit.com', '24/01/48', 92, 4);
INSERT INTO usuaris VALUES (4336, 'Aniela', 'Velez Munguia', 'D', '21 Camiño Ancho', 37767, 'Aniela.Velez.Munguia@dodgit.com', '29/05/63', 58, 9);
INSERT INTO usuaris VALUES (4337, 'Armand', 'Fierro Carrillo', 'H', '50 Pl. Virgen Blanca', 8460, 'Armand.Fierro.Carrillo@trashymail.com', '31/12/40', 74, NULL);
INSERT INTO usuaris VALUES (4338, 'Benigno', 'Arana Laboy', 'H', '45 Cartagena', 30191, 'Benigno.Arana.Laboy@pookmail.com', '15/10/69', 62, 5);
INSERT INTO usuaris VALUES (4339, 'Amy', 'Alvarez Rangel', 'D', '73 Avda. Generalísimo', 31591, 'Amy.Alvarez.Rangel@dodgit.com', '19/02/43', 73, NULL);
INSERT INTO usuaris VALUES (4340, 'Montserrat', 'Alvarado Rivera', 'H', '66 C/ Libertad', 5230, 'Montserrat.Alvarado.Rivera@spambob.com', '23/06/53', 31, 6);
INSERT INTO usuaris VALUES (4341, 'Begoña', 'Alvarez Comejo', 'D', '72 Eusebio Dávila', 41560, 'Begona.Alvarez.Comejo@spambob.com', '10/10/48', 28, 7);
INSERT INTO usuaris VALUES (4342, 'Sigrid', 'Nieves Armenta', 'D', '89 Lamas Carbajal', 41657, 'Sigrid.Nieves.Armenta@dodgit.com', '05/12/85', 22, 4);
INSERT INTO usuaris VALUES (4343, 'Esperance', 'Cardona Matos', 'D', '90 C/ Benito Guinea', 8392, 'Esperance.Cardona.Matos@pookmail.com', '29/09/76', 23, 11);
INSERT INTO usuaris VALUES (4344, 'Ophelia', 'Urías Yáñez', 'D', '17 C/ Fernández de Leceta', 3390, 'Ophelia.Urias.Yanez@spambob.com', '17/11/65', 17, 2);
INSERT INTO usuaris VALUES (4345, 'Lihue', 'Najera Carvajal', 'D', '78 José matía', 1420, 'Lihue.Najera.Carvajal@pookmail.com', '30/10/78', 17, 12);
INSERT INTO usuaris VALUES (4346, 'Nabucodonosor', 'Linares Gracia', 'H', '99 Cruce Casa de Postas', 18360, 'Nabucodonosor.Linares.Gracia@pookmail.com', '17/02/51', 51, NULL);
INSERT INTO usuaris VALUES (4347, 'Saturio', 'Haro Barrientos', 'H', '20 Pza. Fuensanta', 32500, 'Saturio.Haro.Barrientos@spambob.com', '22/07/65', 35, 11);
INSERT INTO usuaris VALUES (4348, 'Geraldina', 'Godínez Murillo', 'D', '67 Calvo Sotelo', 47490, 'Geraldina.Godinez.Murillo@trashymail.com', '02/06/41', 34, 9);
INSERT INTO usuaris VALUES (4349, 'Deonilde', 'Corral Casares', 'D', '47 Comandante Izarduy', 8880, 'Deonilde.Corral.Casares@spambob.com', '05/12/65', 15, NULL);
INSERT INTO usuaris VALUES (4350, 'Martial', 'Ramón Olivárez', 'H', '17 Avda. Alameda Sundheim', 22590, 'Martial.Ramon.Olivarez@mailinator.com', '05/08/49', 69, 9);
INSERT INTO usuaris VALUES (4351, 'Amira', 'Ocasio Nieto', 'D', '86 Quevedo', 15256, 'Amira.Ocasio.Nieto@spambob.com', '16/12/55', 94, 9);
INSERT INTO usuaris VALUES (4352, 'Laurent', 'Tijerina Flórez', 'H', '87 Ctra. de la Puerta', 27100, 'Laurent.Tijerina.Florez@pookmail.com', '27/05/65', 15, 12);
INSERT INTO usuaris VALUES (4353, 'Parmenio', 'Ponce Zamudio', 'H', '76 Ctra. de la Puerta', 26588, 'Parmenio.Ponce.Zamudio@spambob.com', '11/02/68', 95, NULL);
INSERT INTO usuaris VALUES (4354, 'Ticiano', 'Otero Galván', 'H', '33 Alcon Molina', 30880, 'Ticiano.Otero.Galvan@spambob.com', '04/11/56', 27, 8);
INSERT INTO usuaris VALUES (4355, 'Adalgiso', 'Ornelas Yáñez', 'H', '14 C/ Cañada del Rosal', 21400, 'Adalgiso.Ornelas.Yanez@dodgit.com', '22/04/56', 40, 8);
INSERT INTO usuaris VALUES (4356, 'Lutero', 'Regalado Burgos', 'H', '7 Apartado de Correos', 37419, 'Lutero.Regalado.Burgos@trashymail.com', '28/06/67', 71, 5);
INSERT INTO usuaris VALUES (4357, 'Eustasio', 'Carrillo Rosas', 'H', '85 Valadouro', 48114, 'Eustasio.Carrillo.Rosas@mailinator.com', '06/05/64', 50, 2);
INSERT INTO usuaris VALUES (4358, 'Nazarena', 'Chapa Lucio', 'D', '97 Zumalakarregi etorbidea', 7170, 'Nazarena.Chapa.Lucio@spambob.com', '22/12/61', 72, 1);
INSERT INTO usuaris VALUES (4359, 'Flavia', 'Rendón Toledo', 'D', '15 C/ Canarias', 20212, 'Flavia.Rendon.Toledo@pookmail.com', '01/01/59', 12, NULL);
INSERT INTO usuaris VALUES (4360, 'Quirico', 'Alejandro Portillo', 'H', '45 Cañadilla', 22240, 'Quirico.Alejandro.Portillo@mailinator.com', '29/09/52', 63, 11);
INSERT INTO usuaris VALUES (4361, 'Heda', 'Zapata Bustos', 'D', '80 C/ Los Herrán', 6760, 'Heda.Zapata.Bustos@mailinator.com', '06/01/70', 61, 7);
INSERT INTO usuaris VALUES (4362, 'Mirta', 'Venegas Aguilera', 'D', '31 Bouciña', 43840, 'Mirta.Venegas.Aguilera@trashymail.com', '01/08/44', 68, 1);
INSERT INTO usuaris VALUES (4363, 'Erika', 'Acosta Munguia', 'D', '79 Salzillo', 32618, 'Erika.Acosta.Munguia@spambob.com', '02/08/47', 6, NULL);
INSERT INTO usuaris VALUES (4364, 'Maida', 'Partida Oquendo', 'D', '89 Eusebio Dávila', 41564, 'Maida.Partida.Oquendo@trashymail.com', '18/09/54', 15, 1);
INSERT INTO usuaris VALUES (4365, 'Adimar', 'Beltrán Otero', 'H', '56 Plazuela do Porto', 38200, 'Adimar.Beltran.Otero@mailinator.com', '30/12/74', 48, 10);
INSERT INTO usuaris VALUES (4366, 'Eulalia', 'Barragán Peres', 'D', '44 Avda. Explanada Barnuevo', 35430, 'Eulalia.Barragan.Peres@mailinator.com', '12/04/42', 81, 7);
INSERT INTO usuaris VALUES (4367, 'Esopo', 'Mascarenas Enríquez', 'H', '25 Quevedo', 15552, 'Esopo.Mascarenas.Enriquez@dodgit.com', '15/04/67', 38, 4);
INSERT INTO usuaris VALUES (4368, 'Elio', 'Villagómez Lomeli', 'H', '70 Ourense', 42250, 'Elio.Villagomez.Lomeli@mailinator.com', '05/09/81', 7, 12);
INSERT INTO usuaris VALUES (4369, 'Livio', 'Pantoja Rascón', 'H', '81 C/ Arana', 2440, 'Livio.Pantoja.Rascon@mailinator.com', '09/01/78', 82, 10);
INSERT INTO usuaris VALUES (4370, 'Carmina', 'Crespo Segura', 'D', '38 Pascual Yunquera', 18814, 'Carmina.Crespo.Segura@mailinator.com', '24/08/80', 71, 7);
INSERT INTO usuaris VALUES (4371, 'Daira', 'Velásquez Bonilla', 'D', '31 Constitución', 37114, 'Daira.Velasquez.Bonilla@pookmail.com', '09/09/53', 36, 2);
INSERT INTO usuaris VALUES (4372, 'Marino', 'Aguilar Quezada', 'H', '43 Puerto Lugar', 29711, 'Marino.Aguilar.Quezada@mailinator.com', '07/04/82', 87, 2);
INSERT INTO usuaris VALUES (4373, 'Kevin', 'Cotto Corrales', 'H', '45 C/ Andalucía', 4560, 'Kevin.Cotto.Corrales@dodgit.com', '21/08/51', 60, 7);
INSERT INTO usuaris VALUES (4374, 'Yexalén', 'Linares Paez', 'D', '82 C/ Señores Curas', 11650, 'Yexalen.Linares.Paez@dodgit.com', '26/05/42', 79, 11);
INSERT INTO usuaris VALUES (4375, 'Nydia', 'Menéndez Barajas', 'D', '18 C/ Señores Curas', 11687, 'Nydia.Menendez.Barajas@spambob.com', '03/08/76', 2, 10);
INSERT INTO usuaris VALUES (4376, 'Teodorico', 'Alcalá Becerra', 'H', '73 Camiño Real', 48498, 'Teodorico.Alcala.Becerra@spambob.com', '19/07/48', 75, 2);
INSERT INTO usuaris VALUES (4377, 'Toshi', 'Correa Alejandro', 'H', '38 Zumalakarregi etorbidea', 7190, 'Toshi.Correa.Alejandro@dodgit.com', '18/08/50', 47, 11);
INSERT INTO usuaris VALUES (4378, 'André', 'Luján Carreón', 'H', '69 Comandante Izarduy', 8880, 'Andre.Lujan.Carreon@spambob.com', '14/07/85', 21, 11);
INSERT INTO usuaris VALUES (4379, 'Maral', 'Barraza Peres', 'D', '13 Avenida Cervantes', 48350, 'Maral.Barraza.Peres@pookmail.com', '18/06/77', 92, 6);
INSERT INTO usuaris VALUES (4380, 'Ann', 'Zayas Laboy', 'D', '90 C/ Señores Curas', 11670, 'Ann.Zayas.Laboy@mailinator.com', '08/08/68', 7, 8);
INSERT INTO usuaris VALUES (4381, 'Troilo', 'Porras Téllez', 'H', '13 Enxertos', 37542, 'Troilo.Porras.Tellez@pookmail.com', '16/05/69', 65, NULL);
INSERT INTO usuaris VALUES (4382, 'Jacinta', 'Mascarenas Almonte', 'D', '93 Eusebio Dávila', 41360, 'Jacinta.Mascarenas.Almonte@mailinator.com', '11/06/78', 85, 2);
INSERT INTO usuaris VALUES (4383, 'Marie', 'Farías Carrasquill', 'D', '8 José matía', 2120, 'Marie.Farias.Carrasquill@dodgit.com', '07/08/67', 17, 3);
INSERT INTO usuaris VALUES (4384, 'Adimar', 'Tejeda Munguia', 'H', '51 El Roqueo', 15884, 'Adimar.Tejeda.Munguia@dodgit.com', '25/04/56', 84, 1);
INSERT INTO usuaris VALUES (4385, 'Karmina', 'Gastelum Ibarra', 'D', '57 Caño', 32800, 'Karmina.Gastelum.Ibarra@pookmail.com', '10/08/81', 87, 7);
INSERT INTO usuaris VALUES (4386, 'Olmo', 'Leiva Salgado', 'H', '17 El Roqueo', 15881, 'Olmo.Leiva.Salgado@spambob.com', '09/01/78', 3, 5);
INSERT INTO usuaris VALUES (4387, 'Algiso', 'Olivares Carrasco', 'H', '8 Cañadilla', 21740, 'Algiso.Olivares.Carrasco@trashymail.com', '22/04/54', 65, 4);
INSERT INTO usuaris VALUES (4388, 'Mahdi', 'Alvarez Castillo', 'D', '76 Cañadilla', 21720, 'Mahdi.Alvarez.Castillo@pookmail.com', '04/05/64', 9, 7);
INSERT INTO usuaris VALUES (4389, 'Israela', 'Cortés Treviño', 'D', '26 C/ Cañada del Rosal', 21650, 'Israela.Cortes.Trevino@mailinator.com', '08/02/45', 65, 12);
INSERT INTO usuaris VALUES (4390, 'Adelqui', 'Ayala Narváez', 'H', '4 Calle Carril de la Fuente', 13250, 'Adelqui.Ayala.Narvaez@spambob.com', '09/04/62', 19, 1);
INSERT INTO usuaris VALUES (4391, 'Adalbaro', 'Arreola Cabrera', 'H', '93 Ctra. Hornos', 26214, 'Adalbaro.Arreola.Cabrera@mailinator.com', '11/01/78', 64, 6);
INSERT INTO usuaris VALUES (4392, 'Saustin', 'Rentería Orosco', 'H', '55 C/ Eras', 28739, 'Saustin.Renteria.Orosco@spambob.com', '09/07/45', 69, 7);
INSERT INTO usuaris VALUES (4393, 'Nolberto', 'Peralta Enríquez', 'H', '92 C/ Canarias', 20000, 'Nolberto.Peralta.Enriquez@trashymail.com', '09/05/44', 7, 7);
INSERT INTO usuaris VALUES (4394, 'Déborah', 'Rangel Padrón', NULL, '22 Calvo Sotelo', 47196, 'Deborah.Rangel.Padron@dodgit.com', '14/03/56', 81, 6);
INSERT INTO usuaris VALUES (4395, 'Ciset', 'Santiago Caballero', 'H', '83 Ctra. de Fuentenueva', 28320, 'Ciset.Santiago.Caballero@spambob.com', '10/01/81', 30, NULL);
INSERT INTO usuaris VALUES (4396, 'Ives', 'Rangel Tamez', 'H', '4 Herrería', 18194, 'Ives.Rangel.Tamez@spambob.com', '07/08/71', 83, 8);
INSERT INTO usuaris VALUES (4397, 'Azarías', 'Madrigal Esparza', 'H', '50 Bellavista', 50100, 'Azarias.Madrigal.Esparza@spambob.com', '31/12/55', 81, 3);
INSERT INTO usuaris VALUES (4398, 'Rafaela', 'Caldera Mayonga', 'D', '76 C/ Cuesta del  Álamo', 29680, 'Rafaela.Caldera.Mayonga@dodgit.com', '18/06/72', 96, 1);
INSERT INTO usuaris VALUES (4399, 'Geraldina', 'Murillo Cotto', 'D', '8 Avda. Enrique Peinador', 37176, 'Geraldina.Murillo.Cotto@mailinator.com', '16/11/47', 9, 3);
INSERT INTO usuaris VALUES (4400, 'Nicholas', 'Montano Pena', 'H', '49 Maestro Puig Valera', 33720, 'Nicholas.Montano.Pena@mailinator.com', '23/06/66', 17, NULL);
INSERT INTO usuaris VALUES (4401, 'Harold', 'Rael Cadena', 'H', '78 Plazuela do Porto', 38380, 'Harold.Rael.Cadena@mailinator.com', '19/11/54', 37, 9);
INSERT INTO usuaris VALUES (4402, 'Lisístrato', 'Hernádez Vázquez', 'H', '25 C/ Eras', 28737, 'Lisistrato.Hernadez.Vazquez@spambob.com', '05/12/74', 14, 3);
INSERT INTO usuaris VALUES (4403, 'Venus', 'Guerra Bueno', 'D', '49 Rua da Rapina', 37487, 'Venus.Guerra.Bueno@mailinator.com', '17/10/40', 2, NULL);
INSERT INTO usuaris VALUES (4404, 'Bingham', 'Bueno Barraza', 'H', '73 C/ Cuevas de Ambrosio', 23711, 'Bingham.Bueno.Barraza@pookmail.com', '06/03/65', 46, 6);
INSERT INTO usuaris VALUES (4405, 'Plácido', 'Valladares Girón', 'H', '75 Avenida Cervantes', 48289, 'Placido.Valladares.Giron@spambob.com', '09/11/75', 62, 9);
INSERT INTO usuaris VALUES (4406, 'Dora', 'Hernandes Rojas', 'D', '13 Avendaño', 3850, 'Dora.Hernandes.Rojas@pookmail.com', '26/10/59', 85, 6);
INSERT INTO usuaris VALUES (4407, 'Mauli', 'Nino Sanabria', 'D', '24 Calle Proc. San Sebastián', 12596, 'Mauli.Nino.Sanabria@trashymail.com', '21/02/68', 23, 11);
INSERT INTO usuaris VALUES (4408, 'Covadonga', 'Ponce Patino', 'D', '75 Plazuela do Porto', 38280, 'Covadonga.Ponce.Patino@spambob.com', '12/11/56', 95, 5);
INSERT INTO usuaris VALUES (4409, 'Tetis', 'Becerra Saavedra', 'D', '13 Outid de Arriba', 43430, 'Tetis.Becerra.Saavedra@pookmail.com', '23/05/52', 3, 7);
INSERT INTO usuaris VALUES (4410, 'Yain', 'Mares Zepeda', 'H', '30 Avenida Cervantes', 48289, 'Yain.Mares.Zepeda@mailinator.com', '03/01/84', 2, 3);
INSERT INTO usuaris VALUES (4411, 'Tarsilia', 'Orozco Solís', 'D', '25 Ctra. Beas-Cortijos Nuevos', 26374, 'Tarsilia.Orozco.Solis@spambob.com', '23/07/70', 92, 2);
INSERT INTO usuaris VALUES (4412, 'Stefano', 'Pulido Soto', 'H', '13 Avda. de Andalucía', 29240, 'Stefano.Pulido.Soto@dodgit.com', '04/10/56', 6, 11);
INSERT INTO usuaris VALUES (4413, 'Isabelle', 'Velásquez Rubio', 'D', '53 Cañadilla', 22214, 'Isabelle.Velasquez.Rubio@mailinator.com', '21/08/81', 82, 6);
INSERT INTO usuaris VALUES (4414, 'Akemi', 'Mondragón Lara', 'D', '89 C/ Rosa de los Vientos', 11200, 'Akemi.Mondragon.Lara@mailinator.com', '16/07/77', 2, 9);
INSERT INTO usuaris VALUES (4415, 'Salvatore', 'Mesa Laureano', 'H', '19 Socampo', 37620, 'Salvatore.Mesa.Laureano@trashymail.com', '31/08/51', 25, 4);
INSERT INTO usuaris VALUES (4416, 'Anthony', 'Ferrer Quezada', 'H', '76 C/ Cañada del Rosal', 21610, 'Anthony.Ferrer.Quezada@dodgit.com', '14/01/62', 84, NULL);
INSERT INTO usuaris VALUES (4417, 'Siro', 'Nieves Preciado', 'H', '89 C/ Fernández de Leceta', 3520, 'Siro.Nieves.Preciado@dodgit.com', '27/10/43', 40, 6);
INSERT INTO usuaris VALUES (4418, 'Morena', 'Perea Bonilla', 'D', '15 Rúa Olmos', 37329, 'Morena.Perea.Bonilla@mailinator.com', '28/11/49', 44, 11);
INSERT INTO usuaris VALUES (4419, 'Clímaco', 'Campos Pelayo', 'H', '54 C/ Angosto', 23560, 'Climaco.Campos.Pelayo@dodgit.com', '24/09/59', 34, NULL);
INSERT INTO usuaris VALUES (4420, 'Natalio', 'Casanova Garrido', 'H', '25 Avda. Alameda Sundheim', 23110, 'Natalio.Casanova.Garrido@mailinator.com', '29/03/80', 8, 12);
INSERT INTO usuaris VALUES (4421, 'Borja', 'Zepeda Gamez', 'H', '70 Apartado de Correos', 37430, 'Borja.Zepeda.Gamez@mailinator.com', '22/08/47', 35, 8);
INSERT INTO usuaris VALUES (4422, 'Ursy', 'Torres Paez', 'D', '98 Lamas Carbajal', 41630, 'Ursy.Torres.Paez@pookmail.com', '18/01/81', 80, 6);
INSERT INTO usuaris VALUES (4423, 'Filelio', 'Armenta Villaseñor', NULL, '93 Valadouro', 48170, 'Filelio.Armenta.Villasenor@dodgit.com', '23/09/78', 8, 11);
INSERT INTO usuaris VALUES (4424, 'Daryl', 'Ortiz Saldivar', NULL, '22 Calle Aduana', 1160, 'Daryl.Ortiz.Saldivar@spambob.com', '18/01/48', 13, 6);
INSERT INTO usuaris VALUES (4425, 'Aldous', 'Bañuelos Valenzuela', 'H', '74 Enxertos', 37554, 'Aldous.Banuelos.Valenzuela@pookmail.com', '25/07/79', 54, 9);
INSERT INTO usuaris VALUES (4426, 'Tristana', 'Alba Lebrón', NULL, '97 Reiseñor', 45600, 'Tristana.Alba.Lebron@spambob.com', '29/02/40', 67, 1);
INSERT INTO usuaris VALUES (4427, 'Leónidas', 'Rangel Gallardo', 'H', '33 Antonio Vázquez', 38760, 'Leonidas.Rangel.Gallardo@pookmail.com', '05/02/49', 16, 6);
INSERT INTO usuaris VALUES (4428, 'Micael', 'Villaseñor Vallejo', 'H', '20 Fuente del Gallo', 14900, 'Micael.Villasenor.Vallejo@dodgit.com', '16/08/78', 24, 3);
INSERT INTO usuaris VALUES (4429, 'Nisim', 'Perales Ortiz', 'H', '85 C/ Andalucía', 4770, 'Nisim.Perales.Ortiz@spambob.com', '09/07/73', 20, 8);
INSERT INTO usuaris VALUES (4430, 'Delvis', 'Bonilla Tapia', 'D', '83 Carretera del Muelle', 12414, 'Delvis.Bonilla.Tapia@mailinator.com', '29/09/80', 39, 5);
INSERT INTO usuaris VALUES (4431, 'Alcira', 'Cepeda Negrete', 'D', '83 Crta. Cádiz-Málaga', 12191, 'Alcira.Cepeda.Negrete@trashymail.com', '22/07/59', 55, 3);
INSERT INTO usuaris VALUES (4432, 'Rosilda', 'Mojica Robles', 'D', '74 Calle Carril de la Fuente', 13193, 'Rosilda.Mojica.Robles@trashymail.com', '12/02/63', 46, 6);
INSERT INTO usuaris VALUES (4433, 'Paco', 'Rael Parra', 'H', '84 Lamas Carbajal', 41566, 'Paco.Rael.Parra@pookmail.com', '02/11/49', 91, 5);
INSERT INTO usuaris VALUES (4434, 'Purlan', 'Huerta Ocasio', 'H', '11 Rúa Olmos', 37340, 'Purlan.Huerta.Ocasio@dodgit.com', '10/07/52', 23, 1);
INSERT INTO usuaris VALUES (4435, 'Enon', 'Salcido Rubio', 'H', '86 C/ Eras', 28738, 'Enon.Salcido.Rubio@pookmail.com', '15/01/51', 76, 6);
INSERT INTO usuaris VALUES (4436, 'Ervino', 'Gallegos Gallegos', 'H', '65 Puerto Lugar', 29718, 'Ervino.Gallegos.Gallegos@dodgit.com', '05/12/75', 81, 11);
INSERT INTO usuaris VALUES (4437, 'Elea', 'Rivera Adame', 'D', '74 Reyes Católicos', 10400, 'Elea.Rivera.Adame@pookmail.com', '04/03/51', 55, NULL);
INSERT INTO usuaris VALUES (4438, 'Alceo', 'Pulido López', 'H', '2 Avda. Explanada Barnuevo', 34880, 'Alceo.Pulido.Lopez@dodgit.com', '01/02/73', 25, 5);
INSERT INTO usuaris VALUES (4439, 'Yain', 'Matías Alonso', 'H', '92 Boriñaur enparantza', 7430, 'Yain.Matias.Alonso@dodgit.com', '28/02/40', 63, 2);
INSERT INTO usuaris VALUES (4440, 'Emma', 'Armendáriz Curiel', 'D', '95 Alvaro Cunqueiro', 40520, 'Emma.Armendariz.Curiel@mailinator.com', '27/02/64', 26, 7);
INSERT INTO usuaris VALUES (4441, 'Simón', 'Apodaca Bonilla', 'H', '65 Estrela', 39538, 'Simon.Apodaca.Bonilla@dodgit.com', '02/04/52', 63, 5);
INSERT INTO usuaris VALUES (4442, 'Obdulio', 'Soria Enríquez', 'H', '48 Plaza de España', 15700, 'Obdulio.Soria.Enriquez@mailinator.com', '10/05/68', 88, 8);
INSERT INTO usuaris VALUES (4443, 'Elisa', 'Tamayo Valenzuela', 'D', '5 Ctra. de Fuentenueva', 28191, 'Elisa.Tamayo.Valenzuela@dodgit.com', '04/03/46', 40, 7);
INSERT INTO usuaris VALUES (4444, 'Mijal', 'Terrazas Lovato', 'D', '86 El Roqueo', 15960, 'Mijal.Terrazas.Lovato@dodgit.com', '27/03/84', 56, 4);
INSERT INTO usuaris VALUES (4445, 'Carysa', 'Farías Irizarry', 'D', '19 Constitución', 37129, 'Carysa.Farias.Irizarry@spambob.com', '07/03/59', 68, 8);
INSERT INTO usuaris VALUES (4446, 'Alaia', 'Vergara Casares', 'D', '25 Calvo Sotelo', 47420, 'Alaia.Vergara.Casares@spambob.com', '14/01/61', 13, 7);
INSERT INTO usuaris VALUES (4447, 'Rhode', 'Castaneda Pagan', NULL, '76 Calle Carril de la Fuente', 13193, 'Rhode.Castaneda.Pagan@pookmail.com', '21/12/65', 20, 11);
INSERT INTO usuaris VALUES (4448, 'Winni', 'Soria Archuleta', 'D', '73 Calle Carril de la Fuente', 13260, 'Winni.Soria.Archuleta@dodgit.com', '08/10/61', 64, 6);
INSERT INTO usuaris VALUES (4449, 'Anahid', 'Casanova Rojo', 'D', '62 Avda. de la Estación', 28580, 'Anahid.Casanova.Rojo@spambob.com', '22/10/52', 52, 2);
INSERT INTO usuaris VALUES (4450, 'Ambrosia', 'Adame Gaitán', NULL, '61 La Fontanilla', 14450, 'Ambrosia.Adame.Gaitan@spambob.com', '19/12/57', 10, 12);
INSERT INTO usuaris VALUES (4451, 'Peter', 'Quiñones Espino', 'H', '1 C/ Cañada del Rosal', 21592, 'Peter.Quinones.Espino@pookmail.com', '16/03/45', 86, NULL);
INSERT INTO usuaris VALUES (4452, 'Katherine', 'Escobar Madera', 'D', '84 Avda. Alameda Sundheim', 23110, 'Katherine.Escobar.Madera@mailinator.com', '14/03/55', 18, 10);
INSERT INTO usuaris VALUES (4453, 'Jan', 'Muñiz Nieto', 'H', '96 Calle Carril de la Fuente', 13248, 'Jan.Muniz.Nieto@pookmail.com', '03/09/73', 18, 7);
INSERT INTO usuaris VALUES (4454, 'Anarda', 'Vallejo Quesada', 'D', '68 José matía', 1430, 'Anarda.Vallejo.Quesada@dodgit.com', '28/02/52', 56, 2);
INSERT INTO usuaris VALUES (4455, 'Marina', 'Gamez Alonso', 'D', '91 Ctra. de Siles', 27325, 'Marina.Gamez.Alonso@trashymail.com', '26/11/54', 48, 1);
INSERT INTO usuaris VALUES (4456, 'Mariola', 'Cervántez Urbina', 'D', '28 C/ Arana', 2520, 'Mariola.Cervantez.Urbina@trashymail.com', '01/01/57', 7, 10);
INSERT INTO usuaris VALUES (4457, 'Magno', 'Carreón Canales', 'H', '72 C/ Amoladera', 28811, 'Magno.Carreon.Canales@spambob.com', '02/06/69', 18, 7);
INSERT INTO usuaris VALUES (4458, 'Helen', 'Baez Prado', 'D', '74 Cádiz', 18490, 'Helen.Baez.Prado@spambob.com', '13/11/76', 92, 6);
INSERT INTO usuaris VALUES (4459, 'Giannina', 'Vanegas Quiroz', 'D', '56 Cruce Casa de Postas', 18418, 'Giannina.Vanegas.Quiroz@dodgit.com', '23/09/68', 27, 2);
INSERT INTO usuaris VALUES (4460, 'Urbana', 'Serna Rincón', NULL, '92 Avda. Andalucía', 26131, 'Urbana.Serna.Rincon@trashymail.com', '03/06/46', 74, NULL);
INSERT INTO usuaris VALUES (4461, 'Valentín', 'Bañuelos Luevano', 'H', '8 Ctra. de la Puerta', 27279, 'Valentin.Banuelos.Luevano@mailinator.com', '30/06/73', 2, 12);
INSERT INTO usuaris VALUES (4462, 'Ildegunda', 'Galarza Pichardo', 'D', '19 C/ Pablo Iglesias', 26315, 'Ildegunda.Galarza.Pichardo@pookmail.com', '05/11/51', 91, 4);
INSERT INTO usuaris VALUES (4463, 'Zohar', 'Aguirre Apodaca', 'H', '47 Ctra. Bailén-Motril', 23197, 'Zohar.Aguirre.Apodaca@trashymail.com', '10/06/84', 4, 12);
INSERT INTO usuaris VALUES (4464, 'Denise', 'Santana Fonseca', 'D', '3 Escuadro', 46930, 'Denise.Santana.Fonseca@dodgit.com', '29/07/58', 1, 8);
INSERT INTO usuaris VALUES (4465, 'Hervé', 'Marcos Santillán', 'H', '12 Puerta Nueva', 35628, 'Herve.Marcos.Santillan@pookmail.com', '09/02/51', 82, 11);
INSERT INTO usuaris VALUES (4466, 'Michelle', 'Guardado Santillán', NULL, '27 Padre Caro', 13680, 'Michelle.Guardado.Santillan@spambob.com', '30/04/65', 27, 1);
INSERT INTO usuaris VALUES (4467, 'Adalberto', 'Estévez Ramírez', 'H', '8 Outid de Arriba', 43710, 'Adalberto.Estevez.Ramirez@trashymail.com', '17/07/80', 1, NULL);
INSERT INTO usuaris VALUES (4468, 'Caterina', 'Banda Santana', 'D', '15 Plaza de España', 15600, 'Caterina.Banda.Santana@trashymail.com', '21/09/81', 57, 10);
INSERT INTO usuaris VALUES (4469, 'Giselle', 'Sotelo Balderas', 'D', '84 San Andrés', 37272, 'Giselle.Sotelo.Balderas@trashymail.com', '07/12/63', 47, 5);
INSERT INTO usuaris VALUES (4470, 'Margalit', 'Escalante Murillo', 'D', '23 Ourense', 43400, 'Margalit.Escalante.Murillo@pookmail.com', '11/05/50', 70, 3);
INSERT INTO usuaris VALUES (4471, 'Sonia', 'Navarro Garza', 'D', '76 Castelao', 48879, 'Sonia.Navarro.Garza@trashymail.com', '12/06/78', 25, 12);
INSERT INTO usuaris VALUES (4472, 'Renau', 'Gastelum Cervántez', 'H', '28 Plaza Maior', 37217, 'Renau.Gastelum.Cervantez@trashymail.com', '11/12/51', 21, 2);
INSERT INTO usuaris VALUES (4473, 'Mónica', 'Segura Meza', 'H', '46 Avda. Rio Nalon', 33520, 'Monica.Segura.Meza@dodgit.com', '15/06/55', 66, 4);
INSERT INTO usuaris VALUES (4474, 'Cochi', 'Fonseca Jáquez', 'D', '68 Rio Segura', 31490, 'Cochi.Fonseca.Jaquez@pookmail.com', '21/01/78', 21, 5);
INSERT INTO usuaris VALUES (4475, 'Maica', 'Palacios Gutiérrez', 'D', '92 Pza. Fuensanta', 32212, 'Maica.Palacios.Gutierrez@dodgit.com', '09/01/62', 60, 1);
INSERT INTO usuaris VALUES (4476, 'Jerry', 'Roldán Terrazas', 'H', '4 Bellavista', 49530, 'Jerry.Roldan.Terrazas@spambob.com', '15/01/79', 24, 1);
INSERT INTO usuaris VALUES (4477, 'Ivonne', 'Carranza Bustamante', 'D', '39 C/ Domingo Beltrán', 2240, 'Ivonne.Carranza.Bustamante@mailinator.com', '27/04/71', 5, 12);
INSERT INTO usuaris VALUES (4478, 'Oda', 'Vallejo Marcos', 'D', '32 Antonio Vázquez', 38726, 'Oda.Vallejo.Marcos@dodgit.com', '20/04/70', 54, 7);
INSERT INTO usuaris VALUES (4479, 'Nadir', 'Carrera Almaraz', 'H', '52 Ctra. de Fuentenueva', 28190, 'Nadir.Carrera.Almaraz@pookmail.com', '19/01/80', 72, 5);
INSERT INTO usuaris VALUES (4480, 'Pusaki', 'Villa Otero', 'H', '87 Cercas Bajas', 8200, 'Pusaki.Villa.Otero@trashymail.com', '19/04/73', 30, 9);
INSERT INTO usuaris VALUES (4481, 'Melany', 'Hernádez Salas', 'D', '82 Ventanilla de Beas', 27870, 'Melany.Hernadez.Salas@trashymail.com', '21/05/42', 16, 10);
INSERT INTO usuaris VALUES (4482, 'Selesio', 'Valadez Otero', 'H', '36 Inglaterra', 18612, 'Selesio.Valadez.Otero@dodgit.com', '21/06/85', 41, 4);
INSERT INTO usuaris VALUES (4483, 'Ioav', 'Guillén Garay', 'H', '61 C/ Los Herrán', 6400, 'Ioav.Guillen.Garay@spambob.com', '26/08/40', 28, 12);
INSERT INTO usuaris VALUES (4484, 'Elín', 'Escobedo Barreto', 'D', '83 Quevedo', 15510, 'Elin.Escobedo.Barreto@trashymail.com', '17/08/41', 26, 11);
INSERT INTO usuaris VALUES (4485, 'Arquímedes', 'Olivera Treviño', 'H', '76 C/ Señores Curas', 11680, 'Arquimedes.Olivera.Trevino@pookmail.com', '25/03/69', 16, 11);
INSERT INTO usuaris VALUES (4486, 'Adassa', 'Alcantar Rosado', 'H', '76 Avda. de la Estación', 28570, 'Adassa.Alcantar.Rosado@pookmail.com', '12/03/46', 35, 1);
INSERT INTO usuaris VALUES (4487, 'Ardón', 'Gamez Mata', 'H', '48 Antonio Vázquez', 38680, 'Ardon.Gamez.Mata@mailinator.com', '05/08/68', 22, 3);
INSERT INTO usuaris VALUES (4488, 'Filemón', 'Gamboa Cabrera', 'H', '62 Constitución', 37129, 'Filemon.Gamboa.Cabrera@spambob.com', '24/11/41', 73, 6);
INSERT INTO usuaris VALUES (4489, 'Susan', 'Covas Segura', 'D', '79 Paseo del Atlántico', 18000, 'Susan.Covas.Segura@spambob.com', '24/12/66', 19, 3);
INSERT INTO usuaris VALUES (4490, 'Ponce', 'Nieves Escobedo', 'H', '9 Antonio Vázquez', 38780, 'Ponce.Nieves.Escobedo@spambob.com', '07/11/42', 16, 4);
INSERT INTO usuaris VALUES (4491, 'Gibert', 'Griego Ceja', 'H', '73 Comandante Izarduy', 8920, 'Gibert.Griego.Ceja@dodgit.com', '20/08/40', 11, 9);
INSERT INTO usuaris VALUES (4492, 'Uriel', 'Padilla Barajas', 'H', '71 Atamaria', 36670, 'Uriel.Padilla.Barajas@spambob.com', '27/01/60', 89, 10);
INSERT INTO usuaris VALUES (4493, 'Selene', 'Alcalá Serrano', 'D', '42 Canónigo Valiño', 46240, 'Selene.Alcala.Serrano@trashymail.com', '01/10/55', 16, 8);
INSERT INTO usuaris VALUES (4494, 'Paola', 'Mateo Armenta', 'D', '64 Avda. de la Estación', 28597, 'Paola.Mateo.Armenta@pookmail.com', '28/05/55', 83, 11);
INSERT INTO usuaris VALUES (4495, 'Maialen', 'Monroy Pulido', 'D', '38 C/ Domingo Beltrán', 2253, 'Maialen.Monroy.Pulido@mailinator.com', '17/02/44', 53, 10);
INSERT INTO usuaris VALUES (4496, 'Lavinia', 'Comejo Palacios', 'D', '34 Calle Carril de la Fuente', 13270, 'Lavinia.Comejo.Palacios@mailinator.com', '21/07/68', 18, 6);
INSERT INTO usuaris VALUES (4497, 'Itamar', 'Valentín Paredes', 'H', '54 Maestro Puig Valera', 33810, 'Itamar.Valentin.Paredes@pookmail.com', '22/03/84', 41, 5);
INSERT INTO usuaris VALUES (4498, 'Salvator', 'Betancourt Monroy', 'H', '80 Rúa Olmos', 37339, 'Salvator.Betancourt.Monroy@dodgit.com', '15/03/57', 8, 2);
INSERT INTO usuaris VALUES (4499, 'Inda', 'López Arenas', 'D', '97 Calle Carril de la Fuente', 13170, 'Inda.Lopez.Arenas@trashymail.com', '12/10/82', 26, 11);
INSERT INTO usuaris VALUES (4500, 'Nicomedes', 'Reséndez Gamboa', 'H', '9 Prolongacion San Sebastian', 21386, 'Nicomedes.Resendez.Gamboa@spambob.com', '03/05/51', 91, 10);
INSERT INTO usuaris VALUES (4501, 'Lancelot', 'Ávila Castro', 'H', '90 Avda. Enrique Peinador', 37183, 'Lancelot.Avila.Castro@spambob.com', '01/03/79', 93, 2);
INSERT INTO usuaris VALUES (4502, 'Agnus', 'Matías Tello', 'D', '42 Eusebio Dávila', 41320, 'Agnus.Matias.Tello@pookmail.com', '29/04/43', 23, 9);
INSERT INTO usuaris VALUES (4503, 'Aquilino', 'Esquivel Valverde', 'H', '35 Bouciña', 43838, 'Aquilino.Esquivel.Valverde@dodgit.com', '02/07/83', 36, 9);
INSERT INTO usuaris VALUES (4504, 'Abra', 'Centeno Feliciano', 'D', '56 Canónigo Valiño', 46340, 'Abra.Centeno.Feliciano@pookmail.com', '07/01/68', 99, 11);
INSERT INTO usuaris VALUES (4505, 'Galit', 'Montano Salazar', 'D', '32 C/ Los Herrán', 6480, 'Galit.Montano.Salazar@dodgit.com', '09/05/58', 29, 2);
INSERT INTO usuaris VALUES (4506, 'Antipas', 'Vigil Curiel', 'H', '23 Antonio Vázquez', 38712, 'Antipas.Vigil.Curiel@dodgit.com', '02/10/44', 59, 4);
INSERT INTO usuaris VALUES (4507, 'Cuyén', 'Torres Acosta', 'H', '10 Cádiz', 18470, 'Cuyen.Torres.Acosta@trashymail.com', '22/06/58', 45, 12);
INSERT INTO usuaris VALUES (4508, 'Guido', 'Aguayo Sanches', 'H', '71 Crta. Cádiz-Málaga', 12183, 'Guido.Aguayo.Sanches@dodgit.com', '20/02/75', 57, 4);
INSERT INTO usuaris VALUES (4509, 'Arián', 'Aguayo Nieto', 'H', '11 Caño', 32860, 'Arian.Aguayo.Nieto@mailinator.com', '02/12/47', 97, 8);
INSERT INTO usuaris VALUES (4510, 'Leni', 'Vergara Arroyo', 'H', '27 Avda. de la Estación', 28660, 'Leni.Vergara.Arroyo@dodgit.com', '24/04/76', 38, 8);
INSERT INTO usuaris VALUES (4511, 'Let', 'Téllez Farías', 'H', '58 Rúa do Paseo', 41805, 'Let.Tellez.Farias@mailinator.com', '15/02/70', 24, 8);
INSERT INTO usuaris VALUES (4512, 'Edda', 'Quesada Navarrete', 'D', '29 Ourense', 42140, 'Edda.Quesada.Navarrete@mailinator.com', '09/03/45', 78, 2);
INSERT INTO usuaris VALUES (4513, 'Giorgio', 'Varela Ayala', 'H', '93 Eusebio Dávila', 41520, 'Giorgio.Varela.Ayala@spambob.com', '15/07/66', 41, 4);
INSERT INTO usuaris VALUES (4514, 'Pampa', 'Brito Valdivia', 'D', '76 C/ Cuevas de Ambrosio', 23611, 'Pampa.Brito.Valdivia@dodgit.com', '26/08/45', 18, 6);
INSERT INTO usuaris VALUES (4515, 'Arán', 'Alba Meléndez', 'H', '27 Bellavista', 50160, 'Aran.Alba.Melendez@trashymail.com', NULL, 77, 1);
INSERT INTO usuaris VALUES (4516, 'Sebasten', 'Marroquín Verduzco', 'H', '17 Castelao', 48879, 'Sebasten.Marroquin.Verduzco@dodgit.com', '10/03/59', 99, 1);
INSERT INTO usuaris VALUES (4517, 'Melba', 'Casillas Pichardo', 'D', '92 Antonio Vázquez', 38760, 'Melba.Casillas.Pichardo@dodgit.com', '10/01/53', 23, 4);
INSERT INTO usuaris VALUES (4518, 'Elihu', 'Rael Batista', 'H', '63 Valadouro', 48191, 'Elihu.Rael.Batista@pookmail.com', '13/08/69', 57, 4);
INSERT INTO usuaris VALUES (4519, 'Cid', 'Gastelum Candelaria', 'H', '2 La Fontanilla', 14300, 'Cid.Gastelum.Candelaria@mailinator.com', '03/04/59', 24, 7);
INSERT INTO usuaris VALUES (4520, 'Gabelo', 'Elizondo Villanueva', 'H', '10 Ourense', 42100, 'Gabelo.Elizondo.Villanueva@pookmail.com', '19/11/44', 87, 11);
INSERT INTO usuaris VALUES (4521, 'Palma', 'Gaona Cruz', 'D', '82 Avenida Cervantes', 48220, 'Palma.Gaona.Cruz@pookmail.com', '20/08/62', 36, NULL);
INSERT INTO usuaris VALUES (4522, 'Bruno', 'Enríquez Miramontes', 'H', '62 Rúa de San Pedro', 37794, 'Bruno.Enriquez.Miramontes@spambob.com', '30/11/46', 9, NULL);
INSERT INTO usuaris VALUES (4523, 'Hayde', 'Rocha Almaraz', 'D', '76 Atamaria', 36847, 'Hayde.Rocha.Almaraz@pookmail.com', '18/02/59', 2, 8);
INSERT INTO usuaris VALUES (4524, 'Karmina', 'Santiago Madera', 'D', '62 Outid de Arriba', 43530, 'Karmina.Santiago.Madera@trashymail.com', '25/03/84', 34, 10);
INSERT INTO usuaris VALUES (4525, 'Gracias', 'Pacheco Espinal', 'D', '49 Constitución', 37147, 'Gracias.Pacheco.Espinal@dodgit.com', '08/10/62', 91, NULL);
INSERT INTO usuaris VALUES (4526, 'Frederic', 'Alemán Vigil', 'H', '54 Avendaño', 4280, 'Frederic.Aleman.Vigil@spambob.com', '22/08/66', 10, 7);
INSERT INTO usuaris VALUES (4527, 'Shakira', 'Rael Valentín', NULL, '20 C/ Andalucía', 4700, 'Shakira.Rael.Valentin@pookmail.com', '23/04/44', 29, 11);
INSERT INTO usuaris VALUES (4528, 'Clea', 'Quiñónez Ybarra', 'D', '67 Rúa de San Pedro', 37794, 'Clea.Quinonez.Ybarra@spambob.com', '14/02/45', 25, 10);
INSERT INTO usuaris VALUES (4529, 'Baldwin', 'Esquibel Naranjo', 'H', '60 Socampo', 37684, 'Baldwin.Esquibel.Naranjo@spambob.com', '31/05/67', 18, 10);
INSERT INTO usuaris VALUES (4530, 'Quinta', 'Orellana Zúñiga', 'D', '69 C/ Rosa de los Vientos', 11600, 'Quinta.Orellana.Zuniga@trashymail.com', '16/08/74', 0, 6);
INSERT INTO usuaris VALUES (4531, 'Semira', 'Orta Gallegos', 'D', '22 Rúa Olmos', 37407, 'Semira.Orta.Gallegos@dodgit.com', '13/12/84', 24, 9);
INSERT INTO usuaris VALUES (4532, 'Herón', 'Muñiz Sepúlveda', 'H', '30 Prolongacion San Sebastian', 21293, 'Heron.Muniz.Sepulveda@dodgit.com', '05/09/66', 39, 2);
INSERT INTO usuaris VALUES (4533, 'Sergei', 'Rocha Agosto', 'H', '42 Maestro Puig Valera', 33600, 'Sergei.Rocha.Agosto@pookmail.com', '26/12/49', 22, 12);
INSERT INTO usuaris VALUES (4534, 'Fanuel', 'Gamez Beltrán', 'H', '83 Plaza de España', 15800, 'Fanuel.Gamez.Beltran@trashymail.com', '15/04/74', 40, 11);
INSERT INTO usuaris VALUES (4535, 'Jaclyn', 'Pacheco Iglesias', 'D', '65 Rosa de los Vientos', 13340, 'Jaclyn.Pacheco.Iglesias@dodgit.com', '19/09/58', 91, 3);
INSERT INTO usuaris VALUES (4536, 'Amandio', 'Árias Olivárez', 'H', '32 Ctra. de la Puerta', 27250, 'Amandio.Arias.Olivarez@pookmail.com', '03/03/64', 63, 9);
INSERT INTO usuaris VALUES (4537, 'Selim', 'Baez Trejo', 'H', '64 Zumalakarregi etorbidea', 7170, 'Selim.Baez.Trejo@pookmail.com', '08/05/74', 99, 12);
INSERT INTO usuaris VALUES (4538, 'Anahid', 'Solano Marín', NULL, '64 Prolongacion San Sebastian', 21369, 'Anahid.Solano.Marin@trashymail.com', '05/03/61', 85, 2);
INSERT INTO usuaris VALUES (4539, 'Mamerto', 'Árias Villanueva', 'H', '47 Herrería', 18192, 'Mamerto.Arias.Villanueva@pookmail.com', '23/08/68', 17, 1);
INSERT INTO usuaris VALUES (4540, 'Domma', 'Villaseñor Saldivar', 'D', '84 C/ Andalucía', 4650, 'Domma.Villasenor.Saldivar@spambob.com', '01/04/68', 5, 1);
INSERT INTO usuaris VALUES (4541, 'Waldemar', 'Mota Cedillo', 'H', '97 Paraguay', 3720, 'Waldemar.Mota.Cedillo@trashymail.com', '13/09/43', 47, 7);
INSERT INTO usuaris VALUES (4542, 'Ara', 'Ocampo Duran', NULL, '48 Carretera Cádiz-Málaga', 21000, 'Ara.Ocampo.Duran@mailinator.com', '30/04/60', 66, 5);
INSERT INTO usuaris VALUES (4543, 'Fulxencio', 'Ríos Quintana', 'H', '47 Camiño Ancho', 37788, 'Fulxencio.Rios.Quintana@dodgit.com', '27/03/45', 66, 12);
INSERT INTO usuaris VALUES (4544, 'Roque', 'Linares Tapia', 'H', '14 Calle Carril de la Fuente', 13320, 'Roque.Linares.Tapia@dodgit.com', '19/11/45', 73, 12);
INSERT INTO usuaris VALUES (4545, 'Clímaco', 'Luevano Arriaga', 'H', '51 Avda. Enrique Peinador', 37170, 'Climaco.Luevano.Arriaga@spambob.com', '12/07/43', 71, 10);
INSERT INTO usuaris VALUES (4546, 'Rosicler', 'Campos Perea', 'D', '79 Plaza Colón', 25700, 'Rosicler.Campos.Perea@spambob.com', '23/03/44', 76, 8);
INSERT INTO usuaris VALUES (4547, 'Babs', 'Carrera Vanegas', 'D', '34 C/ Señores Curas', 11691, 'Babs.Carrera.Vanegas@mailinator.com', '25/08/70', 75, NULL);
INSERT INTO usuaris VALUES (4548, 'Obadia', 'Colunga Angulo', 'H', '51 Inglaterra', 18530, 'Obadia.Colunga.Angulo@mailinator.com', '03/12/78', 84, 7);
INSERT INTO usuaris VALUES (4549, 'Iris', 'Segovia Bermúdez', 'D', '19 Avda. Enrique Peinador', 37148, 'Iris.Segovia.Bermudez@dodgit.com', '30/09/42', 48, NULL);
INSERT INTO usuaris VALUES (4550, 'Gigí', 'Treviño Rosario', 'D', '63 Cádiz', 18514, 'Gigi.Trevino.Rosario@mailinator.com', '30/11/44', 38, 6);
INSERT INTO usuaris VALUES (4551, 'Simplicio', 'Esparza Pena', 'H', '91 Plaza Colón', 26000, 'Simplicio.Esparza.Pena@spambob.com', '07/11/40', 99, 12);
INSERT INTO usuaris VALUES (4552, 'Yoconda', 'Hinojosa Gastelum', 'D', '7 El Roqueo', 15864, 'Yoconda.Hinojosa.Gastelum@pookmail.com', '07/05/85', 41, 10);
INSERT INTO usuaris VALUES (4553, 'Vin', 'Ojeda Flórez', 'H', '4 El Roqueo', 17200, 'Vin.Ojeda.Florez@trashymail.com', '15/08/77', 84, 1);
INSERT INTO usuaris VALUES (4554, 'Teolinda', 'Torres Domínguez', 'D', '50 Rúa de San Pedro', 37799, 'Teolinda.Torres.Dominguez@spambob.com', '19/12/77', 77, 12);
INSERT INTO usuaris VALUES (4555, 'Calíope', 'Guerrero Montano', 'D', '82 Alcon Molina', 30880, 'Caliope.Guerrero.Montano@spambob.com', '05/11/54', 93, 6);
INSERT INTO usuaris VALUES (4556, 'Saraid', 'Cordero Barrios', 'D', '38 Crta. Cádiz-Málaga', 12182, 'Saraid.Cordero.Barrios@dodgit.com', '17/07/80', 74, 8);
INSERT INTO usuaris VALUES (4557, 'Anna', 'Santillán Flores', 'D', '73 Carretera', 14800, 'Anna.Santillan.Flores@spambob.com', '09/08/55', 56, 2);
INSERT INTO usuaris VALUES (4558, 'Edesio', 'Rolón Sánchez', 'H', '51 Paseo del Atlántico', 18129, 'Edesio.Rolon.Sanchez@spambob.com', '15/04/59', 4, 4);
INSERT INTO usuaris VALUES (4559, 'Moshe', 'Olivera Sedillo', 'H', '61 Paseo del Atlántico', 18129, 'Moshe.Olivera.Sedillo@mailinator.com', '05/08/71', 31, 1);
INSERT INTO usuaris VALUES (4560, 'Katriel', 'Gamez Camacho', 'D', '15 C/ Arana', 2461, 'Katriel.Gamez.Camacho@dodgit.com', '13/06/84', 7, 9);
INSERT INTO usuaris VALUES (4561, 'Palma', 'Ponce Aguayo', 'D', '49 Rosa de los Vientos', 13341, 'Palma.Ponce.Aguayo@trashymail.com', '08/10/64', 53, 6);
INSERT INTO usuaris VALUES (4562, 'Laina', 'Zamudio Linares', 'D', '71 Comandante Izarduy', 8860, 'Laina.Zamudio.Linares@pookmail.com', '28/12/67', 8, 10);
INSERT INTO usuaris VALUES (4563, 'Hadwig', 'Zayas Carrión', NULL, '82 C/ Manuel Iradier', 3778, 'Hadwig.Zayas.Carrion@dodgit.com', '06/03/84', 53, 12);
INSERT INTO usuaris VALUES (4564, 'Aman', 'Ayala Gallegos', 'H', '35 Calle Aduana', 1311, 'Aman.Ayala.Gallegos@spambob.com', '16/11/79', 69, 3);
INSERT INTO usuaris VALUES (4565, 'Felicia', 'Gamboa Aponte', 'D', '52 Canónigo Valiño', 46270, 'Felicia.Gamboa.Aponte@trashymail.com', '28/10/47', 7, 1);
INSERT INTO usuaris VALUES (4566, 'Raynaldo', 'Montenegro Maya', 'H', '12 Paseo Junquera', 12470, 'Raynaldo.Montenegro.Maya@spambob.com', '05/07/78', 94, 12);
INSERT INTO usuaris VALUES (4567, 'Benet', 'Gurule Cardona', 'H', '51 C/ Libertad', 5310, 'Benet.Gurule.Cardona@pookmail.com', '20/03/74', 67, 7);
INSERT INTO usuaris VALUES (4568, 'Ione', 'Bravo Tejada', 'H', '62 Plaza de España', 15821, 'Ione.Bravo.Tejada@mailinator.com', '31/01/68', 85, 5);
INSERT INTO usuaris VALUES (4569, 'Haide', 'Negrón Rangel', 'D', '98 Atamaria', 36620, 'Haide.Negron.Rangel@mailinator.com', '09/05/58', 16, 9);
INSERT INTO usuaris VALUES (4570, 'Aladino', 'Roybal Toledo', 'H', '7 Carretera del Muelle', 12340, 'Aladino.Roybal.Toledo@trashymail.com', '11/10/84', 4, 2);
INSERT INTO usuaris VALUES (4571, 'Benicio', 'Gonzales Argüello', 'H', '42 Valadouro', 48141, 'Benicio.Gonzales.Arguello@pookmail.com', '28/07/44', 84, 11);
INSERT INTO usuaris VALUES (4572, 'Vitalia', 'Cabán Ocampo', 'D', '22 C/ Cañada del Rosal', 21390, 'Vitalia.Caban.Ocampo@spambob.com', '01/07/61', 17, NULL);
INSERT INTO usuaris VALUES (4573, 'Adrián', 'Cazares Sevilla', 'H', '35 Reiseñor', 46132, 'Adrian.Cazares.Sevilla@pookmail.com', '18/10/45', 63, 3);
INSERT INTO usuaris VALUES (4574, 'Adeliz', 'Aguayo Salcedo', 'D', '79 Quevedo', 15317, 'Adeliz.Aguayo.Salcedo@pookmail.com', '05/08/59', 48, 12);
INSERT INTO usuaris VALUES (4575, 'Dan', 'Montés Esquibel', 'H', '65 Crta. Cádiz-Málaga', 12190, 'Dan.Montes.Esquibel@pookmail.com', '06/11/50', 9, NULL);
INSERT INTO usuaris VALUES (4576, 'Jalil', 'Serrato Curiel', 'H', '77 Boriñaur enparantza', 7519, 'Jalil.Serrato.Curiel@dodgit.com', '26/06/60', 93, NULL);
INSERT INTO usuaris VALUES (4577, 'Kira', 'Cano Atencio', 'D', '59 Urzáiz', 44700, 'Kira.Cano.Atencio@pookmail.com', '15/09/75', 15, 1);
INSERT INTO usuaris VALUES (4578, 'Keith', 'Arévalo Padilla', 'H', '89 Celso Emilio Ferreiro', 50260, 'Keith.Arevalo.Padilla@mailinator.com', '15/05/43', 73, 6);
INSERT INTO usuaris VALUES (4579, 'Lizbeth', 'Mena Carrasco', 'D', '96 Carretera Cádiz-Málaga', 20560, 'Lizbeth.Mena.Carrasco@pookmail.com', '05/06/52', 64, 10);
INSERT INTO usuaris VALUES (4580, 'Amiel', 'Arana Guerra', 'H', '52 Cartagena', 30620, 'Amiel.Arana.Guerra@spambob.com', '23/08/54', 8, 2);
INSERT INTO usuaris VALUES (4581, 'Italo', 'Bonilla Hernádez', 'H', '77 Alcon Molina', 31230, 'Italo.Bonilla.Hernadez@mailinator.com', '25/04/60', 57, 9);
INSERT INTO usuaris VALUES (4582, 'Karem', 'Mayonga Mireles', 'D', '91 Pza. Fuensanta', 32456, 'Karem.Mayonga.Mireles@pookmail.com', '22/05/67', 61, 9);
INSERT INTO usuaris VALUES (4583, 'Siro', 'Alba Godínez', 'H', '52 C/ Pablo Iglesias', 26326, 'Siro.Alba.Godinez@spambob.com', '18/04/65', 23, 10);
INSERT INTO usuaris VALUES (4584, 'Cara', 'Limón Armas', 'D', '25 Lamas Carbajal', 41610, 'Cara.Limon.Armas@dodgit.com', '05/01/55', 31, 9);
INSERT INTO usuaris VALUES (4585, 'Segismundo', 'Terrazas Quezada', 'H', '86 Enxertos', 37511, 'Segismundo.Terrazas.Quezada@spambob.com', '10/09/67', 97, 11);
INSERT INTO usuaris VALUES (4586, 'Beattie', 'Villegas Lomeli', 'D', '17 Reyes Católicos', 9430, 'Beattie.Villegas.Lomeli@dodgit.com', '13/04/76', 24, 7);
INSERT INTO usuaris VALUES (4587, 'Giuliana', 'Merino Méndez', 'D', '93 Ctra. Hornos', 26225, 'Giuliana.Merino.Mendez@mailinator.com', '28/04/59', 21, 9);
INSERT INTO usuaris VALUES (4588, 'Romualdo', 'Cruz Murillo', 'H', '74 Estrela', 38900, 'Romualdo.Cruz.Murillo@pookmail.com', '27/08/59', 30, 10);
INSERT INTO usuaris VALUES (4589, 'Violetta', 'Meléndez Olivárez', 'D', '73 C/ Libertad', 5260, 'Violetta.Melendez.Olivarez@pookmail.com', '01/07/43', 91, 6);
INSERT INTO usuaris VALUES (4590, 'Fortunato', 'Carvajal Beltrán', 'H', '10 Puerto Lugar', 29691, 'Fortunato.Carvajal.Beltran@mailinator.com', '06/01/43', 59, NULL);
INSERT INTO usuaris VALUES (4591, 'Bartolomé', 'Quintero Gamboa', 'H', '79 Ourense', 42200, 'Bartolome.Quintero.Gamboa@spambob.com', '25/08/69', 32, 9);
INSERT INTO usuaris VALUES (4592, 'Aristocles', 'Llarnas Ochoa', 'H', '41 Avda. Alameda Sundheim', 22440, 'Aristocles.Llarnas.Ochoa@mailinator.com', '30/08/47', 56, 2);
INSERT INTO usuaris VALUES (4593, 'Christophe', 'Ornelas Limón', 'H', '60 Ctra. Villena', 33829, 'Christophe.Ornelas.Limon@spambob.com', '26/07/84', 63, 9);
INSERT INTO usuaris VALUES (4594, 'Mael', 'Mena Flórez', 'H', '3 Comandante Izarduy', 9000, 'Mael.Mena.Florez@spambob.com', '23/04/50', 96, 7);
INSERT INTO usuaris VALUES (4595, 'Krin', 'Argüello Valentín', NULL, '69 Celso Emilio Ferreiro', 50540, 'Krin.Arguello.Valentin@dodgit.com', '24/05/68', 33, 11);
INSERT INTO usuaris VALUES (4596, 'Geraldina', 'Olivera Montero', 'D', '39 Cartagena', 30640, 'Geraldina.Olivera.Montero@pookmail.com', '19/02/48', 84, 10);
INSERT INTO usuaris VALUES (4597, 'Sharon', 'Manzanares Monroy', 'D', '31 Rosa de los Vientos', 13411, 'Sharon.Manzanares.Monroy@pookmail.com', '21/07/55', 98, 2);
INSERT INTO usuaris VALUES (4598, 'Aime', 'Sosa Urías', 'D', '1 Avda. de Andalucía', 29420, 'Aime.Sosa.Urias@trashymail.com', '30/10/60', 46, 1);
INSERT INTO usuaris VALUES (4599, 'Piedad', 'Luna Alcantar', 'D', '90 Quevedo', 15350, 'Piedad.Luna.Alcantar@trashymail.com', '27/04/47', 89, 12);
INSERT INTO usuaris VALUES (4600, 'Sandor', 'Paredes Gaona', 'H', '30 Prolongacion San Sebastian', 21359, 'Sandor.Paredes.Gaona@pookmail.com', '26/02/82', 52, 12);
INSERT INTO usuaris VALUES (4601, 'Yoel', 'Lira Jáquez', 'H', '12 C/ Canarias', 20214, 'Yoel.Lira.Jaquez@trashymail.com', '28/07/65', 16, 7);
INSERT INTO usuaris VALUES (4602, 'Floro', 'Brito Vargas', 'H', '12 Cruce Casa de Postas', 18418, 'Floro.Brito.Vargas@spambob.com', '16/01/85', 86, 2);
INSERT INTO usuaris VALUES (4603, 'Adaluz', 'Carrasquill Arenas', 'D', '2 Paseo del Atlántico', 17310, 'Adaluz.Carrasquill.Arenas@trashymail.com', '09/10/49', 95, 10);
INSERT INTO usuaris VALUES (4604, 'Goliat', 'Guajardo Anaya', 'H', '26 C/ Henan Cortes', 28970, 'Goliat.Guajardo.Anaya@trashymail.com', '01/09/56', 52, 6);
INSERT INTO usuaris VALUES (4605, 'Yosef', 'Dávila Tejada', 'H', '4 Av. Santiago Lapuente', 50830, 'Yosef.Davila.Tejada@pookmail.com', '04/05/79', 62, 4);
INSERT INTO usuaris VALUES (4606, 'Júpiter', 'Herrera Reynoso', 'H', '27 Padre Caro', 13770, 'Jupiter.Herrera.Reynoso@spambob.com', '23/08/73', 68, 1);
INSERT INTO usuaris VALUES (4607, 'Leandra', 'Barrios Zayas', 'D', '36 Avda. Alameda Sundheim', 22630, 'Leandra.Barrios.Zayas@trashymail.com', '16/04/83', 34, 7);
INSERT INTO usuaris VALUES (4608, 'Lázaro', 'Espino Zayas', 'D', '51 Calle Aduana', 1307, 'Lazaro.Espino.Zayas@mailinator.com', '22/03/54', 18, 11);
INSERT INTO usuaris VALUES (4609, 'Heidi', 'Ponce Árias', 'D', '74 Estrela', 39000, 'Heidi.Ponce.Arias@spambob.com', '21/03/51', 96, 2);
INSERT INTO usuaris VALUES (4610, 'Georgina', 'Sarabia Cabán', NULL, '75 Socampo', 37638, 'Georgina.Sarabia.Caban@pookmail.com', '11/10/48', 15, 8);
INSERT INTO usuaris VALUES (4611, 'Louisa', 'Segura Montez', 'D', '85 Rua da Rapina', 37510, 'Louisa.Segura.Montez@dodgit.com', '02/10/67', 85, 1);
INSERT INTO usuaris VALUES (4612, 'Vaniria', 'Jimínez Marín', NULL, '56 Salzillo', 32613, 'Vaniria.Jiminez.Marin@trashymail.com', '26/10/79', 58, 7);
INSERT INTO usuaris VALUES (4613, 'Shulamit', 'Yáñez Casillas', 'D', '26 Ctra. de Fuentenueva', 28191, 'Shulamit.Yanez.Casillas@trashymail.com', '15/11/62', 22, 8);
INSERT INTO usuaris VALUES (4614, 'Dion', 'Madrid Casas', 'H', '68 Caño', 32824, 'Dion.Madrid.Casas@dodgit.com', '23/07/40', 37, 8);
INSERT INTO usuaris VALUES (4615, 'Dinora', 'Arellano Roldán', NULL, '12 Atamaria', 36660, 'Dinora.Arellano.Roldan@spambob.com', '06/04/82', 30, 9);
INSERT INTO usuaris VALUES (4616, 'Maricruz', 'Melgar Santillán', NULL, '2 Cruce Casa de Postas', 18310, 'Maricruz.Melgar.Santillan@spambob.com', '12/08/44', 74, 9);
INSERT INTO usuaris VALUES (4617, 'Nadelina', 'Lugo Pineda', 'D', '15 Rosa de los Vientos', 13342, 'Nadelina.Lugo.Pineda@trashymail.com', '06/04/81', 56, 7);
INSERT INTO usuaris VALUES (4618, 'Elijah', 'Martínez Barrera', 'H', '99 Calle Carril de la Fuente', 13170, 'Elijah.Martinez.Barrera@spambob.com', '13/03/55', 60, 2);
INSERT INTO usuaris VALUES (4619, 'Rhode', 'Alonzo Banda', 'D', '57 Crta. Cádiz-Málaga', 12230, 'Rhode.Alonzo.Banda@dodgit.com', '24/06/58', 85, 7);
INSERT INTO usuaris VALUES (4620, 'Antonino', 'Mora Najera', 'H', '77 Boriñaur enparantza', 7518, 'Antonino.Mora.Najera@trashymail.com', '13/09/65', 54, 12);
INSERT INTO usuaris VALUES (4621, 'Hygin', 'Arévalo Corrales', 'H', '81 C/ Manuel Iradier', 3769, 'Hygin.Arevalo.Corrales@pookmail.com', '14/09/40', 72, 11);
INSERT INTO usuaris VALUES (4622, 'Babs', 'Armas Olvera', 'D', '49 Zumalakarregi etorbidea', 7315, 'Babs.Armas.Olvera@dodgit.com', '15/12/79', 0, 8);
INSERT INTO usuaris VALUES (4623, 'Menqui', 'Pagan Gamboa', 'H', '73 Avda. Los llanos', 26288, 'Menqui.Pagan.Gamboa@mailinator.com', '05/12/45', 29, 8);
INSERT INTO usuaris VALUES (4624, 'Archer', 'Fierro Pulido', 'H', '56 C/ Cañada del Rosal', 21540, 'Archer.Fierro.Pulido@mailinator.com', '29/09/73', 50, 4);
INSERT INTO usuaris VALUES (4625, 'Cañumil', 'Quiñones Carrión', 'H', '58 Rua da Rapina', 37490, 'Canumil.Quinones.Carrion@trashymail.com', '19/02/69', 89, 6);
INSERT INTO usuaris VALUES (4626, 'Juan Carlos', 'Montoya Mesa', 'H', '84 Ourense', 42200, 'Juan.Carlos.Montoya.Mesa@dodgit.com', '03/10/47', 25, 11);
INSERT INTO usuaris VALUES (4627, 'Utka', 'Iglesias Betancourt', 'H', '4 Padre Caro', 13610, 'Utka.Iglesias.Betancourt@mailinator.com', '18/08/62', NULL, 2);
INSERT INTO usuaris VALUES (4628, 'Noelino', 'Matos Alemán', 'H', '26 Carretera Cádiz-Málaga', 20737, 'Noelino.Matos.Aleman@pookmail.com', '01/03/76', 36, 9);
INSERT INTO usuaris VALUES (4629, 'Delvis', 'Alaniz Muñiz', 'D', '29 Camiño Ancho', 37789, 'Delvis.Alaniz.Muniz@mailinator.com', '07/05/55', 63, 5);
INSERT INTO usuaris VALUES (4630, 'Teodorico', 'Rangel Alarcón', 'H', '49 C/ Henan Cortes', 28979, 'Teodorico.Rangel.Alarcon@pookmail.com', '28/02/72', 18, 8);
INSERT INTO usuaris VALUES (4631, 'Illcapil', 'Mora Rojo', 'D', '24 C/ Cuevas de Ambrosio', 23710, 'Illcapil.Mora.Rojo@pookmail.com', '22/08/41', 62, 11);
INSERT INTO usuaris VALUES (4632, 'Urbano', 'Linares Velásquez', 'H', '73 Apartado de Correos', 37449, 'Urbano.Linares.Velasquez@trashymail.com', '02/02/58', 94, 4);
INSERT INTO usuaris VALUES (4633, 'Gabriella', 'Atencio Alarcón', NULL, '13 Carretera del Muelle', 12400, 'Gabriella.Atencio.Alarcon@spambob.com', '24/03/54', 20, 8);
INSERT INTO usuaris VALUES (4634, 'Noris', 'Tijerina Mondragón', NULL, '9 Calle Carril de la Fuente', 13327, 'Noris.Tijerina.Mondragon@spambob.com', '21/11/73', 57, 11);
INSERT INTO usuaris VALUES (4635, 'Ireñe', 'Saucedo Leiva', 'D', '6 C/ Manuel Iradier', 3814, 'Irene.Saucedo.Leiva@spambob.com', '30/10/63', 96, 9);
INSERT INTO usuaris VALUES (4636, 'Marino', 'Bustos Llarnas', 'H', '71 Carretera del Muelle', 12311, 'Marino.Bustos.Llarnas@mailinator.com', '07/11/58', 98, 12);
INSERT INTO usuaris VALUES (4637, 'Javiera', 'Ortiz Treviño', 'D', '49 C/ Libertad', 5250, 'Javiera.Ortiz.Trevino@trashymail.com', '11/04/70', 22, 9);
INSERT INTO usuaris VALUES (4638, 'Naike', 'Iglesias Medina', 'H', '57 San Andrés', 37249, 'Naike.Iglesias.Medina@trashymail.com', '20/11/57', 4, 11);
INSERT INTO usuaris VALUES (4639, 'Ebony', 'Urbina Pérez', 'D', '95 Constitución', 36994, 'Ebony.Urbina.Perez@trashymail.com', '01/11/83', 96, 12);
INSERT INTO usuaris VALUES (4640, 'Laura', 'Valdés Castellanos', 'D', '38 Outid de Arriba', 43700, 'Laura.Valdes.Castellanos@pookmail.com', '26/07/50', 39, 4);
INSERT INTO usuaris VALUES (4641, 'Miyen', 'Cadena Carmona', 'D', '65 Avda. Enrique Peinador', 37171, 'Miyen.Cadena.Carmona@dodgit.com', '09/06/65', 16, 1);
INSERT INTO usuaris VALUES (4642, 'Tarcila', 'Carrasquill Ontiveros', 'D', '59 Valadouro', 48160, 'Tarcila.Carrasquill.Ontiveros@trashymail.com', '27/12/62', 15, 6);
INSERT INTO usuaris VALUES (4643, 'Romano', 'Mejía Reséndez', 'H', '8 Alcon Molina', 30820, 'Romano.Mejia.Resendez@mailinator.com', NULL, 77, NULL);
INSERT INTO usuaris VALUES (4644, 'Mayda', 'Rosario Solorio', 'D', '50 Reyes Católicos', 10900, 'Mayda.Rosario.Solorio@mailinator.com', '09/01/57', 11, 2);
INSERT INTO usuaris VALUES (4645, 'Llanque', 'Varela Grijalva', 'D', '31 Apartado de Correos', 37430, 'Llanque.Varela.Grijalva@spambob.com', '29/01/66', 42, NULL);
INSERT INTO usuaris VALUES (4646, 'Laurent', 'Valdés Medrano', 'H', '82 Ctra. Hornos', 26224, 'Laurent.Valdes.Medrano@pookmail.com', '03/07/56', 45, 7);
INSERT INTO usuaris VALUES (4647, 'Amós', 'Santana Reynoso', 'H', '62 Rio Segura', 31523, 'Amos.Santana.Reynoso@spambob.com', '17/09/72', 48, 2);
INSERT INTO usuaris VALUES (4648, 'Arthur', 'Valladares Murillo', 'H', '62 Rúa Olmos', 37318, 'Arthur.Valladares.Murillo@spambob.com', '09/12/59', 1, 4);
INSERT INTO usuaris VALUES (4649, 'Laviana', 'Agosto Rael', 'D', '23 Quevedo', 15560, 'Laviana.Agosto.Rael@spambob.com', '04/06/62', 28, 11);
INSERT INTO usuaris VALUES (4650, 'Brandon', 'Amador Uribe', 'H', '48 C/ Canarias', 20000, 'Brandon.Amador.Uribe@mailinator.com', '31/05/65', 57, 3);
INSERT INTO usuaris VALUES (4651, 'Melania', 'Maya Oquendo', 'D', '56 Escuadro', 46760, 'Melania.Maya.Oquendo@mailinator.com', '28/06/50', 6, 4);
INSERT INTO usuaris VALUES (4652, 'Olimpo', 'Ramírez Segura', 'H', '71 Avda. Generalísimo', 32152, 'Olimpo.Ramirez.Segura@trashymail.com', '30/05/81', 23, 4);
INSERT INTO usuaris VALUES (4653, 'Jovanna', 'Aponte Sedillo', 'D', '15 Antonio Vázquez', 38620, 'Jovanna.Aponte.Sedillo@dodgit.com', '03/06/81', 2, 6);
INSERT INTO usuaris VALUES (4654, 'Alano', 'Gamboa Reyna', 'H', '8 C/ Benito Guinea', 8270, 'Alano.Gamboa.Reyna@mailinator.com', '03/03/75', 74, 11);
INSERT INTO usuaris VALUES (4655, 'Virgil', 'Árias Angulo', 'H', '71 Bellavista', 49591, 'Virgil.Arias.Angulo@spambob.com', '15/02/82', 47, 8);
INSERT INTO usuaris VALUES (4656, 'Lauro', 'Negrón Montanez', 'H', '11 Pza. Fuensanta', 32170, 'Lauro.Negron.Montanez@trashymail.com', '04/09/78', 27, 3);
INSERT INTO usuaris VALUES (4657, 'Galileo', 'Hernádez Aguilera', 'H', '3 Rúa de San Pedro', 37870, 'Galileo.Hernadez.Aguilera@mailinator.com', '07/08/54', 63, 5);
INSERT INTO usuaris VALUES (4658, 'Raimon', 'Barragán Elizondo', 'H', '15 El Roqueo', 17230, 'Raimon.Barragan.Elizondo@dodgit.com', '25/05/46', 3, 9);
INSERT INTO usuaris VALUES (4659, 'Morfeo', 'Figueroa Ávila', 'H', '27 Paseo del Atlántico', 17244, 'Morfeo.Figueroa.Avila@mailinator.com', '15/01/66', 5, 12);
INSERT INTO usuaris VALUES (4660, 'Ezilda', 'Rosado Martínez', 'D', '24 Ctra. Hornos', 26225, 'Ezilda.Rosado.Martinez@mailinator.com', '01/02/47', 8, 4);
INSERT INTO usuaris VALUES (4661, 'Arnulfo', 'Ballesteros Garza', 'H', '52 C/ Benito Guinea', 8292, 'Arnulfo.Ballesteros.Garza@trashymail.com', '30/09/84', 56, 7);
INSERT INTO usuaris VALUES (4662, 'Delvis', 'Escobar Posada', 'D', '78 Inglaterra', 18520, 'Delvis.Escobar.Posada@dodgit.com', '01/05/81', 61, 10);
INSERT INTO usuaris VALUES (4663, 'Fabia', 'Montenegro Padilla', 'D', '49 Paseo del Atlántico', 18140, 'Fabia.Montenegro.Padilla@pookmail.com', '07/03/85', 88, 3);
INSERT INTO usuaris VALUES (4664, 'Kistiñe', 'Barraza Esparza', 'D', '60 C/ Rosa de los Vientos', 11560, 'Kistine.Barraza.Esparza@pookmail.com', '12/05/57', 75, 11);
INSERT INTO usuaris VALUES (4665, 'Misael', 'Girón Alanis', 'H', '14 Cádiz', 18449, 'Misael.Giron.Alanis@trashymail.com', '26/11/68', 90, 11);
INSERT INTO usuaris VALUES (4666, 'Emilse', 'Canales Herrera', 'D', '26 Ourense', 43151, 'Emilse.Canales.Herrera@dodgit.com', '27/03/85', 67, 2);
INSERT INTO usuaris VALUES (4667, 'Tránsito', 'Viera Ruvalcaba', 'D', '93 Rua da Rapina', 37491, 'Transito.Viera.Ruvalcaba@mailinator.com', '22/04/64', 60, 11);
INSERT INTO usuaris VALUES (4668, 'Almudena', 'Bahena Covarrubias', 'D', '72 Cañadilla', 22240, 'Almudena.Bahena.Covarrubias@trashymail.com', '26/01/81', 57, 11);
INSERT INTO usuaris VALUES (4669, 'Enio', 'Alvarado Medrano', 'H', '25 Crta. Cádiz-Málaga', 12180, 'Enio.Alvarado.Medrano@spambob.com', '06/03/58', 89, 10);
INSERT INTO usuaris VALUES (4670, 'Adabella', 'Salcedo Yáñez', 'D', '76 Comandante Izarduy', 9200, 'Adabella.Salcedo.Yanez@spambob.com', '22/03/64', 63, 5);
INSERT INTO usuaris VALUES (4671, 'Sinclética', 'Corrales Aragón', NULL, '33 Carretera del Muelle', 12413, 'Sincletica.Corrales.Aragon@mailinator.com', '29/01/63', 89, 11);
INSERT INTO usuaris VALUES (4672, 'Emelinda', 'Carbajal Montalvo', 'D', '17 Avda. Rio Nalon', 33527, 'Emelinda.Carbajal.Montalvo@spambob.com', '04/08/65', 62, 7);
INSERT INTO usuaris VALUES (4673, 'Amir', 'Arriaga Tello', 'H', '76 C/ Andalucía', 4550, 'Amir.Arriaga.Tello@mailinator.com', '31/10/60', 62, 3);
INSERT INTO usuaris VALUES (4674, 'Ale', 'Carrasquill Escobedo', 'D', '76 C/ Canarias', 20170, 'Ale.Carrasquill.Escobedo@mailinator.com', '10/07/73', 13, 11);
INSERT INTO usuaris VALUES (4675, 'Sereno', 'Manzanares Urías', 'H', '65 Paseo del Atlántico', 18000, 'Sereno.Manzanares.Urias@trashymail.com', '16/11/61', 48, 12);
INSERT INTO usuaris VALUES (4676, 'Etel', 'Santiago Cortés', 'D', '94 Calle Aduana', 1300, 'Etel.Santiago.Cortes@trashymail.com', '20/09/43', 58, 2);
INSERT INTO usuaris VALUES (4677, 'Jalil', 'Nazario Mesa', 'H', '96 Constitución', 37139, 'Jalil.Nazario.Mesa@pookmail.com', '20/05/47', 77, 5);
INSERT INTO usuaris VALUES (4678, 'Sibila', 'Valladares Benítez', 'D', '19 C/ Benito Guinea', 8391, 'Sibila.Valladares.Benitez@mailinator.com', '28/05/42', 10, 3);
INSERT INTO usuaris VALUES (4679, 'Palas', 'Lomeli Terán', NULL, '66 Plazuela do Porto', 38360, 'Palas.Lomeli.Teran@dodgit.com', '10/02/59', 55, 12);
INSERT INTO usuaris VALUES (4680, 'Myrna', 'Garza Montero', 'D', '91 Avda. de la Estación', 28609, 'Myrna.Garza.Montero@pookmail.com', '28/09/52', 8, 9);
INSERT INTO usuaris VALUES (4681, 'Midas', 'Márquez Ruiz', 'H', '6 C/ Fernández de Leceta', 3459, 'Midas.Marquez.Ruiz@pookmail.com', '20/03/73', 17, 8);
INSERT INTO usuaris VALUES (4682, 'Bartie', 'Hernandes Miramontes', 'H', '32 C/ Señores Curas', 12134, 'Bartie.Hernandes.Miramontes@mailinator.com', '24/12/83', 88, 6);
INSERT INTO usuaris VALUES (4683, 'Mirella', 'Villalobos Cintrón', NULL, '60 Urzáiz', 44500, 'Mirella.Villalobos.Cintron@pookmail.com', '19/02/56', 95, 3);
INSERT INTO usuaris VALUES (4684, 'Armen', 'Arévalo Navarrete', 'H', '34 Antonio Vázquez', 38720, 'Armen.Arevalo.Navarrete@trashymail.com', '25/04/61', 19, NULL);
INSERT INTO usuaris VALUES (4685, 'Margalit', 'Palacios Vela', 'D', '35 Cañadilla', 21840, 'Margalit.Palacios.Vela@mailinator.com', '11/07/70', 1, 5);
INSERT INTO usuaris VALUES (4686, 'Hadrian', 'Casillas Rendón', 'H', '62 Alcon Molina', 31140, 'Hadrian.Casillas.Rendon@mailinator.com', '05/06/73', 11, 3);
INSERT INTO usuaris VALUES (4687, 'Terence', 'Berrios Nieves', 'H', '80 C/ Fernández de Leceta', 3450, 'Terence.Berrios.Nieves@mailinator.com', '10/07/80', 65, 4);
INSERT INTO usuaris VALUES (4688, 'Elvia', 'Roque Nino', 'D', '4 Eusebio Dávila', 41449, 'Elvia.Roque.Nino@trashymail.com', '06/10/45', 99, 3);
INSERT INTO usuaris VALUES (4689, 'Agueda', 'Montano Garza', 'D', '87 Canónigo Valiño', 46620, 'Agueda.Montano.Garza@dodgit.com', '28/02/53', 39, 9);
INSERT INTO usuaris VALUES (4690, 'Jordan', 'Gamez Valdivia', 'H', '53 Cercas Bajas', 8210, 'Jordan.Gamez.Valdivia@mailinator.com', '21/01/85', 84, 10);
INSERT INTO usuaris VALUES (4691, 'Josemaría', 'Olivares Pizarro', 'H', '76 Valadouro', 48116, 'Josemaria.Olivares.Pizarro@pookmail.com', '14/02/73', 8, 11);
INSERT INTO usuaris VALUES (4692, 'Moira', 'Ayala Lozada', 'D', '65 Carretera del Muelle', 12311, 'Moira.Ayala.Lozada@pookmail.com', '16/10/55', 89, 6);
INSERT INTO usuaris VALUES (4693, 'Yaima', 'Batista Puga', 'D', '86 Bellavista', 50172, 'Yaima.Batista.Puga@dodgit.com', '23/07/84', 98, 4);
INSERT INTO usuaris VALUES (4694, 'Pierina', 'Granados Orta', 'D', '50 Constitución', 36900, 'Pierina.Granados.Orta@dodgit.com', '29/08/41', 92, 10);
INSERT INTO usuaris VALUES (4695, 'Iraida', 'Vargas Rico', 'D', '33 Socampo', 37640, 'Iraida.Vargas.Rico@trashymail.com', '28/02/73', NULL, 7);
INSERT INTO usuaris VALUES (4696, 'Romina', 'Domínguez Tapia', 'D', '37 C/ Angosto', 23530, 'Romina.Dominguez.Tapia@dodgit.com', '19/02/42', 70, NULL);
INSERT INTO usuaris VALUES (4697, 'Melvin', 'Regalado Acevedo', 'D', '56 Paseo del Atlántico', 18127, 'Melvin.Regalado.Acevedo@trashymail.com', '07/01/61', 56, NULL);
INSERT INTO usuaris VALUES (4698, 'Adulfo', 'Medrano Muñoz', 'H', '95 Celso Emilio Ferreiro', 50550, 'Adulfo.Medrano.Munoz@trashymail.com', '09/01/43', 93, 11);
INSERT INTO usuaris VALUES (4699, 'Karol', 'Almanza Enríquez', 'H', '84 C/ Fernández de Leceta', 3370, 'Karol.Almanza.Enriquez@pookmail.com', '30/03/43', 83, 8);
INSERT INTO usuaris VALUES (4700, 'Husai', 'Carrero Quezada', 'H', '59 Avda. Rio Nalon', 33535, 'Husai.Carrero.Quezada@mailinator.com', '29/06/63', 76, 10);
INSERT INTO usuaris VALUES (4701, 'Dyonis', 'Chavarría Cruz', 'H', '44 La Fontanilla', 14200, 'Dyonis.Chavarria.Cruz@mailinator.com', '17/02/83', 40, 3);
INSERT INTO usuaris VALUES (4702, 'Adelio', 'Olvera Barela', 'H', '15 Valadouro', 48196, 'Adelio.Olvera.Barela@spambob.com', '31/03/46', 43, 5);
INSERT INTO usuaris VALUES (4703, 'Eliana', 'Lovato Navarrete', 'D', '24 Cruce Casa de Postas', 18300, 'Eliana.Lovato.Navarrete@trashymail.com', '03/05/44', 39, 3);
INSERT INTO usuaris VALUES (4704, 'Rayen', 'Leal Gamboa', 'H', '96 Rúa do Paseo', 41810, 'Rayen.Leal.Gamboa@pookmail.com', '20/01/51', 79, 5);
INSERT INTO usuaris VALUES (4705, 'Juno', 'Aguilar Salazar', 'D', '18 Ctra. de Fuentenueva', 28191, 'Juno.Aguilar.Salazar@pookmail.com', '12/01/51', 95, 8);
INSERT INTO usuaris VALUES (4706, 'Katriel', 'Cepeda Olivera', 'D', '59 Rio Segura', 31513, 'Katriel.Cepeda.Olivera@trashymail.com', '21/01/82', 61, 4);
INSERT INTO usuaris VALUES (4707, 'Plauto', 'Ojeda Fonseca', 'H', '68 Ctra. Hornos', 26226, 'Plauto.Ojeda.Fonseca@mailinator.com', '23/03/85', 89, 8);
INSERT INTO usuaris VALUES (4708, 'Ara', 'Gaona Roybal', 'D', '69 Plaza Colón', 24420, 'Ara.Gaona.Roybal@pookmail.com', '18/01/46', 41, 2);
INSERT INTO usuaris VALUES (4709, 'Michelle', 'Urías Carreón', NULL, '33 C/ Benito Guinea', 8300, 'Michelle.Urias.Carreon@mailinator.com', '19/03/68', 33, 6);
INSERT INTO usuaris VALUES (4710, 'Dídimo', 'Montemayor Orozco', 'H', '66 Salzillo', 32616, 'Didimo.Montemayor.Orozco@trashymail.com', '29/01/83', 31, 7);
INSERT INTO usuaris VALUES (4711, 'Alba', 'Rascón Barragán', NULL, '81 Ventanilla de Beas', 27760, 'Alba.Rascon.Barragan@mailinator.com', '30/06/63', 34, 1);
INSERT INTO usuaris VALUES (4712, 'Tusnelda', 'Tijerina Caballero', 'D', '6 San Andrés', 37271, 'Tusnelda.Tijerina.Caballero@spambob.com', '23/12/73', 71, 1);
INSERT INTO usuaris VALUES (4713, 'Louis', 'Henríquez Hidalgo', 'H', '17 Rosa de los Vientos', 13427, 'Louis.Henriquez.Hidalgo@mailinator.com', '11/11/54', 3, 1);
INSERT INTO usuaris VALUES (4714, 'Clarissa', 'Puente Cuellar', 'D', '49 Av. Santiago Lapuente', 50730, 'Clarissa.Puente.Cuellar@trashymail.com', '20/11/70', 65, 11);
INSERT INTO usuaris VALUES (4715, 'Icaro', 'Sepúlveda Núñez', 'H', '52 Avda. Alameda Sundheim', 23160, 'Icaro.Sepulveda.Nunez@dodgit.com', '11/08/57', 83, 7);
INSERT INTO usuaris VALUES (4716, 'Salvatore', 'Madrid Juárez', 'H', '41 Ctra. Beas-Cortijos Nuevos', 26525, 'Salvatore.Madrid.Juarez@dodgit.com', '26/09/74', 43, 8);
INSERT INTO usuaris VALUES (4717, 'Natalie', 'Godínez Ulibarri', 'D', '83 Avda. Andalucía', 26191, 'Natalie.Godinez.Ulibarri@pookmail.com', '25/03/82', 74, 9);
INSERT INTO usuaris VALUES (4718, 'Fulvia', 'Anguiano Lovato', 'D', '36 Plaza Maior', 37191, 'Fulvia.Anguiano.Lovato@dodgit.com', '13/03/82', 32, 6);
INSERT INTO usuaris VALUES (4719, 'Juliana', 'Sanches Rivas', 'D', '84 Pza. Fuensanta', 32170, 'Juliana.Sanches.Rivas@pookmail.com', '02/05/78', 81, 5);
INSERT INTO usuaris VALUES (4720, 'Miqueo', 'Velázquez Longoria', 'H', '97 La Fontanilla', 14420, 'Miqueo.Velazquez.Longoria@pookmail.com', '01/10/42', 91, 9);
INSERT INTO usuaris VALUES (4721, 'Semira', 'Garay Carreón', NULL, '72 Puerto Lugar', 29752, 'Semira.Garay.Carreon@pookmail.com', '31/08/75', 83, 5);
INSERT INTO usuaris VALUES (4722, 'Fayruz', 'Maya Ballesteros', 'D', '39 Puerta Nueva', 36440, 'Fayruz.Maya.Ballesteros@spambob.com', '06/06/66', 18, 1);
INSERT INTO usuaris VALUES (4723, 'Heinz', 'Mascarenas Malave', 'H', '74 C/ Rosa de los Vientos', 11611, 'Heinz.Mascarenas.Malave@pookmail.com', '24/03/84', 69, 1);
INSERT INTO usuaris VALUES (4724, 'Ananías', 'Alemán Armenta', 'H', '55 Crta. Cádiz-Málaga', 12194, 'Ananias.Aleman.Armenta@pookmail.com', '28/10/64', 94, 2);
INSERT INTO usuaris VALUES (4725, 'Pirra', 'Arana Aranda', 'D', '3 Cercas Bajas', 8230, 'Pirra.Arana.Aranda@mailinator.com', '05/08/42', 4, 11);
INSERT INTO usuaris VALUES (4726, 'Massimo', 'Godoy Villa', 'H', '65 Avda. Los llanos', 26256, 'Massimo.Godoy.Villa@pookmail.com', '12/12/43', 31, 7);
INSERT INTO usuaris VALUES (4727, 'Agüeda', 'Yáñez Betancourt', NULL, '50 C/ Benito Guinea', 8330, 'Agueda.Yanez.Betancourt@mailinator.com', '18/07/83', 29, 11);
INSERT INTO usuaris VALUES (4728, 'Erika', 'Rodríguez Vela', 'D', '88 Reyes Católicos', 9560, 'Erika.Rodriguez.Vela@dodgit.com', '22/10/42', 54, 2);
INSERT INTO usuaris VALUES (4729, 'Absalón', 'Alonso Marrero', 'H', '23 Reyes Católicos', 9530, 'Absalon.Alonso.Marrero@trashymail.com', '01/01/47', 57, 4);
INSERT INTO usuaris VALUES (4730, 'Anelisa', 'Fernández Collado', 'D', '61 Calle Proc. San Sebastián', 13107, 'Anelisa.Fernandez.Collado@pookmail.com', '04/03/72', 67, 11);
INSERT INTO usuaris VALUES (4731, 'Mar', 'Nieves Ruiz', 'D', '83 Paseo Junquera', 12428, 'Mar.Nieves.Ruiz@mailinator.com', '21/08/58', 45, 6);
INSERT INTO usuaris VALUES (4732, 'Desdémona', 'Treviño Lira', 'D', '79 Carretera del Muelle', 12311, 'Desdemona.Trevino.Lira@dodgit.com', '07/07/60', 49, 1);
INSERT INTO usuaris VALUES (4733, 'Rubí', 'Rascón Serna', 'D', '56 José matía', 2000, 'Rubi.Rascon.Serna@dodgit.com', '03/12/68', 23, 8);
INSERT INTO usuaris VALUES (4734, 'Dafne', 'Bermúdez Mejía', 'D', '99 Boriñaur enparantza', 7420, 'Dafne.Bermudez.Mejia@mailinator.com', '14/01/84', 74, 5);
INSERT INTO usuaris VALUES (4735, 'Roque', 'Meza Mesa', 'H', '55 Quevedo', 15500, 'Roque.Meza.Mesa@dodgit.com', '08/01/59', 5, 8);
INSERT INTO usuaris VALUES (4736, 'Arabia', 'Ortega Baca', 'H', '75 Carretera Cádiz-Málaga', 20700, 'Arabia.Ortega.Baca@dodgit.com', '19/02/73', 14, 5);
INSERT INTO usuaris VALUES (4737, 'Quico', 'Centeno Malave', 'H', '62 C/ Eras', 28729, 'Quico.Centeno.Malave@mailinator.com', '06/07/73', 99, 10);
INSERT INTO usuaris VALUES (4738, 'Taciana', 'Duarte Mora', 'D', '22 Avda. de la Estación', 28595, 'Taciana.Duarte.Mora@dodgit.com', '02/06/62', 54, 7);
INSERT INTO usuaris VALUES (4739, 'Cassandra', 'Mata Chavarría', 'D', '7 C/ Hijuela de Lojo', 20494, 'Cassandra.Mata.Chavarria@spambob.com', '07/11/61', 76, 7);
INSERT INTO usuaris VALUES (4740, 'Lydia', 'Valle Almaraz', 'D', '81 José matía', 1427, 'Lydia.Valle.Almaraz@dodgit.com', '14/01/64', 49, 10);
INSERT INTO usuaris VALUES (4741, 'Anna', 'Solís Gastelum', 'D', '23 Rua da Rapina', 37468, 'Anna.Solis.Gastelum@dodgit.com', '03/12/69', 75, NULL);
INSERT INTO usuaris VALUES (4742, 'Josefina', 'Garza Longoria', 'D', '52 Paseo del Atlántico', 18129, 'Josefina.Garza.Longoria@pookmail.com', '03/08/51', 43, 12);
INSERT INTO usuaris VALUES (4743, 'Berenguer', 'Camacho Alcantar', NULL, '83 Pascual Yunquera', 18810, 'Berenguer.Camacho.Alcantar@pookmail.com', '29/12/79', 73, 9);
INSERT INTO usuaris VALUES (4744, 'Sahara', 'Valencia Arellano', 'D', '37 San Andrés', 37291, 'Sahara.Valencia.Arellano@mailinator.com', '14/06/72', 53, 3);
INSERT INTO usuaris VALUES (4745, 'Kaled', 'Palacios Porras', 'H', '52 Ctra. de la Puerta', 26588, 'Kaled.Palacios.Porras@spambob.com', '13/08/57', 96, 12);
INSERT INTO usuaris VALUES (4746, 'Melanie', 'Ornelas Armijo', 'D', '28 Avda. de la Estación', 28649, 'Melanie.Ornelas.Armijo@mailinator.com', '28/08/64', 3, 1);
INSERT INTO usuaris VALUES (4747, 'Jimeno', 'Burgos Tórrez', 'H', '62 El Roqueo', 17190, 'Jimeno.Burgos.Torrez@pookmail.com', '14/05/62', 2, 3);
INSERT INTO usuaris VALUES (4748, 'Didio', 'Leiva Soliz', 'H', '88 Escuadro', 47100, 'Didio.Leiva.Soliz@pookmail.com', '29/08/67', 15, NULL);
INSERT INTO usuaris VALUES (4749, 'Pigmalion', 'Sosa Montemayor', NULL, '6 Paseo Junquera', 12428, 'Pigmalion.Sosa.Montemayor@dodgit.com', '05/09/67', 59, 6);
INSERT INTO usuaris VALUES (4750, 'Hernando', 'Robles Hinojosa', 'H', '75 Ctra. de Fuentenueva', 28193, 'Hernando.Robles.Hinojosa@trashymail.com', '09/05/44', 57, 7);
INSERT INTO usuaris VALUES (4751, 'Gregor', 'Cotto Cárdenas', 'H', '55 Plazuela do Porto', 37893, 'Gregor.Cotto.Cardenas@trashymail.com', '04/02/47', 0, 12);
INSERT INTO usuaris VALUES (4752, 'Talia', 'Pérez Juárez', 'D', '25 Calle Carril de la Fuente', 13270, 'Talia.Perez.Juarez@spambob.com', '21/12/48', 30, NULL);
INSERT INTO usuaris VALUES (4753, 'Wara', 'Zapata Rael', 'D', '79 José matía', 1420, 'Wara.Zapata.Rael@mailinator.com', '16/02/50', 24, 11);
INSERT INTO usuaris VALUES (4754, 'Adelardo', 'Cárdenas Segura', 'H', '83 Plaza Maior', 37217, 'Adelardo.Cardenas.Segura@pookmail.com', '11/04/73', 58, 11);
INSERT INTO usuaris VALUES (4755, 'Pablo', 'Sisneros Camarillo', 'H', '22 Urzáiz', 44300, 'Pablo.Sisneros.Camarillo@pookmail.com', '28/06/63', 15, 11);
INSERT INTO usuaris VALUES (4756, 'Almira', 'Benavidez Téllez', 'D', '10 Padre Caro', 13630, 'Almira.Benavidez.Tellez@mailinator.com', '31/10/58', 23, 6);
INSERT INTO usuaris VALUES (4757, 'Lalo', 'Ayala Lemus', 'H', '55 Urzáiz', 44530, 'Lalo.Ayala.Lemus@spambob.com', '04/07/60', 56, 2);
INSERT INTO usuaris VALUES (4758, 'Itatí', 'Luevano Castro', 'D', '11 Padre Caro', 13750, 'Itati.Luevano.Castro@spambob.com', '22/10/78', 1, 4);
INSERT INTO usuaris VALUES (4759, 'Tomasa', 'Covas Fonseca', 'D', '99 Calle Proc. San Sebastián', 13150, 'Tomasa.Covas.Fonseca@trashymail.com', '10/01/43', 20, 7);
INSERT INTO usuaris VALUES (4760, 'Fredel', 'Olivares Reséndez', 'D', '43 Canónigo Valiño', 46200, 'Fredel.Olivares.Resendez@mailinator.com', '11/05/74', 28, 8);
INSERT INTO usuaris VALUES (4761, 'Medardo', 'Arredondo Lerma', 'H', '10 Ctra. de Fuentenueva', 28192, 'Medardo.Arredondo.Lerma@trashymail.com', '25/11/79', 76, 7);
INSERT INTO usuaris VALUES (4762, 'Pompei', 'Carbajal Mondragón', 'H', '12 Carretera Cádiz-Málaga', 20809, 'Pompei.Carbajal.Mondragon@dodgit.com', '30/11/47', 50, 2);
INSERT INTO usuaris VALUES (4763, 'Huara', 'Guillén Pichardo', 'D', '78 C/ Rosa de los Vientos', 11150, 'Huara.Guillen.Pichardo@dodgit.com', '02/03/40', 29, 11);
INSERT INTO usuaris VALUES (4764, 'Damián', 'Zúñiga Gonzales', 'H', '8 Cádiz', 18516, 'Damian.Zuniga.Gonzales@spambob.com', '25/10/80', 91, 12);
INSERT INTO usuaris VALUES (4765, 'Elal', 'Domínquez Mendoza', 'D', '78 C/ Pablo Iglesias', 26315, 'Elal.Dominquez.Mendoza@spambob.com', '13/09/56', 26, 1);
INSERT INTO usuaris VALUES (4766, 'Eufemia', 'Sauceda Guerrero', 'D', '63 Pascual Yunquera', 18840, 'Eufemia.Sauceda.Guerrero@spambob.com', '20/03/79', 68, 9);
INSERT INTO usuaris VALUES (4767, 'Eulogia', 'Dávila Padrón', NULL, '1 C/ Los Herrán', 6490, 'Eulogia.Davila.Padron@mailinator.com', '05/08/40', 84, 8);
INSERT INTO usuaris VALUES (4768, 'Rolán', 'Salazar Gracia', 'H', '76 Avenida Cervantes', 48230, 'Rolan.Salazar.Gracia@dodgit.com', '05/10/45', 63, 5);
INSERT INTO usuaris VALUES (4769, 'Barlaan', 'Ybarra Espinoza', 'H', '70 Avda. de Andalucía', 29461, 'Barlaan.Ybarra.Espinoza@trashymail.com', '08/10/63', 65, 6);
INSERT INTO usuaris VALUES (4770, 'Gracia', 'Ulloa Palomino', 'D', '89 Av. Santiago Lapuente', 52000, 'Gracia.Ulloa.Palomino@pookmail.com', '24/05/43', 28, 12);
INSERT INTO usuaris VALUES (4771, 'Hobart', 'Cisneros Luevano', 'H', '66 Calle Carril de la Fuente', 13170, 'Hobart.Cisneros.Luevano@spambob.com', '19/07/52', 8, 6);
INSERT INTO usuaris VALUES (4772, 'Armand', 'Mayonga Malave', 'H', '31 Cádiz', 18470, 'Armand.Mayonga.Malave@dodgit.com', '14/03/44', 99, 10);
INSERT INTO usuaris VALUES (4773, 'Cyprien', 'Armijo Herrera', 'H', '93 Pl. Virgen Blanca', 8757, 'Cyprien.Armijo.Herrera@trashymail.com', '13/12/56', 33, 9);
INSERT INTO usuaris VALUES (4774, 'Lavinia', 'Yáñez Borrego', 'D', '6 C/ Pablo Iglesias', 26315, 'Lavinia.Yanez.Borrego@mailinator.com', '29/11/55', 96, NULL);
INSERT INTO usuaris VALUES (4775, 'Jocelyn', 'Romo Zamudio', 'D', '11 Quevedo', 15350, 'Jocelyn.Romo.Zamudio@mailinator.com', '12/06/69', 6, 7);
INSERT INTO usuaris VALUES (4776, 'Próspero', 'Quintanilla Flores', 'H', '17 Cañadilla', 21668, 'Prospero.Quintanilla.Flores@spambob.com', '22/09/70', 41, 10);
INSERT INTO usuaris VALUES (4777, 'Astrid', 'Guerrero Aponte', 'D', '64 Extramuros', 28390, 'Astrid.Guerrero.Aponte@pookmail.com', '15/05/44', 5, 4);
INSERT INTO usuaris VALUES (4778, 'Nilda', 'Alarcón Rangel', 'D', '59 Outid de Arriba', 43712, 'Nilda.Alarcon.Rangel@dodgit.com', '29/07/47', 72, 6);
INSERT INTO usuaris VALUES (4779, 'Felisa', 'Caraballo Benavidez', 'D', '81 Bouciña', 43838, 'Felisa.Caraballo.Benavidez@dodgit.com', '10/11/71', 20, 9);
INSERT INTO usuaris VALUES (4780, 'Icaro', 'Negrón Avilés', 'H', '7 José matía', 2154, 'Icaro.Negron.Aviles@dodgit.com', '07/03/44', 93, 12);
INSERT INTO usuaris VALUES (4781, 'Gea', 'Lucio Ramírez', 'D', '6 Rua da Rapina', 37480, 'Gea.Lucio.Ramirez@spambob.com', '15/04/74', 94, 1);
INSERT INTO usuaris VALUES (4782, 'Publia', 'Bernal Hurtado', 'D', '59 C/ Hijuela de Lojo', 20400, 'Publia.Bernal.Hurtado@trashymail.com', '11/08/58', 95, NULL);
INSERT INTO usuaris VALUES (4783, 'Prisc', 'Méndez Valenzuela', 'H', '27 Carretera del Muelle', 12312, 'Prisc.Mendez.Valenzuela@trashymail.com', '20/09/85', 39, 9);
INSERT INTO usuaris VALUES (4784, 'Kalid', 'Barreto Vergara', 'D', '3 Ctra. de la Puerta', 26587, 'Kalid.Barreto.Vergara@spambob.com', '20/02/68', 1, 11);
INSERT INTO usuaris VALUES (4785, 'Alueche', 'Covas Quiroz', 'D', '25 Lamas Carbajal', 41620, 'Alueche.Covas.Quiroz@pookmail.com', '22/07/85', 87, 6);
INSERT INTO usuaris VALUES (4786, 'Isachar', 'Lira Lara', 'H', '37 Alcon Molina', 31230, 'Isachar.Lira.Lara@spambob.com', '20/11/57', 17, 9);
INSERT INTO usuaris VALUES (4787, 'Renata', 'Montero Campos', 'D', '21 Constitución', 37114, 'Renata.Montero.Campos@mailinator.com', '21/04/59', 45, 6);
INSERT INTO usuaris VALUES (4788, 'Tamar', 'Velázquez Peres', 'D', '64 Inglaterra', 18538, 'Tamar.Velazquez.Peres@pookmail.com', '22/06/51', 97, NULL);
INSERT INTO usuaris VALUES (4789, 'Laszlo', 'Rosas Balderas', 'H', '79 Paseo del Atlántico', 17480, 'Laszlo.Rosas.Balderas@trashymail.com', '21/10/84', 56, 12);
INSERT INTO usuaris VALUES (4790, 'Sixto', 'Toledo Fajardo', 'H', '53 Avda. Explanada Barnuevo', 34820, 'Sixto.Toledo.Fajardo@pookmail.com', '11/02/77', 63, 5);
INSERT INTO usuaris VALUES (4791, 'Noam', 'Ruelas Rolón', 'H', '47 C/ Cuesta del  Álamo', 29491, 'Noam.Ruelas.Rolon@pookmail.com', '08/07/60', 74, 5);
INSERT INTO usuaris VALUES (4792, 'Edelia', 'Cabán Peralta', 'D', '98 C/ Canarias', 20180, 'Edelia.Caban.Peralta@dodgit.com', '08/02/84', NULL, 3);
INSERT INTO usuaris VALUES (4793, 'Eurico', 'Jáquez Rolón', 'H', '51 C/ Arana', 2611, 'Eurico.Jaquez.Rolon@mailinator.com', '05/03/66', 61, 5);
INSERT INTO usuaris VALUES (4794, 'Eloisa', 'Nava Árias', 'D', '9 C/ Angosto', 23537, 'Eloisa.Nava.Arias@spambob.com', '21/07/85', 44, 1);
INSERT INTO usuaris VALUES (4795, 'Agila', 'Pedroza Dávila', 'H', '76 C/ Canarias', 20230, 'Agila.Pedroza.Davila@mailinator.com', '25/07/49', 44, 4);
INSERT INTO usuaris VALUES (4796, 'Erminia', 'Benítez Cortés', 'D', '51 Rúa de San Pedro', 37795, 'Erminia.Benitez.Cortes@mailinator.com', '26/12/60', 26, 11);
INSERT INTO usuaris VALUES (4797, 'Lizeth', 'Armijo Ornelas', 'D', '76 Canónigo Valiño', 46530, 'Lizeth.Armijo.Ornelas@dodgit.com', '16/11/48', 61, 3);
INSERT INTO usuaris VALUES (4798, 'Hersilia', 'Benavidez Gamez', 'D', '19 Avda. Alameda Sundheim', 22640, 'Hersilia.Benavidez.Gamez@pookmail.com', '02/04/76', 80, 5);
INSERT INTO usuaris VALUES (4799, 'Gervasio', 'Carrillo Narváez', 'H', '44 Pl. Virgen Blanca', 8440, 'Gervasio.Carrillo.Narvaez@trashymail.com', '22/11/64', 60, 5);
INSERT INTO usuaris VALUES (4800, 'Fabricia', 'Magana Portillo', 'D', '60 Castelao', 49100, 'Fabricia.Magana.Portillo@trashymail.com', '28/08/43', 81, NULL);
INSERT INTO usuaris VALUES (4801, 'Gualterio', 'Mora Escobar', NULL, '79 Urzáiz', 44510, 'Gualterio.Mora.Escobar@dodgit.com', '07/03/59', 41, 12);
INSERT INTO usuaris VALUES (4802, 'Austín', 'Terrazas Cazares', 'H', '78 Ctra. Hornos', 26223, 'Austin.Terrazas.Cazares@mailinator.com', '15/09/41', 58, 12);
INSERT INTO usuaris VALUES (4803, 'Elena', 'Hernandes Reynoso', 'D', '18 Inglaterra', 18560, 'Elena.Hernandes.Reynoso@spambob.com', '12/03/75', 17, NULL);
INSERT INTO usuaris VALUES (4804, 'Kensel', 'Mondragón Alfaro', 'H', '8 C/ Pablo Iglesias', 26338, 'Kensel.Mondragon.Alfaro@spambob.com', '25/02/41', 46, 8);
INSERT INTO usuaris VALUES (4805, 'Olaf', 'Cabán Murillo', 'H', '79 C/ Rosa de los Vientos', 11560, 'Olaf.Caban.Murillo@pookmail.com', '26/08/83', 7, 12);
INSERT INTO usuaris VALUES (4806, 'Jabel', 'Nieves Robledo', 'D', '15 Bellavista', 50180, 'Jabel.Nieves.Robledo@pookmail.com', '29/08/47', 6, 8);
INSERT INTO usuaris VALUES (4807, 'Jessie', 'Apodaca Delgado', 'D', '28 Pza. Fuensanta', 32358, 'Jessie.Apodaca.Delgado@spambob.com', '15/02/68', 67, 8);
INSERT INTO usuaris VALUES (4808, 'Joshua', 'Arévalo Ramírez', 'H', '97 Paseo Junquera', 12470, 'Joshua.Arevalo.Ramirez@dodgit.com', '27/07/69', 7, 5);
INSERT INTO usuaris VALUES (4809, 'Joseph', 'Sevilla Quintero', 'H', '14 Castelao', 48879, 'Joseph.Sevilla.Quintero@mailinator.com', '04/01/71', 4, 7);
INSERT INTO usuaris VALUES (4810, 'Victorio', 'Maya Nava', 'H', '16 Ventanilla de Beas', 28170, 'Victorio.Maya.Nava@spambob.com', '30/05/75', 93, 7);
INSERT INTO usuaris VALUES (4811, 'Ailen', 'Cedillo Saldana', 'D', '68 Zumalakarregi etorbidea', 7240, 'Ailen.Cedillo.Saldana@dodgit.com', '12/11/52', 86, 6);
INSERT INTO usuaris VALUES (4812, 'Felicia', 'Pineda Caldera', 'D', '83 Ctra. de la Puerta', 27170, 'Felicia.Pineda.Caldera@dodgit.com', '23/05/57', 93, NULL);
INSERT INTO usuaris VALUES (4813, 'Kirian', 'Carrasquill Carrión', 'H', '67 Castelao', 48879, 'Kirian.Carrasquill.Carrion@dodgit.com', '06/06/78', 83, 5);
INSERT INTO usuaris VALUES (4814, 'Fergus', 'Hidalgo Urena', 'H', '31 Puerto Lugar', 29738, 'Fergus.Hidalgo.Urena@spambob.com', '08/04/82', 25, 1);
INSERT INTO usuaris VALUES (4815, 'Torcuato', 'Carmona Santana', 'H', '72 Pascual Yunquera', 18830, 'Torcuato.Carmona.Santana@dodgit.com', '02/06/56', 80, 3);
INSERT INTO usuaris VALUES (4816, 'Valeska', 'Miranda Arce', 'D', '43 La Fontanilla', 14448, 'Valeska.Miranda.Arce@trashymail.com', '02/04/53', 29, 7);
INSERT INTO usuaris VALUES (4817, 'Favio', 'Abeyta Muñiz', 'H', '86 Cartagena', 30320, 'Favio.Abeyta.Muniz@spambob.com', '19/07/75', 75, NULL);
INSERT INTO usuaris VALUES (4818, 'Ekaterina', 'Alvarado Pedraza', 'D', '89 Calle Proc. San Sebastián', 12580, 'Ekaterina.Alvarado.Pedraza@trashymail.com', '25/02/83', 1, 2);
INSERT INTO usuaris VALUES (4819, 'Bridget', 'Agosto Bermúdez', 'D', '77 Camiño Real', 48370, 'Bridget.Agosto.Bermudez@trashymail.com', '31/12/56', 84, 11);
INSERT INTO usuaris VALUES (4820, 'Meuris', 'Garica Covarrubias', 'H', '79 Plaza Colón', 25200, 'Meuris.Garica.Covarrubias@pookmail.com', '02/08/54', 17, 4);
INSERT INTO usuaris VALUES (4821, 'Farisa', 'Mireles Ulloa', 'D', '34 C/ Eras', 28754, 'Farisa.Mireles.Ulloa@pookmail.com', '16/02/46', 4, 10);
INSERT INTO usuaris VALUES (4822, 'Julian', 'Ibarra Guerra', 'H', '36 Carretera', 14480, 'Julian.Ibarra.Guerra@spambob.com', '07/05/65', 69, 2);
INSERT INTO usuaris VALUES (4823, 'Vesta', 'Caballero Sosa', 'D', '69 Cañadilla', 21800, 'Vesta.Caballero.Sosa@pookmail.com', '24/08/40', 41, 12);
INSERT INTO usuaris VALUES (4824, 'Leónidas', 'Galindo Sosa', 'H', '41 Zumalakarregi etorbidea', 7142, 'Leonidas.Galindo.Sosa@spambob.com', '18/04/67', 85, 5);
INSERT INTO usuaris VALUES (4825, 'Merlín', 'Callas Valentín', 'H', '15 Calvo Sotelo', 47420, 'Merlin.Callas.Valentin@dodgit.com', '03/10/61', 0, NULL);
INSERT INTO usuaris VALUES (4826, 'Amilcar', 'Manzanares Madrid', 'H', '16 Avda. Rio Nalon', 33400, 'Amilcar.Manzanares.Madrid@pookmail.com', '18/09/68', NULL, 10);
INSERT INTO usuaris VALUES (4827, 'Katharina', 'Rodríguez Osorio', 'D', '15 Av. Zumalakarregi', 3340, 'Katharina.Rodriguez.Osorio@spambob.com', '29/09/41', 81, 12);
INSERT INTO usuaris VALUES (4828, 'Mickey', 'Mota Armendáriz', 'H', '30 C/ Hijuela de Lojo', 20300, 'Mickey.Mota.Armendariz@trashymail.com', '22/10/61', 22, 1);
INSERT INTO usuaris VALUES (4829, 'Margalit', 'Ordóñez Berrios', 'D', '86 Camiño Real', 48480, 'Margalit.Ordonez.Berrios@mailinator.com', '12/08/74', 39, 1);
INSERT INTO usuaris VALUES (4830, 'Alejo', 'Agosto Olivas', 'H', '90 C/ Canarias', 20170, 'Alejo.Agosto.Olivas@spambob.com', '13/09/70', 98, 8);
INSERT INTO usuaris VALUES (4831, 'Donosa', 'Alva Paz', 'D', '40 C/ Eras', 28754, 'Donosa.Alva.Paz@dodgit.com', '31/07/81', 64, NULL);
INSERT INTO usuaris VALUES (4832, 'Sibila', 'Ordóñez González', 'D', '76 San Andrés', 37256, 'Sibila.Ordonez.Gonzalez@trashymail.com', '27/08/66', 32, 12);
INSERT INTO usuaris VALUES (4833, 'Ettiene', 'Colunga Acosta', 'H', '56 Camiño Real', 48382, 'Ettiene.Colunga.Acosta@spambob.com', '11/11/75', 88, 1);
INSERT INTO usuaris VALUES (4834, 'Goio', 'Gracia Badillo', 'H', '6 C/ Libertad', 5450, 'Goio.Gracia.Badillo@spambob.com', '08/11/43', 51, 1);
INSERT INTO usuaris VALUES (4835, 'Dante', 'Botello Granado', 'H', '91 Ctra. Hornos', 26226, 'Dante.Botello.Granado@pookmail.com', '06/08/84', 11, 10);
INSERT INTO usuaris VALUES (4836, 'Troilo', 'Puga Villanueva', 'H', '79 Reiseñor', 46117, 'Troilo.Puga.Villanueva@trashymail.com', '08/04/53', 49, NULL);
INSERT INTO usuaris VALUES (4837, 'Manases', 'Padrón Montés', 'H', '50 Avda. Alameda Sundheim', 22400, 'Manases.Padron.Montes@mailinator.com', '01/10/44', 45, 11);
INSERT INTO usuaris VALUES (4838, 'Guillermina', 'Rolón Linares', 'D', '20 Pascual Yunquera', 18699, 'Guillermina.Rolon.Linares@trashymail.com', '04/09/49', 59, 8);
INSERT INTO usuaris VALUES (4839, 'Flavie', 'Arenas Jaimes', 'D', '38 Calle Aduana', 1000, 'Flavie.Arenas.Jaimes@trashymail.com', '30/10/60', 96, 8);
INSERT INTO usuaris VALUES (4840, 'Dalmiro', 'Camarillo Bahena', 'H', '52 Maestro Puig Valera', 33776, 'Dalmiro.Camarillo.Bahena@spambob.com', '18/11/50', 72, 8);
INSERT INTO usuaris VALUES (4841, 'Iriel', 'Lerma Adomo', 'D', '72 Pza. Fuensanta', 32350, 'Iriel.Lerma.Adomo@spambob.com', '02/09/68', 99, 12);
INSERT INTO usuaris VALUES (4842, 'Leontino', 'Mireles Velázquez', 'H', '32 Ctra. Hornos', 26224, 'Leontino.Mireles.Velazquez@spambob.com', '23/07/72', 54, 11);
INSERT INTO usuaris VALUES (4843, 'Hamanchay', 'Casares Vanegas', 'D', '21 Urzáiz', 44770, 'Hamanchay.Casares.Vanegas@dodgit.com', '27/11/71', 59, 3);
INSERT INTO usuaris VALUES (4844, 'Balduino', 'Cintrón Serrato', 'H', '18 Paseo del Atlántico', 17520, 'Balduino.Cintron.Serrato@pookmail.com', '31/05/80', 38, NULL);
INSERT INTO usuaris VALUES (4845, 'Dalmiro', 'Covas Nazario', 'H', '56 Ctra. Beas-Cortijos Nuevos', 26520, 'Dalmiro.Covas.Nazario@trashymail.com', '03/02/71', 74, 9);
INSERT INTO usuaris VALUES (4846, 'Heinz', 'Romo Rael', 'H', '77 Puerta Nueva', 36110, 'Heinz.Romo.Rael@dodgit.com', '28/12/76', 28, 11);
INSERT INTO usuaris VALUES (4847, 'Pericles', 'Negrete Estévez', 'H', '15 Alvaro Cunqueiro', 40470, 'Pericles.Negrete.Estevez@dodgit.com', '20/02/58', 81, 6);
INSERT INTO usuaris VALUES (4848, 'Job', 'Anguiano Solórzano', 'H', '16 Socampo', 37610, 'Job.Anguiano.Solorzano@trashymail.com', '24/04/45', 95, NULL);
INSERT INTO usuaris VALUES (4849, 'Benon', 'Prado Samaniego', 'H', '92 Ctra. Villena', 34480, 'Benon.Prado.Samaniego@mailinator.com', '07/06/43', 89, 4);
INSERT INTO usuaris VALUES (4850, 'Emerson', 'Linares Flores', 'H', '96 José matía', 2210, 'Emerson.Linares.Flores@spambob.com', '31/03/79', 87, 9);
INSERT INTO usuaris VALUES (4851, 'Marilda', 'Apodaca Gonzales', 'D', '24 Estrela', 40000, 'Marilda.Apodaca.Gonzales@pookmail.com', '05/12/44', 59, 3);
INSERT INTO usuaris VALUES (4852, 'Casia', 'Aguirre Quiroz', 'D', '36 Padre Caro', 13710, 'Casia.Aguirre.Quiroz@trashymail.com', '04/09/58', 28, 4);
INSERT INTO usuaris VALUES (4853, 'Isis', 'Anaya Moreno', 'D', '3 C/ Benito Guinea', 8350, 'Isis.Anaya.Moreno@mailinator.com', '31/08/83', 15, 3);
INSERT INTO usuaris VALUES (4854, 'Adelfo', 'Roque Longoria', 'H', '11 C/ Cañada del Rosal', 21650, 'Adelfo.Roque.Longoria@mailinator.com', '09/01/43', 98, 7);
INSERT INTO usuaris VALUES (4855, 'Asael', 'Macías Arana', 'H', '22 Rosa de los Vientos', 13412, 'Asael.Macias.Arana@mailinator.com', '27/10/72', 75, 1);
INSERT INTO usuaris VALUES (4856, 'Henry', 'Jiménez Menchaca', 'H', '44 C/ Canarias', 20115, 'Henry.Jimenez.Menchaca@pookmail.com', '25/04/45', 85, 1);
INSERT INTO usuaris VALUES (4857, 'Nahuel', 'Riojas Gutiérrez', 'H', '65 Plaza de España', 15808, 'Nahuel.Riojas.Gutierrez@trashymail.com', '08/08/52', 51, NULL);
INSERT INTO usuaris VALUES (4858, 'Práxedes', 'Ulibarri Macías', 'D', '83 Ctra. Villena', 33860, 'Praxedes.Ulibarri.Macias@dodgit.com', '22/11/48', 24, NULL);
INSERT INTO usuaris VALUES (4859, 'Gianna', 'Escobedo Valdivia', 'D', '26 Eusebio Dávila', 41530, 'Gianna.Escobedo.Valdivia@spambob.com', '18/05/85', 67, 1);
INSERT INTO usuaris VALUES (4860, 'Luisa', 'Rivera Perales', 'D', '39 Ctra. Beas-Cortijos Nuevos', 26533, 'Luisa.Rivera.Perales@trashymail.com', '02/11/40', 16, 7);
INSERT INTO usuaris VALUES (4861, 'Hemilce', 'Sierra Urbina', 'D', '66 Plaza Maior', 37214, 'Hemilce.Sierra.Urbina@mailinator.com', '05/11/49', 94, 11);
INSERT INTO usuaris VALUES (4862, 'Egda', 'Ornelas Tovar', 'D', '71 Pza. Fuensanta', 32226, 'Egda.Ornelas.Tovar@spambob.com', '18/10/58', 82, 9);
INSERT INTO usuaris VALUES (4863, 'Amón', 'Méndez Covas', 'H', '69 Ctra. Beas-Cortijos Nuevos', 26511, 'Amon.Mendez.Covas@spambob.com', '14/01/57', 1, 7);
INSERT INTO usuaris VALUES (4864, 'Lucrecio', 'Portillo Rosario', 'H', '59 C/ Angosto', 23460, 'Lucrecio.Portillo.Rosario@mailinator.com', '03/03/60', 27, 11);
INSERT INTO usuaris VALUES (4865, 'Elí', 'Acuna Cervantes', 'D', '89 Carretera Cádiz-Málaga', 20496, 'Eli.Acuna.Cervantes@pookmail.com', '17/10/72', 90, 1);
INSERT INTO usuaris VALUES (4866, 'Carmín', 'Munguia Cantú', 'D', '96 Plaza de España', 15687, 'Carmin.Munguia.Cantu@pookmail.com', '08/01/74', 78, 3);
INSERT INTO usuaris VALUES (4867, 'Timoteo', 'Polanco Malave', 'H', '12 Eusebio Dávila', 41530, 'Timoteo.Polanco.Malave@pookmail.com', '19/03/79', 10, 10);
INSERT INTO usuaris VALUES (4868, 'Ursulina', 'Echevarría Guevara', 'D', '99 Estrela', 38900, 'Ursulina.Echevarria.Guevara@pookmail.com', '17/05/79', 59, 9);
INSERT INTO usuaris VALUES (4869, 'Solange', 'Méndez Colunga', 'D', '36 Apartado de Correos', 37439, 'Solange.Mendez.Colunga@dodgit.com', '13/01/77', 75, 4);
INSERT INTO usuaris VALUES (4870, 'Vanya', 'Negrón Villalobos', 'D', '56 Fuente del Gallo', 15129, 'Vanya.Negron.Villalobos@mailinator.com', '29/03/67', 86, 8);
INSERT INTO usuaris VALUES (4871, 'Habid', 'Noriega Barrientos', 'H', '83 Camiño Ancho', 37785, 'Habid.Noriega.Barrientos@mailinator.com', '29/08/47', 39, 10);
INSERT INTO usuaris VALUES (4872, 'Luano', 'Leyva Riojas', 'H', '60 Zumalakarregi etorbidea', 7110, 'Luano.Leyva.Riojas@trashymail.com', '09/01/65', 67, 5);
INSERT INTO usuaris VALUES (4873, 'Ceferina', 'Árias Ledesma', 'D', '62 Rúa de San Pedro', 37850, 'Ceferina.Arias.Ledesma@spambob.com', '13/11/65', 83, 11);
INSERT INTO usuaris VALUES (4874, 'Fedra', 'Padrón Téllez', 'D', '76 Apartado de Correos', 37440, 'Fedra.Padron.Tellez@spambob.com', '12/06/63', 57, 8);
INSERT INTO usuaris VALUES (4875, 'Arquímedes', 'Montano Santana', 'H', '62 Cádiz', 18512, 'Arquimedes.Montano.Santana@mailinator.com', '06/03/46', 40, 11);
INSERT INTO usuaris VALUES (4876, 'Mimi', 'Negrón Colunga', 'D', '15 Puerto Lugar', 29780, 'Mimi.Negron.Colunga@trashymail.com', '24/06/44', 59, 10);
INSERT INTO usuaris VALUES (4877, 'Merlino', 'Canales Enríquez', 'H', '25 Avda. de Andalucía', 29370, 'Merlino.Canales.Enriquez@dodgit.com', '18/07/42', 19, 7);
INSERT INTO usuaris VALUES (4878, 'Sabrina', 'Brito Aponte', 'D', '15 Ctra. Hornos', 26211, 'Sabrina.Brito.Aponte@trashymail.com', '18/05/81', 19, 7);
INSERT INTO usuaris VALUES (4879, 'Casto', 'Garica Díaz', 'H', '74 Avda. Enrique Peinador', 37150, 'Casto.Garica.Diaz@trashymail.com', '31/01/54', NULL, 12);
INSERT INTO usuaris VALUES (4880, 'Lissete', 'Zapata Lucero', 'D', '19 Avda. Rio Nalon', 33400, 'Lissete.Zapata.Lucero@pookmail.com', '10/03/58', 55, 4);
INSERT INTO usuaris VALUES (4881, 'Doria', 'Ocampo Segovia', 'D', '8 Cartagena', 30562, 'Doria.Ocampo.Segovia@dodgit.com', '20/12/76', 79, 4);
INSERT INTO usuaris VALUES (4882, 'Hayde', 'Pena Cepeda', 'D', '89 Paraguay', 3630, 'Hayde.Pena.Cepeda@trashymail.com', '17/12/66', 7, 4);
INSERT INTO usuaris VALUES (4883, 'Trinity', 'Corona Nieto', 'D', '73 C/ Henan Cortes', 28991, 'Trinity.Corona.Nieto@trashymail.com', '26/04/60', 46, 10);
INSERT INTO usuaris VALUES (4884, 'Sabacio', 'Guardado Collazo', 'H', '48 Cercas Bajas', 8211, 'Sabacio.Guardado.Collazo@pookmail.com', '15/03/47', 31, NULL);
INSERT INTO usuaris VALUES (4885, 'Panbil', 'Navarro Bustos', 'H', '42 C/ Los Herrán', 6920, 'Panbil.Navarro.Bustos@dodgit.com', '31/12/66', 2, 2);
INSERT INTO usuaris VALUES (4886, 'Junior', 'Orozco Sotelo', 'H', '17 Paraguay', 3759, 'Junior.Orozco.Sotelo@trashymail.com', '08/01/80', 62, 10);
INSERT INTO usuaris VALUES (4887, 'Favio', 'Aguilar Colunga', 'H', '32 Avda. Explanada Barnuevo', 35450, 'Favio.Aguilar.Colunga@trashymail.com', '21/12/43', 26, NULL);
INSERT INTO usuaris VALUES (4888, 'Leontino', 'Camacho Salazar', NULL, '71 Atamaria', 36658, 'Leontino.Camacho.Salazar@trashymail.com', '28/04/43', 61, 4);
INSERT INTO usuaris VALUES (4889, 'Siglinda', 'Estévez Preciado', 'D', '26 Carretera del Muelle', 12300, 'Siglinda.Estevez.Preciado@dodgit.com', '26/03/47', 98, 9);
INSERT INTO usuaris VALUES (4890, 'Urso', 'Vázquez Mesa', 'H', '56 Celso Emilio Ferreiro', 50695, 'Urso.Vazquez.Mesa@dodgit.com', '05/05/43', 12, 5);
INSERT INTO usuaris VALUES (4891, 'Varinia', 'Madera Ortega', 'D', '90 Maestro Puig Valera', 33774, 'Varinia.Madera.Ortega@trashymail.com', '18/08/84', 60, 2);
INSERT INTO usuaris VALUES (4892, 'Catrin', 'Guzmán Casares', 'D', '79 Visitación de la Encina', 37694, 'Catrin.Guzman.Casares@dodgit.com', '19/06/47', 14, 9);
INSERT INTO usuaris VALUES (4893, 'Hilen', 'Alejandro Negrete', 'D', '65 Ctra. Villena', 33993, 'Hilen.Alejandro.Negrete@pookmail.com', '27/10/56', 5, 2);
INSERT INTO usuaris VALUES (4894, 'Inaxio', 'Ledesma Chacón', 'H', '81 La Fontanilla', 14270, 'Inaxio.Ledesma.Chacon@pookmail.com', '24/12/68', 80, 4);
INSERT INTO usuaris VALUES (4895, 'Pabil', 'Marrero Puente', 'H', '4 Urzáiz', 43896, 'Pabil.Marrero.Puente@dodgit.com', '17/03/55', 13, 11);
INSERT INTO usuaris VALUES (4896, 'Nuriel', 'Borrego Guzmán', NULL, '9 Crta. Cádiz-Málaga', 12184, 'Nuriel.Borrego.Guzman@trashymail.com', '21/02/84', 14, NULL);
INSERT INTO usuaris VALUES (4897, 'Icaro', 'Villalobos Jaimes', 'H', '75 Maestro Puig Valera', 33570, 'Icaro.Villalobos.Jaimes@trashymail.com', '14/11/61', 32, 2);
INSERT INTO usuaris VALUES (4898, 'Malte', 'Carrasco Cortez', 'H', '56 Rúa Olmos', 37329, 'Malte.Carrasco.Cortez@dodgit.com', '03/03/52', 0, 11);
INSERT INTO usuaris VALUES (4899, 'Alessandro', 'Ávila Navarrete', 'H', '90 Camiño Ancho', 37789, 'Alessandro.Avila.Navarrete@mailinator.com', '09/06/73', 54, 6);
INSERT INTO usuaris VALUES (4900, 'Nasha', 'Alonso Robles', 'D', '47 Pascual Yunquera', 18870, 'Nasha.Alonso.Robles@trashymail.com', '11/08/65', 30, 3);
INSERT INTO usuaris VALUES (4901, 'Miles', 'Aparicio Casares', 'H', '19 Avda. Enrique Peinador', 37185, 'Miles.Aparicio.Casares@mailinator.com', '29/10/77', 22, 3);
INSERT INTO usuaris VALUES (4902, 'Douglas', 'Centeno Fernández', 'H', '18 Eusebio Dávila', 41470, 'Douglas.Centeno.Fernandez@dodgit.com', '10/04/79', 21, 9);
INSERT INTO usuaris VALUES (4903, 'Bernabela', 'Peralta Garrido', 'D', '95 Carretera del Muelle', 12410, 'Bernabela.Peralta.Garrido@mailinator.com', '13/07/40', 15, 11);
INSERT INTO usuaris VALUES (4904, 'Naná', 'Chávez Zepeda', 'D', '28 Ourense', 43000, 'Nana.Chavez.Zepeda@spambob.com', '09/04/45', 55, 2);
INSERT INTO usuaris VALUES (4905, 'Sabacio', 'Garrido Fierro', 'H', '99 Antonio Vázquez', 38710, 'Sabacio.Garrido.Fierro@trashymail.com', '29/11/60', 49, 12);
INSERT INTO usuaris VALUES (4906, 'Duncan', 'Hurtado Orozco', 'H', '15 Estrela', 38900, 'Duncan.Hurtado.Orozco@pookmail.com', '07/12/80', 46, 11);
INSERT INTO usuaris VALUES (4907, 'Froilán', 'Gastelum Aguilera', 'H', '98 Ctra. de Siles', 27346, 'Froilan.Gastelum.Aguilera@spambob.com', '17/09/58', 68, 8);
INSERT INTO usuaris VALUES (4908, 'Niranjana', 'Guerrero Carrasquill', 'D', '74 Avda. Andalucía', 26131, 'Niranjana.Guerrero.Carrasquill@spambob.com', '10/01/55', 82, 8);
INSERT INTO usuaris VALUES (4909, 'Aristarco', 'León Villegas', 'H', '64 Apartado de Correos', 37440, 'Aristarco.Leon.Villegas@dodgit.com', NULL, 70, NULL);
INSERT INTO usuaris VALUES (4910, 'Loreta', 'Méndez Mora', 'D', '63 San Andrés', 37251, 'Loreta.Mendez.Mora@spambob.com', '13/11/61', 94, 2);
INSERT INTO usuaris VALUES (4911, 'Maciela', 'Alfaro Aguayo', 'D', '88 Avda. de la Estación', 28696, 'Maciela.Alfaro.Aguayo@mailinator.com', '20/02/72', 19, 2);
INSERT INTO usuaris VALUES (4912, 'Yrko', 'Alba Tórrez', 'H', '13 Pascual Yunquera', 18858, 'Yrko.Alba.Torrez@dodgit.com', '02/07/73', 74, 4);
INSERT INTO usuaris VALUES (4913, 'Hilen', 'Badillo Samaniego', 'D', '94 Ctra. de la Puerta', 26588, 'Hilen.Badillo.Samaniego@mailinator.com', '01/08/42', 42, 11);
INSERT INTO usuaris VALUES (4914, 'Melvin', 'Miranda Carrero', 'D', '44 Constitución', 37100, 'Melvin.Miranda.Carrero@pookmail.com', '05/05/44', 56, 7);
INSERT INTO usuaris VALUES (4915, 'Evasio', 'Domínquez Granados', 'H', '68 Carretera', 14830, 'Evasio.Dominquez.Granados@trashymail.com', '27/02/64', 33, 11);
INSERT INTO usuaris VALUES (4916, 'Sabrina', 'Mata Sierra', 'D', '33 Carretera del Muelle', 12231, 'Sabrina.Mata.Sierra@pookmail.com', '13/03/62', 75, 8);
INSERT INTO usuaris VALUES (4917, 'Domínica', 'Caballero Alonzo', 'D', '72 Salzillo', 32692, 'Dominica.Caballero.Alonzo@pookmail.com', '30/01/55', 61, 12);
INSERT INTO usuaris VALUES (4918, 'Hada', 'González Espinal', 'D', '24 Quevedo', 15214, 'Hada.Gonzalez.Espinal@spambob.com', '18/06/82', 78, 4);
INSERT INTO usuaris VALUES (4919, 'Nuri', 'Porras Peralta', 'H', '72 Caño', 32760, 'Nuri.Porras.Peralta@mailinator.com', '02/04/41', 6, 1);
INSERT INTO usuaris VALUES (4920, 'Hartman', 'Árias Mondragón', 'H', '76 C/ Rosa de los Vientos', 11178, 'Hartman.Arias.Mondragon@mailinator.com', '16/08/63', 49, 1);
INSERT INTO usuaris VALUES (4921, 'Filemón', 'Urbina Ramón', 'H', '53 Inglaterra', 18538, 'Filemon.Urbina.Ramon@pookmail.com', '17/04/84', 45, 7);
INSERT INTO usuaris VALUES (4922, 'Mathías', 'Pedroza Farías', 'H', '84 Carretera del Muelle', 12414, 'Mathias.Pedroza.Farias@pookmail.com', '25/01/46', 18, 1);
INSERT INTO usuaris VALUES (4923, 'Loruhama', 'Benavidez Porras', 'D', '28 C/ Andalucía', 4640, 'Loruhama.Benavidez.Porras@dodgit.com', '14/11/59', 14, 3);
INSERT INTO usuaris VALUES (4924, 'Gianni', 'Camarillo Canales', 'H', '87 Reiseñor', 45860, 'Gianni.Camarillo.Canales@mailinator.com', '30/12/55', 9, 6);
INSERT INTO usuaris VALUES (4925, 'Renée', 'Ruiz Nieves', 'D', '36 El Roqueo', 16220, 'Renee.Ruiz.Nieves@pookmail.com', '12/03/72', 86, 12);
INSERT INTO usuaris VALUES (4926, 'Bastien', 'Valladares Rangel', 'H', '89 Avda. Alameda Sundheim', 22800, 'Bastien.Valladares.Rangel@spambob.com', '26/08/65', 71, 10);
INSERT INTO usuaris VALUES (4927, 'Onella', 'Sauceda Rico', 'D', '88 C/ Libertad', 5440, 'Onella.Sauceda.Rico@mailinator.com', '30/06/53', 36, 9);
INSERT INTO usuaris VALUES (4928, 'Ariane', 'Palomino Menéndez', 'D', '75 Alcon Molina', 31251, 'Ariane.Palomino.Menendez@trashymail.com', '05/10/74', 78, 9);
INSERT INTO usuaris VALUES (4929, 'Parmenio', 'Frías Leal', 'H', '87 Paraguay', 3759, 'Parmenio.Frias.Leal@mailinator.com', '06/04/43', 66, 1);
INSERT INTO usuaris VALUES (4930, 'Elvia', 'Lovato Carreón', NULL, '21 Lamas Carbajal', 41760, 'Elvia.Lovato.Carreon@dodgit.com', '18/05/71', 0, 1);
INSERT INTO usuaris VALUES (4931, 'Hector', 'Lugo Parra', 'H', '67 Avda. Rio Nalon', 33160, 'Hector.Lugo.Parra@pookmail.com', '28/09/84', 20, NULL);
INSERT INTO usuaris VALUES (4932, 'Calímaco', 'Carranza Tovar', NULL, '30 C/ Manuel Iradier', 3814, 'Calimaco.Carranza.Tovar@mailinator.com', '30/08/82', 66, 6);
INSERT INTO usuaris VALUES (4933, 'Germinal', 'Bahena Samaniego', 'H', '95 Fuente del Gallo', 15129, 'Germinal.Bahena.Samaniego@pookmail.com', '22/03/61', 95, 7);
INSERT INTO usuaris VALUES (4934, 'Hervé', 'Reynoso Zavala', 'H', '29 Avda. Los llanos', 26257, 'Herve.Reynoso.Zavala@dodgit.com', '16/10/46', 27, 7);
INSERT INTO usuaris VALUES (4935, 'Electra', 'Urbina Vega', 'D', '52 Ctra. de Siles', 27620, 'Electra.Urbina.Vega@dodgit.com', '19/11/59', 1, 3);
INSERT INTO usuaris VALUES (4936, 'Juno', 'Gaytan Valadez', 'D', '39 Estrela', 40150, 'Juno.Gaytan.Valadez@spambob.com', '31/07/75', 93, 6);
INSERT INTO usuaris VALUES (4937, 'Libio', 'Valverde Loya', 'H', '34 Enxertos', 37590, 'Libio.Valverde.Loya@spambob.com', '07/12/72', 38, 8);
INSERT INTO usuaris VALUES (4938, 'Ivana', 'Anaya Trejo', 'D', '93 Avda. Andalucía', 26131, 'Ivana.Anaya.Trejo@mailinator.com', '12/07/47', 52, 4);
INSERT INTO usuaris VALUES (4939, 'Gianluca', 'Meléndez Pizarro', 'H', '75 Caño', 32840, 'Gianluca.Melendez.Pizarro@spambob.com', '11/06/72', 40, 7);
INSERT INTO usuaris VALUES (4940, 'Berenguer', 'Urrútia Palomino', 'H', '42 Avda. Alameda Sundheim', 22400, 'Berenguer.Urrutia.Palomino@trashymail.com', '14/07/62', 44, 5);
INSERT INTO usuaris VALUES (4941, 'Belisaria', 'Quiñónez Nevarez', 'D', '71 Ctra. Villena', 33980, 'Belisaria.Quinonez.Nevarez@trashymail.com', '22/04/72', 89, 7);
INSERT INTO usuaris VALUES (4942, 'Gustav', 'Figueroa Carranza', 'H', '19 C/ Cuevas de Ambrosio', 24000, 'Gustav.Figueroa.Carranza@pookmail.com', '06/12/73', 26, NULL);
INSERT INTO usuaris VALUES (4943, 'Areb', 'Rael Casillas', 'H', '68 Rúa Olmos', 37316, 'Areb.Rael.Casillas@mailinator.com', '27/10/58', 66, 9);
INSERT INTO usuaris VALUES (4944, 'Doménica', 'Holguín Arana', 'D', '37 Ctra. Hornos', 26210, 'Domenica.Holguin.Arana@pookmail.com', '18/10/44', 94, 11);
INSERT INTO usuaris VALUES (4945, 'Constancio', 'Narváez Serna', 'H', '18 C/ Canarias', 20100, 'Constancio.Narvaez.Serna@trashymail.com', '12/02/70', 14, 1);
INSERT INTO usuaris VALUES (4946, 'Anastasie', 'Ruiz Tello', 'D', '44 El Roqueo', 17220, 'Anastasie.Ruiz.Tello@mailinator.com', '04/12/59', 25, 12);
INSERT INTO usuaris VALUES (4947, 'Lucrecio', 'Nazario Benítez', 'H', '9 Ctra. Bailén-Motril', 23320, 'Lucrecio.Nazario.Benitez@trashymail.com', '29/11/41', 15, NULL);
INSERT INTO usuaris VALUES (4948, 'Fe', 'Pineda Barragán', NULL, '2 Av. Zumalakarregi', 3169, 'Fe.Pineda.Barragan@pookmail.com', '13/05/41', 93, 1);
INSERT INTO usuaris VALUES (4949, 'Aristóteles', 'Verduzco Bustamante', 'H', '11 Ctra. Hornos', 26221, 'Aristoteles.Verduzco.Bustamante@dodgit.com', '13/05/58', 35, 10);
INSERT INTO usuaris VALUES (4950, 'Luigi', 'Luna Rivera', 'H', '50 Camiño Ancho', 37762, 'Luigi.Luna.Rivera@pookmail.com', '10/02/80', 70, 12);
INSERT INTO usuaris VALUES (4951, 'Casia', 'Vázquez Partida', 'D', '66 Plaza de España', 15818, 'Casia.Vazquez.Partida@spambob.com', '09/12/50', 7, 12);
INSERT INTO usuaris VALUES (4952, 'Calfu', 'Cortés Baez', 'D', '98 Constitución', 36980, 'Calfu.Cortes.Baez@dodgit.com', '12/12/60', 24, 5);
INSERT INTO usuaris VALUES (4953, 'Maro', 'Ybarra Pedraza', 'H', '50 C/ Canarias', 20214, 'Maro.Ybarra.Pedraza@spambob.com', '08/12/75', 83, 4);
INSERT INTO usuaris VALUES (4954, 'Aldino', 'Gutiérrez Razo', 'H', '47 C/ Los Herrán', 6460, 'Aldino.Gutierrez.Razo@pookmail.com', '16/04/81', 85, 7);
INSERT INTO usuaris VALUES (4955, 'Cirinea', 'Molina Menéndez', 'D', '53 Alvaro Cunqueiro', 41250, 'Cirinea.Molina.Menendez@mailinator.com', '15/12/45', 39, 7);
INSERT INTO usuaris VALUES (4956, 'Paciente', 'Espinal Farías', 'H', '5 C/ Cañada del Rosal', 21600, 'Paciente.Espinal.Farias@trashymail.com', '17/05/78', 15, 1);
INSERT INTO usuaris VALUES (4957, 'Miqueas', 'Camacho Arreola', 'D', '52 Ctra. Villena', 33990, 'Miqueas.Camacho.Arreola@trashymail.com', '23/01/42', 35, 6);
INSERT INTO usuaris VALUES (4958, 'Agueda', 'Riojas Bahena', 'D', '10 Apartado de Correos', 37448, 'Agueda.Riojas.Bahena@mailinator.com', '04/03/71', 6, 1);
INSERT INTO usuaris VALUES (4959, 'Apolinar', 'Lomeli Gaona', 'H', '78 Socampo', 37619, 'Apolinar.Lomeli.Gaona@dodgit.com', '05/06/60', 25, 1);
INSERT INTO usuaris VALUES (4960, 'Ascensión', 'Baez Villa', 'D', '45 Visitación de la Encina', 37718, 'Ascension.Baez.Villa@dodgit.com', '18/10/76', 72, 3);
INSERT INTO usuaris VALUES (4961, 'Shantell', 'Fonseca Cortés', 'D', '74 Rio Segura', 31520, 'Shantell.Fonseca.Cortes@mailinator.com', '04/01/43', 70, 11);
INSERT INTO usuaris VALUES (4962, 'Cleandro', 'Benítez Galván', 'H', '5 Carretera del Muelle', 12350, 'Cleandro.Benitez.Galvan@dodgit.com', '25/03/76', 58, 5);
INSERT INTO usuaris VALUES (4963, 'Terencio', 'Gracia Cantú', 'H', '79 Avda. de la Estación', 28710, 'Terencio.Gracia.Cantu@mailinator.com', '18/01/74', 37, 11);
INSERT INTO usuaris VALUES (4964, 'Martial', 'Flórez Ruvalcaba', 'H', '46 Avda. Explanada Barnuevo', 35530, 'Martial.Florez.Ruvalcaba@trashymail.com', '17/03/52', 84, NULL);
INSERT INTO usuaris VALUES (4965, 'Rancul', 'Muro Godoy', 'H', '37 Plaza de España', 15578, 'Rancul.Muro.Godoy@dodgit.com', '14/10/53', 79, 2);
INSERT INTO usuaris VALUES (4966, 'Rogelia', 'Mayonga Sierra', 'D', '4 Bouciña', 43786, 'Rogelia.Mayonga.Sierra@pookmail.com', '19/07/64', 82, 2);
INSERT INTO usuaris VALUES (4967, 'Nais', 'Puga Valentín', NULL, '36 C/ Eras', 28742, 'Nais.Puga.Valentin@mailinator.com', '07/05/74', 96, 3);
INSERT INTO usuaris VALUES (4968, 'Eddie', 'Osorio Menchaca', 'H', '33 Enxertos', 37522, 'Eddie.Osorio.Menchaca@mailinator.com', '05/05/46', 30, 9);
INSERT INTO usuaris VALUES (4969, 'Rut', 'Rosario Ponce', 'D', '27 Constitución', 37129, 'Rut.Rosario.Ponce@spambob.com', '01/06/61', 41, 6);
INSERT INTO usuaris VALUES (4970, 'Iverna', 'Luna Guerra', 'D', '14 Reyes Católicos', 9500, 'Iverna.Luna.Guerra@dodgit.com', '05/09/49', 82, 10);
INSERT INTO usuaris VALUES (4971, 'Luisa', 'Esquibel Rodarte', 'D', '22 Canónigo Valiño', 46200, 'Luisa.Esquibel.Rodarte@mailinator.com', '09/03/62', 72, 8);
INSERT INTO usuaris VALUES (4972, 'Nimia', 'Alvarado Menéndez', 'D', '69 C/ Angosto', 23591, 'Nimia.Alvarado.Menendez@pookmail.com', '13/05/57', 68, 9);
INSERT INTO usuaris VALUES (4973, 'Dimas', 'Lozano Fierro', 'H', '27 Urzáiz', 44500, 'Dimas.Lozano.Fierro@spambob.com', '26/05/68', 78, 10);
INSERT INTO usuaris VALUES (4974, 'Yamel', 'Meléndez Mireles', 'D', '14 Urzáiz', 44610, 'Yamel.Melendez.Mireles@pookmail.com', '22/01/48', 9, NULL);
INSERT INTO usuaris VALUES (4975, 'Medardo', 'Herrera Villalobos', 'H', '13 Cercas Bajas', 8186, 'Medardo.Herrera.Villalobos@dodgit.com', '11/01/79', 6, 12);
INSERT INTO usuaris VALUES (4976, 'Florinda', 'Cadena Macías', 'D', '96 Enxertos', 37520, 'Florinda.Cadena.Macias@pookmail.com', '22/03/62', 45, 9);
INSERT INTO usuaris VALUES (4977, 'Mahdi', 'Soto Segovia', 'D', '68 Fuente del Gallo', 14913, 'Mahdi.Soto.Segovia@trashymail.com', '08/03/82', 76, 9);
INSERT INTO usuaris VALUES (4978, 'Modesto', 'Ulibarri Amaya', 'H', '90 Rúa de San Pedro', 37799, 'Modesto.Ulibarri.Amaya@spambob.com', '04/03/66', 41, 12);
INSERT INTO usuaris VALUES (4979, 'Dalma', 'Ruvalcaba Alejandro', 'D', '98 Canónigo Valiño', 46530, 'Dalma.Ruvalcaba.Alejandro@spambob.com', '07/06/59', 27, 5);
INSERT INTO usuaris VALUES (4980, 'Sócrates', 'Chavarría Pabón', 'H', '72 Rúa Olmos', 37339, 'Socrates.Chavarria.Pabon@mailinator.com', '21/04/52', 49, 5);
INSERT INTO usuaris VALUES (4981, 'Heráclito', 'Zayas Abeyta', 'H', '8 Prolongacion San Sebastian', 21293, 'Heraclito.Zayas.Abeyta@pookmail.com', '07/08/46', 0, 12);
INSERT INTO usuaris VALUES (4982, 'Alejandrino', 'Ortiz Portillo', 'H', '75 C/ Andalucía', 4610, 'Alejandrino.Ortiz.Portillo@trashymail.com', '30/06/47', 54, 5);
INSERT INTO usuaris VALUES (4983, 'Nino', 'Posada Domínquez', 'H', '72 Lamas Carbajal', 41567, 'Nino.Posada.Dominquez@pookmail.com', '14/02/68', 25, 5);
INSERT INTO usuaris VALUES (4984, 'Napoleón', 'Granados Solano', 'H', '35 C/ Señores Curas', 12127, 'Napoleon.Granados.Solano@dodgit.com', '27/02/61', 12, 3);
INSERT INTO usuaris VALUES (4985, 'Menqui', 'Cruz Gastelum', NULL, '28 Rúa do Paseo', 41805, 'Menqui.Cruz.Gastelum@pookmail.com', '05/11/82', 7, 4);
INSERT INTO usuaris VALUES (4986, 'Sintiques', 'Manzanares Villalobos', 'D', '3 Avda. Rio Nalon', 33180, 'Sintiques.Manzanares.Villalobos@spambob.com', '27/01/65', 81, 1);
INSERT INTO usuaris VALUES (4987, 'Porcia', 'Padilla Fernández', 'D', '91 Cartagena', 30540, 'Porcia.Padilla.Fernandez@spambob.com', '20/09/71', 63, 7);
INSERT INTO usuaris VALUES (4988, 'Shulinen', 'Cárdenas Flórez', 'D', '71 C/ Fernández de Leceta', 3459, 'Shulinen.Cardenas.Florez@mailinator.com', '28/02/63', 31, 12);
INSERT INTO usuaris VALUES (4989, 'Nabor', 'Arenas Camarillo', 'H', '86 C/ Los Herrán', 6300, 'Nabor.Arenas.Camarillo@mailinator.com', '12/10/69', 97, 9);
INSERT INTO usuaris VALUES (4990, 'Polixena', 'Marcos Irizarry', 'D', '81 C/ Amoladera', 28794, 'Polixena.Marcos.Irizarry@spambob.com', '01/12/51', 21, NULL);
INSERT INTO usuaris VALUES (4991, 'Naiquen', 'Ceja Corrales', 'D', '51 Quevedo', 15250, 'Naiquen.Ceja.Corrales@pookmail.com', '23/09/52', 55, 7);
INSERT INTO usuaris VALUES (4992, 'Ionatán', 'Colón Colunga', 'H', '70 Rosa de los Vientos', 13344, 'Ionatan.Colon.Colunga@dodgit.com', '25/01/82', 63, 5);
INSERT INTO usuaris VALUES (4993, 'Gaspar', 'Manzanares Valle', 'H', '37 Visitación de la Encina', 37716, 'Gaspar.Manzanares.Valle@mailinator.com', '14/03/45', 44, 8);
INSERT INTO usuaris VALUES (4994, 'Aristides', 'Pelayo Menéndez', 'H', '21 José matía', 2154, 'Aristides.Pelayo.Menendez@pookmail.com', '20/07/51', 6, 4);
INSERT INTO usuaris VALUES (4995, 'Noé', 'Ruelas Tejeda', 'H', '99 C/ Hijuela de Lojo', 20300, 'Noe.Ruelas.Tejeda@pookmail.com', '01/04/59', 62, 12);
INSERT INTO usuaris VALUES (4996, 'Sixta', 'Ybarra Jáquez', 'D', '42 C/ Domingo Beltrán', 2240, 'Sixta.Ybarra.Jaquez@mailinator.com', '22/09/78', 51, NULL);
INSERT INTO usuaris VALUES (4997, 'Rancul', 'Banda Botello', 'H', '58 La Fontanilla', 14450, 'Rancul.Banda.Botello@spambob.com', '14/06/67', 10, 8);
INSERT INTO usuaris VALUES (4998, 'Janoc', 'Lucero Lemus', 'H', '39 Avendaño', 3850, 'Janoc.Lucero.Lemus@dodgit.com', '15/06/55', 33, 2);
INSERT INTO usuaris VALUES (4999, 'Astra', 'Solano Portillo', 'D', '99 Ourense', 43300, 'Astra.Solano.Portillo@mailinator.com', '23/09/43', 34, 1);
INSERT INTO usuaris VALUES (5000, 'Pimpinela', 'Núñez Cabrera', 'D', '99 C/ Cañada del Rosal', 21410, 'Pimpinela.Nunez.Cabrera@trashymail.com', '30/11/52', 5, NULL);



INSERT INTO valoracions VALUES (1, 8, '08/06/2001', 8);
INSERT INTO valoracions VALUES (1, 23, '08/04/2005', 7);
INSERT INTO valoracions VALUES (1, 33, '07/05/2008', 4);
INSERT INTO valoracions VALUES (2, 54, '29/05/2004', 4);
INSERT INTO valoracions VALUES (2, 37, '19/12/2008', 3);
INSERT INTO valoracions VALUES (2, 26, '19/03/2004', 8);
INSERT INTO valoracions VALUES (3, 73, '02/12/2001', 8);
INSERT INTO valoracions VALUES (3, 99, '02/10/2003', 4);
INSERT INTO valoracions VALUES (3, 105, '20/05/2008', 5);
INSERT INTO valoracions VALUES (3, 39, '09/01/2006', 9);
INSERT INTO valoracions VALUES (4, 52, '03/05/2002', 4);
INSERT INTO valoracions VALUES (4, 66, '10/04/2005', 4);
INSERT INTO valoracions VALUES (4, 13, '10/12/2002', 5);
INSERT INTO valoracions VALUES (4, 95, '07/10/2009', 7);
INSERT INTO valoracions VALUES (5, 73, '12/06/2001', 6);
INSERT INTO valoracions VALUES (5, 27, '07/03/2005', 8);
INSERT INTO valoracions VALUES (6, 45, '26/09/2010', 7);
INSERT INTO valoracions VALUES (6, 26, '13/09/2006', 6);
INSERT INTO valoracions VALUES (6, 1, '21/08/2006', 9);
INSERT INTO valoracions VALUES (6, 42, '07/04/2010', 8);
INSERT INTO valoracions VALUES (6, 50, '08/08/2003', 3);
INSERT INTO valoracions VALUES (7, 36, '16/06/2010', 9);
INSERT INTO valoracions VALUES (7, 78, '28/08/2008', 4);
INSERT INTO valoracions VALUES (7, 80, '18/04/2001', 6);
INSERT INTO valoracions VALUES (7, 24, '08/03/2010', 4);
INSERT INTO valoracions VALUES (7, 10, '12/03/2002', 5);
INSERT INTO valoracions VALUES (8, 116, '18/10/2006', 2);
INSERT INTO valoracions VALUES (9, 64, '04/11/2005', 10);
INSERT INTO valoracions VALUES (9, 116, '15/05/2002', 1);
INSERT INTO valoracions VALUES (9, 40, '14/08/2007', 4);
INSERT INTO valoracions VALUES (9, 5, '13/05/2002', 8);
INSERT INTO valoracions VALUES (10, 36, '26/07/2009', 8);
INSERT INTO valoracions VALUES (10, 34, '15/08/2002', 6);
INSERT INTO valoracions VALUES (10, 46, '23/05/2006', 4);
INSERT INTO valoracions VALUES (10, 99, '26/10/2007', 4);
INSERT INTO valoracions VALUES (10, 99, '17/03/2007', 6);
INSERT INTO valoracions VALUES (10, 73, '11/12/2003', 4);
INSERT INTO valoracions VALUES (10, 54, '29/07/2010', 6);
INSERT INTO valoracions VALUES (11, 104, '25/11/2002', 4);
INSERT INTO valoracions VALUES (11, 70, '01/08/2008', 8);
INSERT INTO valoracions VALUES (12, 106, '26/03/2009', 9);
INSERT INTO valoracions VALUES (12, 47, '03/09/2005', 9);
INSERT INTO valoracions VALUES (12, 104, '06/11/2007', 4);
INSERT INTO valoracions VALUES (12, 103, '08/01/2007', 9);
INSERT INTO valoracions VALUES (12, 44, '14/07/2006', 8);
INSERT INTO valoracions VALUES (13, 18, '22/07/2002', 7);
INSERT INTO valoracions VALUES (13, 31, '12/03/2008', 6);
INSERT INTO valoracions VALUES (14, 9, '03/04/2005', 10);
INSERT INTO valoracions VALUES (14, 41, '11/08/2002', 9);
INSERT INTO valoracions VALUES (15, 115, '15/04/2008', 0);
INSERT INTO valoracions VALUES (15, 64, '15/03/2008', 2);
INSERT INTO valoracions VALUES (15, 59, '03/01/2008', 6);
INSERT INTO valoracions VALUES (15, 59, '26/04/2002', 4);
INSERT INTO valoracions VALUES (16, 7, '09/06/2004', 6);
INSERT INTO valoracions VALUES (16, 87, '21/12/2005', 7);
INSERT INTO valoracions VALUES (16, 113, '21/03/2005', 9);
INSERT INTO valoracions VALUES (16, 94, '01/08/2007', 2);
INSERT INTO valoracions VALUES (16, 102, '12/02/2005', 1);
INSERT INTO valoracions VALUES (16, 4, '19/08/2003', 9);
INSERT INTO valoracions VALUES (17, 11, '02/12/2007', 6);
INSERT INTO valoracions VALUES (17, 78, '04/11/2002', 4);
INSERT INTO valoracions VALUES (17, 57, '04/03/2008', 8);
INSERT INTO valoracions VALUES (17, 8, '24/04/2010', 10);
INSERT INTO valoracions VALUES (18, 20, '22/09/2003', 8);
INSERT INTO valoracions VALUES (18, 25, '09/06/2004', 6);
INSERT INTO valoracions VALUES (19, 111, '01/10/2001', 7);
INSERT INTO valoracions VALUES (20, 92, '28/12/2009', 5);
INSERT INTO valoracions VALUES (21, 54, '27/02/2008', 7);
INSERT INTO valoracions VALUES (21, 75, '06/03/2007', 7);
INSERT INTO valoracions VALUES (22, 83, '26/07/2004', 7);
INSERT INTO valoracions VALUES (22, 61, '26/08/2002', 9);
INSERT INTO valoracions VALUES (22, 71, '19/12/2001', 10);
INSERT INTO valoracions VALUES (22, 62, '27/03/2008', 9);
INSERT INTO valoracions VALUES (23, 57, '21/09/2001', 6);
INSERT INTO valoracions VALUES (23, 29, '26/12/2006', 6);
INSERT INTO valoracions VALUES (23, 115, '22/10/2010', 5);
INSERT INTO valoracions VALUES (23, 88, '10/05/2010', 1);
INSERT INTO valoracions VALUES (23, 107, '02/06/2001', 6);
INSERT INTO valoracions VALUES (23, 29, '28/08/2004', 6);
INSERT INTO valoracions VALUES (23, 53, '27/09/2006', 7);
INSERT INTO valoracions VALUES (24, 78, '20/03/2002', 9);
INSERT INTO valoracions VALUES (24, 28, '23/02/2003', 4);
INSERT INTO valoracions VALUES (24, 16, '01/10/2001', 6);
INSERT INTO valoracions VALUES (24, 42, '24/07/2009', 9);
INSERT INTO valoracions VALUES (25, 27, '03/01/2009', 10);
INSERT INTO valoracions VALUES (25, 42, '28/04/2005', 6);
INSERT INTO valoracions VALUES (25, 10, '11/05/2008', 8);
INSERT INTO valoracions VALUES (25, 22, '24/04/2005', 8);
INSERT INTO valoracions VALUES (25, 14, '02/05/2009', 6);
INSERT INTO valoracions VALUES (25, 94, '05/09/2002', 1);
INSERT INTO valoracions VALUES (26, 21, '27/05/2008', 4);
INSERT INTO valoracions VALUES (26, 78, '22/02/2008', 5);
INSERT INTO valoracions VALUES (26, 87, '12/03/2007', 2);
INSERT INTO valoracions VALUES (27, 101, '29/08/2008', 2);
INSERT INTO valoracions VALUES (27, 90, '10/04/2009', 7);
INSERT INTO valoracions VALUES (27, 38, '01/11/2003', 6);
INSERT INTO valoracions VALUES (27, 9, '01/04/2005', 5);
INSERT INTO valoracions VALUES (27, 55, '23/11/2007', 4);
INSERT INTO valoracions VALUES (28, 11, '18/10/2006', 7);
INSERT INTO valoracions VALUES (29, 4, '14/01/2010', 6);
INSERT INTO valoracions VALUES (29, 10, '25/02/2007', 6);
INSERT INTO valoracions VALUES (29, 7, '20/05/2009', 9);
INSERT INTO valoracions VALUES (29, 45, '03/06/2008', 8);
INSERT INTO valoracions VALUES (30, 68, '10/06/2003', 8);
INSERT INTO valoracions VALUES (30, 4, '05/09/2003', 5);
INSERT INTO valoracions VALUES (30, 88, '08/05/2007', 8);
INSERT INTO valoracions VALUES (31, 75, '16/12/2006', 7);
INSERT INTO valoracions VALUES (31, 15, '11/09/2008', 10);
INSERT INTO valoracions VALUES (31, 107, '08/11/2004', 1);
INSERT INTO valoracions VALUES (31, 40, '01/02/2003', 5);
INSERT INTO valoracions VALUES (32, 54, '10/07/2002', 5);
INSERT INTO valoracions VALUES (32, 48, '03/12/2007', 9);
INSERT INTO valoracions VALUES (32, 86, '14/10/2002', 2);
INSERT INTO valoracions VALUES (32, 29, '14/01/2010', 9);
INSERT INTO valoracions VALUES (33, 61, '28/03/2006', 5);
INSERT INTO valoracions VALUES (33, 21, '26/06/2008', 5);
INSERT INTO valoracions VALUES (33, 55, '22/11/2009', 3);
INSERT INTO valoracions VALUES (33, 99, '22/05/2006', 4);
INSERT INTO valoracions VALUES (33, 18, '30/12/2006', 9);
INSERT INTO valoracions VALUES (34, 106, '15/10/2002', 6);
INSERT INTO valoracions VALUES (34, 72, '22/12/2004', 4);
INSERT INTO valoracions VALUES (34, 79, '24/02/2007', 6);
INSERT INTO valoracions VALUES (35, 56, '05/01/2002', 6);
INSERT INTO valoracions VALUES (35, 1, '27/03/2008', 7);
INSERT INTO valoracions VALUES (35, 46, '07/07/2007', 3);
INSERT INTO valoracions VALUES (35, 17, '04/09/2001', 7);
INSERT INTO valoracions VALUES (36, 10, '17/12/2002', 5);
INSERT INTO valoracions VALUES (36, 102, '07/11/2002', 7);
INSERT INTO valoracions VALUES (36, 85, '26/05/2005', 8);
INSERT INTO valoracions VALUES (36, 49, '07/03/2010', 8);
INSERT INTO valoracions VALUES (37, 97, '11/02/2006', 7);
INSERT INTO valoracions VALUES (37, 44, '23/01/2008', 7);
INSERT INTO valoracions VALUES (37, 32, '08/09/2005', 8);
INSERT INTO valoracions VALUES (38, 31, '13/01/2009', 8);
INSERT INTO valoracions VALUES (38, 78, '14/01/2007', 7);
INSERT INTO valoracions VALUES (38, 88, '22/05/2008', 8);
INSERT INTO valoracions VALUES (39, 85, '28/02/2010', 8);
INSERT INTO valoracions VALUES (39, 102, '31/03/2006', 10);
INSERT INTO valoracions VALUES (39, 114, '31/10/2009', 5);
INSERT INTO valoracions VALUES (40, 72, '16/05/2005', 3);
INSERT INTO valoracions VALUES (40, 48, '15/11/2005', 6);
INSERT INTO valoracions VALUES (40, 71, '06/08/2005', 8);
INSERT INTO valoracions VALUES (40, 83, '08/11/2005', 7);
INSERT INTO valoracions VALUES (41, 19, '08/04/2004', 4);
INSERT INTO valoracions VALUES (41, 87, '18/05/2005', 10);
INSERT INTO valoracions VALUES (42, 24, '03/03/2007', 9);
INSERT INTO valoracions VALUES (42, 80, '10/09/2004', 10);
INSERT INTO valoracions VALUES (42, 81, '04/05/2004', 4);
INSERT INTO valoracions VALUES (42, 8, '29/04/2001', 7);
INSERT INTO valoracions VALUES (42, 105, '03/08/2003', 2);
INSERT INTO valoracions VALUES (42, 4, '21/01/2005', 7);
INSERT INTO valoracions VALUES (43, 89, '15/03/2007', 1);
INSERT INTO valoracions VALUES (43, 14, '01/01/2008', 8);
INSERT INTO valoracions VALUES (43, 92, '16/07/2009', 1);
INSERT INTO valoracions VALUES (44, 57, '25/06/2007', 3);
INSERT INTO valoracions VALUES (44, 71, '03/08/2007', 7);
INSERT INTO valoracions VALUES (44, 100, '31/07/2002', 6);
INSERT INTO valoracions VALUES (45, 16, '04/06/2003', 9);
INSERT INTO valoracions VALUES (45, 105, '21/12/2003', 8);
INSERT INTO valoracions VALUES (45, 114, '12/04/2006', 8);
INSERT INTO valoracions VALUES (45, 18, '13/02/2007', 4);
INSERT INTO valoracions VALUES (45, 72, '19/04/2009', 7);
INSERT INTO valoracions VALUES (45, 115, '04/05/2008', 1);
INSERT INTO valoracions VALUES (46, 115, '18/03/2006', 8);
INSERT INTO valoracions VALUES (46, 99, '02/03/2010', 7);
INSERT INTO valoracions VALUES (46, 1, '29/08/2002', 8);
INSERT INTO valoracions VALUES (47, 77, '27/02/2008', 4);
INSERT INTO valoracions VALUES (47, 101, '21/12/2001', 3);
INSERT INTO valoracions VALUES (47, 91, '01/07/2002', 2);
INSERT INTO valoracions VALUES (47, 94, '12/08/2003', 6);
INSERT INTO valoracions VALUES (48, 88, '01/05/2009', 6);
INSERT INTO valoracions VALUES (49, 32, '25/10/2010', 4);
INSERT INTO valoracions VALUES (49, 116, '14/12/2005', 10);
INSERT INTO valoracions VALUES (49, 11, '08/11/2006', 9);
INSERT INTO valoracions VALUES (50, 84, '05/02/2005', 10);
INSERT INTO valoracions VALUES (51, 13, '24/11/2003', 10);
INSERT INTO valoracions VALUES (51, 62, '01/08/2010', 9);
INSERT INTO valoracions VALUES (51, 44, '13/02/2003', 4);
INSERT INTO valoracions VALUES (51, 105, '13/09/2006', 8);
INSERT INTO valoracions VALUES (51, 25, '12/09/2001', 7);
INSERT INTO valoracions VALUES (52, 30, '06/10/2010', 7);
INSERT INTO valoracions VALUES (52, 7, '16/03/2010', 6);
INSERT INTO valoracions VALUES (52, 35, '14/08/2004', 9);
INSERT INTO valoracions VALUES (53, 5, '19/07/2001', 9);
INSERT INTO valoracions VALUES (53, 3, '21/04/2002', 7);
INSERT INTO valoracions VALUES (53, 75, '07/04/2008', 9);
INSERT INTO valoracions VALUES (53, 29, '17/02/2010', 9);
INSERT INTO valoracions VALUES (54, 65, '16/03/2009', 4);
INSERT INTO valoracions VALUES (55, 115, '05/05/2004', 7);
INSERT INTO valoracions VALUES (55, 36, '23/12/2005', 4);
INSERT INTO valoracions VALUES (55, 34, '24/05/2002', 7);
INSERT INTO valoracions VALUES (55, 82, '03/01/2006', 5);
INSERT INTO valoracions VALUES (56, 14, '06/01/2007', 9);
INSERT INTO valoracions VALUES (56, 76, '28/06/2006', 7);
INSERT INTO valoracions VALUES (56, 113, '07/04/2002', 2);
INSERT INTO valoracions VALUES (58, 86, '09/05/2003', 2);
INSERT INTO valoracions VALUES (58, 48, '03/05/2003', 7);
INSERT INTO valoracions VALUES (58, 33, '25/02/2008', 6);
INSERT INTO valoracions VALUES (58, 99, '16/06/2002', 4);
INSERT INTO valoracions VALUES (59, 57, '24/09/2003', 4);
INSERT INTO valoracions VALUES (59, 22, '13/04/2001', 7);
INSERT INTO valoracions VALUES (59, 55, '26/10/2008', 6);
INSERT INTO valoracions VALUES (59, 16, '26/08/2009', 8);
INSERT INTO valoracions VALUES (59, 116, '23/03/2003', 9);
INSERT INTO valoracions VALUES (59, 115, '11/03/2007', 1);
INSERT INTO valoracions VALUES (60, 76, '11/06/2001', 7);
INSERT INTO valoracions VALUES (60, 53, '19/08/2001', 6);
INSERT INTO valoracions VALUES (60, 98, '02/08/2002', 1);
INSERT INTO valoracions VALUES (60, 59, '03/12/2003', 6);
INSERT INTO valoracions VALUES (61, 18, '16/08/2006', 9);
INSERT INTO valoracions VALUES (61, 21, '23/05/2004', 6);
INSERT INTO valoracions VALUES (61, 110, '20/02/2005', 5);
INSERT INTO valoracions VALUES (61, 116, '19/04/2003', 3);
INSERT INTO valoracions VALUES (61, 36, '09/08/2002', 8);
INSERT INTO valoracions VALUES (61, 68, '29/06/2009', 3);
INSERT INTO valoracions VALUES (62, 87, '04/05/2001', 7);
INSERT INTO valoracions VALUES (62, 104, '29/09/2008', 5);
INSERT INTO valoracions VALUES (62, 93, '04/02/2005', 6);
INSERT INTO valoracions VALUES (62, 49, '08/06/2002', 3);
INSERT INTO valoracions VALUES (62, 71, '08/12/2007', 6);
INSERT INTO valoracions VALUES (62, 2, '24/08/2008', 8);
INSERT INTO valoracions VALUES (63, 22, '07/02/2006', 5);
INSERT INTO valoracions VALUES (63, 63, '28/12/2006', 4);
INSERT INTO valoracions VALUES (63, 106, '09/09/2008', 5);
INSERT INTO valoracions VALUES (63, 37, '17/07/2007', 9);
INSERT INTO valoracions VALUES (63, 21, '18/05/2007', 9);
INSERT INTO valoracions VALUES (63, 19, '22/07/2008', 7);
INSERT INTO valoracions VALUES (63, 24, '09/11/2007', 9);
INSERT INTO valoracions VALUES (64, 10, '05/02/2007', 7);
INSERT INTO valoracions VALUES (64, 46, '02/01/2002', 6);
INSERT INTO valoracions VALUES (64, 60, '26/11/2008', 8);
INSERT INTO valoracions VALUES (64, 88, '21/05/2007', 9);
INSERT INTO valoracions VALUES (64, 30, '09/02/2010', 9);
INSERT INTO valoracions VALUES (65, 13, '23/11/2008', 8);
INSERT INTO valoracions VALUES (65, 38, '26/08/2010', 7);
INSERT INTO valoracions VALUES (65, 48, '09/12/2006', 10);
INSERT INTO valoracions VALUES (65, 96, '07/08/2003', 3);
INSERT INTO valoracions VALUES (65, 109, '12/08/2009', 5);
INSERT INTO valoracions VALUES (65, 78, '10/07/2009', 3);
INSERT INTO valoracions VALUES (65, 22, '05/11/2005', 10);
INSERT INTO valoracions VALUES (65, 41, '05/04/2004', 4);
INSERT INTO valoracions VALUES (65, 66, '12/02/2004', 3);
INSERT INTO valoracions VALUES (65, 95, '03/08/2008', 3);
INSERT INTO valoracions VALUES (66, 14, '24/04/2008', 9);
INSERT INTO valoracions VALUES (66, 12, '08/05/2004', 9);
INSERT INTO valoracions VALUES (66, 77, '26/04/2010', 2);
INSERT INTO valoracions VALUES (66, 9, '17/07/2004', 5);
INSERT INTO valoracions VALUES (66, 106, '06/11/2006', 9);
INSERT INTO valoracions VALUES (66, 30, '29/04/2007', 9);
INSERT INTO valoracions VALUES (67, 94, '05/10/2006', 2);
INSERT INTO valoracions VALUES (67, 70, '30/06/2010', 8);
INSERT INTO valoracions VALUES (67, 4, '16/12/2001', 6);
INSERT INTO valoracions VALUES (67, 66, '25/11/2005', 10);
INSERT INTO valoracions VALUES (68, 46, '21/01/2005', 6);
INSERT INTO valoracions VALUES (68, 95, '14/01/2010', 7);
INSERT INTO valoracions VALUES (68, 34, '11/03/2005', 9);
INSERT INTO valoracions VALUES (68, 29, '20/12/2008', 8);
INSERT INTO valoracions VALUES (69, 108, '18/10/2004', 6);
INSERT INTO valoracions VALUES (69, 9, '15/01/2007', 5);
INSERT INTO valoracions VALUES (69, 33, '19/10/2007', 4);
INSERT INTO valoracions VALUES (70, 1, '02/04/2004', 8);
INSERT INTO valoracions VALUES (70, 96, '05/09/2005', 2);
INSERT INTO valoracions VALUES (70, 84, '04/02/2007', 8);
INSERT INTO valoracions VALUES (70, 50, '17/09/2002', 8);
INSERT INTO valoracions VALUES (71, 99, '22/06/2010', 5);
INSERT INTO valoracions VALUES (72, 70, '20/08/2008', 5);
INSERT INTO valoracions VALUES (72, 50, '14/02/2007', 3);
INSERT INTO valoracions VALUES (72, 100, '12/12/2002', 6);
INSERT INTO valoracions VALUES (72, 110, '18/04/2003', 1);
INSERT INTO valoracions VALUES (72, 35, '07/11/2009', 4);
INSERT INTO valoracions VALUES (72, 34, '25/05/2004', 6);
INSERT INTO valoracions VALUES (72, 94, '17/12/2009', 6);
INSERT INTO valoracions VALUES (72, 68, '09/08/2009', 3);
INSERT INTO valoracions VALUES (73, 115, '22/08/2007', 8);
INSERT INTO valoracions VALUES (73, 5, '29/12/2009', 7);
INSERT INTO valoracions VALUES (73, 116, '21/01/2003', 5);
INSERT INTO valoracions VALUES (73, 25, '01/01/2007', 10);
INSERT INTO valoracions VALUES (74, 20, '14/04/2006', 6);
INSERT INTO valoracions VALUES (74, 107, '02/10/2006', 0);
INSERT INTO valoracions VALUES (74, 10, '06/09/2007', 8);
INSERT INTO valoracions VALUES (74, 65, '28/05/2002', 8);
INSERT INTO valoracions VALUES (75, 12, '20/03/2005', 6);
INSERT INTO valoracions VALUES (75, 49, '31/07/2007', 9);
INSERT INTO valoracions VALUES (75, 36, '01/10/2010', 7);
INSERT INTO valoracions VALUES (75, 5, '19/08/2002', 5);
INSERT INTO valoracions VALUES (76, 43, '04/06/2006', 7);
INSERT INTO valoracions VALUES (76, 114, '03/04/2007', 1);
INSERT INTO valoracions VALUES (76, 49, '24/08/2005', 4);
INSERT INTO valoracions VALUES (77, 111, '26/10/2006', 7);
INSERT INTO valoracions VALUES (77, 41, '09/09/2004', 7);
INSERT INTO valoracions VALUES (77, 78, '17/05/2007', 8);
INSERT INTO valoracions VALUES (77, 100, '26/02/2004', 7);
INSERT INTO valoracions VALUES (78, 77, '29/01/2003', 9);
INSERT INTO valoracions VALUES (78, 57, '16/07/2010', 5);
INSERT INTO valoracions VALUES (79, 20, '28/06/2002', 5);
INSERT INTO valoracions VALUES (80, 101, '07/10/2004', 10);
INSERT INTO valoracions VALUES (80, 49, '09/02/2002', 3);
INSERT INTO valoracions VALUES (80, 29, '03/08/2002', 10);
INSERT INTO valoracions VALUES (80, 91, '28/12/2001', 9);
INSERT INTO valoracions VALUES (81, 53, '24/03/2002', 7);
INSERT INTO valoracions VALUES (81, 55, '10/11/2009', 7);
INSERT INTO valoracions VALUES (82, 64, '13/08/2008', 6);
INSERT INTO valoracions VALUES (82, 12, '01/05/2003', 5);
INSERT INTO valoracions VALUES (82, 67, '15/08/2005', 8);
INSERT INTO valoracions VALUES (82, 100, '25/02/2009', 3);
INSERT INTO valoracions VALUES (83, 73, '21/06/2003', 9);
INSERT INTO valoracions VALUES (83, 2, '24/03/2006', 8);
INSERT INTO valoracions VALUES (83, 35, '11/08/2010', 7);
INSERT INTO valoracions VALUES (83, 18, '24/09/2006', 5);
INSERT INTO valoracions VALUES (84, 16, '26/07/2008', 9);
INSERT INTO valoracions VALUES (84, 114, '09/01/2005', 9);
INSERT INTO valoracions VALUES (84, 114, '16/09/2004', 3);
INSERT INTO valoracions VALUES (84, 67, '28/04/2007', 6);
INSERT INTO valoracions VALUES (84, 2, '20/09/2006', 8);
INSERT INTO valoracions VALUES (85, 93, '17/03/2007', 8);
INSERT INTO valoracions VALUES (85, 35, '15/09/2010', 5);
INSERT INTO valoracions VALUES (85, 93, '16/06/2010', 1);
INSERT INTO valoracions VALUES (85, 7, '15/11/2002', 9);
INSERT INTO valoracions VALUES (85, 36, '29/05/2008', 9);
INSERT INTO valoracions VALUES (86, 89, '01/06/2008', 5);
INSERT INTO valoracions VALUES (86, 95, '04/07/2007', 5);
INSERT INTO valoracions VALUES (86, 23, '07/12/2005', 9);
INSERT INTO valoracions VALUES (86, 33, '25/10/2007', 7);
INSERT INTO valoracions VALUES (86, 40, '07/09/2003', 9);
INSERT INTO valoracions VALUES (86, 61, '23/02/2009', 5);
INSERT INTO valoracions VALUES (87, 95, '26/01/2007', 5);
INSERT INTO valoracions VALUES (87, 5, '14/02/2008', 5);
INSERT INTO valoracions VALUES (87, 73, '26/08/2008', 5);
INSERT INTO valoracions VALUES (88, 99, '23/11/2007', 6);
INSERT INTO valoracions VALUES (88, 47, '24/04/2003', 7);
INSERT INTO valoracions VALUES (89, 26, '07/01/2002', 5);
INSERT INTO valoracions VALUES (89, 18, '09/01/2005', 8);
INSERT INTO valoracions VALUES (90, 90, '21/05/2007', 9);
INSERT INTO valoracions VALUES (90, 39, '04/01/2003', 5);
INSERT INTO valoracions VALUES (90, 31, '17/01/2010', 9);
INSERT INTO valoracions VALUES (91, 28, '22/07/2002', 9);
INSERT INTO valoracions VALUES (91, 86, '10/04/2007', 9);
INSERT INTO valoracions VALUES (92, 110, '27/10/2007', 1);
INSERT INTO valoracions VALUES (93, 78, '16/11/2003', 9);
INSERT INTO valoracions VALUES (93, 71, '19/08/2002', 10);
INSERT INTO valoracions VALUES (93, 45, '03/05/2003', 9);
INSERT INTO valoracions VALUES (93, 116, '11/02/2004', 5);
INSERT INTO valoracions VALUES (93, 109, '14/01/2009', 7);
INSERT INTO valoracions VALUES (93, 53, '27/04/2009', 6);
INSERT INTO valoracions VALUES (94, 35, '09/10/2006', 4);
INSERT INTO valoracions VALUES (94, 41, '11/07/2005', 7);
INSERT INTO valoracions VALUES (94, 8, '11/01/2004', 5);
INSERT INTO valoracions VALUES (94, 110, '05/10/2001', 3);
INSERT INTO valoracions VALUES (94, 61, '02/03/2004', 8);
INSERT INTO valoracions VALUES (95, 20, '19/03/2009', 6);
INSERT INTO valoracions VALUES (95, 73, '12/03/2004', 7);
INSERT INTO valoracions VALUES (96, 106, '31/05/2003', 2);
INSERT INTO valoracions VALUES (96, 5, '19/12/2002', 10);
INSERT INTO valoracions VALUES (96, 27, '06/02/2006', 9);
INSERT INTO valoracions VALUES (97, 115, '23/11/2003', 3);
INSERT INTO valoracions VALUES (97, 53, '19/01/2003', 5);
INSERT INTO valoracions VALUES (97, 46, '05/07/2002', 10);
INSERT INTO valoracions VALUES (97, 41, '29/08/2009', 9);
INSERT INTO valoracions VALUES (98, 9, '04/09/2004', 5);
INSERT INTO valoracions VALUES (98, 115, '05/01/2007', 6);
INSERT INTO valoracions VALUES (98, 50, '09/06/2001', 9);
INSERT INTO valoracions VALUES (98, 108, '02/07/2007', 10);
INSERT INTO valoracions VALUES (98, 114, '26/06/2005', 2);
INSERT INTO valoracions VALUES (98, 83, '21/07/2003', 7);
INSERT INTO valoracions VALUES (99, 52, '05/11/2002', 9);
INSERT INTO valoracions VALUES (99, 1, '23/06/2009', 6);
INSERT INTO valoracions VALUES (99, 10, '16/03/2003', 9);
INSERT INTO valoracions VALUES (99, 38, '12/10/2007', 8);
INSERT INTO valoracions VALUES (100, 38, '22/08/2008', 6);
INSERT INTO valoracions VALUES (100, 47, '13/10/2003', 4);
INSERT INTO valoracions VALUES (100, 53, '12/12/2004', 9);
INSERT INTO valoracions VALUES (100, 73, '12/02/2007', 4);
INSERT INTO valoracions VALUES (101, 18, '04/04/2002', 8);
INSERT INTO valoracions VALUES (101, 68, '16/09/2006', 4);
INSERT INTO valoracions VALUES (101, 74, '16/06/2005', 8);
INSERT INTO valoracions VALUES (102, 32, '05/12/2001', 4);
INSERT INTO valoracions VALUES (103, 34, '04/08/2006', 7);
INSERT INTO valoracions VALUES (104, 59, '07/09/2006', 10);
INSERT INTO valoracions VALUES (104, 114, '20/05/2003', 6);
INSERT INTO valoracions VALUES (104, 75, '26/07/2003', 10);
INSERT INTO valoracions VALUES (105, 114, '05/02/2010', 6);
INSERT INTO valoracions VALUES (105, 78, '16/05/2009', 3);
INSERT INTO valoracions VALUES (105, 68, '31/01/2010', 8);
INSERT INTO valoracions VALUES (105, 82, '29/05/2010', 5);
INSERT INTO valoracions VALUES (105, 23, '14/12/2005', 8);
INSERT INTO valoracions VALUES (105, 75, '16/12/2005', 4);
INSERT INTO valoracions VALUES (106, 27, '22/02/2005', 5);
INSERT INTO valoracions VALUES (106, 107, '13/01/2005', 2);
INSERT INTO valoracions VALUES (106, 26, '22/07/2006', 8);
INSERT INTO valoracions VALUES (106, 35, '28/11/2005', 7);
INSERT INTO valoracions VALUES (106, 110, '22/08/2009', 7);
INSERT INTO valoracions VALUES (106, 7, '11/07/2009', 6);
INSERT INTO valoracions VALUES (107, 87, '31/12/2001', 5);
INSERT INTO valoracions VALUES (107, 57, '09/10/2008', 9);
INSERT INTO valoracions VALUES (107, 46, '10/09/2005', 9);
INSERT INTO valoracions VALUES (107, 108, '15/11/2006', 4);
INSERT INTO valoracions VALUES (107, 16, '17/07/2006', 6);
INSERT INTO valoracions VALUES (107, 16, '14/05/2008', 10);
INSERT INTO valoracions VALUES (107, 99, '27/02/2003', 7);
INSERT INTO valoracions VALUES (108, 42, '17/01/2002', 10);
INSERT INTO valoracions VALUES (108, 116, '26/07/2009', 3);
INSERT INTO valoracions VALUES (108, 62, '10/09/2001', 2);
INSERT INTO valoracions VALUES (108, 71, '18/11/2003', 9);
INSERT INTO valoracions VALUES (108, 87, '21/02/2010', 6);
INSERT INTO valoracions VALUES (109, 38, '20/10/2009', 7);
INSERT INTO valoracions VALUES (109, 28, '02/06/2003', 7);
INSERT INTO valoracions VALUES (109, 113, '18/11/2005', 1);
INSERT INTO valoracions VALUES (109, 110, '12/02/2006', 0);
INSERT INTO valoracions VALUES (109, 26, '13/04/2006', 9);
INSERT INTO valoracions VALUES (110, 12, '12/05/2008', 5);
INSERT INTO valoracions VALUES (110, 13, '26/07/2002', 5);
INSERT INTO valoracions VALUES (110, 22, '10/06/2008', 8);
INSERT INTO valoracions VALUES (110, 66, '14/01/2010', 5);
INSERT INTO valoracions VALUES (111, 7, '25/01/2002', 9);
INSERT INTO valoracions VALUES (112, 111, '07/09/2006', 9);
INSERT INTO valoracions VALUES (112, 31, '13/12/2005', 6);
INSERT INTO valoracions VALUES (113, 88, '12/12/2005', 1);
INSERT INTO valoracions VALUES (113, 116, '25/06/2009', 5);
INSERT INTO valoracions VALUES (113, 63, '15/06/2002', 9);
INSERT INTO valoracions VALUES (113, 54, '25/01/2009', 3);
INSERT INTO valoracions VALUES (113, 26, '19/09/2006', 7);
INSERT INTO valoracions VALUES (114, 42, '17/09/2004', 9);
INSERT INTO valoracions VALUES (114, 17, '18/04/2006', 8);
INSERT INTO valoracions VALUES (115, 57, '07/05/2008', 3);
INSERT INTO valoracions VALUES (115, 113, '26/02/2004', 2);
INSERT INTO valoracions VALUES (116, 7, '14/09/2001', 6);
INSERT INTO valoracions VALUES (116, 3, '20/12/2009', 8);
INSERT INTO valoracions VALUES (116, 76, '11/06/2010', 7);
INSERT INTO valoracions VALUES (116, 14, '20/05/2001', 9);
INSERT INTO valoracions VALUES (117, 95, '02/02/2007', 3);
INSERT INTO valoracions VALUES (117, 25, '09/08/2001', 8);
INSERT INTO valoracions VALUES (118, 47, '15/03/2006', 4);
INSERT INTO valoracions VALUES (118, 81, '28/12/2008', 3);
INSERT INTO valoracions VALUES (118, 76, '26/05/2005', 5);
INSERT INTO valoracions VALUES (118, 4, '24/04/2001', 8);
INSERT INTO valoracions VALUES (119, 62, '12/10/2004', 9);
INSERT INTO valoracions VALUES (120, 61, '28/10/2008', 5);
INSERT INTO valoracions VALUES (120, 51, '13/10/2006', 9);
INSERT INTO valoracions VALUES (120, 106, '14/02/2007', 10);
INSERT INTO valoracions VALUES (121, 17, '01/01/2009', 5);
INSERT INTO valoracions VALUES (121, 77, '28/11/2009', 3);
INSERT INTO valoracions VALUES (121, 16, '18/09/2010', 9);
INSERT INTO valoracions VALUES (122, 50, '08/03/2007', 8);
INSERT INTO valoracions VALUES (123, 86, '17/01/2004', 7);
INSERT INTO valoracions VALUES (123, 82, '28/06/2007', 8);
INSERT INTO valoracions VALUES (123, 56, '20/12/2007', 9);
INSERT INTO valoracions VALUES (123, 93, '24/09/2004', 5);
INSERT INTO valoracions VALUES (124, 53, '25/04/2003', 6);
INSERT INTO valoracions VALUES (124, 104, '03/10/2003', 6);
INSERT INTO valoracions VALUES (125, 22, '26/03/2008', 6);
INSERT INTO valoracions VALUES (125, 54, '23/02/2005', 3);
INSERT INTO valoracions VALUES (126, 100, '28/09/2009', 9);
INSERT INTO valoracions VALUES (126, 77, '09/07/2010', 8);
INSERT INTO valoracions VALUES (126, 16, '21/12/2009', 8);
INSERT INTO valoracions VALUES (126, 70, '04/10/2006', 5);
INSERT INTO valoracions VALUES (126, 94, '04/09/2005', 3);
INSERT INTO valoracions VALUES (126, 69, '12/01/2007', 8);
INSERT INTO valoracions VALUES (126, 2, '29/10/2008', 10);
INSERT INTO valoracions VALUES (127, 103, '12/01/2007', 5);
INSERT INTO valoracions VALUES (127, 14, '02/07/2002', 6);
INSERT INTO valoracions VALUES (128, 99, '26/08/2008', 4);
INSERT INTO valoracions VALUES (128, 38, '08/12/2004', 7);
INSERT INTO valoracions VALUES (128, 112, '23/08/2004', 2);
INSERT INTO valoracions VALUES (128, 109, '22/09/2002', 5);
INSERT INTO valoracions VALUES (128, 43, '25/05/2002', 5);
INSERT INTO valoracions VALUES (128, 30, '12/07/2010', 8);
INSERT INTO valoracions VALUES (128, 78, '24/08/2004', 8);
INSERT INTO valoracions VALUES (128, 113, '26/10/2008', 0);
INSERT INTO valoracions VALUES (128, 8, '30/05/2003', 5);
INSERT INTO valoracions VALUES (129, 16, '05/03/2007', 7);
INSERT INTO valoracions VALUES (129, 40, '23/11/2004', 8);
INSERT INTO valoracions VALUES (129, 17, '16/08/2001', 5);
INSERT INTO valoracions VALUES (129, 107, '30/06/2002', 2);
INSERT INTO valoracions VALUES (129, 60, '21/07/2004', 10);
INSERT INTO valoracions VALUES (130, 88, '28/08/2002', 5);
INSERT INTO valoracions VALUES (130, 40, '26/08/2003', 7);
INSERT INTO valoracions VALUES (131, 84, '18/03/2005', 8);
INSERT INTO valoracions VALUES (131, 56, '04/06/2010', 8);
INSERT INTO valoracions VALUES (131, 29, '19/01/2007', 7);
INSERT INTO valoracions VALUES (131, 32, '14/02/2006', 6);
INSERT INTO valoracions VALUES (132, 87, '30/03/2005', 3);
INSERT INTO valoracions VALUES (132, 114, '28/08/2001', 6);
INSERT INTO valoracions VALUES (132, 116, '25/01/2008', 6);
INSERT INTO valoracions VALUES (133, 48, '22/02/2006', 5);
INSERT INTO valoracions VALUES (133, 39, '08/01/2004', 3);
INSERT INTO valoracions VALUES (133, 84, '23/04/2006', 6);
INSERT INTO valoracions VALUES (133, 78, '26/05/2006', 4);
INSERT INTO valoracions VALUES (133, 30, '20/05/2001', 9);
INSERT INTO valoracions VALUES (133, 32, '02/11/2007', 9);
INSERT INTO valoracions VALUES (134, 59, '07/03/2003', 10);
INSERT INTO valoracions VALUES (134, 61, '28/06/2003', 8);
INSERT INTO valoracions VALUES (135, 113, '25/05/2010', 8);
INSERT INTO valoracions VALUES (135, 44, '22/08/2009', 5);
INSERT INTO valoracions VALUES (135, 23, '18/06/2001', 9);
INSERT INTO valoracions VALUES (135, 44, '11/07/2010', 5);
INSERT INTO valoracions VALUES (136, 22, '16/10/2002', 7);
INSERT INTO valoracions VALUES (137, 2, '23/03/2008', 9);
INSERT INTO valoracions VALUES (137, 39, '14/09/2008', 8);
INSERT INTO valoracions VALUES (137, 19, '26/06/2003', 4);
INSERT INTO valoracions VALUES (137, 59, '09/02/2010', 7);
INSERT INTO valoracions VALUES (137, 52, '20/12/2001', 4);
INSERT INTO valoracions VALUES (137, 5, '08/10/2010', 5);
INSERT INTO valoracions VALUES (138, 104, '28/07/2006', 2);
INSERT INTO valoracions VALUES (138, 16, '21/06/2007', 5);
INSERT INTO valoracions VALUES (138, 48, '15/03/2005', 9);
INSERT INTO valoracions VALUES (139, 56, '27/03/2002', 9);
INSERT INTO valoracions VALUES (139, 107, '08/11/2008', 5);
INSERT INTO valoracions VALUES (140, 96, '04/02/2004', 3);
INSERT INTO valoracions VALUES (140, 45, '16/01/2004', 4);
INSERT INTO valoracions VALUES (140, 103, '08/08/2007', 9);
INSERT INTO valoracions VALUES (140, 16, '11/09/2005', 10);
INSERT INTO valoracions VALUES (140, 70, '29/07/2007', 6);
INSERT INTO valoracions VALUES (140, 42, '27/03/2006', 7);
INSERT INTO valoracions VALUES (141, 39, '19/07/2001', 9);
INSERT INTO valoracions VALUES (141, 11, '10/04/2010', 6);
INSERT INTO valoracions VALUES (142, 37, '14/06/2004', 7);
INSERT INTO valoracions VALUES (142, 109, '21/04/2009', 2);
INSERT INTO valoracions VALUES (142, 26, '23/04/2001', 6);
INSERT INTO valoracions VALUES (142, 44, '15/02/2010', 7);
INSERT INTO valoracions VALUES (142, 8, '06/04/2002', 5);
INSERT INTO valoracions VALUES (142, 93, '08/08/2008', 8);
INSERT INTO valoracions VALUES (143, 97, '07/10/2001', 9);
INSERT INTO valoracions VALUES (143, 95, '01/08/2001', 2);
INSERT INTO valoracions VALUES (144, 106, '31/05/2010', 9);
INSERT INTO valoracions VALUES (144, 70, '08/09/2004', 5);
INSERT INTO valoracions VALUES (144, 58, '14/11/2008', 7);
INSERT INTO valoracions VALUES (144, 13, '10/11/2005', 8);
INSERT INTO valoracions VALUES (145, 62, '08/08/2004', 7);
INSERT INTO valoracions VALUES (145, 109, '12/07/2002', 0);
INSERT INTO valoracions VALUES (145, 82, '20/07/2001', 2);
INSERT INTO valoracions VALUES (145, 39, '06/05/2002', 10);
INSERT INTO valoracions VALUES (146, 92, '28/10/2009', 6);
INSERT INTO valoracions VALUES (146, 98, '31/07/2002', 10);
INSERT INTO valoracions VALUES (146, 90, '10/08/2005', 10);
INSERT INTO valoracions VALUES (146, 67, '01/12/2001', 3);
INSERT INTO valoracions VALUES (146, 4, '12/03/2009', 5);
INSERT INTO valoracions VALUES (147, 85, '14/09/2002', 2);
INSERT INTO valoracions VALUES (147, 42, '25/04/2003', 3);
INSERT INTO valoracions VALUES (148, 53, '08/08/2004', 5);
INSERT INTO valoracions VALUES (148, 18, '27/06/2005', 7);
INSERT INTO valoracions VALUES (148, 6, '12/07/2010', 6);
INSERT INTO valoracions VALUES (148, 60, '05/11/2003', 5);
INSERT INTO valoracions VALUES (148, 99, '19/06/2008', 7);
INSERT INTO valoracions VALUES (149, 73, '04/06/2010', 8);
INSERT INTO valoracions VALUES (149, 107, '10/06/2001', 4);
INSERT INTO valoracions VALUES (150, 93, '10/05/2006', 5);
INSERT INTO valoracions VALUES (150, 65, '06/12/2002', 5);
INSERT INTO valoracions VALUES (150, 36, '05/11/2007', 7);
INSERT INTO valoracions VALUES (150, 28, '03/05/2007', 7);
INSERT INTO valoracions VALUES (150, 63, '06/01/2002', 6);
INSERT INTO valoracions VALUES (151, 1, '31/07/2010', 7);
INSERT INTO valoracions VALUES (151, 107, '22/04/2008', 9);
INSERT INTO valoracions VALUES (151, 61, '17/06/2004', 8);
INSERT INTO valoracions VALUES (152, 57, '13/02/2009', 6);
INSERT INTO valoracions VALUES (152, 65, '25/07/2001', 6);
INSERT INTO valoracions VALUES (152, 58, '30/05/2007', 5);
INSERT INTO valoracions VALUES (152, 7, '29/09/2008', 8);
INSERT INTO valoracions VALUES (152, 29, '08/06/2010', 6);
INSERT INTO valoracions VALUES (152, 8, '03/05/2003', 9);
INSERT INTO valoracions VALUES (153, 94, '08/11/2006', 7);
INSERT INTO valoracions VALUES (153, 52, '21/11/2006', 3);
INSERT INTO valoracions VALUES (153, 4, '07/07/2006', 6);
INSERT INTO valoracions VALUES (153, 5, '10/05/2010', 9);
INSERT INTO valoracions VALUES (153, 34, '10/09/2010', 6);
INSERT INTO valoracions VALUES (153, 16, '14/05/2010', 6);
INSERT INTO valoracions VALUES (153, 62, '24/02/2007', 3);
INSERT INTO valoracions VALUES (154, 59, '10/06/2010', 10);
INSERT INTO valoracions VALUES (154, 33, '25/04/2010', 7);
INSERT INTO valoracions VALUES (154, 13, '24/05/2003', 7);
INSERT INTO valoracions VALUES (154, 67, '09/08/2001', 5);
INSERT INTO valoracions VALUES (154, 21, '05/01/2004', 9);
INSERT INTO valoracions VALUES (154, 94, '12/05/2005', 8);
INSERT INTO valoracions VALUES (155, 103, '26/06/2010', 8);
INSERT INTO valoracions VALUES (155, 102, '13/07/2007', 6);
INSERT INTO valoracions VALUES (155, 63, '11/02/2008', 10);
INSERT INTO valoracions VALUES (155, 52, '23/07/2007', 9);
INSERT INTO valoracions VALUES (155, 50, '24/03/2010', 4);
INSERT INTO valoracions VALUES (156, 45, '17/10/2010', 9);
INSERT INTO valoracions VALUES (156, 115, '05/12/2002', 7);
INSERT INTO valoracions VALUES (156, 66, '30/06/2003', 8);
INSERT INTO valoracions VALUES (156, 75, '03/11/2006', 6);
INSERT INTO valoracions VALUES (156, 80, '28/03/2008', 10);
INSERT INTO valoracions VALUES (156, 71, '24/07/2001', 3);
INSERT INTO valoracions VALUES (157, 28, '16/02/2002', 9);
INSERT INTO valoracions VALUES (157, 109, '25/01/2005', 9);
INSERT INTO valoracions VALUES (157, 90, '13/01/2006', 7);
INSERT INTO valoracions VALUES (158, 105, '12/06/2001', 5);
INSERT INTO valoracions VALUES (158, 45, '10/07/2006', 7);
INSERT INTO valoracions VALUES (158, 102, '24/09/2003', 6);
INSERT INTO valoracions VALUES (158, 55, '18/01/2003', 6);
INSERT INTO valoracions VALUES (158, 92, '01/12/2002', 6);
INSERT INTO valoracions VALUES (159, 34, '10/03/2003', 9);
INSERT INTO valoracions VALUES (159, 64, '19/12/2003', 8);
INSERT INTO valoracions VALUES (159, 76, '28/01/2008', 4);
INSERT INTO valoracions VALUES (160, 9, '31/05/2010', 7);
INSERT INTO valoracions VALUES (160, 91, '25/05/2010', 5);
INSERT INTO valoracions VALUES (160, 26, '29/08/2004', 7);
INSERT INTO valoracions VALUES (160, 22, '23/05/2010', 6);
INSERT INTO valoracions VALUES (161, 52, '17/02/2006', 9);
INSERT INTO valoracions VALUES (161, 8, '01/02/2008', 9);
INSERT INTO valoracions VALUES (161, 37, '26/10/2007', 7);
INSERT INTO valoracions VALUES (161, 35, '26/01/2002', 8);
INSERT INTO valoracions VALUES (162, 105, '07/05/2007', 1);
INSERT INTO valoracions VALUES (162, 31, '04/01/2005', 6);
INSERT INTO valoracions VALUES (162, 67, '20/03/2004', 7);
INSERT INTO valoracions VALUES (162, 80, '22/04/2002', 7);
INSERT INTO valoracions VALUES (162, 32, '03/01/2004', 4);
INSERT INTO valoracions VALUES (162, 95, '01/03/2008', 5);
INSERT INTO valoracions VALUES (163, 41, '24/04/2008', 7);
INSERT INTO valoracions VALUES (163, 67, '10/09/2003', 8);
INSERT INTO valoracions VALUES (163, 3, '30/10/2002', 6);
INSERT INTO valoracions VALUES (163, 36, '27/07/2008', 8);
INSERT INTO valoracions VALUES (163, 25, '21/04/2003', 6);
INSERT INTO valoracions VALUES (163, 96, '09/07/2006', 2);
INSERT INTO valoracions VALUES (163, 65, '25/07/2010', 9);
INSERT INTO valoracions VALUES (164, 3, '11/12/2003', 8);
INSERT INTO valoracions VALUES (164, 92, '16/06/2002', 9);
INSERT INTO valoracions VALUES (164, 106, '28/07/2004', 3);
INSERT INTO valoracions VALUES (164, 21, '21/01/2003', 5);
INSERT INTO valoracions VALUES (164, 3, '26/06/2008', 8);
INSERT INTO valoracions VALUES (164, 30, '12/10/2006', 9);
INSERT INTO valoracions VALUES (165, 17, '13/09/2007', 5);
INSERT INTO valoracions VALUES (165, 58, '14/07/2001', 4);
INSERT INTO valoracions VALUES (166, 64, '12/08/2010', 10);
INSERT INTO valoracions VALUES (166, 48, '18/08/2002', 7);
INSERT INTO valoracions VALUES (166, 64, '20/12/2008', 8);
INSERT INTO valoracions VALUES (167, 63, '04/02/2003', 9);
INSERT INTO valoracions VALUES (167, 79, '12/11/2001', 3);
INSERT INTO valoracions VALUES (167, 77, '10/04/2008', 4);
INSERT INTO valoracions VALUES (167, 55, '24/12/2002', 4);
INSERT INTO valoracions VALUES (167, 78, '05/07/2010', 3);
INSERT INTO valoracions VALUES (168, 110, '12/09/2008', 4);
INSERT INTO valoracions VALUES (168, 103, '16/07/2009', 1);
INSERT INTO valoracions VALUES (168, 39, '02/10/2006', 8);
INSERT INTO valoracions VALUES (168, 50, '04/01/2006', 9);
INSERT INTO valoracions VALUES (169, 103, '02/06/2009', 6);
INSERT INTO valoracions VALUES (169, 5, '14/08/2002', 7);
INSERT INTO valoracions VALUES (169, 90, '18/07/2009', 10);
INSERT INTO valoracions VALUES (170, 27, '27/09/2002', 8);
INSERT INTO valoracions VALUES (170, 103, '18/02/2004', 8);
INSERT INTO valoracions VALUES (170, 105, '07/09/2006', 7);
INSERT INTO valoracions VALUES (171, 84, '19/02/2002', 8);
INSERT INTO valoracions VALUES (171, 55, '10/08/2010', 7);
INSERT INTO valoracions VALUES (171, 67, '21/04/2010', 6);
INSERT INTO valoracions VALUES (171, 105, '06/08/2009', 7);
INSERT INTO valoracions VALUES (171, 115, '19/12/2009', 7);
INSERT INTO valoracions VALUES (171, 23, '30/11/2006', 6);
INSERT INTO valoracions VALUES (171, 50, '17/07/2006', 7);
INSERT INTO valoracions VALUES (173, 107, '21/04/2006', 5);
INSERT INTO valoracions VALUES (173, 40, '15/03/2008', 4);
INSERT INTO valoracions VALUES (173, 43, '01/09/2003', 8);
INSERT INTO valoracions VALUES (173, 105, '19/11/2007', 9);
INSERT INTO valoracions VALUES (173, 42, '13/06/2006', 5);
INSERT INTO valoracions VALUES (173, 57, '12/07/2008', 6);
INSERT INTO valoracions VALUES (173, 5, '05/08/2001', 5);
INSERT INTO valoracions VALUES (174, 30, '02/11/2004', 8);
INSERT INTO valoracions VALUES (174, 9, '25/09/2003', 5);
INSERT INTO valoracions VALUES (174, 68, '20/05/2008', 10);
INSERT INTO valoracions VALUES (174, 66, '30/10/2007', 8);
INSERT INTO valoracions VALUES (174, 85, '26/05/2005', 4);
INSERT INTO valoracions VALUES (174, 77, '12/05/2002', 4);
INSERT INTO valoracions VALUES (175, 22, '16/11/2009', 5);
INSERT INTO valoracions VALUES (175, 58, '17/06/2007', 3);
INSERT INTO valoracions VALUES (175, 5, '22/04/2002', 5);
INSERT INTO valoracions VALUES (175, 22, '03/02/2005', 6);
INSERT INTO valoracions VALUES (175, 112, '16/06/2008', 8);
INSERT INTO valoracions VALUES (175, 28, '28/08/2004', 9);
INSERT INTO valoracions VALUES (175, 62, '22/12/2002', 5);
INSERT INTO valoracions VALUES (176, 32, '19/08/2009', 5);
INSERT INTO valoracions VALUES (176, 72, '30/09/2006', 6);
INSERT INTO valoracions VALUES (176, 72, '26/05/2004', 8);
INSERT INTO valoracions VALUES (176, 4, '19/05/2004', 8);
INSERT INTO valoracions VALUES (176, 39, '21/11/2004', 5);
INSERT INTO valoracions VALUES (176, 12, '17/11/2008', 6);
INSERT INTO valoracions VALUES (177, 99, '07/08/2010', 3);
INSERT INTO valoracions VALUES (177, 40, '05/08/2009', 9);
INSERT INTO valoracions VALUES (178, 115, '03/04/2002', 4);
INSERT INTO valoracions VALUES (178, 56, '07/11/2003', 9);
INSERT INTO valoracions VALUES (178, 17, '24/12/2005', 8);
INSERT INTO valoracions VALUES (178, 109, '15/01/2009', 1);
INSERT INTO valoracions VALUES (178, 14, '06/12/2009', 10);
INSERT INTO valoracions VALUES (178, 67, '07/10/2007', 3);
INSERT INTO valoracions VALUES (178, 87, '21/06/2003', 9);
INSERT INTO valoracions VALUES (178, 57, '07/10/2006', 3);
INSERT INTO valoracions VALUES (179, 96, '16/11/2008', 4);
INSERT INTO valoracions VALUES (179, 31, '24/11/2005', 9);
INSERT INTO valoracions VALUES (179, 13, '10/08/2010', 6);
INSERT INTO valoracions VALUES (180, 27, '25/09/2002', 10);
INSERT INTO valoracions VALUES (180, 7, '23/06/2009', 6);
INSERT INTO valoracions VALUES (180, 15, '10/07/2008', 7);
INSERT INTO valoracions VALUES (180, 4, '07/05/2006', 7);
INSERT INTO valoracions VALUES (180, 13, '07/04/2003', 8);
INSERT INTO valoracions VALUES (180, 52, '26/10/2009', 9);
INSERT INTO valoracions VALUES (180, 43, '24/06/2003', 5);
INSERT INTO valoracions VALUES (181, 60, '21/05/2006', 5);
INSERT INTO valoracions VALUES (181, 110, '28/02/2003', 2);
INSERT INTO valoracions VALUES (181, 61, '02/03/2009', 4);
INSERT INTO valoracions VALUES (181, 114, '11/06/2003', 8);
INSERT INTO valoracions VALUES (181, 12, '04/12/2008', 9);
INSERT INTO valoracions VALUES (182, 4, '22/07/2002', 5);
INSERT INTO valoracions VALUES (182, 12, '02/04/2010', 8);
INSERT INTO valoracions VALUES (182, 19, '31/08/2003', 7);
INSERT INTO valoracions VALUES (183, 87, '05/12/2007', 6);
INSERT INTO valoracions VALUES (183, 110, '30/01/2008', 6);
INSERT INTO valoracions VALUES (184, 18, '06/04/2002', 5);
INSERT INTO valoracions VALUES (184, 110, '03/07/2008', 4);
INSERT INTO valoracions VALUES (185, 96, '23/01/2006', 8);
INSERT INTO valoracions VALUES (185, 85, '21/07/2005', 3);
INSERT INTO valoracions VALUES (185, 65, '16/11/2001', 9);
INSERT INTO valoracions VALUES (185, 44, '22/01/2003', 6);
INSERT INTO valoracions VALUES (185, 77, '31/10/2003', 10);
INSERT INTO valoracions VALUES (185, 30, '07/11/2006', 10);
INSERT INTO valoracions VALUES (186, 32, '23/03/2004', 6);
INSERT INTO valoracions VALUES (186, 48, '06/11/2003', 4);
INSERT INTO valoracions VALUES (186, 92, '19/04/2009', 8);
INSERT INTO valoracions VALUES (187, 40, '12/12/2009', 7);
INSERT INTO valoracions VALUES (187, 60, '01/08/2005', 9);
INSERT INTO valoracions VALUES (187, 58, '15/07/2009', 9);
INSERT INTO valoracions VALUES (187, 24, '24/11/2009', 6);
INSERT INTO valoracions VALUES (187, 55, '04/06/2007', 7);
INSERT INTO valoracions VALUES (188, 30, '11/10/2002', 8);
INSERT INTO valoracions VALUES (188, 73, '22/06/2002', 8);
INSERT INTO valoracions VALUES (188, 104, '12/01/2010', 9);
INSERT INTO valoracions VALUES (188, 59, '24/01/2010', 9);
INSERT INTO valoracions VALUES (188, 37, '23/08/2003', 5);
INSERT INTO valoracions VALUES (189, 89, '09/07/2001', 5);
INSERT INTO valoracions VALUES (189, 87, '25/11/2004', 2);
INSERT INTO valoracions VALUES (189, 15, '15/11/2003', 9);
INSERT INTO valoracions VALUES (189, 34, '20/03/2007', 5);
INSERT INTO valoracions VALUES (189, 25, '30/05/2010', 4);
INSERT INTO valoracions VALUES (190, 2, '12/05/2004', 8);
INSERT INTO valoracions VALUES (190, 7, '22/03/2009', 7);
INSERT INTO valoracions VALUES (190, 71, '10/04/2005', 8);
INSERT INTO valoracions VALUES (191, 86, '26/07/2008', 2);
INSERT INTO valoracions VALUES (191, 66, '24/08/2007', 8);
INSERT INTO valoracions VALUES (191, 56, '04/03/2006', 9);
INSERT INTO valoracions VALUES (192, 68, '14/03/2009', 5);
INSERT INTO valoracions VALUES (192, 81, '20/09/2008', 9);
INSERT INTO valoracions VALUES (192, 96, '29/10/2005', 4);
INSERT INTO valoracions VALUES (192, 112, '13/09/2008', 5);
INSERT INTO valoracions VALUES (193, 41, '31/01/2008', 9);
INSERT INTO valoracions VALUES (193, 70, '21/06/2010', 5);
INSERT INTO valoracions VALUES (193, 4, '28/04/2003', 9);
INSERT INTO valoracions VALUES (194, 110, '24/07/2007', 7);
INSERT INTO valoracions VALUES (194, 66, '13/02/2002', 7);
INSERT INTO valoracions VALUES (194, 100, '04/09/2004', 5);
INSERT INTO valoracions VALUES (195, 54, '14/01/2003', 5);
INSERT INTO valoracions VALUES (195, 98, '25/05/2008', 3);
INSERT INTO valoracions VALUES (195, 56, '15/06/2002', 4);
INSERT INTO valoracions VALUES (195, 34, '16/03/2002', 8);
INSERT INTO valoracions VALUES (196, 86, '15/04/2003', 7);
INSERT INTO valoracions VALUES (196, 51, '14/11/2003', 4);
INSERT INTO valoracions VALUES (196, 60, '03/10/2008', 8);
INSERT INTO valoracions VALUES (196, 74, '15/06/2010', 8);
INSERT INTO valoracions VALUES (196, 15, '19/04/2007', 9);
INSERT INTO valoracions VALUES (196, 42, '21/03/2006', 5);
INSERT INTO valoracions VALUES (197, 15, '10/02/2003', 8);
INSERT INTO valoracions VALUES (197, 71, '23/09/2008', 3);
INSERT INTO valoracions VALUES (197, 71, '28/05/2006', 4);
INSERT INTO valoracions VALUES (197, 17, '22/09/2008', 7);
INSERT INTO valoracions VALUES (197, 48, '10/04/2006', 4);
INSERT INTO valoracions VALUES (198, 34, '14/12/2006', 4);
INSERT INTO valoracions VALUES (198, 77, '05/11/2005', 9);
INSERT INTO valoracions VALUES (198, 74, '16/05/2009', 9);
INSERT INTO valoracions VALUES (198, 15, '28/03/2006', 6);
INSERT INTO valoracions VALUES (198, 30, '15/02/2008', 6);
INSERT INTO valoracions VALUES (199, 70, '18/07/2010', 5);
INSERT INTO valoracions VALUES (199, 48, '01/05/2007', 9);
INSERT INTO valoracions VALUES (199, 84, '26/11/2001', 3);
INSERT INTO valoracions VALUES (199, 31, '14/11/2002', 7);
INSERT INTO valoracions VALUES (199, 79, '30/11/2009', 2);
INSERT INTO valoracions VALUES (200, 82, '28/04/2005', 7);
INSERT INTO valoracions VALUES (200, 89, '01/08/2008', 6);
INSERT INTO valoracions VALUES (200, 106, '31/05/2008', 10);
INSERT INTO valoracions VALUES (200, 49, '02/03/2005', 10);
INSERT INTO valoracions VALUES (201, 37, '28/06/2001', 7);
INSERT INTO valoracions VALUES (201, 64, '02/06/2010', 8);
INSERT INTO valoracions VALUES (201, 25, '08/01/2005', 6);
INSERT INTO valoracions VALUES (201, 9, '06/03/2007', 8);
INSERT INTO valoracions VALUES (201, 29, '19/02/2002', 8);
INSERT INTO valoracions VALUES (202, 105, '27/05/2010', 2);
INSERT INTO valoracions VALUES (202, 39, '01/04/2004', 8);
INSERT INTO valoracions VALUES (203, 40, '16/02/2002', 10);
INSERT INTO valoracions VALUES (203, 104, '04/02/2003', 3);
INSERT INTO valoracions VALUES (203, 56, '23/05/2002', 5);
INSERT INTO valoracions VALUES (203, 5, '14/07/2009', 10);
INSERT INTO valoracions VALUES (203, 8, '31/03/2004', 6);
INSERT INTO valoracions VALUES (204, 88, '15/07/2010', 4);
INSERT INTO valoracions VALUES (205, 50, '09/05/2005', 9);
INSERT INTO valoracions VALUES (205, 104, '28/07/2005', 3);
INSERT INTO valoracions VALUES (205, 30, '07/04/2005', 6);
INSERT INTO valoracions VALUES (205, 97, '12/08/2010', 6);
INSERT INTO valoracions VALUES (205, 105, '01/07/2003', 1);
INSERT INTO valoracions VALUES (205, 82, '08/11/2001', 6);
INSERT INTO valoracions VALUES (206, 50, '08/10/2004', 4);
INSERT INTO valoracions VALUES (206, 91, '06/07/2008', 6);
INSERT INTO valoracions VALUES (206, 55, '13/08/2010', 6);
INSERT INTO valoracions VALUES (206, 86, '02/03/2008', 4);
INSERT INTO valoracions VALUES (206, 101, '19/07/2005', 3);
INSERT INTO valoracions VALUES (206, 33, '18/03/2009', 5);
INSERT INTO valoracions VALUES (207, 57, '03/10/2001', 9);
INSERT INTO valoracions VALUES (207, 105, '16/12/2002', 7);
INSERT INTO valoracions VALUES (207, 38, '13/10/2002', 7);
INSERT INTO valoracions VALUES (208, 22, '16/11/2009', 5);
INSERT INTO valoracions VALUES (208, 45, '15/03/2006', 5);
INSERT INTO valoracions VALUES (208, 91, '03/06/2010', 5);
INSERT INTO valoracions VALUES (208, 87, '25/06/2005', 7);
INSERT INTO valoracions VALUES (209, 32, '22/08/2010', 10);
INSERT INTO valoracions VALUES (209, 78, '11/11/2009', 7);
INSERT INTO valoracions VALUES (209, 36, '23/05/2007', 5);
INSERT INTO valoracions VALUES (209, 36, '02/03/2007', 8);
INSERT INTO valoracions VALUES (210, 108, '09/01/2006', 4);
INSERT INTO valoracions VALUES (211, 47, '13/07/2008', 7);
INSERT INTO valoracions VALUES (211, 105, '14/12/2009', 9);
INSERT INTO valoracions VALUES (211, 51, '13/06/2007', 6);
INSERT INTO valoracions VALUES (211, 104, '22/06/2008', 7);
INSERT INTO valoracions VALUES (211, 67, '23/01/2008', 5);
INSERT INTO valoracions VALUES (211, 12, '21/12/2009', 6);
INSERT INTO valoracions VALUES (211, 46, '08/05/2001', 6);
INSERT INTO valoracions VALUES (212, 84, '18/05/2004', 9);
INSERT INTO valoracions VALUES (212, 2, '16/10/2005', 8);
INSERT INTO valoracions VALUES (212, 116, '14/10/2004', 4);
INSERT INTO valoracions VALUES (212, 20, '05/05/2006', 5);
INSERT INTO valoracions VALUES (212, 91, '25/08/2004', 6);
INSERT INTO valoracions VALUES (212, 10, '23/09/2005', 10);
INSERT INTO valoracions VALUES (212, 33, '08/03/2007', 7);
INSERT INTO valoracions VALUES (212, 10, '16/10/2007', 5);
INSERT INTO valoracions VALUES (213, 17, '10/06/2008', 9);
INSERT INTO valoracions VALUES (213, 109, '14/08/2001', 6);
INSERT INTO valoracions VALUES (213, 95, '15/11/2006', 4);
INSERT INTO valoracions VALUES (214, 90, '27/09/2004', 5);
INSERT INTO valoracions VALUES (214, 97, '20/10/2002', 2);
INSERT INTO valoracions VALUES (214, 90, '17/02/2004', 6);
INSERT INTO valoracions VALUES (214, 79, '10/12/2009', 2);
INSERT INTO valoracions VALUES (215, 8, '13/05/2007', 7);
INSERT INTO valoracions VALUES (216, 106, '17/08/2010', 0);
INSERT INTO valoracions VALUES (217, 83, '02/09/2001', 5);
INSERT INTO valoracions VALUES (218, 19, '02/06/2007', 6);
INSERT INTO valoracions VALUES (218, 106, '02/02/2008', 7);
INSERT INTO valoracions VALUES (218, 114, '16/06/2003', 1);
INSERT INTO valoracions VALUES (218, 102, '15/04/2005', 3);
INSERT INTO valoracions VALUES (218, 61, '26/09/2004', 5);
INSERT INTO valoracions VALUES (219, 114, '15/11/2004', 7);
INSERT INTO valoracions VALUES (219, 1, '06/06/2010', 7);
INSERT INTO valoracions VALUES (219, 32, '02/10/2003', 7);
INSERT INTO valoracions VALUES (219, 108, '20/05/2005', 8);
INSERT INTO valoracions VALUES (219, 29, '07/02/2006', 4);
INSERT INTO valoracions VALUES (219, 84, '28/07/2008', 2);
INSERT INTO valoracions VALUES (219, 82, '09/03/2006', 2);
INSERT INTO valoracions VALUES (220, 71, '13/06/2006', 3);
INSERT INTO valoracions VALUES (220, 24, '05/02/2005', 9);
INSERT INTO valoracions VALUES (220, 76, '01/04/2003', 9);
INSERT INTO valoracions VALUES (221, 109, '07/05/2009', 8);
INSERT INTO valoracions VALUES (221, 98, '16/03/2007', 3);
INSERT INTO valoracions VALUES (222, 111, '09/06/2010', 3);
INSERT INTO valoracions VALUES (222, 31, '07/11/2003', 7);
INSERT INTO valoracions VALUES (222, 71, '15/11/2008', 4);
INSERT INTO valoracions VALUES (222, 91, '25/12/2005', 3);
INSERT INTO valoracions VALUES (222, 15, '19/03/2003', 6);
INSERT INTO valoracions VALUES (222, 19, '15/07/2009', 8);
INSERT INTO valoracions VALUES (222, 42, '12/07/2006', 7);
INSERT INTO valoracions VALUES (222, 42, '22/04/2007', 9);
INSERT INTO valoracions VALUES (222, 75, '12/02/2003', 5);
INSERT INTO valoracions VALUES (222, 43, '02/04/2001', 6);
INSERT INTO valoracions VALUES (223, 50, '02/01/2009', 9);
INSERT INTO valoracions VALUES (224, 63, '24/02/2003', 9);
INSERT INTO valoracions VALUES (224, 116, '11/03/2009', 4);
INSERT INTO valoracions VALUES (224, 24, '02/05/2009', 6);
INSERT INTO valoracions VALUES (224, 59, '24/04/2007', 7);
INSERT INTO valoracions VALUES (224, 87, '11/09/2004', 2);
INSERT INTO valoracions VALUES (224, 53, '27/06/2010', 4);
INSERT INTO valoracions VALUES (225, 33, '26/07/2006', 6);
INSERT INTO valoracions VALUES (225, 7, '01/05/2004', 5);
INSERT INTO valoracions VALUES (225, 63, '31/07/2008', 8);
INSERT INTO valoracions VALUES (225, 39, '14/03/2008', 7);
INSERT INTO valoracions VALUES (226, 2, '03/05/2003', 8);
INSERT INTO valoracions VALUES (226, 28, '14/08/2007', 4);
INSERT INTO valoracions VALUES (226, 88, '10/05/2005', 1);
INSERT INTO valoracions VALUES (227, 9, '16/05/2006', 9);
INSERT INTO valoracions VALUES (227, 105, '11/08/2004', 10);
INSERT INTO valoracions VALUES (227, 57, '22/04/2005', 7);
INSERT INTO valoracions VALUES (227, 42, '16/12/2003', 5);
INSERT INTO valoracions VALUES (228, 110, '09/03/2005', 1);
INSERT INTO valoracions VALUES (228, 78, '01/04/2006', 3);
INSERT INTO valoracions VALUES (228, 22, '04/02/2008', 6);
INSERT INTO valoracions VALUES (228, 25, '15/06/2008', 5);
INSERT INTO valoracions VALUES (228, 75, '29/09/2008', 5);
INSERT INTO valoracions VALUES (229, 52, '21/02/2004', 9);
INSERT INTO valoracions VALUES (229, 61, '19/01/2005', 6);
INSERT INTO valoracions VALUES (229, 67, '17/02/2009', 5);
INSERT INTO valoracions VALUES (229, 17, '27/02/2004', 8);
INSERT INTO valoracions VALUES (229, 33, '26/03/2010', 8);
INSERT INTO valoracions VALUES (230, 113, '25/12/2003', 8);
INSERT INTO valoracions VALUES (231, 68, '07/08/2005', 6);
INSERT INTO valoracions VALUES (231, 42, '19/06/2010', 7);
INSERT INTO valoracions VALUES (231, 84, '09/08/2008', 4);
INSERT INTO valoracions VALUES (231, 85, '27/04/2004', 4);
INSERT INTO valoracions VALUES (231, 42, '27/11/2003', 8);
INSERT INTO valoracions VALUES (231, 29, '03/09/2002', 5);
INSERT INTO valoracions VALUES (232, 72, '23/09/2001', 4);
INSERT INTO valoracions VALUES (232, 24, '20/06/2009', 9);
INSERT INTO valoracions VALUES (232, 43, '27/09/2009', 8);
INSERT INTO valoracions VALUES (232, 83, '04/03/2002', 7);
INSERT INTO valoracions VALUES (232, 95, '21/03/2006', 2);
INSERT INTO valoracions VALUES (232, 87, '13/03/2008', 2);
INSERT INTO valoracions VALUES (233, 76, '20/07/2007', 9);
INSERT INTO valoracions VALUES (233, 74, '25/08/2002', 3);
INSERT INTO valoracions VALUES (233, 71, '13/08/2006', 4);
INSERT INTO valoracions VALUES (234, 42, '24/12/2006', 4);
INSERT INTO valoracions VALUES (234, 74, '05/12/2007', 10);
INSERT INTO valoracions VALUES (234, 75, '28/11/2008', 2);
INSERT INTO valoracions VALUES (234, 50, '27/01/2003', 8);
INSERT INTO valoracions VALUES (234, 38, '10/09/2004', 5);
INSERT INTO valoracions VALUES (235, 99, '17/11/2006', 9);
INSERT INTO valoracions VALUES (235, 35, '17/11/2002', 5);
INSERT INTO valoracions VALUES (235, 40, '16/03/2004', 7);
INSERT INTO valoracions VALUES (235, 93, '25/01/2006', 3);
INSERT INTO valoracions VALUES (236, 77, '14/01/2004', 5);
INSERT INTO valoracions VALUES (236, 43, '23/09/2008', 9);
INSERT INTO valoracions VALUES (236, 22, '23/02/2006', 8);
INSERT INTO valoracions VALUES (236, 35, '29/06/2006', 9);
INSERT INTO valoracions VALUES (237, 113, '20/10/2004', 2);
INSERT INTO valoracions VALUES (237, 80, '18/09/2006', 6);
INSERT INTO valoracions VALUES (237, 49, '20/02/2003', 6);
INSERT INTO valoracions VALUES (237, 55, '25/09/2008', 3);
INSERT INTO valoracions VALUES (237, 50, '31/08/2003', 8);
INSERT INTO valoracions VALUES (238, 3, '17/04/2007', 9);
INSERT INTO valoracions VALUES (238, 26, '03/01/2003', 9);
INSERT INTO valoracions VALUES (238, 2, '29/06/2001', 7);
INSERT INTO valoracions VALUES (238, 29, '23/06/2002', 8);
INSERT INTO valoracions VALUES (239, 101, '03/11/2001', 2);
INSERT INTO valoracions VALUES (239, 74, '19/10/2001', 6);
INSERT INTO valoracions VALUES (239, 47, '29/02/2004', 9);
INSERT INTO valoracions VALUES (239, 67, '20/10/2003', 8);
INSERT INTO valoracions VALUES (240, 26, '17/09/2002', 8);
INSERT INTO valoracions VALUES (240, 91, '01/11/2005', 7);
INSERT INTO valoracions VALUES (240, 62, '24/04/2003', 8);
INSERT INTO valoracions VALUES (240, 14, '11/12/2008', 8);
INSERT INTO valoracions VALUES (241, 89, '15/03/2004', 7);
INSERT INTO valoracions VALUES (241, 59, '11/12/2006', 3);
INSERT INTO valoracions VALUES (241, 86, '31/12/2003', 8);
INSERT INTO valoracions VALUES (241, 108, '04/09/2004', 3);
INSERT INTO valoracions VALUES (241, 38, '26/10/2006', 4);
INSERT INTO valoracions VALUES (242, 63, '23/08/2010', 5);
INSERT INTO valoracions VALUES (242, 34, '29/06/2005', 9);
INSERT INTO valoracions VALUES (242, 42, '24/02/2005', 7);
INSERT INTO valoracions VALUES (242, 108, '02/01/2008', 5);
INSERT INTO valoracions VALUES (242, 38, '04/09/2008', 5);
INSERT INTO valoracions VALUES (243, 110, '05/07/2003', 4);
INSERT INTO valoracions VALUES (243, 8, '26/02/2003', 7);
INSERT INTO valoracions VALUES (244, 71, '27/01/2002', 8);
INSERT INTO valoracions VALUES (244, 47, '04/05/2006', 9);
INSERT INTO valoracions VALUES (244, 16, '28/03/2010', 7);
INSERT INTO valoracions VALUES (245, 18, '26/02/2004', 6);
INSERT INTO valoracions VALUES (245, 84, '20/04/2005', 5);
INSERT INTO valoracions VALUES (245, 33, '04/12/2004', 5);
INSERT INTO valoracions VALUES (246, 40, '16/09/2005', 5);
INSERT INTO valoracions VALUES (246, 88, '22/11/2004', 5);
INSERT INTO valoracions VALUES (246, 45, '12/04/2004', 5);
INSERT INTO valoracions VALUES (246, 105, '05/04/2009', 3);
INSERT INTO valoracions VALUES (246, 83, '28/08/2001', 4);
INSERT INTO valoracions VALUES (246, 2, '28/07/2004', 10);
INSERT INTO valoracions VALUES (247, 17, '03/07/2004', 9);
INSERT INTO valoracions VALUES (247, 91, '19/11/2006', 3);
INSERT INTO valoracions VALUES (247, 62, '18/10/2004', 8);
INSERT INTO valoracions VALUES (247, 61, '29/07/2008', 3);
INSERT INTO valoracions VALUES (248, 25, '13/09/2005', 9);
INSERT INTO valoracions VALUES (248, 83, '13/10/2006', 2);
INSERT INTO valoracions VALUES (248, 86, '24/12/2005', 4);
INSERT INTO valoracions VALUES (248, 16, '06/01/2004', 5);
INSERT INTO valoracions VALUES (248, 52, '30/08/2006', 5);
INSERT INTO valoracions VALUES (248, 42, '25/01/2010', 3);
INSERT INTO valoracions VALUES (248, 27, '24/12/2008', 7);
INSERT INTO valoracions VALUES (248, 32, '16/08/2009', 7);
INSERT INTO valoracions VALUES (248, 116, '16/08/2009', 2);
INSERT INTO valoracions VALUES (249, 52, '24/07/2002', 9);
INSERT INTO valoracions VALUES (250, 33, '22/01/2003', 6);
INSERT INTO valoracions VALUES (250, 50, '19/11/2007', 7);
INSERT INTO valoracions VALUES (250, 40, '07/06/2004', 4);
INSERT INTO valoracions VALUES (250, 30, '23/10/2008', 5);
INSERT INTO valoracions VALUES (250, 69, '07/07/2009', 8);
INSERT INTO valoracions VALUES (250, 67, '10/02/2003', 9);
INSERT INTO valoracions VALUES (250, 78, '04/05/2007', 6);
INSERT INTO valoracions VALUES (251, 83, '07/10/2003', 7);
INSERT INTO valoracions VALUES (251, 70, '08/11/2001', 6);
INSERT INTO valoracions VALUES (251, 93, '14/06/2008', 4);
INSERT INTO valoracions VALUES (251, 23, '02/10/2009', 8);
INSERT INTO valoracions VALUES (251, 1, '19/07/2003', 6);
INSERT INTO valoracions VALUES (251, 99, '17/09/2003', 7);
INSERT INTO valoracions VALUES (251, 55, '09/04/2010', 6);
INSERT INTO valoracions VALUES (252, 69, '01/04/2005', 4);
INSERT INTO valoracions VALUES (252, 66, '15/07/2001', 10);
INSERT INTO valoracions VALUES (252, 114, '03/04/2003', 7);
INSERT INTO valoracions VALUES (252, 84, '18/06/2005', 7);
INSERT INTO valoracions VALUES (252, 11, '03/11/2008', 9);
INSERT INTO valoracions VALUES (252, 27, '28/12/2007', 6);
INSERT INTO valoracions VALUES (252, 51, '16/07/2003', 6);
INSERT INTO valoracions VALUES (252, 116, '14/04/2010', 9);
INSERT INTO valoracions VALUES (252, 29, '08/12/2003', 8);
INSERT INTO valoracions VALUES (253, 31, '07/09/2001', 8);
INSERT INTO valoracions VALUES (253, 77, '06/04/2003', 6);
INSERT INTO valoracions VALUES (253, 90, '01/04/2006', 3);
INSERT INTO valoracions VALUES (253, 20, '31/03/2008', 5);
INSERT INTO valoracions VALUES (253, 27, '30/12/2004', 6);
INSERT INTO valoracions VALUES (253, 64, '06/05/2005', 5);
INSERT INTO valoracions VALUES (253, 45, '13/02/2005', 5);
INSERT INTO valoracions VALUES (253, 57, '12/03/2008', 9);
INSERT INTO valoracions VALUES (254, 96, '18/01/2008', 2);
INSERT INTO valoracions VALUES (254, 110, '24/09/2010', 2);
INSERT INTO valoracions VALUES (254, 108, '07/08/2009', 8);
INSERT INTO valoracions VALUES (255, 103, '16/04/2007', 4);
INSERT INTO valoracions VALUES (255, 45, '09/07/2006', 9);
INSERT INTO valoracions VALUES (255, 29, '18/03/2007', 8);
INSERT INTO valoracions VALUES (255, 26, '09/12/2002', 7);
INSERT INTO valoracions VALUES (255, 29, '10/10/2003', 5);
INSERT INTO valoracions VALUES (255, 29, '10/10/2005', 7);
INSERT INTO valoracions VALUES (256, 40, '25/01/2006', 6);
INSERT INTO valoracions VALUES (257, 61, '23/05/2010', 6);
INSERT INTO valoracions VALUES (257, 38, '04/05/2003', 4);
INSERT INTO valoracions VALUES (257, 40, '31/12/2002', 5);
INSERT INTO valoracions VALUES (257, 40, '23/01/2006', 4);
INSERT INTO valoracions VALUES (257, 59, '12/07/2010', 9);
INSERT INTO valoracions VALUES (257, 74, '29/01/2006', 8);
INSERT INTO valoracions VALUES (258, 17, '31/10/2009', 6);
INSERT INTO valoracions VALUES (258, 36, '08/04/2007', 10);
INSERT INTO valoracions VALUES (258, 90, '09/05/2004', 6);
INSERT INTO valoracions VALUES (259, 71, '08/06/2004', 8);
INSERT INTO valoracions VALUES (259, 21, '12/08/2002', 4);
INSERT INTO valoracions VALUES (259, 50, '21/02/2009', 10);
INSERT INTO valoracions VALUES (259, 92, '11/09/2010', 9);
INSERT INTO valoracions VALUES (259, 69, '17/12/2003', 9);
INSERT INTO valoracions VALUES (259, 26, '19/09/2003', 7);
INSERT INTO valoracions VALUES (260, 29, '08/08/2004', 6);
INSERT INTO valoracions VALUES (260, 23, '31/07/2001', 9);
INSERT INTO valoracions VALUES (260, 104, '18/03/2008', 9);
INSERT INTO valoracions VALUES (261, 21, '26/01/2009', 9);
INSERT INTO valoracions VALUES (261, 114, '06/08/2006', 7);
INSERT INTO valoracions VALUES (261, 85, '17/02/2007', 2);
INSERT INTO valoracions VALUES (262, 83, '29/04/2003', 8);
INSERT INTO valoracions VALUES (262, 38, '13/07/2004', 7);
INSERT INTO valoracions VALUES (262, 13, '10/04/2003', 6);
INSERT INTO valoracions VALUES (262, 85, '09/06/2003', 2);
INSERT INTO valoracions VALUES (262, 60, '11/03/2005', 4);
INSERT INTO valoracions VALUES (262, 45, '04/01/2003', 4);
INSERT INTO valoracions VALUES (263, 39, '18/08/2002', 8);
INSERT INTO valoracions VALUES (263, 28, '17/12/2009', 9);
INSERT INTO valoracions VALUES (264, 36, '04/11/2005', 9);
INSERT INTO valoracions VALUES (264, 38, '29/09/2009', 7);
INSERT INTO valoracions VALUES (264, 31, '11/09/2001', 9);
INSERT INTO valoracions VALUES (264, 73, '23/05/2006', 9);
INSERT INTO valoracions VALUES (265, 8, '09/01/2004', 7);
INSERT INTO valoracions VALUES (266, 95, '23/05/2006', 4);
INSERT INTO valoracions VALUES (266, 83, '19/11/2001', 4);
INSERT INTO valoracions VALUES (266, 76, '20/07/2001', 9);
INSERT INTO valoracions VALUES (267, 108, '23/04/2010', 7);
INSERT INTO valoracions VALUES (267, 6, '28/11/2009', 7);
INSERT INTO valoracions VALUES (267, 1, '25/10/2008', 7);
INSERT INTO valoracions VALUES (267, 102, '28/03/2005', 2);
INSERT INTO valoracions VALUES (267, 41, '09/10/2005', 7);
INSERT INTO valoracions VALUES (268, 70, '17/10/2003', 7);
INSERT INTO valoracions VALUES (268, 46, '04/01/2007', 4);
INSERT INTO valoracions VALUES (269, 82, '28/11/2004', 4);
INSERT INTO valoracions VALUES (269, 86, '16/03/2004', 9);
INSERT INTO valoracions VALUES (269, 90, '13/04/2001', 3);
INSERT INTO valoracions VALUES (269, 23, '21/03/2002', 7);
INSERT INTO valoracions VALUES (269, 12, '19/07/2007', 8);
INSERT INTO valoracions VALUES (269, 91, '31/05/2010', 6);
INSERT INTO valoracions VALUES (270, 81, '10/02/2007', 2);
INSERT INTO valoracions VALUES (271, 36, '03/04/2004', 5);
INSERT INTO valoracions VALUES (271, 30, '13/11/2004', 8);
INSERT INTO valoracions VALUES (271, 26, '27/10/2007', 8);
INSERT INTO valoracions VALUES (271, 31, '11/04/2001', 9);
INSERT INTO valoracions VALUES (271, 12, '15/12/2006', 6);
INSERT INTO valoracions VALUES (271, 82, '09/08/2004', 9);
INSERT INTO valoracions VALUES (271, 95, '23/06/2004', 1);
INSERT INTO valoracions VALUES (271, 66, '27/04/2002', 4);
INSERT INTO valoracions VALUES (271, 37, '15/04/2009', 5);
INSERT INTO valoracions VALUES (271, 113, '17/10/2001', 3);
INSERT INTO valoracions VALUES (272, 39, '30/06/2010', 4);
INSERT INTO valoracions VALUES (272, 43, '25/02/2007', 7);
INSERT INTO valoracions VALUES (272, 82, '02/07/2006', 8);
INSERT INTO valoracions VALUES (272, 36, '25/03/2009', 5);
INSERT INTO valoracions VALUES (272, 36, '02/05/2010', 7);
INSERT INTO valoracions VALUES (272, 27, '18/01/2006', 8);
INSERT INTO valoracions VALUES (272, 50, '03/07/2008', 3);
INSERT INTO valoracions VALUES (272, 47, '20/08/2003', 5);
INSERT INTO valoracions VALUES (273, 46, '25/09/2004', 4);
INSERT INTO valoracions VALUES (273, 94, '12/09/2004', 8);
INSERT INTO valoracions VALUES (274, 90, '14/05/2004', 3);
INSERT INTO valoracions VALUES (274, 54, '11/01/2003', 4);
INSERT INTO valoracions VALUES (274, 28, '21/10/2003', 8);
INSERT INTO valoracions VALUES (274, 14, '27/08/2001', 5);
INSERT INTO valoracions VALUES (274, 68, '02/01/2004', 5);
INSERT INTO valoracions VALUES (275, 75, '12/04/2004', 8);
INSERT INTO valoracions VALUES (275, 73, '26/02/2009', 10);
INSERT INTO valoracions VALUES (276, 23, '12/11/2008', 5);
INSERT INTO valoracions VALUES (276, 8, '15/11/2007', 9);
INSERT INTO valoracions VALUES (276, 22, '25/01/2006', 10);
INSERT INTO valoracions VALUES (276, 85, '31/08/2001', 2);
INSERT INTO valoracions VALUES (276, 39, '15/09/2005', 6);
INSERT INTO valoracions VALUES (276, 107, '24/09/2005', 1);
INSERT INTO valoracions VALUES (276, 89, '03/04/2006', 5);
INSERT INTO valoracions VALUES (277, 78, '11/02/2003', 8);
INSERT INTO valoracions VALUES (277, 97, '16/05/2008', 7);
INSERT INTO valoracions VALUES (277, 106, '20/03/2002', 2);
INSERT INTO valoracions VALUES (277, 53, '26/02/2002', 10);
INSERT INTO valoracions VALUES (277, 96, '07/07/2005', 1);
INSERT INTO valoracions VALUES (278, 12, '25/05/2008', 5);
INSERT INTO valoracions VALUES (279, 111, '31/07/2006', 8);
INSERT INTO valoracions VALUES (279, 85, '27/06/2004', 7);
INSERT INTO valoracions VALUES (279, 40, '20/02/2002', 3);
INSERT INTO valoracions VALUES (280, 99, '23/10/2001', 4);
INSERT INTO valoracions VALUES (280, 83, '02/01/2010', 2);
INSERT INTO valoracions VALUES (280, 18, '22/07/2008', 8);
INSERT INTO valoracions VALUES (280, 87, '30/11/2004', 3);
INSERT INTO valoracions VALUES (280, 31, '10/04/2008', 9);
INSERT INTO valoracions VALUES (280, 102, '15/02/2007', 4);
INSERT INTO valoracions VALUES (280, 33, '09/10/2003', 6);
INSERT INTO valoracions VALUES (281, 50, '08/04/2004', 4);
INSERT INTO valoracions VALUES (281, 27, '09/01/2006', 6);
INSERT INTO valoracions VALUES (281, 109, '05/02/2007', 10);
INSERT INTO valoracions VALUES (281, 99, '19/10/2001', 8);
INSERT INTO valoracions VALUES (282, 39, '19/09/2004', 9);
INSERT INTO valoracions VALUES (282, 62, '19/02/2003', 3);
INSERT INTO valoracions VALUES (282, 26, '10/08/2005', 6);
INSERT INTO valoracions VALUES (282, 26, '22/12/2005', 8);
INSERT INTO valoracions VALUES (284, 65, '20/04/2001', 5);
INSERT INTO valoracions VALUES (284, 64, '28/05/2004', 7);
INSERT INTO valoracions VALUES (284, 86, '08/10/2009', 8);
INSERT INTO valoracions VALUES (284, 70, '09/04/2008', 9);
INSERT INTO valoracions VALUES (285, 63, '12/08/2008', 6);
INSERT INTO valoracions VALUES (285, 110, '14/01/2004', 5);
INSERT INTO valoracions VALUES (286, 73, '16/08/2009', 3);
INSERT INTO valoracions VALUES (286, 101, '01/10/2003', 7);
INSERT INTO valoracions VALUES (287, 26, '13/11/2009', 6);
INSERT INTO valoracions VALUES (287, 101, '13/09/2008', 3);
INSERT INTO valoracions VALUES (287, 12, '31/08/2009', 5);
INSERT INTO valoracions VALUES (287, 59, '03/09/2002', 4);
INSERT INTO valoracions VALUES (288, 80, '29/11/2009', 5);
INSERT INTO valoracions VALUES (288, 25, '16/01/2006', 8);
INSERT INTO valoracions VALUES (288, 2, '21/08/2005', 10);
INSERT INTO valoracions VALUES (288, 29, '19/03/2003', 6);
INSERT INTO valoracions VALUES (289, 16, '06/03/2007', 5);
INSERT INTO valoracions VALUES (289, 92, '23/01/2009', 6);
INSERT INTO valoracions VALUES (289, 14, '09/02/2003', 6);
INSERT INTO valoracions VALUES (289, 85, '18/05/2009', 7);
INSERT INTO valoracions VALUES (289, 13, '29/10/2010', 8);
INSERT INTO valoracions VALUES (290, 56, '23/01/2008', 6);
INSERT INTO valoracions VALUES (290, 111, '19/03/2006', 6);
INSERT INTO valoracions VALUES (290, 42, '17/05/2006', 3);
INSERT INTO valoracions VALUES (290, 66, '19/11/2004', 8);
INSERT INTO valoracions VALUES (290, 46, '07/09/2005', 7);
INSERT INTO valoracions VALUES (290, 20, '20/07/2003', 6);
INSERT INTO valoracions VALUES (290, 18, '10/12/2004', 8);
INSERT INTO valoracions VALUES (291, 63, '06/09/2001', 5);
INSERT INTO valoracions VALUES (291, 52, '26/05/2003', 4);
INSERT INTO valoracions VALUES (292, 71, '30/09/2008', 10);
INSERT INTO valoracions VALUES (292, 93, '09/07/2005', 9);
INSERT INTO valoracions VALUES (292, 96, '03/02/2006', 6);
INSERT INTO valoracions VALUES (293, 46, '26/04/2001', 8);
INSERT INTO valoracions VALUES (293, 52, '25/04/2010', 9);
INSERT INTO valoracions VALUES (293, 13, '06/12/2007', 7);
INSERT INTO valoracions VALUES (293, 19, '14/04/2004', 7);
INSERT INTO valoracions VALUES (293, 79, '27/08/2005', 2);
INSERT INTO valoracions VALUES (293, 10, '09/05/2007', 9);
INSERT INTO valoracions VALUES (294, 33, '20/02/2002', 9);
INSERT INTO valoracions VALUES (294, 15, '30/11/2006', 9);
INSERT INTO valoracions VALUES (294, 87, '01/03/2009', 7);
INSERT INTO valoracions VALUES (294, 33, '30/01/2007', 6);
INSERT INTO valoracions VALUES (294, 3, '18/06/2003', 6);
INSERT INTO valoracions VALUES (294, 116, '18/09/2002', 2);
INSERT INTO valoracions VALUES (295, 113, '23/12/2005', 5);
INSERT INTO valoracions VALUES (295, 82, '29/01/2006', 7);
INSERT INTO valoracions VALUES (296, 48, '15/11/2008', 8);
INSERT INTO valoracions VALUES (296, 22, '19/03/2004', 9);
INSERT INTO valoracions VALUES (296, 3, '10/08/2010', 6);
INSERT INTO valoracions VALUES (296, 37, '23/09/2009', 5);
INSERT INTO valoracions VALUES (296, 80, '19/10/2002', 3);
INSERT INTO valoracions VALUES (296, 47, '08/12/2008', 5);
INSERT INTO valoracions VALUES (296, 112, '03/01/2005', 5);
INSERT INTO valoracions VALUES (296, 95, '02/05/2007', 6);
INSERT INTO valoracions VALUES (297, 83, '04/10/2008', 1);
INSERT INTO valoracions VALUES (297, 115, '06/03/2002', 0);
INSERT INTO valoracions VALUES (297, 92, '22/06/2003', 7);
INSERT INTO valoracions VALUES (297, 7, '18/01/2004', 7);
INSERT INTO valoracions VALUES (298, 47, '18/09/2001', 9);
INSERT INTO valoracions VALUES (298, 111, '03/01/2009', 8);
INSERT INTO valoracions VALUES (299, 22, '29/12/2005', 5);
INSERT INTO valoracions VALUES (299, 30, '06/06/2007', 9);
INSERT INTO valoracions VALUES (299, 96, '06/03/2008', 7);
INSERT INTO valoracions VALUES (299, 40, '22/04/2006', 5);
INSERT INTO valoracions VALUES (300, 56, '19/10/2004', 9);
INSERT INTO valoracions VALUES (300, 16, '23/07/2005', 6);
INSERT INTO valoracions VALUES (300, 14, '30/07/2010', 10);
INSERT INTO valoracions VALUES (301, 43, '30/06/2008', 5);
INSERT INTO valoracions VALUES (301, 41, '21/11/2004', 7);
INSERT INTO valoracions VALUES (302, 6, '19/08/2010', 8);
INSERT INTO valoracions VALUES (302, 32, '20/08/2010', 9);
INSERT INTO valoracions VALUES (302, 106, '19/11/2004', 8);
INSERT INTO valoracions VALUES (302, 47, '03/10/2010', 6);
INSERT INTO valoracions VALUES (302, 72, '22/04/2005', 7);
INSERT INTO valoracions VALUES (302, 6, '31/03/2001', 9);
INSERT INTO valoracions VALUES (303, 91, '15/10/2008', 5);
INSERT INTO valoracions VALUES (303, 98, '15/11/2006', 4);
INSERT INTO valoracions VALUES (303, 24, '09/10/2003', 5);
INSERT INTO valoracions VALUES (303, 56, '17/10/2002', 6);
INSERT INTO valoracions VALUES (304, 29, '15/12/2004', 8);
INSERT INTO valoracions VALUES (304, 66, '29/10/2002', 5);
INSERT INTO valoracions VALUES (304, 53, '08/05/2003', 5);
INSERT INTO valoracions VALUES (304, 53, '06/12/2005', 6);
INSERT INTO valoracions VALUES (304, 25, '10/01/2009', 6);
INSERT INTO valoracions VALUES (304, 98, '02/04/2005', 9);
INSERT INTO valoracions VALUES (305, 85, '14/06/2005', 6);
INSERT INTO valoracions VALUES (305, 51, '17/01/2008', 7);
INSERT INTO valoracions VALUES (305, 3, '12/09/2001', 9);
INSERT INTO valoracions VALUES (305, 84, '26/12/2007', 9);
INSERT INTO valoracions VALUES (305, 49, '06/01/2008', 6);
INSERT INTO valoracions VALUES (305, 64, '16/04/2003', 3);
INSERT INTO valoracions VALUES (306, 58, '25/03/2003', 10);
INSERT INTO valoracions VALUES (306, 88, '19/11/2009', 7);
INSERT INTO valoracions VALUES (307, 53, '28/02/2005', 5);
INSERT INTO valoracions VALUES (307, 110, '07/02/2003', 3);
INSERT INTO valoracions VALUES (307, 31, '15/11/2003', 9);
INSERT INTO valoracions VALUES (307, 26, '17/11/2005', 6);
INSERT INTO valoracions VALUES (307, 32, '13/11/2003', 8);
INSERT INTO valoracions VALUES (307, 35, '07/05/2001', 8);
INSERT INTO valoracions VALUES (308, 97, '25/06/2003', 1);
INSERT INTO valoracions VALUES (308, 113, '15/07/2005', 3);
INSERT INTO valoracions VALUES (308, 35, '10/10/2007', 10);
INSERT INTO valoracions VALUES (308, 106, '14/10/2008', 8);
INSERT INTO valoracions VALUES (308, 55, '12/05/2008', 7);
INSERT INTO valoracions VALUES (308, 93, '12/08/2002', 6);
INSERT INTO valoracions VALUES (309, 16, '26/04/2002', 6);
INSERT INTO valoracions VALUES (309, 73, '14/08/2004', 4);
INSERT INTO valoracions VALUES (309, 92, '26/09/2003', 2);
INSERT INTO valoracions VALUES (309, 85, '05/06/2010', 7);
INSERT INTO valoracions VALUES (309, 59, '20/01/2008', 8);
INSERT INTO valoracions VALUES (309, 105, '22/08/2002', 4);
INSERT INTO valoracions VALUES (309, 83, '03/10/2006', 2);
INSERT INTO valoracions VALUES (309, 55, '01/04/2002', 6);
INSERT INTO valoracions VALUES (311, 37, '02/11/2005', 9);
INSERT INTO valoracions VALUES (311, 12, '08/06/2007', 7);
INSERT INTO valoracions VALUES (311, 13, '15/01/2006', 8);
INSERT INTO valoracions VALUES (311, 103, '27/12/2003', 10);
INSERT INTO valoracions VALUES (311, 22, '14/07/2002', 6);
INSERT INTO valoracions VALUES (311, 38, '11/03/2007', 9);
INSERT INTO valoracions VALUES (312, 73, '18/11/2001', 8);
INSERT INTO valoracions VALUES (312, 74, '07/02/2004', 5);
INSERT INTO valoracions VALUES (312, 35, '17/05/2006', 9);
INSERT INTO valoracions VALUES (312, 40, '09/01/2003', 9);
INSERT INTO valoracions VALUES (313, 74, '02/01/2010', 6);
INSERT INTO valoracions VALUES (313, 108, '18/05/2005', 3);
INSERT INTO valoracions VALUES (313, 44, '07/05/2006', 4);
INSERT INTO valoracions VALUES (313, 95, '12/08/2001', 9);
INSERT INTO valoracions VALUES (313, 19, '13/09/2004', 6);
INSERT INTO valoracions VALUES (313, 47, '12/06/2003', 9);
INSERT INTO valoracions VALUES (313, 72, '06/02/2006', 3);
INSERT INTO valoracions VALUES (314, 113, '17/02/2010', 5);
INSERT INTO valoracions VALUES (315, 18, '19/07/2006', 10);
INSERT INTO valoracions VALUES (315, 10, '20/08/2007', 8);
INSERT INTO valoracions VALUES (315, 88, '08/02/2002', 4);
INSERT INTO valoracions VALUES (315, 72, '01/05/2002', 4);
INSERT INTO valoracions VALUES (315, 88, '12/04/2010', 10);
INSERT INTO valoracions VALUES (316, 83, '01/10/2005', 5);
INSERT INTO valoracions VALUES (316, 103, '06/11/2008', 9);
INSERT INTO valoracions VALUES (316, 109, '18/06/2010', 7);
INSERT INTO valoracions VALUES (316, 36, '23/06/2004', 8);
INSERT INTO valoracions VALUES (316, 100, '24/09/2003', 2);
INSERT INTO valoracions VALUES (317, 44, '03/04/2005', 8);
INSERT INTO valoracions VALUES (317, 107, '21/08/2001', 5);
INSERT INTO valoracions VALUES (317, 30, '10/02/2005', 4);
INSERT INTO valoracions VALUES (317, 45, '02/09/2001', 8);
INSERT INTO valoracions VALUES (317, 104, '09/08/2006', 2);
INSERT INTO valoracions VALUES (317, 76, '22/10/2008', 3);
INSERT INTO valoracions VALUES (317, 77, '03/05/2009', 8);
INSERT INTO valoracions VALUES (317, 62, '06/12/2008', 9);
INSERT INTO valoracions VALUES (317, 74, '01/07/2004', 8);
INSERT INTO valoracions VALUES (318, 38, '13/04/2006', 7);
INSERT INTO valoracions VALUES (318, 77, '09/03/2004', 5);
INSERT INTO valoracions VALUES (318, 65, '25/04/2003', 4);
INSERT INTO valoracions VALUES (319, 47, '17/05/2001', 8);
INSERT INTO valoracions VALUES (319, 83, '27/02/2009', 9);
INSERT INTO valoracions VALUES (319, 21, '15/06/2005', 9);
INSERT INTO valoracions VALUES (319, 1, '22/07/2006', 6);
INSERT INTO valoracions VALUES (320, 3, '08/09/2005', 8);
INSERT INTO valoracions VALUES (320, 116, '07/06/2002', 7);
INSERT INTO valoracions VALUES (320, 79, '28/08/2001', 2);
INSERT INTO valoracions VALUES (320, 45, '08/04/2005', 4);
INSERT INTO valoracions VALUES (320, 63, '08/05/2003', 5);
INSERT INTO valoracions VALUES (320, 83, '31/07/2010', 4);
INSERT INTO valoracions VALUES (320, 77, '30/04/2003', 8);
INSERT INTO valoracions VALUES (321, 99, '08/02/2008', 9);
INSERT INTO valoracions VALUES (321, 44, '07/01/2003', 6);
INSERT INTO valoracions VALUES (322, 94, '20/03/2003', 6);
INSERT INTO valoracions VALUES (322, 107, '24/10/2006', 5);
INSERT INTO valoracions VALUES (322, 78, '09/03/2003', 9);
INSERT INTO valoracions VALUES (322, 68, '28/05/2006', 4);
INSERT INTO valoracions VALUES (323, 26, '30/07/2002', 7);
INSERT INTO valoracions VALUES (323, 74, '10/08/2006', 9);
INSERT INTO valoracions VALUES (323, 5, '20/02/2004', 9);
INSERT INTO valoracions VALUES (323, 28, '12/10/2004', 4);
INSERT INTO valoracions VALUES (323, 2, '01/05/2003', 6);
INSERT INTO valoracions VALUES (324, 9, '31/08/2009', 5);
INSERT INTO valoracions VALUES (324, 90, '07/04/2003', 8);
INSERT INTO valoracions VALUES (324, 36, '03/11/2009', 9);
INSERT INTO valoracions VALUES (324, 67, '01/05/2010', 3);
INSERT INTO valoracions VALUES (325, 68, '10/08/2008', 3);
INSERT INTO valoracions VALUES (325, 65, '01/02/2010', 7);
INSERT INTO valoracions VALUES (325, 110, '08/08/2004', 5);
INSERT INTO valoracions VALUES (326, 24, '28/06/2009', 5);
INSERT INTO valoracions VALUES (326, 115, '04/05/2002', 9);
INSERT INTO valoracions VALUES (327, 51, '06/01/2007', 7);
INSERT INTO valoracions VALUES (327, 37, '20/02/2007', 7);
INSERT INTO valoracions VALUES (327, 110, '18/01/2007', 0);
INSERT INTO valoracions VALUES (327, 20, '05/05/2008', 5);
INSERT INTO valoracions VALUES (328, 78, '12/04/2008', 9);
INSERT INTO valoracions VALUES (329, 57, '25/09/2006', 7);
INSERT INTO valoracions VALUES (329, 104, '29/01/2008', 5);
INSERT INTO valoracions VALUES (330, 80, '08/04/2009', 2);
INSERT INTO valoracions VALUES (330, 24, '19/06/2003', 7);
INSERT INTO valoracions VALUES (330, 112, '29/01/2004', 3);
INSERT INTO valoracions VALUES (331, 49, '14/09/2005', 7);
INSERT INTO valoracions VALUES (331, 33, '02/01/2006', 7);
INSERT INTO valoracions VALUES (332, 92, '12/08/2010', 1);
INSERT INTO valoracions VALUES (332, 9, '29/12/2002', 6);
INSERT INTO valoracions VALUES (332, 87, '18/10/2003', 5);
INSERT INTO valoracions VALUES (332, 103, '24/10/2009', 2);
INSERT INTO valoracions VALUES (332, 87, '05/08/2007', 7);
INSERT INTO valoracions VALUES (332, 114, '20/02/2003', 5);
INSERT INTO valoracions VALUES (332, 94, '17/05/2004', 2);
INSERT INTO valoracions VALUES (332, 72, '30/07/2002', 10);
INSERT INTO valoracions VALUES (332, 65, '27/03/2004', 7);
INSERT INTO valoracions VALUES (333, 20, '23/06/2002', 7);
INSERT INTO valoracions VALUES (333, 105, '04/08/2002', 7);
INSERT INTO valoracions VALUES (333, 107, '06/05/2008', 2);
INSERT INTO valoracions VALUES (333, 98, '11/12/2007', 7);
INSERT INTO valoracions VALUES (333, 34, '06/10/2010', 10);
INSERT INTO valoracions VALUES (334, 41, '01/01/2005', 7);
INSERT INTO valoracions VALUES (334, 101, '24/06/2007', 3);
INSERT INTO valoracions VALUES (334, 45, '17/07/2005', 5);
INSERT INTO valoracions VALUES (334, 111, '25/03/2008', 2);
INSERT INTO valoracions VALUES (334, 50, '24/12/2007', 4);
INSERT INTO valoracions VALUES (334, 45, '18/07/2007', 7);
INSERT INTO valoracions VALUES (335, 28, '21/08/2005', 6);
INSERT INTO valoracions VALUES (335, 114, '18/07/2005', 0);
INSERT INTO valoracions VALUES (335, 76, '10/04/2007', 3);
INSERT INTO valoracions VALUES (336, 84, '19/01/2010', 4);
INSERT INTO valoracions VALUES (336, 59, '12/12/2008', 4);
INSERT INTO valoracions VALUES (336, 86, '07/12/2007', 3);
INSERT INTO valoracions VALUES (336, 38, '19/10/2007', 6);
INSERT INTO valoracions VALUES (337, 3, '25/06/2004', 8);
INSERT INTO valoracions VALUES (337, 4, '12/05/2003', 6);
INSERT INTO valoracions VALUES (337, 52, '02/09/2005', 4);
INSERT INTO valoracions VALUES (337, 98, '26/04/2006', 10);
INSERT INTO valoracions VALUES (337, 15, '09/11/2008', 6);
INSERT INTO valoracions VALUES (338, 82, '19/03/2010', 4);
INSERT INTO valoracions VALUES (338, 50, '22/02/2008', 5);
INSERT INTO valoracions VALUES (338, 13, '13/11/2001', 9);
INSERT INTO valoracions VALUES (338, 30, '09/08/2010', 6);
INSERT INTO valoracions VALUES (338, 95, '31/01/2010', 10);
INSERT INTO valoracions VALUES (338, 101, '06/06/2001', 3);
INSERT INTO valoracions VALUES (339, 62, '09/06/2002', 10);
INSERT INTO valoracions VALUES (339, 114, '25/06/2008', 10);
INSERT INTO valoracions VALUES (339, 74, '12/11/2006', 7);
INSERT INTO valoracions VALUES (339, 19, '30/01/2008', 5);
INSERT INTO valoracions VALUES (340, 5, '01/07/2001', 6);
INSERT INTO valoracions VALUES (340, 111, '01/07/2009', 6);
INSERT INTO valoracions VALUES (340, 3, '26/01/2007', 7);
INSERT INTO valoracions VALUES (340, 20, '15/06/2002', 8);
INSERT INTO valoracions VALUES (340, 57, '16/12/2008', 6);
INSERT INTO valoracions VALUES (341, 109, '09/08/2006', 3);
INSERT INTO valoracions VALUES (341, 8, '21/02/2003', 8);
INSERT INTO valoracions VALUES (341, 5, '14/12/2002', 6);
INSERT INTO valoracions VALUES (342, 99, '24/03/2005', 4);
INSERT INTO valoracions VALUES (342, 32, '26/03/2003', 9);
INSERT INTO valoracions VALUES (343, 17, '16/01/2004', 9);
INSERT INTO valoracions VALUES (343, 90, '09/06/2004', 7);
INSERT INTO valoracions VALUES (343, 79, '15/05/2003', 2);
INSERT INTO valoracions VALUES (343, 15, '25/08/2005', 7);
INSERT INTO valoracions VALUES (343, 25, '19/12/2003', 5);
INSERT INTO valoracions VALUES (343, 39, '02/01/2008', 6);
INSERT INTO valoracions VALUES (343, 21, '07/04/2001', 7);
INSERT INTO valoracions VALUES (344, 110, '25/12/2005', 2);
INSERT INTO valoracions VALUES (344, 26, '30/04/2004', 6);
INSERT INTO valoracions VALUES (345, 78, '23/01/2010', 6);
INSERT INTO valoracions VALUES (346, 22, '08/03/2008', 10);
INSERT INTO valoracions VALUES (346, 30, '14/09/2003', 7);
INSERT INTO valoracions VALUES (347, 64, '26/06/2007', 5);
INSERT INTO valoracions VALUES (347, 113, '11/12/2004', 2);
INSERT INTO valoracions VALUES (347, 109, '19/12/2008', 8);
INSERT INTO valoracions VALUES (349, 85, '04/11/2009', 7);
INSERT INTO valoracions VALUES (349, 7, '06/03/2008', 5);
INSERT INTO valoracions VALUES (349, 75, '21/10/2007', 4);
INSERT INTO valoracions VALUES (349, 55, '26/04/2002', 7);
INSERT INTO valoracions VALUES (350, 26, '31/01/2004', 7);
INSERT INTO valoracions VALUES (350, 88, '04/07/2005', 3);
INSERT INTO valoracions VALUES (351, 20, '07/10/2010', 6);
INSERT INTO valoracions VALUES (351, 2, '07/09/2007', 8);
INSERT INTO valoracions VALUES (351, 59, '23/08/2005', 6);
INSERT INTO valoracions VALUES (351, 69, '09/12/2005', 6);
INSERT INTO valoracions VALUES (352, 89, '27/01/2005', 6);
INSERT INTO valoracions VALUES (354, 59, '19/05/2002', 3);
INSERT INTO valoracions VALUES (354, 61, '01/06/2006', 7);
INSERT INTO valoracions VALUES (354, 48, '05/05/2004', 4);
INSERT INTO valoracions VALUES (354, 26, '16/07/2001', 9);
INSERT INTO valoracions VALUES (354, 46, '16/06/2008', 7);
INSERT INTO valoracions VALUES (355, 113, '30/11/2008', 3);
INSERT INTO valoracions VALUES (355, 25, '16/06/2005', 9);
INSERT INTO valoracions VALUES (355, 102, '29/12/2002', 6);
INSERT INTO valoracions VALUES (356, 103, '02/07/2004', 1);
INSERT INTO valoracions VALUES (356, 85, '01/10/2005', 7);
INSERT INTO valoracions VALUES (356, 116, '26/01/2003', 0);
INSERT INTO valoracions VALUES (356, 61, '12/04/2006', 6);
INSERT INTO valoracions VALUES (356, 81, '24/01/2003', 2);
INSERT INTO valoracions VALUES (357, 62, '22/09/2004', 7);
INSERT INTO valoracions VALUES (357, 47, '23/12/2001', 9);
INSERT INTO valoracions VALUES (357, 27, '05/02/2003', 6);
INSERT INTO valoracions VALUES (357, 18, '30/07/2004', 9);
INSERT INTO valoracions VALUES (357, 31, '30/04/2010', 9);
INSERT INTO valoracions VALUES (358, 60, '12/10/2006', 6);
INSERT INTO valoracions VALUES (358, 3, '29/07/2007', 10);
INSERT INTO valoracions VALUES (358, 34, '14/03/2007', 6);
INSERT INTO valoracions VALUES (358, 92, '01/05/2009', 10);
INSERT INTO valoracions VALUES (358, 67, '08/12/2005', 2);
INSERT INTO valoracions VALUES (358, 74, '02/03/2010', 6);
INSERT INTO valoracions VALUES (359, 100, '26/10/2010', 5);
INSERT INTO valoracions VALUES (359, 100, '17/08/2006', 9);
INSERT INTO valoracions VALUES (360, 72, '08/06/2003', 8);
INSERT INTO valoracions VALUES (360, 38, '14/10/2003', 6);
INSERT INTO valoracions VALUES (360, 104, '10/05/2005', 10);
INSERT INTO valoracions VALUES (361, 100, '31/07/2001', 7);
INSERT INTO valoracions VALUES (361, 15, '20/12/2001', 9);
INSERT INTO valoracions VALUES (361, 108, '03/02/2009', 8);
INSERT INTO valoracions VALUES (361, 9, '01/11/2007', 5);
INSERT INTO valoracions VALUES (362, 62, '07/11/2007', 9);
INSERT INTO valoracions VALUES (362, 44, '24/09/2001', 6);
INSERT INTO valoracions VALUES (362, 52, '28/11/2003', 9);
INSERT INTO valoracions VALUES (362, 35, '13/10/2010', 4);
INSERT INTO valoracions VALUES (363, 92, '22/12/2008', 3);
INSERT INTO valoracions VALUES (363, 58, '16/03/2006', 3);
INSERT INTO valoracions VALUES (363, 11, '25/10/2010', 8);
INSERT INTO valoracions VALUES (363, 110, '31/07/2007', 6);
INSERT INTO valoracions VALUES (364, 7, '27/08/2001', 7);
INSERT INTO valoracions VALUES (364, 10, '07/03/2009', 6);
INSERT INTO valoracions VALUES (365, 55, '13/08/2010', 3);
INSERT INTO valoracions VALUES (365, 41, '17/03/2009', 9);
INSERT INTO valoracions VALUES (365, 25, '08/06/2002', 8);
INSERT INTO valoracions VALUES (365, 65, '08/06/2005', 3);
INSERT INTO valoracions VALUES (366, 39, '20/02/2006', 4);
INSERT INTO valoracions VALUES (366, 72, '24/08/2008', 5);
INSERT INTO valoracions VALUES (366, 108, '02/04/2006', 10);
INSERT INTO valoracions VALUES (366, 79, '24/07/2007', 3);
INSERT INTO valoracions VALUES (366, 62, '21/03/2007', 8);
INSERT INTO valoracions VALUES (367, 40, '24/11/2002', 7);
INSERT INTO valoracions VALUES (367, 65, '03/08/2008', 9);
INSERT INTO valoracions VALUES (367, 34, '06/04/2008', 7);
INSERT INTO valoracions VALUES (368, 65, '05/01/2004', 6);
INSERT INTO valoracions VALUES (368, 22, '18/04/2009', 5);
INSERT INTO valoracions VALUES (368, 71, '09/09/2007', 9);
INSERT INTO valoracions VALUES (369, 99, '27/06/2001', 9);
INSERT INTO valoracions VALUES (369, 91, '21/11/2005', 2);
INSERT INTO valoracions VALUES (369, 55, '06/06/2008', 3);
INSERT INTO valoracions VALUES (371, 103, '21/05/2008', 9);
INSERT INTO valoracions VALUES (371, 44, '29/04/2005', 7);
INSERT INTO valoracions VALUES (371, 20, '07/12/2008', 9);
INSERT INTO valoracions VALUES (371, 49, '18/05/2004', 9);
INSERT INTO valoracions VALUES (371, 45, '09/01/2003', 10);
INSERT INTO valoracions VALUES (372, 75, '24/07/2009', 4);
INSERT INTO valoracions VALUES (372, 90, '19/04/2006', 6);
INSERT INTO valoracions VALUES (373, 94, '03/09/2006', 6);
INSERT INTO valoracions VALUES (373, 31, '10/09/2003', 7);
INSERT INTO valoracions VALUES (373, 27, '06/11/2007', 5);
INSERT INTO valoracions VALUES (374, 109, '27/02/2002', 4);
INSERT INTO valoracions VALUES (374, 52, '09/01/2007', 4);
INSERT INTO valoracions VALUES (374, 2, '05/08/2004', 10);
INSERT INTO valoracions VALUES (374, 85, '19/11/2001', 7);
INSERT INTO valoracions VALUES (374, 63, '12/10/2003', 6);
INSERT INTO valoracions VALUES (375, 67, '02/09/2004', 9);
INSERT INTO valoracions VALUES (376, 100, '11/02/2003', 7);
INSERT INTO valoracions VALUES (377, 62, '11/04/2007', 8);
INSERT INTO valoracions VALUES (377, 99, '29/10/2008', 6);
INSERT INTO valoracions VALUES (378, 95, '20/05/2003', 2);
INSERT INTO valoracions VALUES (378, 26, '04/08/2008', 9);
INSERT INTO valoracions VALUES (378, 68, '20/09/2009', 5);
INSERT INTO valoracions VALUES (379, 28, '27/04/2004', 9);
INSERT INTO valoracions VALUES (379, 84, '05/07/2002', 7);
INSERT INTO valoracions VALUES (379, 99, '25/06/2010', 6);
INSERT INTO valoracions VALUES (379, 6, '13/12/2003', 9);
INSERT INTO valoracions VALUES (380, 58, '04/12/2006', 7);
INSERT INTO valoracions VALUES (380, 51, '20/06/2005', 8);
INSERT INTO valoracions VALUES (380, 109, '25/11/2006', 7);
INSERT INTO valoracions VALUES (380, 10, '04/01/2009', 9);
INSERT INTO valoracions VALUES (380, 66, '19/01/2007', 8);
INSERT INTO valoracions VALUES (380, 36, '24/04/2010', 4);
INSERT INTO valoracions VALUES (381, 77, '15/09/2008', 8);
INSERT INTO valoracions VALUES (381, 43, '12/12/2001', 7);
INSERT INTO valoracions VALUES (381, 2, '02/05/2006', 10);
INSERT INTO valoracions VALUES (382, 59, '15/02/2009', 5);
INSERT INTO valoracions VALUES (382, 23, '17/05/2010', 9);
INSERT INTO valoracions VALUES (382, 15, '28/12/2001', 6);
INSERT INTO valoracions VALUES (382, 40, '29/08/2008', 6);
INSERT INTO valoracions VALUES (383, 76, '27/08/2009', 8);
INSERT INTO valoracions VALUES (383, 44, '24/08/2007', 3);
INSERT INTO valoracions VALUES (383, 15, '15/04/2007', 8);
INSERT INTO valoracions VALUES (384, 26, '05/09/2004', 7);
INSERT INTO valoracions VALUES (384, 13, '24/07/2008', 6);
INSERT INTO valoracions VALUES (384, 4, '09/06/2007', 9);
INSERT INTO valoracions VALUES (385, 56, '23/01/2010', 9);
INSERT INTO valoracions VALUES (385, 20, '17/03/2004', 7);
INSERT INTO valoracions VALUES (385, 97, '26/10/2009', 6);
INSERT INTO valoracions VALUES (385, 116, '06/02/2007', 2);
INSERT INTO valoracions VALUES (385, 46, '06/01/2005', 9);
INSERT INTO valoracions VALUES (386, 66, '29/12/2008', 6);
INSERT INTO valoracions VALUES (387, 22, '02/09/2005', 8);
INSERT INTO valoracions VALUES (387, 92, '17/09/2005', 3);
INSERT INTO valoracions VALUES (388, 76, '10/12/2006', 10);
INSERT INTO valoracions VALUES (388, 65, '13/06/2006', 7);
INSERT INTO valoracions VALUES (388, 100, '04/03/2002', 2);
INSERT INTO valoracions VALUES (388, 81, '14/03/2003', 9);
INSERT INTO valoracions VALUES (389, 63, '27/11/2009', 4);
INSERT INTO valoracions VALUES (389, 56, '26/10/2010', 5);
INSERT INTO valoracions VALUES (389, 94, '12/08/2003', 10);
INSERT INTO valoracions VALUES (390, 48, '19/07/2001', 4);
INSERT INTO valoracions VALUES (390, 78, '21/02/2010', 8);
INSERT INTO valoracions VALUES (390, 5, '05/08/2001', 9);
INSERT INTO valoracions VALUES (391, 106, '10/09/2002', 3);
INSERT INTO valoracions VALUES (391, 88, '01/04/2002', 3);
INSERT INTO valoracions VALUES (391, 27, '04/07/2009', 5);
INSERT INTO valoracions VALUES (391, 98, '13/03/2004', 8);
INSERT INTO valoracions VALUES (392, 1, '05/10/2001', 6);
INSERT INTO valoracions VALUES (392, 63, '22/10/2004', 7);
INSERT INTO valoracions VALUES (392, 27, '09/12/2003', 9);
INSERT INTO valoracions VALUES (392, 19, '03/10/2009', 9);
INSERT INTO valoracions VALUES (393, 5, '27/10/2004', 9);
INSERT INTO valoracions VALUES (393, 56, '16/11/2004', 5);
INSERT INTO valoracions VALUES (393, 80, '19/07/2005', 2);
INSERT INTO valoracions VALUES (394, 108, '06/07/2004', 6);
INSERT INTO valoracions VALUES (394, 111, '29/10/2003', 7);
INSERT INTO valoracions VALUES (394, 60, '27/11/2002', 7);
INSERT INTO valoracions VALUES (395, 18, '01/12/2009', 5);
INSERT INTO valoracions VALUES (395, 68, '12/09/2007', 6);
INSERT INTO valoracions VALUES (395, 23, '27/10/2006', 5);
INSERT INTO valoracions VALUES (395, 100, '06/02/2002', 8);
INSERT INTO valoracions VALUES (396, 26, '08/02/2003', 5);
INSERT INTO valoracions VALUES (396, 24, '29/10/2009', 8);
INSERT INTO valoracions VALUES (396, 25, '26/11/2003', 8);
INSERT INTO valoracions VALUES (396, 77, '13/05/2009', 7);
INSERT INTO valoracions VALUES (397, 5, '30/10/2010', 5);
INSERT INTO valoracions VALUES (397, 25, '26/04/2001', 9);
INSERT INTO valoracions VALUES (397, 112, '03/06/2001', 0);
INSERT INTO valoracions VALUES (398, 7, '11/05/2010', 7);
INSERT INTO valoracions VALUES (398, 48, '09/01/2010', 6);
INSERT INTO valoracions VALUES (398, 16, '16/02/2002', 9);
INSERT INTO valoracions VALUES (398, 76, '01/08/2004', 8);
INSERT INTO valoracions VALUES (398, 113, '18/05/2008', 8);
INSERT INTO valoracions VALUES (398, 61, '05/07/2006', 10);
INSERT INTO valoracions VALUES (399, 31, '23/02/2007', 6);
INSERT INTO valoracions VALUES (399, 11, '09/02/2009', 8);
INSERT INTO valoracions VALUES (399, 18, '06/04/2003', 7);
INSERT INTO valoracions VALUES (400, 83, '23/03/2006', 2);
INSERT INTO valoracions VALUES (400, 32, '09/03/2002', 6);
INSERT INTO valoracions VALUES (400, 15, '13/01/2003', 7);
INSERT INTO valoracions VALUES (402, 16, '16/06/2010', 9);
INSERT INTO valoracions VALUES (403, 22, '20/10/2006', 4);
INSERT INTO valoracions VALUES (403, 70, '11/04/2009', 4);
INSERT INTO valoracions VALUES (403, 85, '30/07/2009', 7);
INSERT INTO valoracions VALUES (404, 55, '27/08/2008', 10);
INSERT INTO valoracions VALUES (405, 25, '07/01/2005', 10);
INSERT INTO valoracions VALUES (405, 71, '16/05/2003', 5);
INSERT INTO valoracions VALUES (406, 110, '01/04/2010', 0);
INSERT INTO valoracions VALUES (406, 64, '27/06/2006', 5);
INSERT INTO valoracions VALUES (406, 53, '23/02/2004', 9);
INSERT INTO valoracions VALUES (406, 97, '02/05/2008', 10);
INSERT INTO valoracions VALUES (407, 88, '25/08/2005', 3);
INSERT INTO valoracions VALUES (408, 84, '16/05/2004', 4);
INSERT INTO valoracions VALUES (408, 116, '10/01/2007', 8);
INSERT INTO valoracions VALUES (408, 111, '23/05/2007', 8);
INSERT INTO valoracions VALUES (408, 12, '20/02/2006', 6);
INSERT INTO valoracions VALUES (409, 14, '29/06/2003', 5);
INSERT INTO valoracions VALUES (409, 48, '27/11/2003', 4);
INSERT INTO valoracions VALUES (410, 99, '04/08/2003', 1);
INSERT INTO valoracions VALUES (410, 58, '18/10/2008', 5);
INSERT INTO valoracions VALUES (410, 20, '18/01/2003', 9);
INSERT INTO valoracions VALUES (410, 73, '23/09/2002', 9);
INSERT INTO valoracions VALUES (410, 7, '06/03/2006', 5);
INSERT INTO valoracions VALUES (410, 106, '13/03/2006', 6);
INSERT INTO valoracions VALUES (411, 114, '25/08/2004', 1);
INSERT INTO valoracions VALUES (412, 31, '18/05/2006', 9);
INSERT INTO valoracions VALUES (412, 23, '24/12/2007', 7);
INSERT INTO valoracions VALUES (412, 14, '16/06/2008', 5);
INSERT INTO valoracions VALUES (412, 14, '14/08/2002', 9);
INSERT INTO valoracions VALUES (412, 87, '29/12/2001', 5);
INSERT INTO valoracions VALUES (413, 70, '13/05/2006', 5);
INSERT INTO valoracions VALUES (413, 28, '07/11/2004', 6);
INSERT INTO valoracions VALUES (413, 66, '31/05/2010', 8);
INSERT INTO valoracions VALUES (413, 95, '10/12/2008', 5);
INSERT INTO valoracions VALUES (414, 8, '31/12/2009', 9);
INSERT INTO valoracions VALUES (414, 60, '04/08/2002', 8);
INSERT INTO valoracions VALUES (414, 34, '04/04/2004', 7);
INSERT INTO valoracions VALUES (414, 97, '18/04/2010', 8);
INSERT INTO valoracions VALUES (415, 59, '03/10/2009', 8);
INSERT INTO valoracions VALUES (415, 13, '01/08/2008', 9);
INSERT INTO valoracions VALUES (415, 74, '11/04/2004', 6);
INSERT INTO valoracions VALUES (415, 49, '04/03/2004', 10);
INSERT INTO valoracions VALUES (416, 31, '05/04/2006', 10);
INSERT INTO valoracions VALUES (416, 50, '21/05/2007', 6);
INSERT INTO valoracions VALUES (416, 95, '25/08/2004', 5);
INSERT INTO valoracions VALUES (416, 29, '20/05/2002', 10);
INSERT INTO valoracions VALUES (416, 36, '30/04/2004', 6);
INSERT INTO valoracions VALUES (417, 12, '01/09/2008', 7);
INSERT INTO valoracions VALUES (417, 19, '19/09/2007', 6);
INSERT INTO valoracions VALUES (417, 99, '05/07/2004', 3);
INSERT INTO valoracions VALUES (417, 39, '26/10/2004', 8);
INSERT INTO valoracions VALUES (417, 83, '14/04/2001', 1);
INSERT INTO valoracions VALUES (417, 25, '25/04/2006', 6);
INSERT INTO valoracions VALUES (418, 52, '06/10/2003', 6);
INSERT INTO valoracions VALUES (419, 45, '09/10/2003', 9);
INSERT INTO valoracions VALUES (419, 10, '16/06/2007', 5);
INSERT INTO valoracions VALUES (419, 66, '30/04/2010', 7);
INSERT INTO valoracions VALUES (419, 92, '19/03/2010', 6);
INSERT INTO valoracions VALUES (419, 71, '10/02/2010', 5);
INSERT INTO valoracions VALUES (419, 32, '20/04/2007', 6);
INSERT INTO valoracions VALUES (419, 6, '08/04/2001', 6);
INSERT INTO valoracions VALUES (420, 81, '08/03/2009', 8);
INSERT INTO valoracions VALUES (420, 108, '30/01/2008', 3);
INSERT INTO valoracions VALUES (420, 46, '11/05/2004', 5);
INSERT INTO valoracions VALUES (420, 51, '03/05/2002', 9);
INSERT INTO valoracions VALUES (421, 86, '27/11/2007', 5);
INSERT INTO valoracions VALUES (421, 64, '21/12/2004', 8);
INSERT INTO valoracions VALUES (422, 28, '31/10/2002', 8);
INSERT INTO valoracions VALUES (422, 5, '08/05/2002', 9);
INSERT INTO valoracions VALUES (422, 103, '24/11/2009', 5);
INSERT INTO valoracions VALUES (423, 70, '10/12/2004', 10);
INSERT INTO valoracions VALUES (423, 48, '31/01/2004', 5);
INSERT INTO valoracions VALUES (423, 7, '02/07/2002', 7);
INSERT INTO valoracions VALUES (423, 28, '12/06/2009', 9);
INSERT INTO valoracions VALUES (423, 31, '01/09/2009', 6);
INSERT INTO valoracions VALUES (424, 96, '10/06/2008', 9);
INSERT INTO valoracions VALUES (424, 26, '28/01/2006', 5);
INSERT INTO valoracions VALUES (424, 90, '08/03/2009', 8);
INSERT INTO valoracions VALUES (424, 65, '11/12/2001', 8);
INSERT INTO valoracions VALUES (425, 72, '17/04/2001', 8);
INSERT INTO valoracions VALUES (425, 70, '12/06/2004', 4);
INSERT INTO valoracions VALUES (425, 1, '15/02/2006', 7);
INSERT INTO valoracions VALUES (425, 5, '15/08/2006', 8);
INSERT INTO valoracions VALUES (425, 22, '11/04/2009', 6);
INSERT INTO valoracions VALUES (426, 10, '27/10/2002', 8);
INSERT INTO valoracions VALUES (426, 16, '09/08/2001', 7);
INSERT INTO valoracions VALUES (426, 24, '28/04/2002', 8);
INSERT INTO valoracions VALUES (426, 102, '03/03/2006', 3);
INSERT INTO valoracions VALUES (426, 98, '04/05/2006', 8);
INSERT INTO valoracions VALUES (426, 109, '03/05/2004', 4);
INSERT INTO valoracions VALUES (427, 95, '06/03/2004', 6);
INSERT INTO valoracions VALUES (427, 3, '13/02/2003', 8);
INSERT INTO valoracions VALUES (428, 22, '22/07/2009', 4);
INSERT INTO valoracions VALUES (428, 79, '14/12/2009', 4);
INSERT INTO valoracions VALUES (428, 23, '17/01/2006', 4);
INSERT INTO valoracions VALUES (428, 61, '08/01/2006', 6);
INSERT INTO valoracions VALUES (428, 5, '27/02/2004', 5);
INSERT INTO valoracions VALUES (429, 80, '25/09/2010', 6);
INSERT INTO valoracions VALUES (429, 64, '06/09/2008', 7);
INSERT INTO valoracions VALUES (430, 8, '18/02/2003', 9);
INSERT INTO valoracions VALUES (430, 54, '23/04/2002', 5);
INSERT INTO valoracions VALUES (430, 57, '17/04/2003', 8);
INSERT INTO valoracions VALUES (430, 24, '29/10/2007', 9);
INSERT INTO valoracions VALUES (430, 41, '04/11/2005', 7);
INSERT INTO valoracions VALUES (431, 77, '18/08/2003', 7);
INSERT INTO valoracions VALUES (431, 75, '12/10/2005', 3);
INSERT INTO valoracions VALUES (431, 72, '22/05/2001', 3);
INSERT INTO valoracions VALUES (431, 29, '21/12/2005', 6);
INSERT INTO valoracions VALUES (431, 74, '08/08/2004', 8);
INSERT INTO valoracions VALUES (432, 99, '05/07/2002', 1);
INSERT INTO valoracions VALUES (432, 38, '24/09/2004', 9);
INSERT INTO valoracions VALUES (432, 32, '22/04/2009', 6);
INSERT INTO valoracions VALUES (432, 1, '19/09/2009', 6);
INSERT INTO valoracions VALUES (432, 96, '06/03/2005', 4);
INSERT INTO valoracions VALUES (432, 19, '14/11/2005', 5);
INSERT INTO valoracions VALUES (432, 24, '31/01/2007', 5);
INSERT INTO valoracions VALUES (432, 94, '15/09/2010', 2);
INSERT INTO valoracions VALUES (433, 84, '15/04/2002', 7);
INSERT INTO valoracions VALUES (433, 50, '20/11/2006', 8);
INSERT INTO valoracions VALUES (433, 77, '01/08/2008', 4);
INSERT INTO valoracions VALUES (433, 112, '13/10/2006', 8);
INSERT INTO valoracions VALUES (434, 72, '24/08/2002', 7);
INSERT INTO valoracions VALUES (434, 31, '02/06/2006', 8);
INSERT INTO valoracions VALUES (434, 96, '09/09/2007', 4);
INSERT INTO valoracions VALUES (434, 61, '10/06/2006', 8);
INSERT INTO valoracions VALUES (435, 61, '26/03/2004', 4);
INSERT INTO valoracions VALUES (435, 29, '20/12/2009', 6);
INSERT INTO valoracions VALUES (435, 51, '29/01/2004', 6);
INSERT INTO valoracions VALUES (435, 79, '22/08/2004', 8);
INSERT INTO valoracions VALUES (435, 86, '22/11/2003', 2);
INSERT INTO valoracions VALUES (435, 81, '17/11/2007', 7);
INSERT INTO valoracions VALUES (435, 47, '21/09/2009', 5);
INSERT INTO valoracions VALUES (436, 54, '16/07/2004', 3);
INSERT INTO valoracions VALUES (436, 87, '11/12/2005', 6);
INSERT INTO valoracions VALUES (436, 16, '19/01/2008', 9);
INSERT INTO valoracions VALUES (436, 104, '10/03/2003', 7);
INSERT INTO valoracions VALUES (437, 44, '03/04/2002', 5);
INSERT INTO valoracions VALUES (437, 37, '11/01/2008', 7);
INSERT INTO valoracions VALUES (437, 62, '01/12/2001', 8);
INSERT INTO valoracions VALUES (437, 37, '21/12/2004', 10);
INSERT INTO valoracions VALUES (437, 57, '27/01/2010', 6);
INSERT INTO valoracions VALUES (437, 8, '31/05/2010', 9);
INSERT INTO valoracions VALUES (437, 90, '30/12/2003', 9);
INSERT INTO valoracions VALUES (438, 69, '19/04/2006', 5);
INSERT INTO valoracions VALUES (438, 2, '22/12/2005', 6);
INSERT INTO valoracions VALUES (438, 34, '18/07/2006', 10);
INSERT INTO valoracions VALUES (438, 100, '30/07/2003', 6);
INSERT INTO valoracions VALUES (438, 56, '01/05/2003', 4);
INSERT INTO valoracions VALUES (438, 44, '01/07/2004', 5);
INSERT INTO valoracions VALUES (438, 48, '29/09/2004', 9);
INSERT INTO valoracions VALUES (438, 11, '21/06/2006', 6);
INSERT INTO valoracions VALUES (439, 14, '03/06/2002', 8);
INSERT INTO valoracions VALUES (439, 85, '16/01/2008', 4);
INSERT INTO valoracions VALUES (439, 28, '15/07/2008', 9);
INSERT INTO valoracions VALUES (440, 109, '29/11/2009', 8);
INSERT INTO valoracions VALUES (440, 31, '06/09/2010', 6);
INSERT INTO valoracions VALUES (440, 48, '09/10/2002', 6);
INSERT INTO valoracions VALUES (440, 71, '08/11/2003', 8);
INSERT INTO valoracions VALUES (440, 101, '14/02/2004', 5);
INSERT INTO valoracions VALUES (440, 113, '28/06/2006', 9);
INSERT INTO valoracions VALUES (440, 14, '15/03/2007', 6);
INSERT INTO valoracions VALUES (440, 9, '13/11/2007', 8);
INSERT INTO valoracions VALUES (440, 54, '19/05/2004', 3);
INSERT INTO valoracions VALUES (441, 65, '08/08/2001', 7);
INSERT INTO valoracions VALUES (441, 65, '08/05/2004', 4);
INSERT INTO valoracions VALUES (441, 2, '23/11/2005', 7);
INSERT INTO valoracions VALUES (441, 61, '19/06/2009', 8);
INSERT INTO valoracions VALUES (442, 27, '05/02/2009', 4);
INSERT INTO valoracions VALUES (442, 83, '09/10/2007', 5);
INSERT INTO valoracions VALUES (442, 80, '12/04/2010', 7);
INSERT INTO valoracions VALUES (442, 19, '04/12/2008', 5);
INSERT INTO valoracions VALUES (442, 39, '03/09/2001', 7);
INSERT INTO valoracions VALUES (442, 91, '12/10/2005', 5);
INSERT INTO valoracions VALUES (442, 74, '24/10/2003', 4);
INSERT INTO valoracions VALUES (442, 98, '31/03/2006', 6);
INSERT INTO valoracions VALUES (443, 44, '08/07/2001', 5);
INSERT INTO valoracions VALUES (443, 83, '05/08/2001', 6);
INSERT INTO valoracions VALUES (443, 41, '28/10/2008', 8);
INSERT INTO valoracions VALUES (444, 76, '30/01/2003', 8);
INSERT INTO valoracions VALUES (444, 115, '07/05/2007', 4);
INSERT INTO valoracions VALUES (444, 66, '19/07/2010', 6);
INSERT INTO valoracions VALUES (445, 6, '13/02/2005', 7);
INSERT INTO valoracions VALUES (445, 47, '12/10/2009', 7);
INSERT INTO valoracions VALUES (445, 23, '02/08/2008', 4);
INSERT INTO valoracions VALUES (445, 32, '29/03/2004', 9);
INSERT INTO valoracions VALUES (445, 57, '24/04/2003', 5);
INSERT INTO valoracions VALUES (446, 69, '29/07/2002', 8);
INSERT INTO valoracions VALUES (446, 103, '11/03/2010', 6);
INSERT INTO valoracions VALUES (446, 107, '02/09/2001', 10);
INSERT INTO valoracions VALUES (447, 37, '09/10/2006', 5);
INSERT INTO valoracions VALUES (447, 72, '06/10/2001', 2);
INSERT INTO valoracions VALUES (447, 45, '23/07/2009', 7);
INSERT INTO valoracions VALUES (447, 49, '25/07/2004', 4);
INSERT INTO valoracions VALUES (448, 45, '23/02/2003', 9);
INSERT INTO valoracions VALUES (448, 33, '13/12/2007', 5);
INSERT INTO valoracions VALUES (449, 115, '20/02/2003', 7);
INSERT INTO valoracions VALUES (450, 88, '03/04/2005', 2);
INSERT INTO valoracions VALUES (450, 29, '20/12/2004', 8);
INSERT INTO valoracions VALUES (450, 41, '06/03/2004', 6);
INSERT INTO valoracions VALUES (450, 40, '13/06/2004', 9);
INSERT INTO valoracions VALUES (451, 28, '13/05/2005', 5);
INSERT INTO valoracions VALUES (451, 40, '17/09/2001', 5);
INSERT INTO valoracions VALUES (451, 21, '24/08/2005', 5);
INSERT INTO valoracions VALUES (451, 46, '01/06/2002', 3);
INSERT INTO valoracions VALUES (451, 71, '20/11/2005', 8);
INSERT INTO valoracions VALUES (452, 12, '31/01/2002', 8);
INSERT INTO valoracions VALUES (452, 38, '10/11/2003', 5);
INSERT INTO valoracions VALUES (452, 59, '13/02/2007', 9);
INSERT INTO valoracions VALUES (453, 72, '06/11/2006', 9);
INSERT INTO valoracions VALUES (453, 94, '02/02/2003', 6);
INSERT INTO valoracions VALUES (453, 75, '24/07/2005', 6);
INSERT INTO valoracions VALUES (453, 16, '28/04/2006', 9);
INSERT INTO valoracions VALUES (454, 35, '08/09/2005', 5);
INSERT INTO valoracions VALUES (454, 20, '15/02/2003', 6);
INSERT INTO valoracions VALUES (454, 69, '03/03/2004', 4);
INSERT INTO valoracions VALUES (454, 104, '27/11/2004', 8);
INSERT INTO valoracions VALUES (455, 75, '20/01/2002', 8);
INSERT INTO valoracions VALUES (455, 18, '06/10/2010', 5);
INSERT INTO valoracions VALUES (455, 43, '11/08/2001', 6);
INSERT INTO valoracions VALUES (455, 94, '01/08/2009', 4);
INSERT INTO valoracions VALUES (456, 67, '21/12/2004', 4);
INSERT INTO valoracions VALUES (456, 60, '11/04/2007', 8);
INSERT INTO valoracions VALUES (456, 58, '25/06/2007', 5);
INSERT INTO valoracions VALUES (456, 54, '11/08/2005', 6);
INSERT INTO valoracions VALUES (458, 81, '26/11/2005', 6);
INSERT INTO valoracions VALUES (459, 47, '07/07/2008', 5);
INSERT INTO valoracions VALUES (459, 102, '18/05/2002', 4);
INSERT INTO valoracions VALUES (459, 84, '27/09/2009', 7);
INSERT INTO valoracions VALUES (459, 93, '02/02/2009', 10);
INSERT INTO valoracions VALUES (459, 47, '22/06/2002', 4);
INSERT INTO valoracions VALUES (460, 20, '15/12/2004', 6);
INSERT INTO valoracions VALUES (460, 105, '14/01/2006', 8);
INSERT INTO valoracions VALUES (461, 27, '08/12/2009', 6);
INSERT INTO valoracions VALUES (461, 5, '12/01/2003', 5);
INSERT INTO valoracions VALUES (461, 67, '02/12/2004', 4);
INSERT INTO valoracions VALUES (462, 5, '03/09/2004', 8);
INSERT INTO valoracions VALUES (462, 108, '22/05/2008', 5);
INSERT INTO valoracions VALUES (462, 107, '29/03/2010', 9);
INSERT INTO valoracions VALUES (462, 32, '16/09/2006', 5);
INSERT INTO valoracions VALUES (462, 100, '09/10/2004', 6);
INSERT INTO valoracions VALUES (463, 75, '30/06/2007', 4);
INSERT INTO valoracions VALUES (463, 33, '08/06/2008', 6);
INSERT INTO valoracions VALUES (463, 51, '18/06/2001', 6);
INSERT INTO valoracions VALUES (463, 80, '23/06/2002', 9);
INSERT INTO valoracions VALUES (463, 10, '27/02/2006', 7);
INSERT INTO valoracions VALUES (463, 75, '14/12/2006', 9);
INSERT INTO valoracions VALUES (463, 64, '24/02/2008', 5);
INSERT INTO valoracions VALUES (464, 33, '24/05/2002', 9);
INSERT INTO valoracions VALUES (464, 20, '04/05/2009', 9);
INSERT INTO valoracions VALUES (465, 52, '01/10/2002', 6);
INSERT INTO valoracions VALUES (465, 74, '12/03/2006', 6);
INSERT INTO valoracions VALUES (465, 13, '20/11/2003', 10);
INSERT INTO valoracions VALUES (465, 24, '26/08/2007', 7);
INSERT INTO valoracions VALUES (466, 91, '10/12/2007', 6);
INSERT INTO valoracions VALUES (466, 35, '22/08/2008', 9);
INSERT INTO valoracions VALUES (466, 81, '04/02/2009', 5);
INSERT INTO valoracions VALUES (466, 17, '16/02/2003', 4);
INSERT INTO valoracions VALUES (466, 62, '30/06/2006', 4);
INSERT INTO valoracions VALUES (467, 22, '20/03/2008', 5);
INSERT INTO valoracions VALUES (467, 22, '23/01/2002', 7);
INSERT INTO valoracions VALUES (467, 22, '18/07/2010', 8);
INSERT INTO valoracions VALUES (468, 20, '06/03/2003', 7);
INSERT INTO valoracions VALUES (468, 34, '20/01/2002', 9);
INSERT INTO valoracions VALUES (468, 24, '27/08/2001', 8);
INSERT INTO valoracions VALUES (468, 31, '09/04/2009', 9);
INSERT INTO valoracions VALUES (468, 16, '25/02/2002', 7);
INSERT INTO valoracions VALUES (469, 29, '07/10/2010', 7);
INSERT INTO valoracions VALUES (469, 52, '09/01/2007', 4);
INSERT INTO valoracions VALUES (470, 111, '25/10/2010', 8);
INSERT INTO valoracions VALUES (470, 53, '07/07/2002', 6);
INSERT INTO valoracions VALUES (470, 2, '03/08/2006', 7);
INSERT INTO valoracions VALUES (471, 5, '04/08/2001', 6);
INSERT INTO valoracions VALUES (471, 108, '09/09/2006', 9);
INSERT INTO valoracions VALUES (471, 18, '31/01/2010', 5);
INSERT INTO valoracions VALUES (472, 100, '31/07/2004', 8);
INSERT INTO valoracions VALUES (472, 115, '19/09/2001', 2);
INSERT INTO valoracions VALUES (472, 57, '28/09/2008', 8);
INSERT INTO valoracions VALUES (472, 115, '05/11/2008', 6);
INSERT INTO valoracions VALUES (472, 7, '11/08/2006', 9);
INSERT INTO valoracions VALUES (472, 79, '04/01/2008', 7);
INSERT INTO valoracions VALUES (472, 36, '27/06/2003', 9);
INSERT INTO valoracions VALUES (473, 46, '23/07/2003', 4);
INSERT INTO valoracions VALUES (473, 74, '23/05/2005', 3);
INSERT INTO valoracions VALUES (473, 16, '23/12/2006', 6);
INSERT INTO valoracions VALUES (473, 19, '29/03/2007', 5);
INSERT INTO valoracions VALUES (474, 49, '08/02/2007', 6);
INSERT INTO valoracions VALUES (474, 108, '27/07/2002', 6);
INSERT INTO valoracions VALUES (474, 102, '11/04/2001', 8);
INSERT INTO valoracions VALUES (474, 67, '02/05/2008', 10);
INSERT INTO valoracions VALUES (474, 104, '29/05/2004', 3);
INSERT INTO valoracions VALUES (474, 8, '06/05/2002', 7);
INSERT INTO valoracions VALUES (475, 98, '24/11/2007', 4);
INSERT INTO valoracions VALUES (475, 46, '09/04/2006', 5);
INSERT INTO valoracions VALUES (476, 40, '15/12/2007', 7);
INSERT INTO valoracions VALUES (476, 103, '13/10/2004', 2);
INSERT INTO valoracions VALUES (476, 8, '25/06/2005', 9);
INSERT INTO valoracions VALUES (477, 27, '18/03/2010', 10);
INSERT INTO valoracions VALUES (477, 9, '18/03/2006', 6);
INSERT INTO valoracions VALUES (478, 36, '31/12/2009', 6);
INSERT INTO valoracions VALUES (478, 32, '22/07/2010', 7);
INSERT INTO valoracions VALUES (478, 54, '26/11/2009', 8);
INSERT INTO valoracions VALUES (478, 93, '12/06/2008', 6);
INSERT INTO valoracions VALUES (479, 24, '23/02/2005', 5);
INSERT INTO valoracions VALUES (479, 92, '26/07/2001', 7);
INSERT INTO valoracions VALUES (480, 92, '17/10/2005', 4);
INSERT INTO valoracions VALUES (480, 68, '30/03/2006', 6);
INSERT INTO valoracions VALUES (480, 110, '24/06/2001', 7);
INSERT INTO valoracions VALUES (481, 5, '14/05/2004', 7);
INSERT INTO valoracions VALUES (481, 11, '18/11/2007', 8);
INSERT INTO valoracions VALUES (481, 17, '21/05/2010', 6);
INSERT INTO valoracions VALUES (481, 1, '12/12/2007', 7);
INSERT INTO valoracions VALUES (482, 71, '20/10/2002', 7);
INSERT INTO valoracions VALUES (482, 25, '29/02/2004', 5);
INSERT INTO valoracions VALUES (482, 59, '16/07/2001', 9);
INSERT INTO valoracions VALUES (482, 35, '16/08/2001', 5);
INSERT INTO valoracions VALUES (482, 37, '30/03/2008', 7);
INSERT INTO valoracions VALUES (482, 39, '06/05/2009', 8);
INSERT INTO valoracions VALUES (483, 30, '29/04/2010', 9);
INSERT INTO valoracions VALUES (483, 5, '14/01/2003', 7);
INSERT INTO valoracions VALUES (483, 108, '11/06/2001', 3);
INSERT INTO valoracions VALUES (483, 62, '07/11/2009', 4);
INSERT INTO valoracions VALUES (483, 76, '08/06/2003', 5);
INSERT INTO valoracions VALUES (483, 34, '22/05/2007', 4);
INSERT INTO valoracions VALUES (484, 62, '13/07/2009', 5);
INSERT INTO valoracions VALUES (484, 89, '31/12/2008', 4);
INSERT INTO valoracions VALUES (484, 116, '18/06/2009', 1);
INSERT INTO valoracions VALUES (484, 2, '27/03/2006', 9);
INSERT INTO valoracions VALUES (484, 13, '31/05/2004', 8);
INSERT INTO valoracions VALUES (485, 115, '02/08/2004', 8);
INSERT INTO valoracions VALUES (485, 35, '15/09/2006', 4);
INSERT INTO valoracions VALUES (486, 36, '04/09/2003', 9);
INSERT INTO valoracions VALUES (486, 15, '04/07/2009', 7);
INSERT INTO valoracions VALUES (487, 63, '23/02/2010', 8);
INSERT INTO valoracions VALUES (487, 17, '07/08/2002', 7);
INSERT INTO valoracions VALUES (487, 111, '20/12/2002', 1);
INSERT INTO valoracions VALUES (487, 76, '08/01/2004', 7);
INSERT INTO valoracions VALUES (488, 60, '25/05/2010', 9);
INSERT INTO valoracions VALUES (488, 67, '27/04/2005', 8);
INSERT INTO valoracions VALUES (488, 105, '31/03/2007', 3);
INSERT INTO valoracions VALUES (488, 82, '30/09/2007', 5);
INSERT INTO valoracions VALUES (488, 92, '09/11/2006', 5);
INSERT INTO valoracions VALUES (488, 4, '22/01/2006', 9);
INSERT INTO valoracions VALUES (488, 47, '21/07/2007', 9);
INSERT INTO valoracions VALUES (488, 26, '22/05/2004', 6);
INSERT INTO valoracions VALUES (488, 21, '31/03/2008', 5);
INSERT INTO valoracions VALUES (490, 75, '11/11/2006', 9);
INSERT INTO valoracions VALUES (490, 56, '21/06/2008', 9);
INSERT INTO valoracions VALUES (490, 37, '21/03/2002', 4);
INSERT INTO valoracions VALUES (490, 68, '29/05/2003', 8);
INSERT INTO valoracions VALUES (491, 42, '29/06/2002', 9);
INSERT INTO valoracions VALUES (491, 113, '17/01/2006', 8);
INSERT INTO valoracions VALUES (491, 90, '02/01/2003', 9);
INSERT INTO valoracions VALUES (491, 26, '23/06/2006', 9);
INSERT INTO valoracions VALUES (491, 96, '03/12/2008', 5);
INSERT INTO valoracions VALUES (492, 91, '26/07/2001', 7);
INSERT INTO valoracions VALUES (492, 88, '06/12/2006', 8);
INSERT INTO valoracions VALUES (493, 87, '17/01/2002', 4);
INSERT INTO valoracions VALUES (493, 38, '02/02/2009', 4);
INSERT INTO valoracions VALUES (493, 88, '05/03/2003', 6);
INSERT INTO valoracions VALUES (494, 67, '02/05/2008', 8);
INSERT INTO valoracions VALUES (494, 56, '19/07/2003', 4);
INSERT INTO valoracions VALUES (494, 68, '07/02/2002', 7);
INSERT INTO valoracions VALUES (494, 56, '24/08/2010', 8);
INSERT INTO valoracions VALUES (494, 24, '12/08/2007', 5);
INSERT INTO valoracions VALUES (494, 54, '13/07/2004', 3);
INSERT INTO valoracions VALUES (494, 96, '23/09/2001', 5);
INSERT INTO valoracions VALUES (494, 51, '20/07/2005', 6);
INSERT INTO valoracions VALUES (495, 41, '09/03/2005', 10);
INSERT INTO valoracions VALUES (495, 53, '13/01/2003', 8);
INSERT INTO valoracions VALUES (495, 103, '18/08/2003', 7);
INSERT INTO valoracions VALUES (496, 112, '28/07/2005', 4);
INSERT INTO valoracions VALUES (496, 97, '25/12/2005', 10);
INSERT INTO valoracions VALUES (496, 74, '15/01/2006', 4);
INSERT INTO valoracions VALUES (497, 33, '01/04/2004', 8);
INSERT INTO valoracions VALUES (497, 65, '18/09/2002', 8);
INSERT INTO valoracions VALUES (498, 47, '06/08/2007', 6);
INSERT INTO valoracions VALUES (498, 104, '17/05/2004', 7);
INSERT INTO valoracions VALUES (498, 34, '12/09/2007', 9);
INSERT INTO valoracions VALUES (498, 83, '14/10/2004', 8);
INSERT INTO valoracions VALUES (498, 84, '25/09/2008', 7);
INSERT INTO valoracions VALUES (499, 42, '05/08/2008', 9);
INSERT INTO valoracions VALUES (499, 40, '17/08/2003', 7);
INSERT INTO valoracions VALUES (500, 12, '21/03/2007', 10);
INSERT INTO valoracions VALUES (500, 22, '22/12/2002', 6);
INSERT INTO valoracions VALUES (500, 27, '21/04/2010', 4);
INSERT INTO valoracions VALUES (500, 105, '04/05/2006', 5);
INSERT INTO valoracions VALUES (500, 55, '12/03/2002', 9);
INSERT INTO valoracions VALUES (500, 92, '14/04/2007', 8);
INSERT INTO valoracions VALUES (501, 57, '29/01/2004', 4);
INSERT INTO valoracions VALUES (501, 2, '22/05/2001', 5);
INSERT INTO valoracions VALUES (501, 67, '04/03/2007', 4);
INSERT INTO valoracions VALUES (501, 61, '04/10/2009', 7);
INSERT INTO valoracions VALUES (501, 20, '10/08/2007', 6);
INSERT INTO valoracions VALUES (501, 45, '07/11/2008', 7);
INSERT INTO valoracions VALUES (501, 1, '09/02/2004', 8);
INSERT INTO valoracions VALUES (502, 48, '17/08/2008', 5);
INSERT INTO valoracions VALUES (502, 62, '22/03/2005', 10);
INSERT INTO valoracions VALUES (502, 8, '08/11/2009', 8);
INSERT INTO valoracions VALUES (502, 71, '20/01/2005', 10);
INSERT INTO valoracions VALUES (504, 24, '18/04/2003', 8);
INSERT INTO valoracions VALUES (504, 34, '27/03/2005', 5);
INSERT INTO valoracions VALUES (504, 97, '06/01/2010', 5);
INSERT INTO valoracions VALUES (504, 68, '12/11/2006', 8);
INSERT INTO valoracions VALUES (505, 34, '06/08/2001', 4);
INSERT INTO valoracions VALUES (505, 4, '29/03/2007', 10);
INSERT INTO valoracions VALUES (505, 79, '07/10/2007', 9);
INSERT INTO valoracions VALUES (505, 55, '30/12/2003', 5);
INSERT INTO valoracions VALUES (506, 27, '09/04/2007', 9);
INSERT INTO valoracions VALUES (506, 114, '17/01/2005', 0);
INSERT INTO valoracions VALUES (506, 3, '17/09/2010', 6);
INSERT INTO valoracions VALUES (506, 23, '06/03/2004', 5);
INSERT INTO valoracions VALUES (507, 88, '07/05/2006', 5);
INSERT INTO valoracions VALUES (507, 90, '18/07/2003', 4);
INSERT INTO valoracions VALUES (507, 4, '24/09/2009', 6);
INSERT INTO valoracions VALUES (508, 73, '11/11/2004', 6);
INSERT INTO valoracions VALUES (508, 100, '26/12/2007', 2);
INSERT INTO valoracions VALUES (508, 21, '01/01/2008', 5);
INSERT INTO valoracions VALUES (509, 76, '12/01/2009', 8);
INSERT INTO valoracions VALUES (509, 4, '06/06/2006', 5);
INSERT INTO valoracions VALUES (509, 115, '09/10/2006', 6);
INSERT INTO valoracions VALUES (509, 8, '26/12/2004', 7);
INSERT INTO valoracions VALUES (509, 80, '23/06/2006', 2);
INSERT INTO valoracions VALUES (510, 73, '15/07/2005', 10);
INSERT INTO valoracions VALUES (510, 64, '16/08/2009', 3);
INSERT INTO valoracions VALUES (510, 36, '26/01/2002', 5);
INSERT INTO valoracions VALUES (510, 71, '14/06/2002', 6);
INSERT INTO valoracions VALUES (510, 65, '06/12/2006', 2);
INSERT INTO valoracions VALUES (511, 49, '21/03/2008', 8);
INSERT INTO valoracions VALUES (511, 9, '11/12/2009', 8);
INSERT INTO valoracions VALUES (511, 61, '29/02/2008', 5);
INSERT INTO valoracions VALUES (511, 35, '04/08/2003', 9);
INSERT INTO valoracions VALUES (512, 46, '29/03/2005', 5);
INSERT INTO valoracions VALUES (512, 68, '02/03/2005', 3);
INSERT INTO valoracions VALUES (512, 24, '04/10/2010', 6);
INSERT INTO valoracions VALUES (512, 70, '25/04/2003', 2);
INSERT INTO valoracions VALUES (512, 79, '14/05/2010', 7);
INSERT INTO valoracions VALUES (512, 73, '02/10/2008', 6);
INSERT INTO valoracions VALUES (512, 29, '17/07/2001', 10);
INSERT INTO valoracions VALUES (512, 59, '26/06/2003', 8);
INSERT INTO valoracions VALUES (512, 40, '20/10/2001', 6);
INSERT INTO valoracions VALUES (512, 44, '10/05/2004', 9);
INSERT INTO valoracions VALUES (512, 24, '18/12/2002', 8);
INSERT INTO valoracions VALUES (513, 100, '04/04/2006', 4);
INSERT INTO valoracions VALUES (513, 77, '05/06/2004', 4);
INSERT INTO valoracions VALUES (513, 110, '21/09/2001', 2);
INSERT INTO valoracions VALUES (513, 22, '09/08/2006', 6);
INSERT INTO valoracions VALUES (514, 25, '14/11/2009', 6);
INSERT INTO valoracions VALUES (514, 80, '22/10/2001', 6);
INSERT INTO valoracions VALUES (514, 20, '17/09/2002', 6);
INSERT INTO valoracions VALUES (514, 45, '01/11/2008', 7);
INSERT INTO valoracions VALUES (514, 113, '26/10/2008', 2);
INSERT INTO valoracions VALUES (514, 24, '24/08/2002', 5);
INSERT INTO valoracions VALUES (515, 59, '06/06/2005', 9);
INSERT INTO valoracions VALUES (515, 98, '02/02/2007', 5);
INSERT INTO valoracions VALUES (516, 2, '09/02/2007', 7);
INSERT INTO valoracions VALUES (516, 88, '01/03/2009', 10);
INSERT INTO valoracions VALUES (516, 114, '16/10/2001', 5);
INSERT INTO valoracions VALUES (517, 35, '04/03/2002', 9);
INSERT INTO valoracions VALUES (517, 69, '30/09/2004', 3);
INSERT INTO valoracions VALUES (518, 67, '14/11/2008', 9);
INSERT INTO valoracions VALUES (518, 110, '03/05/2002', 0);
INSERT INTO valoracions VALUES (518, 64, '05/05/2003', 9);
INSERT INTO valoracions VALUES (519, 89, '13/06/2008', 3);
INSERT INTO valoracions VALUES (519, 104, '05/10/2004', 7);
INSERT INTO valoracions VALUES (519, 110, '16/12/2006', 3);
INSERT INTO valoracions VALUES (519, 97, '09/04/2007', 6);
INSERT INTO valoracions VALUES (520, 49, '18/08/2001', 9);
INSERT INTO valoracions VALUES (520, 82, '08/11/2002', 4);
INSERT INTO valoracions VALUES (520, 66, '10/12/2009', 8);
INSERT INTO valoracions VALUES (520, 19, '18/09/2003', 5);
INSERT INTO valoracions VALUES (520, 8, '11/07/2006', 10);
INSERT INTO valoracions VALUES (520, 72, '18/08/2006', 3);
INSERT INTO valoracions VALUES (521, 7, '08/01/2009', 8);
INSERT INTO valoracions VALUES (521, 115, '31/08/2007', 2);
INSERT INTO valoracions VALUES (521, 62, '18/01/2009', 5);
INSERT INTO valoracions VALUES (522, 107, '20/09/2001', 6);
INSERT INTO valoracions VALUES (522, 35, '09/08/2002', 5);
INSERT INTO valoracions VALUES (522, 4, '26/08/2005', 7);
INSERT INTO valoracions VALUES (523, 19, '30/07/2005', 5);
INSERT INTO valoracions VALUES (523, 106, '11/01/2006', 5);
INSERT INTO valoracions VALUES (523, 105, '19/09/2010', 4);
INSERT INTO valoracions VALUES (523, 14, '18/12/2009', 8);
INSERT INTO valoracions VALUES (523, 104, '25/01/2007', 7);
INSERT INTO valoracions VALUES (524, 7, '25/09/2008', 5);
INSERT INTO valoracions VALUES (524, 112, '22/04/2002', 6);
INSERT INTO valoracions VALUES (524, 111, '14/05/2005', 6);
INSERT INTO valoracions VALUES (525, 73, '01/04/2009', 7);
INSERT INTO valoracions VALUES (526, 84, '20/09/2003', 7);
INSERT INTO valoracions VALUES (526, 1, '18/06/2010', 8);
INSERT INTO valoracions VALUES (526, 107, '12/09/2010', 3);
INSERT INTO valoracions VALUES (527, 43, '13/12/2006', 4);
INSERT INTO valoracions VALUES (527, 2, '04/02/2004', 7);
INSERT INTO valoracions VALUES (527, 93, '05/01/2010', 6);
INSERT INTO valoracions VALUES (527, 101, '09/10/2007', 4);
INSERT INTO valoracions VALUES (527, 40, '29/07/2004', 8);
INSERT INTO valoracions VALUES (527, 55, '28/11/2001', 8);
INSERT INTO valoracions VALUES (527, 14, '26/12/2004', 10);
INSERT INTO valoracions VALUES (528, 27, '10/03/2009', 5);
INSERT INTO valoracions VALUES (528, 88, '14/02/2005', 9);
INSERT INTO valoracions VALUES (529, 5, '29/07/2003', 8);
INSERT INTO valoracions VALUES (529, 30, '10/05/2004', 5);
INSERT INTO valoracions VALUES (530, 64, '19/10/2002', 2);
INSERT INTO valoracions VALUES (530, 50, '30/06/2005', 4);
INSERT INTO valoracions VALUES (531, 38, '21/03/2002', 4);
INSERT INTO valoracions VALUES (531, 61, '31/12/2006', 5);
INSERT INTO valoracions VALUES (531, 76, '08/06/2006', 8);
INSERT INTO valoracions VALUES (531, 104, '11/08/2010', 7);
INSERT INTO valoracions VALUES (531, 78, '21/11/2009', 9);
INSERT INTO valoracions VALUES (532, 43, '03/09/2006', 7);
INSERT INTO valoracions VALUES (532, 79, '25/07/2006', 7);
INSERT INTO valoracions VALUES (532, 66, '11/03/2008', 5);
INSERT INTO valoracions VALUES (532, 48, '16/07/2003', 4);
INSERT INTO valoracions VALUES (533, 14, '19/05/2010', 7);
INSERT INTO valoracions VALUES (533, 7, '14/03/2002', 5);
INSERT INTO valoracions VALUES (533, 77, '31/08/2010', 2);
INSERT INTO valoracions VALUES (534, 31, '14/05/2007', 8);
INSERT INTO valoracions VALUES (534, 5, '01/04/2010', 8);
INSERT INTO valoracions VALUES (534, 66, '09/12/2006', 8);
INSERT INTO valoracions VALUES (535, 84, '16/01/2005', 4);
INSERT INTO valoracions VALUES (535, 74, '06/01/2003', 5);
INSERT INTO valoracions VALUES (535, 28, '25/03/2002', 4);
INSERT INTO valoracions VALUES (535, 94, '16/05/2008', 4);
INSERT INTO valoracions VALUES (536, 95, '01/10/2006', 3);
INSERT INTO valoracions VALUES (536, 54, '21/01/2003', 6);
INSERT INTO valoracions VALUES (537, 113, '03/01/2008', 2);
INSERT INTO valoracions VALUES (537, 93, '22/05/2004', 6);
INSERT INTO valoracions VALUES (537, 59, '21/09/2007', 7);
INSERT INTO valoracions VALUES (538, 22, '08/12/2001', 6);
INSERT INTO valoracions VALUES (538, 83, '19/06/2008', 4);
INSERT INTO valoracions VALUES (539, 38, '30/04/2008', 8);
INSERT INTO valoracions VALUES (539, 68, '03/10/2004', 8);
INSERT INTO valoracions VALUES (539, 35, '02/05/2001', 5);
INSERT INTO valoracions VALUES (540, 69, '05/02/2006', 6);
INSERT INTO valoracions VALUES (540, 104, '09/03/2005', 5);
INSERT INTO valoracions VALUES (540, 40, '30/06/2010', 5);
INSERT INTO valoracions VALUES (541, 110, '22/12/2002', 7);
INSERT INTO valoracions VALUES (541, 106, '12/01/2002', 6);
INSERT INTO valoracions VALUES (541, 89, '16/05/2003', 9);
INSERT INTO valoracions VALUES (541, 26, '17/12/2001', 8);
INSERT INTO valoracions VALUES (542, 55, '02/08/2002', 8);
INSERT INTO valoracions VALUES (542, 52, '07/07/2009', 6);
INSERT INTO valoracions VALUES (543, 115, '03/09/2008', 6);
INSERT INTO valoracions VALUES (543, 83, '15/04/2008', 2);
INSERT INTO valoracions VALUES (543, 95, '07/08/2007', 6);
INSERT INTO valoracions VALUES (543, 31, '02/07/2001', 10);
INSERT INTO valoracions VALUES (544, 21, '08/04/2010', 9);
INSERT INTO valoracions VALUES (544, 34, '26/09/2002', 8);
INSERT INTO valoracions VALUES (544, 39, '03/09/2005', 10);
INSERT INTO valoracions VALUES (544, 92, '27/04/2007', 9);
INSERT INTO valoracions VALUES (544, 72, '19/05/2008', 3);
INSERT INTO valoracions VALUES (545, 68, '11/09/2008', 8);
INSERT INTO valoracions VALUES (545, 29, '30/12/2006', 6);
INSERT INTO valoracions VALUES (545, 66, '03/03/2005', 7);
INSERT INTO valoracions VALUES (545, 7, '09/12/2001', 5);
INSERT INTO valoracions VALUES (545, 1, '28/01/2010', 10);
INSERT INTO valoracions VALUES (545, 66, '14/05/2009', 9);
INSERT INTO valoracions VALUES (545, 48, '08/01/2003', 4);
INSERT INTO valoracions VALUES (546, 71, '10/12/2001', 7);
INSERT INTO valoracions VALUES (546, 116, '23/08/2001', 10);
INSERT INTO valoracions VALUES (546, 42, '25/08/2004', 5);
INSERT INTO valoracions VALUES (547, 38, '30/07/2007', 9);
INSERT INTO valoracions VALUES (547, 28, '14/10/2010', 8);
INSERT INTO valoracions VALUES (547, 107, '24/01/2010', 7);
INSERT INTO valoracions VALUES (547, 62, '29/01/2006', 5);
INSERT INTO valoracions VALUES (548, 79, '31/01/2002', 10);
INSERT INTO valoracions VALUES (548, 98, '07/03/2009', 3);
INSERT INTO valoracions VALUES (548, 107, '11/02/2007', 4);
INSERT INTO valoracions VALUES (548, 64, '26/08/2008', 5);
INSERT INTO valoracions VALUES (548, 15, '13/08/2001', 8);
INSERT INTO valoracions VALUES (548, 66, '13/12/2009', 8);
INSERT INTO valoracions VALUES (548, 3, '10/04/2001', 9);
INSERT INTO valoracions VALUES (548, 16, '02/08/2004', 7);
INSERT INTO valoracions VALUES (549, 68, '09/03/2008', 4);
INSERT INTO valoracions VALUES (550, 72, '16/02/2004', 9);
INSERT INTO valoracions VALUES (550, 45, '25/11/2004', 6);
INSERT INTO valoracions VALUES (550, 61, '04/07/2008', 9);
INSERT INTO valoracions VALUES (551, 37, '20/11/2001', 8);
INSERT INTO valoracions VALUES (551, 77, '26/05/2003', 8);
INSERT INTO valoracions VALUES (551, 1, '14/04/2006', 10);
INSERT INTO valoracions VALUES (551, 18, '14/05/2008', 7);
INSERT INTO valoracions VALUES (552, 95, '19/09/2010', 2);
INSERT INTO valoracions VALUES (552, 9, '21/12/2003', 5);
INSERT INTO valoracions VALUES (552, 100, '13/11/2008', 4);
INSERT INTO valoracions VALUES (552, 110, '17/12/2006', 9);
INSERT INTO valoracions VALUES (552, 29, '26/10/2006', 6);
INSERT INTO valoracions VALUES (552, 90, '31/01/2003', 4);
INSERT INTO valoracions VALUES (552, 72, '04/04/2007', 3);
INSERT INTO valoracions VALUES (554, 28, '12/12/2006', 5);
INSERT INTO valoracions VALUES (554, 84, '26/06/2008', 3);
INSERT INTO valoracions VALUES (554, 38, '08/06/2010', 7);
INSERT INTO valoracions VALUES (554, 53, '24/09/2006', 5);
INSERT INTO valoracions VALUES (555, 28, '26/04/2009', 7);
INSERT INTO valoracions VALUES (556, 77, '04/05/2005', 8);
INSERT INTO valoracions VALUES (556, 64, '18/07/2005', 5);
INSERT INTO valoracions VALUES (556, 82, '15/07/2003', 2);
INSERT INTO valoracions VALUES (556, 90, '09/02/2003', 6);
INSERT INTO valoracions VALUES (556, 113, '31/05/2004', 8);
INSERT INTO valoracions VALUES (556, 52, '19/03/2003', 9);
INSERT INTO valoracions VALUES (556, 107, '03/06/2006', 0);
INSERT INTO valoracions VALUES (556, 60, '24/05/2006', 8);
INSERT INTO valoracions VALUES (557, 5, '29/12/2007', 8);
INSERT INTO valoracions VALUES (557, 28, '11/08/2007', 8);
INSERT INTO valoracions VALUES (558, 14, '19/09/2004', 7);
INSERT INTO valoracions VALUES (558, 102, '13/01/2007', 7);
INSERT INTO valoracions VALUES (559, 15, '28/12/2009', 8);
INSERT INTO valoracions VALUES (559, 71, '01/03/2005', 6);
INSERT INTO valoracions VALUES (559, 56, '22/12/2001', 7);
INSERT INTO valoracions VALUES (560, 1, '09/12/2006', 6);
INSERT INTO valoracions VALUES (560, 67, '07/08/2004', 9);
INSERT INTO valoracions VALUES (560, 111, '14/03/2002', 8);
INSERT INTO valoracions VALUES (560, 64, '02/07/2002', 5);
INSERT INTO valoracions VALUES (561, 92, '21/09/2009', 9);
INSERT INTO valoracions VALUES (561, 99, '29/04/2009', 5);
INSERT INTO valoracions VALUES (562, 90, '29/10/2006', 1);
INSERT INTO valoracions VALUES (562, 2, '12/05/2010', 6);
INSERT INTO valoracions VALUES (563, 115, '30/06/2007', 1);
INSERT INTO valoracions VALUES (563, 22, '12/09/2002', 9);
INSERT INTO valoracions VALUES (564, 52, '19/07/2001', 6);
INSERT INTO valoracions VALUES (564, 68, '25/08/2005', 4);
INSERT INTO valoracions VALUES (564, 94, '12/01/2003', 8);
INSERT INTO valoracions VALUES (564, 4, '11/12/2006', 6);
INSERT INTO valoracions VALUES (564, 104, '01/05/2007', 8);
INSERT INTO valoracions VALUES (565, 66, '12/12/2007', 4);
INSERT INTO valoracions VALUES (565, 93, '21/11/2005', 4);
INSERT INTO valoracions VALUES (565, 15, '16/09/2006', 7);
INSERT INTO valoracions VALUES (566, 109, '19/07/2006', 2);
INSERT INTO valoracions VALUES (566, 4, '21/12/2001', 5);
INSERT INTO valoracions VALUES (566, 75, '17/05/2002', 6);
INSERT INTO valoracions VALUES (566, 77, '26/09/2009', 4);
INSERT INTO valoracions VALUES (567, 59, '29/10/2008', 8);
INSERT INTO valoracions VALUES (567, 28, '30/03/2004', 7);
INSERT INTO valoracions VALUES (568, 71, '13/11/2005', 6);
INSERT INTO valoracions VALUES (568, 15, '12/10/2002', 10);
INSERT INTO valoracions VALUES (568, 51, '25/02/2006', 8);
INSERT INTO valoracions VALUES (568, 9, '03/07/2005', 9);
INSERT INTO valoracions VALUES (568, 107, '30/04/2008', 6);
INSERT INTO valoracions VALUES (569, 38, '26/09/2010', 7);
INSERT INTO valoracions VALUES (569, 45, '29/06/2004', 7);
INSERT INTO valoracions VALUES (569, 95, '29/10/2001', 3);
INSERT INTO valoracions VALUES (569, 114, '21/11/2002', 9);
INSERT INTO valoracions VALUES (569, 28, '11/07/2004', 4);
INSERT INTO valoracions VALUES (570, 101, '24/05/2008', 3);
INSERT INTO valoracions VALUES (570, 13, '31/03/2001', 5);
INSERT INTO valoracions VALUES (570, 76, '03/04/2002', 8);
INSERT INTO valoracions VALUES (571, 71, '13/03/2008', 7);
INSERT INTO valoracions VALUES (571, 55, '31/01/2009', 6);
INSERT INTO valoracions VALUES (572, 70, '17/04/2007', 7);
INSERT INTO valoracions VALUES (572, 9, '09/10/2006', 5);
INSERT INTO valoracions VALUES (573, 9, '31/03/2003', 10);
INSERT INTO valoracions VALUES (573, 101, '08/10/2006', 3);
INSERT INTO valoracions VALUES (573, 113, '18/06/2006', 6);
INSERT INTO valoracions VALUES (573, 51, '31/05/2003', 4);
INSERT INTO valoracions VALUES (574, 23, '24/01/2003', 5);
INSERT INTO valoracions VALUES (574, 60, '22/01/2009', 2);
INSERT INTO valoracions VALUES (574, 93, '22/09/2006', 2);
INSERT INTO valoracions VALUES (574, 27, '01/08/2006', 5);
INSERT INTO valoracions VALUES (574, 49, '25/10/2003', 4);
INSERT INTO valoracions VALUES (574, 113, '23/01/2005', 5);
INSERT INTO valoracions VALUES (574, 40, '02/03/2004', 5);
INSERT INTO valoracions VALUES (575, 40, '27/06/2002', 8);
INSERT INTO valoracions VALUES (575, 10, '17/03/2003', 7);
INSERT INTO valoracions VALUES (575, 21, '02/05/2001', 10);
INSERT INTO valoracions VALUES (575, 100, '14/01/2010', 4);
INSERT INTO valoracions VALUES (575, 42, '20/04/2002', 10);
INSERT INTO valoracions VALUES (575, 24, '28/07/2009', 4);
INSERT INTO valoracions VALUES (575, 89, '12/04/2008', 4);
INSERT INTO valoracions VALUES (576, 73, '25/09/2007', 6);
INSERT INTO valoracions VALUES (576, 108, '23/11/2002', 9);
INSERT INTO valoracions VALUES (576, 63, '22/02/2010', 4);
INSERT INTO valoracions VALUES (576, 63, '06/12/2006', 5);
INSERT INTO valoracions VALUES (576, 88, '17/05/2001', 8);
INSERT INTO valoracions VALUES (576, 48, '20/12/2009', 8);
INSERT INTO valoracions VALUES (576, 59, '08/04/2002', 6);
INSERT INTO valoracions VALUES (577, 42, '21/06/2002', 5);
INSERT INTO valoracions VALUES (577, 70, '05/10/2006', 4);
INSERT INTO valoracions VALUES (577, 71, '11/02/2002', 4);
INSERT INTO valoracions VALUES (577, 2, '18/08/2007', 10);
INSERT INTO valoracions VALUES (578, 33, '20/03/2003', 10);
INSERT INTO valoracions VALUES (579, 41, '01/02/2008', 6);
INSERT INTO valoracions VALUES (579, 115, '16/03/2007', 7);
INSERT INTO valoracions VALUES (579, 13, '09/12/2005', 9);
INSERT INTO valoracions VALUES (579, 66, '23/04/2003', 8);
INSERT INTO valoracions VALUES (579, 70, '20/06/2007', 8);
INSERT INTO valoracions VALUES (579, 96, '05/09/2010', 7);
INSERT INTO valoracions VALUES (580, 1, '07/07/2010', 10);
INSERT INTO valoracions VALUES (580, 50, '27/01/2010', 6);
INSERT INTO valoracions VALUES (580, 84, '06/02/2009', 2);
INSERT INTO valoracions VALUES (581, 90, '02/08/2005', 8);
INSERT INTO valoracions VALUES (581, 12, '09/03/2003', 6);
INSERT INTO valoracions VALUES (581, 45, '04/09/2005', 9);
INSERT INTO valoracions VALUES (582, 95, '09/05/2010', 7);
INSERT INTO valoracions VALUES (582, 110, '02/02/2006', 5);
INSERT INTO valoracions VALUES (582, 111, '10/04/2008', 4);
INSERT INTO valoracions VALUES (582, 56, '20/01/2004', 6);
INSERT INTO valoracions VALUES (582, 84, '19/04/2006', 6);
INSERT INTO valoracions VALUES (582, 100, '11/01/2009', 6);
INSERT INTO valoracions VALUES (583, 38, '01/05/2009', 10);
INSERT INTO valoracions VALUES (583, 33, '25/11/2003', 8);
INSERT INTO valoracions VALUES (583, 62, '29/05/2007', 3);
INSERT INTO valoracions VALUES (583, 9, '02/07/2008', 7);
INSERT INTO valoracions VALUES (584, 27, '16/02/2006', 8);
INSERT INTO valoracions VALUES (584, 72, '01/03/2010', 7);
INSERT INTO valoracions VALUES (584, 23, '09/09/2006', 10);
INSERT INTO valoracions VALUES (584, 13, '09/12/2004', 8);
INSERT INTO valoracions VALUES (584, 42, '02/04/2002', 9);
INSERT INTO valoracions VALUES (584, 106, '23/05/2010', 5);
INSERT INTO valoracions VALUES (584, 18, '04/08/2004', 8);
INSERT INTO valoracions VALUES (585, 72, '22/07/2001', 8);
INSERT INTO valoracions VALUES (585, 37, '17/06/2010', 9);
INSERT INTO valoracions VALUES (585, 39, '05/10/2006', 9);
INSERT INTO valoracions VALUES (585, 7, '12/07/2004', 10);
INSERT INTO valoracions VALUES (586, 11, '05/06/2008', 8);
INSERT INTO valoracions VALUES (586, 88, '12/11/2004', 7);
INSERT INTO valoracions VALUES (586, 102, '17/09/2007', 6);
INSERT INTO valoracions VALUES (586, 85, '05/08/2004', 3);
INSERT INTO valoracions VALUES (586, 28, '03/06/2002', 8);
INSERT INTO valoracions VALUES (587, 113, '27/04/2007', 8);
INSERT INTO valoracions VALUES (587, 83, '27/08/2008', 5);
INSERT INTO valoracions VALUES (587, 17, '27/08/2001', 6);
INSERT INTO valoracions VALUES (587, 20, '06/06/2007', 9);
INSERT INTO valoracions VALUES (587, 80, '05/01/2002', 6);
INSERT INTO valoracions VALUES (588, 21, '29/04/2007', 9);
INSERT INTO valoracions VALUES (588, 75, '06/03/2009', 8);
INSERT INTO valoracions VALUES (588, 61, '23/09/2009', 3);
INSERT INTO valoracions VALUES (588, 20, '06/10/2002', 7);
INSERT INTO valoracions VALUES (589, 76, '21/12/2009', 5);
INSERT INTO valoracions VALUES (589, 53, '10/11/2001', 10);
INSERT INTO valoracions VALUES (589, 112, '17/01/2004', 10);
INSERT INTO valoracions VALUES (590, 70, '17/11/2004', 7);
INSERT INTO valoracions VALUES (590, 106, '23/04/2010', 4);
INSERT INTO valoracions VALUES (590, 68, '20/05/2005', 4);
INSERT INTO valoracions VALUES (590, 57, '16/07/2007', 6);
INSERT INTO valoracions VALUES (590, 98, '19/06/2010', 1);
INSERT INTO valoracions VALUES (591, 40, '25/01/2002', 9);
INSERT INTO valoracions VALUES (591, 18, '28/04/2009', 5);
INSERT INTO valoracions VALUES (592, 3, '16/10/2002', 5);
INSERT INTO valoracions VALUES (593, 4, '25/05/2008', 8);
INSERT INTO valoracions VALUES (593, 80, '09/01/2009', 9);
INSERT INTO valoracions VALUES (593, 27, '13/03/2002', 9);
INSERT INTO valoracions VALUES (593, 41, '01/04/2002', 7);
INSERT INTO valoracions VALUES (593, 115, '31/08/2008', 5);
INSERT INTO valoracions VALUES (594, 22, '26/06/2001', 10);
INSERT INTO valoracions VALUES (594, 23, '30/10/2007', 9);
INSERT INTO valoracions VALUES (595, 66, '07/11/2006', 2);
INSERT INTO valoracions VALUES (595, 60, '15/02/2003', 8);
INSERT INTO valoracions VALUES (596, 63, '11/10/2008', 3);
INSERT INTO valoracions VALUES (596, 40, '13/09/2003', 5);
INSERT INTO valoracions VALUES (596, 60, '28/08/2003', 5);
INSERT INTO valoracions VALUES (596, 22, '25/10/2006', 5);
INSERT INTO valoracions VALUES (596, 11, '09/03/2007', 6);
INSERT INTO valoracions VALUES (597, 93, '04/08/2010', 4);
INSERT INTO valoracions VALUES (597, 6, '11/08/2002', 6);
INSERT INTO valoracions VALUES (597, 111, '13/04/2010', 2);
INSERT INTO valoracions VALUES (598, 84, '04/07/2008', 6);
INSERT INTO valoracions VALUES (598, 85, '01/07/2010', 8);
INSERT INTO valoracions VALUES (598, 1, '13/11/2002', 7);
INSERT INTO valoracions VALUES (598, 13, '08/05/2007', 6);
INSERT INTO valoracions VALUES (599, 11, '23/03/2003', 7);
INSERT INTO valoracions VALUES (599, 107, '13/12/2002', 9);
INSERT INTO valoracions VALUES (599, 61, '25/12/2008', 8);
INSERT INTO valoracions VALUES (599, 78, '08/10/2009', 5);
INSERT INTO valoracions VALUES (600, 50, '25/11/2002', 3);
INSERT INTO valoracions VALUES (600, 1, '13/10/2007', 9);
INSERT INTO valoracions VALUES (601, 42, '06/08/2010', 4);
INSERT INTO valoracions VALUES (601, 6, '21/05/2003', 9);
INSERT INTO valoracions VALUES (601, 43, '29/07/2003', 9);
INSERT INTO valoracions VALUES (601, 12, '25/04/2009', 8);
INSERT INTO valoracions VALUES (602, 65, '03/02/2010', 5);
INSERT INTO valoracions VALUES (602, 106, '17/01/2008', 8);
INSERT INTO valoracions VALUES (602, 99, '14/11/2003', 6);
INSERT INTO valoracions VALUES (602, 60, '23/08/2002', 5);
INSERT INTO valoracions VALUES (602, 62, '04/06/2002', 10);
INSERT INTO valoracions VALUES (603, 1, '07/10/2007', 6);
INSERT INTO valoracions VALUES (603, 27, '18/10/2003', 6);
INSERT INTO valoracions VALUES (604, 84, '03/11/2008', 7);
INSERT INTO valoracions VALUES (604, 56, '14/09/2003', 9);
INSERT INTO valoracions VALUES (604, 7, '04/07/2003', 7);
INSERT INTO valoracions VALUES (605, 112, '24/11/2006', 7);
INSERT INTO valoracions VALUES (605, 25, '07/07/2007', 10);
INSERT INTO valoracions VALUES (606, 116, '07/05/2002', 9);
INSERT INTO valoracions VALUES (606, 113, '23/09/2007', 1);
INSERT INTO valoracions VALUES (606, 72, '13/05/2002', 4);
INSERT INTO valoracions VALUES (606, 13, '12/01/2006', 9);
INSERT INTO valoracions VALUES (606, 32, '23/05/2009', 9);
INSERT INTO valoracions VALUES (607, 60, '15/05/2007', 9);
INSERT INTO valoracions VALUES (607, 112, '28/03/2008', 1);
INSERT INTO valoracions VALUES (607, 9, '26/03/2009', 9);
INSERT INTO valoracions VALUES (607, 14, '27/05/2007', 5);
INSERT INTO valoracions VALUES (607, 77, '04/11/2004', 8);
INSERT INTO valoracions VALUES (608, 83, '07/05/2003', 10);
INSERT INTO valoracions VALUES (608, 36, '13/04/2005', 5);
INSERT INTO valoracions VALUES (608, 77, '06/12/2005', 3);
INSERT INTO valoracions VALUES (608, 28, '23/09/2010', 7);
INSERT INTO valoracions VALUES (609, 80, '11/06/2001', 5);
INSERT INTO valoracions VALUES (609, 79, '15/04/2009', 10);
INSERT INTO valoracions VALUES (609, 32, '24/04/2005', 10);
INSERT INTO valoracions VALUES (610, 19, '09/04/2005', 9);
INSERT INTO valoracions VALUES (611, 33, '28/06/2005', 5);
INSERT INTO valoracions VALUES (611, 81, '28/11/2004', 8);
INSERT INTO valoracions VALUES (611, 27, '08/08/2008', 5);
INSERT INTO valoracions VALUES (611, 99, '03/02/2010', 8);
INSERT INTO valoracions VALUES (611, 20, '27/09/2006', 8);
INSERT INTO valoracions VALUES (611, 4, '07/04/2010', 5);
INSERT INTO valoracions VALUES (612, 75, '14/05/2003', 7);
INSERT INTO valoracions VALUES (613, 48, '12/02/2009', 5);
INSERT INTO valoracions VALUES (613, 94, '26/08/2003', 2);
INSERT INTO valoracions VALUES (613, 100, '29/06/2004', 4);
INSERT INTO valoracions VALUES (614, 10, '08/05/2002', 9);
INSERT INTO valoracions VALUES (614, 65, '21/04/2005', 4);
INSERT INTO valoracions VALUES (614, 41, '03/01/2005', 9);
INSERT INTO valoracions VALUES (615, 95, '21/10/2002', 3);
INSERT INTO valoracions VALUES (615, 77, '21/06/2007', 9);
INSERT INTO valoracions VALUES (615, 30, '23/08/2001', 6);
INSERT INTO valoracions VALUES (616, 79, '16/07/2007', 6);
INSERT INTO valoracions VALUES (616, 18, '21/09/2002', 5);
INSERT INTO valoracions VALUES (616, 32, '09/05/2007', 8);
INSERT INTO valoracions VALUES (616, 2, '15/08/2004', 9);
INSERT INTO valoracions VALUES (617, 61, '16/07/2003', 10);
INSERT INTO valoracions VALUES (617, 2, '12/12/2005', 9);
INSERT INTO valoracions VALUES (617, 86, '10/02/2004', 7);
INSERT INTO valoracions VALUES (617, 44, '11/05/2004', 8);
INSERT INTO valoracions VALUES (618, 37, '10/05/2004', 6);
INSERT INTO valoracions VALUES (618, 69, '09/12/2005', 7);
INSERT INTO valoracions VALUES (618, 50, '13/12/2009', 5);
INSERT INTO valoracions VALUES (619, 50, '11/04/2004', 6);
INSERT INTO valoracions VALUES (619, 34, '30/05/2008', 9);
INSERT INTO valoracions VALUES (620, 16, '31/10/2007', 10);
INSERT INTO valoracions VALUES (620, 62, '21/04/2007', 9);
INSERT INTO valoracions VALUES (620, 33, '16/03/2006', 9);
INSERT INTO valoracions VALUES (620, 82, '08/09/2008', 6);
INSERT INTO valoracions VALUES (620, 7, '05/12/2005', 6);
INSERT INTO valoracions VALUES (620, 99, '05/05/2002', 4);
INSERT INTO valoracions VALUES (621, 79, '15/08/2002', 3);
INSERT INTO valoracions VALUES (621, 67, '03/10/2010', 8);
INSERT INTO valoracions VALUES (621, 28, '05/04/2005', 6);
INSERT INTO valoracions VALUES (621, 46, '04/12/2007', 4);
INSERT INTO valoracions VALUES (622, 76, '20/12/2006', 3);
INSERT INTO valoracions VALUES (622, 91, '24/03/2009', 8);
INSERT INTO valoracions VALUES (622, 3, '11/05/2003', 7);
INSERT INTO valoracions VALUES (623, 97, '13/06/2007', 5);
INSERT INTO valoracions VALUES (623, 21, '30/12/2005', 8);
INSERT INTO valoracions VALUES (623, 109, '07/05/2002', 7);
INSERT INTO valoracions VALUES (623, 104, '05/04/2004', 8);
INSERT INTO valoracions VALUES (623, 69, '12/05/2009', 8);
INSERT INTO valoracions VALUES (624, 22, '08/03/2002', 6);
INSERT INTO valoracions VALUES (624, 55, '21/12/2009', 3);
INSERT INTO valoracions VALUES (624, 105, '27/10/2003', 1);
INSERT INTO valoracions VALUES (624, 24, '26/03/2006', 5);
INSERT INTO valoracions VALUES (625, 18, '13/07/2010', 8);
INSERT INTO valoracions VALUES (625, 2, '21/12/2007', 5);
INSERT INTO valoracions VALUES (625, 95, '07/07/2006', 6);
INSERT INTO valoracions VALUES (625, 52, '28/06/2002', 9);
INSERT INTO valoracions VALUES (626, 75, '07/11/2007', 5);
INSERT INTO valoracions VALUES (626, 1, '16/10/2004', 9);
INSERT INTO valoracions VALUES (626, 39, '02/03/2007', 5);
INSERT INTO valoracions VALUES (626, 43, '01/10/2009', 5);
INSERT INTO valoracions VALUES (627, 78, '23/05/2008', 3);
INSERT INTO valoracions VALUES (627, 71, '04/07/2001', 8);
INSERT INTO valoracions VALUES (627, 32, '15/12/2007', 9);
INSERT INTO valoracions VALUES (627, 42, '06/10/2001', 6);
INSERT INTO valoracions VALUES (627, 68, '16/09/2008', 5);
INSERT INTO valoracions VALUES (627, 111, '21/12/2006', 10);
INSERT INTO valoracions VALUES (627, 12, '20/11/2001', 5);
INSERT INTO valoracions VALUES (628, 44, '10/09/2006', 7);
INSERT INTO valoracions VALUES (628, 78, '26/04/2002', 10);
INSERT INTO valoracions VALUES (628, 11, '08/11/2001', 9);
INSERT INTO valoracions VALUES (628, 90, '14/03/2008', 5);
INSERT INTO valoracions VALUES (628, 58, '31/03/2010', 6);
INSERT INTO valoracions VALUES (629, 51, '11/05/2009', 3);
INSERT INTO valoracions VALUES (629, 55, '16/10/2004', 3);
INSERT INTO valoracions VALUES (630, 87, '10/07/2007', 1);
INSERT INTO valoracions VALUES (630, 55, '13/05/2005', 8);
INSERT INTO valoracions VALUES (630, 23, '31/01/2010', 10);
INSERT INTO valoracions VALUES (630, 112, '24/08/2010', 2);
INSERT INTO valoracions VALUES (630, 59, '12/12/2009', 6);
INSERT INTO valoracions VALUES (630, 24, '25/10/2004', 6);
INSERT INTO valoracions VALUES (630, 114, '27/11/2006', 7);
INSERT INTO valoracions VALUES (630, 56, '02/04/2007', 4);
INSERT INTO valoracions VALUES (631, 30, '01/10/2004', 8);
INSERT INTO valoracions VALUES (631, 95, '01/08/2001', 8);
INSERT INTO valoracions VALUES (631, 3, '11/07/2004', 7);
INSERT INTO valoracions VALUES (631, 103, '17/07/2010', 4);
INSERT INTO valoracions VALUES (631, 64, '02/12/2005', 6);
INSERT INTO valoracions VALUES (631, 81, '22/10/2007', 4);
INSERT INTO valoracions VALUES (631, 71, '30/03/2002', 9);
INSERT INTO valoracions VALUES (631, 25, '16/06/2006', 6);
INSERT INTO valoracions VALUES (632, 103, '25/02/2007', 4);
INSERT INTO valoracions VALUES (632, 34, '04/02/2009', 7);
INSERT INTO valoracions VALUES (632, 82, '26/09/2008', 4);
INSERT INTO valoracions VALUES (633, 57, '24/10/2006', 4);
INSERT INTO valoracions VALUES (633, 91, '04/03/2002', 3);
INSERT INTO valoracions VALUES (633, 9, '07/06/2006', 7);
INSERT INTO valoracions VALUES (633, 6, '02/04/2008', 8);
INSERT INTO valoracions VALUES (634, 107, '24/04/2003', 1);
INSERT INTO valoracions VALUES (634, 56, '10/07/2003', 6);
INSERT INTO valoracions VALUES (634, 37, '23/02/2010', 5);
INSERT INTO valoracions VALUES (635, 94, '13/11/2001', 6);
INSERT INTO valoracions VALUES (635, 7, '25/10/2008', 7);
INSERT INTO valoracions VALUES (635, 63, '23/05/2002', 5);
INSERT INTO valoracions VALUES (635, 15, '26/07/2001', 9);
INSERT INTO valoracions VALUES (635, 49, '21/07/2009', 5);
INSERT INTO valoracions VALUES (635, 45, '08/03/2006', 6);
INSERT INTO valoracions VALUES (636, 8, '07/09/2003', 8);
INSERT INTO valoracions VALUES (636, 13, '06/01/2003', 6);
INSERT INTO valoracions VALUES (637, 42, '06/11/2008', 9);
INSERT INTO valoracions VALUES (637, 104, '06/08/2007', 8);
INSERT INTO valoracions VALUES (637, 54, '18/11/2006', 8);
INSERT INTO valoracions VALUES (637, 94, '13/09/2010', 9);
INSERT INTO valoracions VALUES (637, 54, '01/11/2004', 3);
INSERT INTO valoracions VALUES (638, 18, '10/05/2010', 5);
INSERT INTO valoracions VALUES (639, 7, '30/05/2005', 6);
INSERT INTO valoracions VALUES (639, 108, '19/12/2003', 1);
INSERT INTO valoracions VALUES (639, 54, '10/05/2006', 10);
INSERT INTO valoracions VALUES (639, 11, '06/02/2002', 6);
INSERT INTO valoracions VALUES (640, 50, '24/07/2001', 6);
INSERT INTO valoracions VALUES (640, 30, '27/03/2003', 8);
INSERT INTO valoracions VALUES (640, 38, '22/06/2008', 4);
INSERT INTO valoracions VALUES (640, 60, '15/01/2002', 10);
INSERT INTO valoracions VALUES (641, 95, '18/12/2005', 7);
INSERT INTO valoracions VALUES (641, 17, '15/02/2008', 5);
INSERT INTO valoracions VALUES (641, 17, '21/08/2008', 5);
INSERT INTO valoracions VALUES (641, 11, '19/04/2010', 9);
INSERT INTO valoracions VALUES (641, 77, '26/11/2004', 9);
INSERT INTO valoracions VALUES (641, 27, '20/08/2003', 5);
INSERT INTO valoracions VALUES (641, 51, '27/01/2008', 7);
INSERT INTO valoracions VALUES (642, 16, '27/05/2008', 6);
INSERT INTO valoracions VALUES (642, 17, '05/03/2006', 7);
INSERT INTO valoracions VALUES (642, 34, '21/07/2002', 6);
INSERT INTO valoracions VALUES (642, 82, '04/11/2002', 7);
INSERT INTO valoracions VALUES (642, 87, '21/12/2005', 3);
INSERT INTO valoracions VALUES (643, 68, '14/06/2007', 4);
INSERT INTO valoracions VALUES (643, 15, '03/04/2002', 9);
INSERT INTO valoracions VALUES (643, 26, '24/07/2007', 8);
INSERT INTO valoracions VALUES (644, 48, '09/04/2001', 7);
INSERT INTO valoracions VALUES (644, 80, '11/07/2005', 2);
INSERT INTO valoracions VALUES (644, 23, '03/07/2009', 6);
INSERT INTO valoracions VALUES (646, 30, '09/05/2006', 6);
INSERT INTO valoracions VALUES (646, 77, '15/04/2010', 9);
INSERT INTO valoracions VALUES (646, 96, '23/10/2009', 5);
INSERT INTO valoracions VALUES (646, 87, '02/02/2006', 8);
INSERT INTO valoracions VALUES (646, 104, '22/02/2006', 8);
INSERT INTO valoracions VALUES (646, 66, '20/02/2005', 5);
INSERT INTO valoracions VALUES (647, 114, '09/02/2007', 1);
INSERT INTO valoracions VALUES (647, 54, '14/08/2009', 10);
INSERT INTO valoracions VALUES (647, 111, '26/12/2002', 3);
INSERT INTO valoracions VALUES (647, 66, '07/09/2009', 2);
INSERT INTO valoracions VALUES (648, 76, '30/03/2010', 8);
INSERT INTO valoracions VALUES (648, 45, '30/01/2006', 7);
INSERT INTO valoracions VALUES (649, 67, '18/06/2007', 4);
INSERT INTO valoracions VALUES (649, 77, '30/04/2003', 4);
INSERT INTO valoracions VALUES (650, 14, '13/10/2006', 9);
INSERT INTO valoracions VALUES (650, 26, '11/03/2009', 5);
INSERT INTO valoracions VALUES (651, 24, '22/02/2004', 5);
INSERT INTO valoracions VALUES (651, 35, '24/08/2009', 9);
INSERT INTO valoracions VALUES (651, 104, '06/10/2009', 7);
INSERT INTO valoracions VALUES (651, 66, '24/05/2005', 6);
INSERT INTO valoracions VALUES (651, 48, '20/12/2003', 4);
INSERT INTO valoracions VALUES (651, 91, '22/08/2002', 6);
INSERT INTO valoracions VALUES (652, 15, '27/11/2002', 7);
INSERT INTO valoracions VALUES (652, 58, '20/03/2006', 9);
INSERT INTO valoracions VALUES (652, 112, '25/08/2002', 5);
INSERT INTO valoracions VALUES (652, 88, '31/08/2007', 10);
INSERT INTO valoracions VALUES (653, 108, '20/03/2005', 3);
INSERT INTO valoracions VALUES (653, 49, '14/11/2009', 8);
INSERT INTO valoracions VALUES (653, 27, '04/12/2007', 9);
INSERT INTO valoracions VALUES (653, 20, '04/08/2004', 10);
INSERT INTO valoracions VALUES (654, 115, '25/05/2005', 8);
INSERT INTO valoracions VALUES (654, 105, '23/08/2010', 1);
INSERT INTO valoracions VALUES (654, 7, '06/03/2006', 9);
INSERT INTO valoracions VALUES (654, 66, '01/09/2003', 8);
INSERT INTO valoracions VALUES (654, 46, '30/08/2001', 7);
INSERT INTO valoracions VALUES (655, 26, '26/05/2007', 9);
INSERT INTO valoracions VALUES (655, 44, '26/01/2004', 7);
INSERT INTO valoracions VALUES (655, 92, '29/01/2005', 9);
INSERT INTO valoracions VALUES (655, 76, '15/08/2005', 6);
INSERT INTO valoracions VALUES (655, 90, '04/06/2001', 2);
INSERT INTO valoracions VALUES (655, 27, '14/11/2008', 9);
INSERT INTO valoracions VALUES (655, 3, '16/05/2007', 6);
INSERT INTO valoracions VALUES (655, 11, '05/04/2006', 7);
INSERT INTO valoracions VALUES (656, 95, '22/05/2008', 8);
INSERT INTO valoracions VALUES (656, 25, '01/12/2003', 9);
INSERT INTO valoracions VALUES (656, 73, '19/07/2001', 5);
INSERT INTO valoracions VALUES (657, 65, '22/12/2007', 3);
INSERT INTO valoracions VALUES (657, 51, '21/10/2001', 7);
INSERT INTO valoracions VALUES (657, 100, '23/12/2005', 9);
INSERT INTO valoracions VALUES (657, 42, '19/09/2009', 4);
INSERT INTO valoracions VALUES (658, 59, '17/12/2008', 8);
INSERT INTO valoracions VALUES (658, 112, '18/10/2007', 5);
INSERT INTO valoracions VALUES (658, 43, '30/04/2008', 9);
INSERT INTO valoracions VALUES (659, 88, '29/02/2004', 1);
INSERT INTO valoracions VALUES (659, 92, '20/08/2005', 5);
INSERT INTO valoracions VALUES (659, 97, '07/07/2007', 2);
INSERT INTO valoracions VALUES (660, 90, '27/06/2004', 9);
INSERT INTO valoracions VALUES (660, 55, '28/07/2009', 6);
INSERT INTO valoracions VALUES (660, 21, '17/04/2006', 9);
INSERT INTO valoracions VALUES (660, 100, '30/07/2010', 2);
INSERT INTO valoracions VALUES (660, 90, '16/02/2003', 8);
INSERT INTO valoracions VALUES (660, 94, '04/12/2009', 8);
INSERT INTO valoracions VALUES (661, 105, '01/06/2010', 2);
INSERT INTO valoracions VALUES (661, 66, '17/06/2003', 9);
INSERT INTO valoracions VALUES (661, 11, '07/02/2008', 9);
INSERT INTO valoracions VALUES (661, 79, '16/04/2008', 8);
INSERT INTO valoracions VALUES (661, 30, '29/04/2006', 8);
INSERT INTO valoracions VALUES (661, 34, '02/12/2008', 9);
INSERT INTO valoracions VALUES (661, 2, '19/12/2007', 7);
INSERT INTO valoracions VALUES (662, 44, '07/10/2001', 6);
INSERT INTO valoracions VALUES (662, 84, '18/08/2003', 6);
INSERT INTO valoracions VALUES (662, 102, '08/03/2010', 5);
INSERT INTO valoracions VALUES (662, 17, '13/12/2007', 9);
INSERT INTO valoracions VALUES (663, 13, '24/02/2005', 7);
INSERT INTO valoracions VALUES (663, 35, '26/06/2006', 7);
INSERT INTO valoracions VALUES (663, 94, '30/08/2009', 8);
INSERT INTO valoracions VALUES (663, 112, '22/09/2004', 5);
INSERT INTO valoracions VALUES (663, 38, '08/09/2001', 3);
INSERT INTO valoracions VALUES (664, 101, '12/07/2006', 4);
INSERT INTO valoracions VALUES (664, 68, '17/04/2004', 7);
INSERT INTO valoracions VALUES (664, 33, '14/06/2002', 4);
INSERT INTO valoracions VALUES (664, 29, '04/12/2009', 9);
INSERT INTO valoracions VALUES (664, 34, '31/07/2004', 9);
INSERT INTO valoracions VALUES (665, 91, '08/05/2010', 9);
INSERT INTO valoracions VALUES (665, 107, '25/11/2004', 6);
INSERT INTO valoracions VALUES (665, 58, '16/07/2010', 6);
INSERT INTO valoracions VALUES (665, 5, '12/09/2003', 5);
INSERT INTO valoracions VALUES (666, 11, '16/05/2008', 7);
INSERT INTO valoracions VALUES (666, 25, '01/04/2003', 6);
INSERT INTO valoracions VALUES (666, 98, '30/07/2009', 5);
INSERT INTO valoracions VALUES (666, 66, '02/10/2007', 9);
INSERT INTO valoracions VALUES (666, 18, '24/01/2006', 7);
INSERT INTO valoracions VALUES (666, 32, '14/08/2007', 6);
INSERT INTO valoracions VALUES (666, 4, '05/06/2003', 6);
INSERT INTO valoracions VALUES (666, 108, '06/04/2005', 10);
INSERT INTO valoracions VALUES (666, 106, '11/05/2004', 5);
INSERT INTO valoracions VALUES (667, 52, '25/06/2006', 4);
INSERT INTO valoracions VALUES (668, 94, '25/08/2007', 8);
INSERT INTO valoracions VALUES (668, 49, '17/04/2009', 9);
INSERT INTO valoracions VALUES (668, 28, '09/03/2006', 6);
INSERT INTO valoracions VALUES (669, 52, '18/04/2004', 5);
INSERT INTO valoracions VALUES (669, 70, '23/10/2004', 10);
INSERT INTO valoracions VALUES (669, 3, '30/01/2009', 7);
INSERT INTO valoracions VALUES (670, 26, '06/03/2008', 8);
INSERT INTO valoracions VALUES (670, 32, '16/02/2002', 9);
INSERT INTO valoracions VALUES (670, 89, '04/06/2010', 4);
INSERT INTO valoracions VALUES (670, 64, '11/06/2003', 4);
INSERT INTO valoracions VALUES (671, 53, '10/12/2002', 7);
INSERT INTO valoracions VALUES (671, 94, '06/03/2007', 3);
INSERT INTO valoracions VALUES (671, 70, '25/11/2007', 7);
INSERT INTO valoracions VALUES (672, 92, '08/06/2009', 5);
INSERT INTO valoracions VALUES (672, 35, '25/11/2007', 8);
INSERT INTO valoracions VALUES (672, 32, '19/10/2001', 7);
INSERT INTO valoracions VALUES (673, 95, '24/06/2001', 7);
INSERT INTO valoracions VALUES (674, 54, '17/02/2004', 5);
INSERT INTO valoracions VALUES (674, 27, '06/01/2009', 7);
INSERT INTO valoracions VALUES (674, 96, '25/10/2004', 5);
INSERT INTO valoracions VALUES (674, 116, '21/06/2007', 2);
INSERT INTO valoracions VALUES (674, 7, '22/02/2009', 7);
INSERT INTO valoracions VALUES (674, 116, '11/08/2002', 3);
INSERT INTO valoracions VALUES (675, 106, '22/09/2002', 0);
INSERT INTO valoracions VALUES (675, 91, '03/07/2006', 9);
INSERT INTO valoracions VALUES (675, 1, '24/09/2009', 10);
INSERT INTO valoracions VALUES (676, 55, '04/02/2010', 3);
INSERT INTO valoracions VALUES (676, 41, '30/12/2009', 10);
INSERT INTO valoracions VALUES (676, 52, '28/05/2010', 9);
INSERT INTO valoracions VALUES (676, 66, '09/05/2005', 8);
INSERT INTO valoracions VALUES (676, 76, '27/10/2001', 3);
INSERT INTO valoracions VALUES (676, 63, '18/02/2007', 6);
INSERT INTO valoracions VALUES (676, 93, '23/05/2001', 6);
INSERT INTO valoracions VALUES (677, 45, '26/05/2006', 9);
INSERT INTO valoracions VALUES (677, 76, '15/01/2010', 3);
INSERT INTO valoracions VALUES (678, 111, '25/10/2005', 1);
INSERT INTO valoracions VALUES (678, 9, '12/05/2002', 8);
INSERT INTO valoracions VALUES (679, 6, '06/10/2010', 9);
INSERT INTO valoracions VALUES (679, 67, '04/01/2004', 6);
INSERT INTO valoracions VALUES (679, 35, '29/11/2006', 8);
INSERT INTO valoracions VALUES (679, 88, '19/09/2006', 7);
INSERT INTO valoracions VALUES (680, 107, '06/07/2007', 9);
INSERT INTO valoracions VALUES (680, 32, '31/08/2007', 7);
INSERT INTO valoracions VALUES (680, 42, '11/03/2007', 8);
INSERT INTO valoracions VALUES (680, 92, '26/10/2005', 10);
INSERT INTO valoracions VALUES (681, 103, '08/06/2009', 10);
INSERT INTO valoracions VALUES (681, 60, '10/09/2002', 8);
INSERT INTO valoracions VALUES (681, 91, '18/07/2007', 7);
INSERT INTO valoracions VALUES (681, 3, '10/03/2004', 5);
INSERT INTO valoracions VALUES (681, 87, '22/10/2001', 7);
INSERT INTO valoracions VALUES (682, 8, '27/03/2009', 9);
INSERT INTO valoracions VALUES (682, 80, '15/09/2002', 10);
INSERT INTO valoracions VALUES (682, 80, '06/07/2004', 9);
INSERT INTO valoracions VALUES (682, 110, '25/10/2003', 4);
INSERT INTO valoracions VALUES (682, 49, '07/03/2010', 7);
INSERT INTO valoracions VALUES (682, 81, '17/01/2007', 10);
INSERT INTO valoracions VALUES (682, 19, '27/06/2010', 5);
INSERT INTO valoracions VALUES (683, 111, '22/04/2004', 5);
INSERT INTO valoracions VALUES (683, 37, '12/02/2004', 5);
INSERT INTO valoracions VALUES (684, 89, '12/01/2002', 3);
INSERT INTO valoracions VALUES (684, 22, '03/02/2008', 5);
INSERT INTO valoracions VALUES (684, 31, '15/02/2007', 5);
INSERT INTO valoracions VALUES (684, 55, '09/11/2005', 9);
INSERT INTO valoracions VALUES (684, 111, '10/01/2003', 10);
INSERT INTO valoracions VALUES (684, 23, '12/08/2003', 6);
INSERT INTO valoracions VALUES (685, 33, '25/04/2007', 4);
INSERT INTO valoracions VALUES (685, 34, '23/02/2004', 8);
INSERT INTO valoracions VALUES (685, 71, '10/02/2008', 6);
INSERT INTO valoracions VALUES (686, 90, '18/06/2007', 10);
INSERT INTO valoracions VALUES (686, 10, '07/08/2005', 7);
INSERT INTO valoracions VALUES (686, 24, '22/11/2004', 5);
INSERT INTO valoracions VALUES (686, 89, '29/10/2003', 8);
INSERT INTO valoracions VALUES (686, 101, '04/08/2004', 9);
INSERT INTO valoracions VALUES (686, 12, '07/01/2004', 6);
INSERT INTO valoracions VALUES (687, 63, '30/01/2008', 6);
INSERT INTO valoracions VALUES (687, 39, '12/02/2006', 7);
INSERT INTO valoracions VALUES (687, 110, '27/04/2006', 9);
INSERT INTO valoracions VALUES (687, 88, '26/11/2003', 7);
INSERT INTO valoracions VALUES (687, 10, '04/10/2007', 8);
INSERT INTO valoracions VALUES (688, 21, '16/03/2006', 5);
INSERT INTO valoracions VALUES (688, 113, '15/10/2001', 1);
INSERT INTO valoracions VALUES (689, 66, '27/08/2008', 5);
INSERT INTO valoracions VALUES (689, 103, '26/06/2010', 2);
INSERT INTO valoracions VALUES (689, 93, '06/01/2009', 10);
INSERT INTO valoracions VALUES (689, 26, '11/04/2002', 5);
INSERT INTO valoracions VALUES (690, 52, '13/08/2001', 6);
INSERT INTO valoracions VALUES (690, 89, '04/06/2005', 6);
INSERT INTO valoracions VALUES (690, 10, '21/07/2001', 6);
INSERT INTO valoracions VALUES (690, 58, '23/03/2002', 6);
INSERT INTO valoracions VALUES (691, 73, '25/08/2004', 8);
INSERT INTO valoracions VALUES (691, 26, '24/09/2010', 6);
INSERT INTO valoracions VALUES (691, 74, '19/10/2007', 8);
INSERT INTO valoracions VALUES (692, 77, '12/05/2002', 4);
INSERT INTO valoracions VALUES (692, 20, '29/06/2002', 5);
INSERT INTO valoracions VALUES (692, 1, '01/06/2003', 8);
INSERT INTO valoracions VALUES (692, 14, '19/02/2006', 7);
INSERT INTO valoracions VALUES (692, 106, '23/08/2002', 6);
INSERT INTO valoracions VALUES (693, 66, '25/02/2006', 4);
INSERT INTO valoracions VALUES (693, 102, '08/04/2006', 8);
INSERT INTO valoracions VALUES (693, 104, '19/04/2004', 7);
INSERT INTO valoracions VALUES (693, 45, '21/09/2001', 7);
INSERT INTO valoracions VALUES (694, 49, '15/01/2005', 6);
INSERT INTO valoracions VALUES (694, 82, '02/01/2007', 9);
INSERT INTO valoracions VALUES (694, 81, '01/09/2010', 6);
INSERT INTO valoracions VALUES (694, 100, '06/12/2001', 4);
INSERT INTO valoracions VALUES (694, 106, '14/09/2001', 2);
INSERT INTO valoracions VALUES (694, 43, '13/11/2007', 6);
INSERT INTO valoracions VALUES (694, 105, '08/03/2003', 2);
INSERT INTO valoracions VALUES (694, 115, '21/04/2001', 9);
INSERT INTO valoracions VALUES (694, 42, '01/01/2003', 5);
INSERT INTO valoracions VALUES (695, 56, '27/03/2006', 3);
INSERT INTO valoracions VALUES (695, 54, '12/08/2009', 3);
INSERT INTO valoracions VALUES (695, 11, '27/02/2010', 10);
INSERT INTO valoracions VALUES (695, 96, '03/02/2002', 6);
INSERT INTO valoracions VALUES (695, 22, '02/09/2009', 6);
INSERT INTO valoracions VALUES (695, 54, '10/11/2006', 8);
INSERT INTO valoracions VALUES (695, 37, '28/09/2004', 5);
INSERT INTO valoracions VALUES (696, 66, '31/12/2009', 5);
INSERT INTO valoracions VALUES (697, 113, '10/05/2003', 8);
INSERT INTO valoracions VALUES (697, 42, '02/03/2008', 6);
INSERT INTO valoracions VALUES (698, 80, '09/03/2005', 10);
INSERT INTO valoracions VALUES (698, 50, '10/05/2001', 6);
INSERT INTO valoracions VALUES (698, 59, '18/07/2002', 7);
INSERT INTO valoracions VALUES (698, 59, '20/12/2002', 9);
INSERT INTO valoracions VALUES (699, 68, '09/01/2004', 4);
INSERT INTO valoracions VALUES (699, 40, '18/08/2010', 9);
INSERT INTO valoracions VALUES (699, 38, '29/06/2001', 8);
INSERT INTO valoracions VALUES (699, 15, '05/02/2005', 4);
INSERT INTO valoracions VALUES (699, 18, '05/11/2005', 5);
INSERT INTO valoracions VALUES (699, 45, '22/08/2001', 9);
INSERT INTO valoracions VALUES (699, 53, '10/01/2004', 10);
INSERT INTO valoracions VALUES (700, 11, '16/04/2003', 9);
INSERT INTO valoracions VALUES (700, 9, '21/11/2006', 7);
INSERT INTO valoracions VALUES (700, 98, '24/03/2008', 5);
INSERT INTO valoracions VALUES (700, 100, '07/01/2008', 2);
INSERT INTO valoracions VALUES (700, 39, '02/12/2003', 4);
INSERT INTO valoracions VALUES (700, 99, '21/07/2001', 6);
INSERT INTO valoracions VALUES (701, 20, '30/08/2009', 4);
INSERT INTO valoracions VALUES (701, 42, '22/06/2006', 7);
INSERT INTO valoracions VALUES (701, 76, '18/06/2001', 4);
INSERT INTO valoracions VALUES (702, 23, '30/07/2001', 9);
INSERT INTO valoracions VALUES (702, 84, '27/05/2003', 2);
INSERT INTO valoracions VALUES (702, 5, '08/03/2003', 8);
INSERT INTO valoracions VALUES (702, 60, '29/03/2006', 8);
INSERT INTO valoracions VALUES (702, 51, '24/01/2003', 4);
INSERT INTO valoracions VALUES (703, 102, '13/08/2005', 3);
INSERT INTO valoracions VALUES (703, 89, '08/04/2010', 4);
INSERT INTO valoracions VALUES (703, 3, '11/01/2002', 5);
INSERT INTO valoracions VALUES (703, 53, '08/04/2003', 4);
INSERT INTO valoracions VALUES (703, 24, '15/07/2001', 4);
INSERT INTO valoracions VALUES (703, 65, '28/02/2008', 7);
INSERT INTO valoracions VALUES (704, 60, '05/08/2005', 3);
INSERT INTO valoracions VALUES (705, 71, '13/02/2009', 8);
INSERT INTO valoracions VALUES (705, 80, '28/06/2002', 7);
INSERT INTO valoracions VALUES (705, 15, '04/08/2004', 7);
INSERT INTO valoracions VALUES (705, 57, '16/10/2002', 8);
INSERT INTO valoracions VALUES (705, 50, '03/02/2002', 7);
INSERT INTO valoracions VALUES (706, 61, '09/12/2008', 6);
INSERT INTO valoracions VALUES (706, 76, '18/05/2004', 8);
INSERT INTO valoracions VALUES (706, 50, '27/08/2006', 9);
INSERT INTO valoracions VALUES (706, 20, '26/02/2005', 5);
INSERT INTO valoracions VALUES (706, 16, '20/05/2010', 8);
INSERT INTO valoracions VALUES (706, 9, '14/01/2009', 9);
INSERT INTO valoracions VALUES (707, 60, '21/10/2004', 5);
INSERT INTO valoracions VALUES (707, 113, '07/10/2007', 5);
INSERT INTO valoracions VALUES (707, 9, '16/08/2005', 8);
INSERT INTO valoracions VALUES (707, 80, '23/12/2001', 7);
INSERT INTO valoracions VALUES (707, 97, '10/03/2002', 6);
INSERT INTO valoracions VALUES (708, 103, '25/04/2004', 6);
INSERT INTO valoracions VALUES (708, 64, '11/07/2002', 3);
INSERT INTO valoracions VALUES (708, 53, '31/10/2001', 7);
INSERT INTO valoracions VALUES (709, 96, '20/04/2005', 7);
INSERT INTO valoracions VALUES (709, 65, '21/02/2003', 5);
INSERT INTO valoracions VALUES (709, 78, '14/07/2008', 2);
INSERT INTO valoracions VALUES (709, 77, '02/10/2003', 8);
INSERT INTO valoracions VALUES (709, 7, '28/07/2006', 10);
INSERT INTO valoracions VALUES (709, 50, '21/07/2001', 6);
INSERT INTO valoracions VALUES (709, 52, '15/09/2004', 3);
INSERT INTO valoracions VALUES (709, 36, '01/12/2005', 6);
INSERT INTO valoracions VALUES (710, 1, '07/08/2009', 8);
INSERT INTO valoracions VALUES (710, 45, '25/01/2006', 10);
INSERT INTO valoracions VALUES (710, 85, '28/03/2005', 4);
INSERT INTO valoracions VALUES (710, 45, '19/10/2009', 7);
INSERT INTO valoracions VALUES (710, 51, '22/06/2009', 6);
INSERT INTO valoracions VALUES (711, 12, '18/03/2002', 6);
INSERT INTO valoracions VALUES (712, 115, '18/08/2010', 9);
INSERT INTO valoracions VALUES (712, 44, '14/05/2007', 9);
INSERT INTO valoracions VALUES (712, 92, '03/05/2010', 4);
INSERT INTO valoracions VALUES (713, 109, '05/04/2005', 7);
INSERT INTO valoracions VALUES (713, 28, '07/08/2010', 9);
INSERT INTO valoracions VALUES (713, 52, '12/01/2006', 4);
INSERT INTO valoracions VALUES (713, 83, '21/05/2008', 1);
INSERT INTO valoracions VALUES (713, 21, '30/07/2001', 6);
INSERT INTO valoracions VALUES (714, 10, '25/04/2007', 6);
INSERT INTO valoracions VALUES (714, 110, '09/04/2002', 6);
INSERT INTO valoracions VALUES (715, 26, '23/11/2005', 8);
INSERT INTO valoracions VALUES (715, 31, '25/08/2008', 10);
INSERT INTO valoracions VALUES (715, 85, '26/01/2004', 6);
INSERT INTO valoracions VALUES (715, 14, '21/08/2002', 8);
INSERT INTO valoracions VALUES (715, 72, '30/10/2008', 5);
INSERT INTO valoracions VALUES (715, 54, '29/12/2009', 10);
INSERT INTO valoracions VALUES (715, 17, '02/08/2006', 9);
INSERT INTO valoracions VALUES (716, 51, '04/10/2009', 5);
INSERT INTO valoracions VALUES (716, 16, '06/07/2005', 9);
INSERT INTO valoracions VALUES (716, 36, '29/08/2010', 9);
INSERT INTO valoracions VALUES (717, 1, '14/02/2009', 9);
INSERT INTO valoracions VALUES (717, 106, '13/02/2007', 2);
INSERT INTO valoracions VALUES (717, 85, '22/07/2002', 7);
INSERT INTO valoracions VALUES (718, 114, '03/11/2002', 1);
INSERT INTO valoracions VALUES (718, 20, '21/04/2007', 5);
INSERT INTO valoracions VALUES (718, 66, '30/04/2005', 5);
INSERT INTO valoracions VALUES (719, 103, '19/02/2006', 6);
INSERT INTO valoracions VALUES (719, 28, '11/08/2001', 8);
INSERT INTO valoracions VALUES (720, 69, '21/02/2009', 8);
INSERT INTO valoracions VALUES (720, 114, '29/03/2005', 0);
INSERT INTO valoracions VALUES (720, 47, '24/04/2001', 5);
INSERT INTO valoracions VALUES (720, 46, '27/01/2007', 8);
INSERT INTO valoracions VALUES (721, 45, '30/12/2002', 5);
INSERT INTO valoracions VALUES (721, 23, '24/01/2008', 6);
INSERT INTO valoracions VALUES (722, 96, '28/02/2008', 5);
INSERT INTO valoracions VALUES (723, 69, '23/01/2003', 10);
INSERT INTO valoracions VALUES (723, 107, '02/05/2001', 5);
INSERT INTO valoracions VALUES (724, 111, '31/03/2010', 7);
INSERT INTO valoracions VALUES (724, 53, '26/06/2002', 4);
INSERT INTO valoracions VALUES (724, 71, '16/05/2004', 2);
INSERT INTO valoracions VALUES (724, 45, '02/12/2003', 8);
INSERT INTO valoracions VALUES (724, 92, '10/05/2005', 5);
INSERT INTO valoracions VALUES (724, 65, '04/04/2007', 8);
INSERT INTO valoracions VALUES (725, 116, '05/01/2002', 10);
INSERT INTO valoracions VALUES (725, 115, '28/04/2004', 8);
INSERT INTO valoracions VALUES (726, 68, '01/05/2007', 9);
INSERT INTO valoracions VALUES (726, 12, '26/02/2007', 8);
INSERT INTO valoracions VALUES (726, 3, '13/01/2006', 6);
INSERT INTO valoracions VALUES (726, 16, '11/11/2002', 8);
INSERT INTO valoracions VALUES (727, 70, '03/02/2008', 8);
INSERT INTO valoracions VALUES (727, 85, '19/11/2001', 8);
INSERT INTO valoracions VALUES (727, 91, '06/10/2009', 4);
INSERT INTO valoracions VALUES (727, 90, '28/12/2007', 8);
INSERT INTO valoracions VALUES (727, 23, '28/07/2010', 6);
INSERT INTO valoracions VALUES (727, 78, '14/07/2004', 3);
INSERT INTO valoracions VALUES (727, 12, '11/07/2001', 7);
INSERT INTO valoracions VALUES (728, 2, '12/02/2009', 8);
INSERT INTO valoracions VALUES (728, 58, '18/04/2003', 3);
INSERT INTO valoracions VALUES (728, 79, '28/06/2005', 5);
INSERT INTO valoracions VALUES (729, 21, '22/04/2010', 7);
INSERT INTO valoracions VALUES (729, 88, '22/04/2008', 6);
INSERT INTO valoracions VALUES (729, 105, '07/04/2009', 8);
INSERT INTO valoracions VALUES (729, 71, '06/12/2009', 7);
INSERT INTO valoracions VALUES (729, 17, '31/01/2006', 7);
INSERT INTO valoracions VALUES (729, 12, '28/04/2008', 7);
INSERT INTO valoracions VALUES (729, 96, '05/02/2005', 5);
INSERT INTO valoracions VALUES (729, 85, '19/12/2005', 6);
INSERT INTO valoracions VALUES (730, 12, '16/05/2006', 7);
INSERT INTO valoracions VALUES (730, 65, '30/07/2006', 4);
INSERT INTO valoracions VALUES (730, 68, '30/01/2006', 8);
INSERT INTO valoracions VALUES (730, 60, '30/05/2004', 7);
INSERT INTO valoracions VALUES (730, 49, '27/02/2003', 9);
INSERT INTO valoracions VALUES (730, 116, '04/11/2001', 5);
INSERT INTO valoracions VALUES (730, 68, '14/02/2002', 5);
INSERT INTO valoracions VALUES (730, 77, '14/03/2010', 8);
INSERT INTO valoracions VALUES (730, 55, '20/08/2007', 3);
INSERT INTO valoracions VALUES (731, 111, '08/07/2001', 7);
INSERT INTO valoracions VALUES (731, 116, '06/07/2007', 6);
INSERT INTO valoracions VALUES (731, 88, '24/04/2008', 3);
INSERT INTO valoracions VALUES (731, 17, '08/04/2010', 8);
INSERT INTO valoracions VALUES (731, 35, '06/06/2002', 7);
INSERT INTO valoracions VALUES (732, 29, '17/07/2002', 9);
INSERT INTO valoracions VALUES (732, 12, '06/12/2009', 8);
INSERT INTO valoracions VALUES (732, 59, '16/09/2002', 4);
INSERT INTO valoracions VALUES (732, 69, '27/07/2003', 5);
INSERT INTO valoracions VALUES (733, 48, '23/12/2002', 5);
INSERT INTO valoracions VALUES (733, 98, '09/07/2008', 4);
INSERT INTO valoracions VALUES (733, 25, '21/04/2001', 8);
INSERT INTO valoracions VALUES (733, 81, '09/10/2001', 2);
INSERT INTO valoracions VALUES (733, 14, '18/04/2010', 7);
INSERT INTO valoracions VALUES (734, 106, '20/02/2008', 7);
INSERT INTO valoracions VALUES (734, 110, '02/11/2005', 3);
INSERT INTO valoracions VALUES (735, 62, '12/02/2005', 5);
INSERT INTO valoracions VALUES (735, 37, '23/10/2004', 7);
INSERT INTO valoracions VALUES (735, 27, '13/06/2010', 4);
INSERT INTO valoracions VALUES (736, 61, '17/11/2006', 10);
INSERT INTO valoracions VALUES (736, 59, '23/10/2010', 5);
INSERT INTO valoracions VALUES (736, 2, '06/07/2002', 9);
INSERT INTO valoracions VALUES (737, 18, '10/07/2001', 9);
INSERT INTO valoracions VALUES (738, 54, '16/07/2006', 4);
INSERT INTO valoracions VALUES (738, 69, '04/05/2007', 4);
INSERT INTO valoracions VALUES (739, 43, '02/08/2001', 9);
INSERT INTO valoracions VALUES (739, 36, '02/10/2008', 5);
INSERT INTO valoracions VALUES (739, 87, '29/12/2008', 2);
INSERT INTO valoracions VALUES (739, 41, '21/08/2010', 7);
INSERT INTO valoracions VALUES (739, 60, '31/01/2010', 2);
INSERT INTO valoracions VALUES (739, 24, '18/04/2004', 8);
INSERT INTO valoracions VALUES (739, 86, '07/04/2009', 5);
INSERT INTO valoracions VALUES (739, 115, '14/08/2004', 4);
INSERT INTO valoracions VALUES (739, 27, '10/03/2007', 6);
INSERT INTO valoracions VALUES (740, 66, '08/10/2004', 7);
INSERT INTO valoracions VALUES (740, 13, '13/02/2006', 6);
INSERT INTO valoracions VALUES (740, 35, '05/02/2003', 8);
INSERT INTO valoracions VALUES (740, 14, '17/10/2005', 4);
INSERT INTO valoracions VALUES (740, 46, '13/03/2009', 4);
INSERT INTO valoracions VALUES (741, 94, '13/05/2002', 3);
INSERT INTO valoracions VALUES (741, 112, '26/01/2010', 1);
INSERT INTO valoracions VALUES (741, 40, '23/04/2003', 5);
INSERT INTO valoracions VALUES (741, 41, '30/01/2002', 8);
INSERT INTO valoracions VALUES (742, 65, '12/08/2004', 5);
INSERT INTO valoracions VALUES (742, 60, '07/05/2003', 8);
INSERT INTO valoracions VALUES (742, 88, '10/03/2005', 5);
INSERT INTO valoracions VALUES (743, 39, '20/03/2003', 8);
INSERT INTO valoracions VALUES (743, 93, '02/03/2007', 6);
INSERT INTO valoracions VALUES (743, 81, '18/08/2008', 7);
INSERT INTO valoracions VALUES (744, 25, '10/04/2004', 8);
INSERT INTO valoracions VALUES (744, 48, '12/02/2005', 10);
INSERT INTO valoracions VALUES (744, 13, '04/08/2002', 8);
INSERT INTO valoracions VALUES (744, 19, '11/11/2005', 7);
INSERT INTO valoracions VALUES (744, 105, '16/12/2008', 1);
INSERT INTO valoracions VALUES (745, 2, '29/08/2008', 9);
INSERT INTO valoracions VALUES (745, 96, '18/12/2006', 7);
INSERT INTO valoracions VALUES (746, 90, '19/10/2010', 2);
INSERT INTO valoracions VALUES (746, 69, '13/01/2007', 2);
INSERT INTO valoracions VALUES (746, 24, '09/10/2005', 5);
INSERT INTO valoracions VALUES (746, 24, '04/04/2007', 5);
INSERT INTO valoracions VALUES (747, 28, '03/06/2008', 4);
INSERT INTO valoracions VALUES (747, 55, '29/11/2007', 9);
INSERT INTO valoracions VALUES (747, 37, '04/05/2002', 7);
INSERT INTO valoracions VALUES (747, 115, '28/04/2002', 3);
INSERT INTO valoracions VALUES (747, 79, '30/07/2001', 6);
INSERT INTO valoracions VALUES (747, 90, '12/09/2001', 2);
INSERT INTO valoracions VALUES (747, 77, '11/07/2005', 2);
INSERT INTO valoracions VALUES (747, 114, '27/07/2007', 1);
INSERT INTO valoracions VALUES (747, 5, '22/09/2005', 5);
INSERT INTO valoracions VALUES (748, 43, '20/10/2003', 9);
INSERT INTO valoracions VALUES (748, 97, '21/02/2008', 4);
INSERT INTO valoracions VALUES (748, 56, '20/08/2008', 10);
INSERT INTO valoracions VALUES (748, 87, '07/04/2004', 4);
INSERT INTO valoracions VALUES (748, 23, '05/05/2007', 9);
INSERT INTO valoracions VALUES (748, 80, '25/05/2007', 7);
INSERT INTO valoracions VALUES (748, 98, '13/12/2001', 4);
INSERT INTO valoracions VALUES (749, 8, '17/06/2009', 7);
INSERT INTO valoracions VALUES (749, 44, '27/06/2003', 7);
INSERT INTO valoracions VALUES (749, 54, '13/05/2007', 9);
INSERT INTO valoracions VALUES (749, 26, '29/08/2008', 5);
INSERT INTO valoracions VALUES (749, 16, '20/10/2004', 6);
INSERT INTO valoracions VALUES (750, 94, '22/10/2006', 6);
INSERT INTO valoracions VALUES (750, 89, '13/01/2008', 1);
INSERT INTO valoracions VALUES (750, 26, '01/11/2002', 9);
INSERT INTO valoracions VALUES (751, 98, '16/10/2010', 4);
INSERT INTO valoracions VALUES (751, 57, '27/04/2008', 6);
INSERT INTO valoracions VALUES (752, 73, '09/10/2004', 6);
INSERT INTO valoracions VALUES (752, 80, '20/01/2009', 9);
INSERT INTO valoracions VALUES (752, 29, '10/11/2005', 8);
INSERT INTO valoracions VALUES (752, 80, '24/05/2005', 3);
INSERT INTO valoracions VALUES (752, 104, '28/11/2004', 2);
INSERT INTO valoracions VALUES (753, 116, '12/05/2007', 1);
INSERT INTO valoracions VALUES (753, 45, '18/02/2002', 8);
INSERT INTO valoracions VALUES (754, 90, '08/02/2008', 2);
INSERT INTO valoracions VALUES (754, 89, '08/05/2010', 3);
INSERT INTO valoracions VALUES (754, 104, '06/01/2002', 2);
INSERT INTO valoracions VALUES (754, 2, '11/10/2004', 7);
INSERT INTO valoracions VALUES (754, 37, '20/04/2003', 7);
INSERT INTO valoracions VALUES (755, 59, '20/09/2002', 3);
INSERT INTO valoracions VALUES (755, 29, '12/01/2002', 6);
INSERT INTO valoracions VALUES (755, 68, '12/10/2010', 7);
INSERT INTO valoracions VALUES (755, 79, '15/11/2002', 4);
INSERT INTO valoracions VALUES (756, 52, '25/01/2004', 9);
INSERT INTO valoracions VALUES (756, 21, '08/11/2002', 8);
INSERT INTO valoracions VALUES (756, 56, '23/01/2009', 8);
INSERT INTO valoracions VALUES (756, 69, '14/11/2004', 3);
INSERT INTO valoracions VALUES (757, 109, '17/04/2008', 2);
INSERT INTO valoracions VALUES (757, 102, '31/07/2007', 4);
INSERT INTO valoracions VALUES (757, 111, '04/08/2010', 10);
INSERT INTO valoracions VALUES (758, 61, '08/04/2009', 9);
INSERT INTO valoracions VALUES (758, 7, '22/03/2003', 8);
INSERT INTO valoracions VALUES (758, 41, '28/06/2004', 8);
INSERT INTO valoracions VALUES (758, 82, '28/07/2006', 5);
INSERT INTO valoracions VALUES (759, 49, '02/06/2004', 9);
INSERT INTO valoracions VALUES (759, 29, '02/08/2004', 8);
INSERT INTO valoracions VALUES (759, 23, '02/08/2003', 8);
INSERT INTO valoracions VALUES (759, 58, '26/02/2006', 6);
INSERT INTO valoracions VALUES (759, 39, '01/07/2008', 5);
INSERT INTO valoracions VALUES (759, 45, '29/09/2009', 4);
INSERT INTO valoracions VALUES (759, 93, '28/09/2007', 9);
INSERT INTO valoracions VALUES (759, 77, '11/02/2006', 3);
INSERT INTO valoracions VALUES (759, 68, '21/04/2010', 4);
INSERT INTO valoracions VALUES (759, 24, '14/09/2010', 5);
INSERT INTO valoracions VALUES (761, 51, '16/03/2009', 10);
INSERT INTO valoracions VALUES (761, 3, '17/03/2010', 5);
INSERT INTO valoracions VALUES (761, 97, '29/06/2010', 10);
INSERT INTO valoracions VALUES (761, 88, '14/11/2009', 3);
INSERT INTO valoracions VALUES (762, 102, '01/10/2004', 3);
INSERT INTO valoracions VALUES (762, 94, '17/02/2005', 2);
INSERT INTO valoracions VALUES (762, 24, '01/06/2008', 8);
INSERT INTO valoracions VALUES (762, 116, '04/02/2009', 8);
INSERT INTO valoracions VALUES (762, 65, '31/12/2004', 4);
INSERT INTO valoracions VALUES (763, 54, '05/01/2006', 6);
INSERT INTO valoracions VALUES (763, 19, '16/07/2009', 6);
INSERT INTO valoracions VALUES (763, 34, '30/12/2008', 5);
INSERT INTO valoracions VALUES (764, 20, '03/06/2002', 5);
INSERT INTO valoracions VALUES (765, 42, '21/01/2009', 6);
INSERT INTO valoracions VALUES (766, 77, '16/03/2002', 7);
INSERT INTO valoracions VALUES (766, 65, '12/04/2005', 7);
INSERT INTO valoracions VALUES (766, 47, '17/02/2007', 9);
INSERT INTO valoracions VALUES (766, 102, '16/04/2010', 8);
INSERT INTO valoracions VALUES (767, 107, '28/08/2006', 1);
INSERT INTO valoracions VALUES (767, 114, '22/12/2001', 2);
INSERT INTO valoracions VALUES (767, 100, '02/06/2001', 9);
INSERT INTO valoracions VALUES (768, 12, '11/11/2005', 9);
INSERT INTO valoracions VALUES (768, 84, '09/02/2005', 7);
INSERT INTO valoracions VALUES (768, 30, '12/12/2006', 8);
INSERT INTO valoracions VALUES (768, 66, '19/04/2009', 10);
INSERT INTO valoracions VALUES (768, 44, '28/04/2003', 6);
INSERT INTO valoracions VALUES (768, 48, '17/10/2001', 8);
INSERT INTO valoracions VALUES (768, 55, '13/09/2001', 9);
INSERT INTO valoracions VALUES (768, 54, '10/06/2010', 3);
INSERT INTO valoracions VALUES (768, 85, '09/10/2007', 2);
INSERT INTO valoracions VALUES (769, 93, '05/07/2002', 9);
INSERT INTO valoracions VALUES (769, 101, '12/04/2003', 6);
INSERT INTO valoracions VALUES (769, 45, '05/04/2010', 7);
INSERT INTO valoracions VALUES (769, 52, '10/10/2009', 4);
INSERT INTO valoracions VALUES (769, 51, '01/01/2005', 6);
INSERT INTO valoracions VALUES (769, 41, '27/06/2001', 7);
INSERT INTO valoracions VALUES (769, 93, '17/04/2006', 9);
INSERT INTO valoracions VALUES (770, 13, '29/10/2001', 7);
INSERT INTO valoracions VALUES (770, 5, '09/11/2002', 10);
INSERT INTO valoracions VALUES (770, 10, '21/10/2005', 7);
INSERT INTO valoracions VALUES (771, 26, '14/04/2007', 8);
INSERT INTO valoracions VALUES (771, 33, '04/10/2003', 5);
INSERT INTO valoracions VALUES (771, 111, '27/12/2001', 6);
INSERT INTO valoracions VALUES (771, 106, '10/02/2003', 8);
INSERT INTO valoracions VALUES (771, 45, '27/08/2005', 5);
INSERT INTO valoracions VALUES (772, 63, '07/12/2007', 2);
INSERT INTO valoracions VALUES (772, 67, '15/09/2007', 4);
INSERT INTO valoracions VALUES (772, 19, '12/09/2007', 5);
INSERT INTO valoracions VALUES (773, 11, '09/03/2006', 6);
INSERT INTO valoracions VALUES (773, 48, '12/12/2006', 4);
INSERT INTO valoracions VALUES (773, 39, '20/04/2008', 7);
INSERT INTO valoracions VALUES (773, 113, '13/07/2008', 3);
INSERT INTO valoracions VALUES (774, 18, '31/01/2004', 8);
INSERT INTO valoracions VALUES (774, 47, '14/06/2006', 4);
INSERT INTO valoracions VALUES (774, 90, '22/02/2003', 3);
INSERT INTO valoracions VALUES (774, 55, '13/08/2004', 9);
INSERT INTO valoracions VALUES (775, 44, '28/05/2007', 7);
INSERT INTO valoracions VALUES (775, 27, '08/04/2009', 6);
INSERT INTO valoracions VALUES (776, 104, '22/12/2003', 2);
INSERT INTO valoracions VALUES (776, 14, '04/05/2007', 7);
INSERT INTO valoracions VALUES (776, 100, '11/03/2003', 2);
INSERT INTO valoracions VALUES (776, 105, '18/05/2009', 2);
INSERT INTO valoracions VALUES (776, 33, '07/10/2010', 4);
INSERT INTO valoracions VALUES (777, 94, '15/10/2001', 6);
INSERT INTO valoracions VALUES (777, 24, '24/08/2003', 5);
INSERT INTO valoracions VALUES (777, 8, '22/06/2005', 8);
INSERT INTO valoracions VALUES (777, 51, '20/06/2008', 9);
INSERT INTO valoracions VALUES (777, 19, '21/05/2009', 8);
INSERT INTO valoracions VALUES (777, 69, '07/01/2008', 8);
INSERT INTO valoracions VALUES (777, 22, '23/02/2003', 8);
INSERT INTO valoracions VALUES (777, 47, '29/08/2002', 7);
INSERT INTO valoracions VALUES (778, 89, '15/07/2006', 8);
INSERT INTO valoracions VALUES (778, 25, '18/09/2005', 9);
INSERT INTO valoracions VALUES (778, 36, '08/08/2007', 9);
INSERT INTO valoracions VALUES (779, 10, '11/08/2007', 7);
INSERT INTO valoracions VALUES (779, 56, '16/03/2009', 3);
INSERT INTO valoracions VALUES (779, 11, '15/08/2003', 9);
INSERT INTO valoracions VALUES (780, 9, '29/10/2008', 6);
INSERT INTO valoracions VALUES (780, 36, '23/10/2002', 6);
INSERT INTO valoracions VALUES (780, 48, '25/02/2009', 5);
INSERT INTO valoracions VALUES (780, 86, '17/04/2002', 2);
INSERT INTO valoracions VALUES (780, 11, '09/10/2001', 6);
INSERT INTO valoracions VALUES (780, 66, '12/05/2005', 8);
INSERT INTO valoracions VALUES (780, 42, '14/07/2007', 4);
INSERT INTO valoracions VALUES (781, 67, '02/04/2003', 6);
INSERT INTO valoracions VALUES (781, 89, '31/05/2001', 4);
INSERT INTO valoracions VALUES (781, 53, '27/10/2009', 8);
INSERT INTO valoracions VALUES (781, 107, '16/05/2004', 9);
INSERT INTO valoracions VALUES (781, 114, '14/06/2003', 9);
INSERT INTO valoracions VALUES (782, 105, '20/10/2007', 1);
INSERT INTO valoracions VALUES (782, 16, '01/01/2010', 7);
INSERT INTO valoracions VALUES (782, 7, '18/09/2006', 5);
INSERT INTO valoracions VALUES (782, 106, '03/11/2003', 5);
INSERT INTO valoracions VALUES (782, 105, '06/08/2010', 2);
INSERT INTO valoracions VALUES (783, 38, '21/12/2004', 9);
INSERT INTO valoracions VALUES (783, 50, '14/01/2010', 5);
INSERT INTO valoracions VALUES (783, 89, '27/07/2005', 3);
INSERT INTO valoracions VALUES (783, 7, '18/07/2001', 8);
INSERT INTO valoracions VALUES (783, 60, '18/05/2009', 8);
INSERT INTO valoracions VALUES (784, 72, '06/09/2001', 4);
INSERT INTO valoracions VALUES (785, 1, '15/02/2005', 5);
INSERT INTO valoracions VALUES (785, 49, '14/01/2010', 4);
INSERT INTO valoracions VALUES (786, 37, '26/09/2005', 3);
INSERT INTO valoracions VALUES (787, 80, '04/11/2004', 3);
INSERT INTO valoracions VALUES (787, 17, '20/05/2005', 5);
INSERT INTO valoracions VALUES (788, 83, '19/12/2009', 1);
INSERT INTO valoracions VALUES (789, 91, '21/06/2009', 9);
INSERT INTO valoracions VALUES (789, 27, '14/12/2003', 9);
INSERT INTO valoracions VALUES (789, 67, '29/09/2010', 8);
INSERT INTO valoracions VALUES (789, 67, '06/12/2008', 5);
INSERT INTO valoracions VALUES (790, 77, '28/07/2004', 8);
INSERT INTO valoracions VALUES (790, 37, '03/05/2008', 5);
INSERT INTO valoracions VALUES (790, 31, '27/01/2008', 7);
INSERT INTO valoracions VALUES (790, 55, '14/11/2002', 6);
INSERT INTO valoracions VALUES (790, 30, '07/09/2010', 9);
INSERT INTO valoracions VALUES (791, 66, '10/03/2002', 7);
INSERT INTO valoracions VALUES (791, 77, '19/05/2007', 7);
INSERT INTO valoracions VALUES (791, 106, '09/03/2006', 0);
INSERT INTO valoracions VALUES (791, 58, '09/06/2005', 7);
INSERT INTO valoracions VALUES (792, 92, '12/09/2003', 2);
INSERT INTO valoracions VALUES (792, 77, '16/09/2008', 3);
INSERT INTO valoracions VALUES (792, 109, '18/07/2008', 1);
INSERT INTO valoracions VALUES (792, 62, '08/12/2005', 9);
INSERT INTO valoracions VALUES (793, 88, '02/07/2002', 8);
INSERT INTO valoracions VALUES (794, 54, '03/01/2003', 9);
INSERT INTO valoracions VALUES (794, 107, '23/11/2003', 3);
INSERT INTO valoracions VALUES (794, 80, '27/08/2003', 10);
INSERT INTO valoracions VALUES (795, 103, '08/06/2009', 2);
INSERT INTO valoracions VALUES (795, 115, '04/11/2005', 9);
INSERT INTO valoracions VALUES (795, 70, '12/04/2001', 4);
INSERT INTO valoracions VALUES (796, 31, '04/01/2010', 6);
INSERT INTO valoracions VALUES (796, 21, '19/03/2005', 8);
INSERT INTO valoracions VALUES (796, 55, '14/09/2010', 4);
INSERT INTO valoracions VALUES (796, 35, '28/10/2002', 9);
INSERT INTO valoracions VALUES (796, 30, '27/01/2005', 9);
INSERT INTO valoracions VALUES (797, 10, '13/11/2005', 6);
INSERT INTO valoracions VALUES (797, 39, '17/06/2009', 7);
INSERT INTO valoracions VALUES (797, 15, '30/04/2007', 9);
INSERT INTO valoracions VALUES (798, 65, '12/02/2007', 8);
INSERT INTO valoracions VALUES (798, 65, '29/12/2002', 8);
INSERT INTO valoracions VALUES (798, 8, '13/07/2008', 7);
INSERT INTO valoracions VALUES (798, 54, '31/07/2009', 4);
INSERT INTO valoracions VALUES (798, 36, '01/04/2009', 4);
INSERT INTO valoracions VALUES (799, 113, '23/05/2010', 10);
INSERT INTO valoracions VALUES (799, 9, '08/05/2002', 5);
INSERT INTO valoracions VALUES (799, 9, '30/04/2004', 6);
INSERT INTO valoracions VALUES (800, 16, '01/04/2001', 6);
INSERT INTO valoracions VALUES (800, 103, '15/12/2003', 3);
INSERT INTO valoracions VALUES (800, 111, '23/08/2003', 3);
INSERT INTO valoracions VALUES (800, 99, '21/11/2008', 6);
INSERT INTO valoracions VALUES (800, 80, '21/11/2004', 7);
INSERT INTO valoracions VALUES (800, 95, '13/01/2002', 10);
INSERT INTO valoracions VALUES (800, 57, '08/01/2007', 3);
INSERT INTO valoracions VALUES (800, 92, '25/01/2005', 1);
INSERT INTO valoracions VALUES (801, 64, '02/07/2003', 8);
INSERT INTO valoracions VALUES (801, 91, '06/06/2002', 5);
INSERT INTO valoracions VALUES (801, 71, '22/11/2005', 2);
INSERT INTO valoracions VALUES (801, 74, '14/11/2002', 3);
INSERT INTO valoracions VALUES (801, 91, '27/09/2006', 9);
INSERT INTO valoracions VALUES (802, 44, '13/07/2004', 6);
INSERT INTO valoracions VALUES (802, 73, '06/08/2002', 6);
INSERT INTO valoracions VALUES (802, 46, '24/12/2003', 8);
INSERT INTO valoracions VALUES (803, 12, '08/05/2002', 6);
INSERT INTO valoracions VALUES (803, 21, '19/10/2006', 8);
INSERT INTO valoracions VALUES (803, 114, '23/10/2007', 10);
INSERT INTO valoracions VALUES (804, 23, '21/08/2009', 4);
INSERT INTO valoracions VALUES (804, 22, '28/05/2010', 5);
INSERT INTO valoracions VALUES (805, 26, '17/02/2004', 7);
INSERT INTO valoracions VALUES (805, 17, '03/10/2002', 9);
INSERT INTO valoracions VALUES (805, 55, '27/02/2010', 5);
INSERT INTO valoracions VALUES (805, 73, '12/06/2005', 4);
INSERT INTO valoracions VALUES (805, 110, '16/09/2001', 4);
INSERT INTO valoracions VALUES (806, 97, '02/04/2006', 5);
INSERT INTO valoracions VALUES (806, 81, '22/06/2001', 7);
INSERT INTO valoracions VALUES (806, 8, '05/11/2003', 9);
INSERT INTO valoracions VALUES (806, 70, '17/09/2006', 4);
INSERT INTO valoracions VALUES (807, 62, '11/01/2002', 3);
INSERT INTO valoracions VALUES (808, 44, '03/10/2004', 5);
INSERT INTO valoracions VALUES (808, 72, '06/02/2010', 9);
INSERT INTO valoracions VALUES (808, 49, '08/02/2007', 5);
INSERT INTO valoracions VALUES (808, 104, '17/02/2005', 1);
INSERT INTO valoracions VALUES (808, 114, '15/06/2001', 2);
INSERT INTO valoracions VALUES (809, 112, '16/06/2010', 1);
INSERT INTO valoracions VALUES (810, 24, '20/08/2005', 6);
INSERT INTO valoracions VALUES (810, 84, '31/03/2001', 7);
INSERT INTO valoracions VALUES (810, 56, '16/06/2001', 10);
INSERT INTO valoracions VALUES (810, 98, '13/06/2007', 4);
INSERT INTO valoracions VALUES (810, 106, '28/12/2007', 4);
INSERT INTO valoracions VALUES (810, 45, '03/12/2004', 7);
INSERT INTO valoracions VALUES (810, 75, '30/12/2001', 3);
INSERT INTO valoracions VALUES (811, 18, '24/02/2002', 6);
INSERT INTO valoracions VALUES (811, 108, '10/10/2005', 6);
INSERT INTO valoracions VALUES (812, 46, '18/01/2002', 9);
INSERT INTO valoracions VALUES (812, 46, '29/05/2005', 10);
INSERT INTO valoracions VALUES (812, 90, '18/05/2009', 10);
INSERT INTO valoracions VALUES (812, 92, '13/06/2007', 7);
INSERT INTO valoracions VALUES (812, 28, '25/06/2003', 7);
INSERT INTO valoracions VALUES (813, 100, '16/02/2002', 2);
INSERT INTO valoracions VALUES (813, 5, '07/02/2007', 10);
INSERT INTO valoracions VALUES (813, 101, '16/11/2006', 3);
INSERT INTO valoracions VALUES (813, 103, '10/01/2004', 6);
INSERT INTO valoracions VALUES (813, 3, '06/07/2002', 5);
INSERT INTO valoracions VALUES (813, 8, '12/01/2002', 9);
INSERT INTO valoracions VALUES (813, 88, '15/02/2004', 1);
INSERT INTO valoracions VALUES (813, 42, '20/06/2006', 7);
INSERT INTO valoracions VALUES (813, 66, '21/08/2002', 2);
INSERT INTO valoracions VALUES (814, 35, '07/04/2007', 7);
INSERT INTO valoracions VALUES (814, 22, '13/08/2010', 8);
INSERT INTO valoracions VALUES (815, 38, '01/04/2010', 6);
INSERT INTO valoracions VALUES (815, 70, '27/09/2003', 6);
INSERT INTO valoracions VALUES (816, 25, '23/12/2005', 5);
INSERT INTO valoracions VALUES (816, 107, '01/12/2006', 2);
INSERT INTO valoracions VALUES (817, 25, '04/08/2009', 4);
INSERT INTO valoracions VALUES (817, 112, '14/12/2002', 5);
INSERT INTO valoracions VALUES (817, 72, '23/02/2008', 9);
INSERT INTO valoracions VALUES (817, 95, '29/03/2003', 8);
INSERT INTO valoracions VALUES (818, 71, '12/04/2005', 8);
INSERT INTO valoracions VALUES (818, 52, '02/07/2008', 7);
INSERT INTO valoracions VALUES (818, 113, '11/05/2002', 3);
INSERT INTO valoracions VALUES (819, 107, '28/07/2002', 5);
INSERT INTO valoracions VALUES (819, 35, '30/04/2007', 5);
INSERT INTO valoracions VALUES (819, 88, '17/02/2006', 8);
INSERT INTO valoracions VALUES (819, 24, '26/08/2009', 7);
INSERT INTO valoracions VALUES (819, 73, '28/07/2005', 2);
INSERT INTO valoracions VALUES (820, 7, '03/05/2004', 7);
INSERT INTO valoracions VALUES (820, 11, '01/03/2002', 6);
INSERT INTO valoracions VALUES (821, 45, '27/04/2004', 6);
INSERT INTO valoracions VALUES (821, 65, '15/03/2007', 10);
INSERT INTO valoracions VALUES (821, 43, '24/09/2010', 9);
INSERT INTO valoracions VALUES (821, 113, '08/07/2004', 5);
INSERT INTO valoracions VALUES (821, 67, '11/12/2007', 5);
INSERT INTO valoracions VALUES (822, 35, '21/12/2006', 5);
INSERT INTO valoracions VALUES (822, 82, '02/05/2010', 9);
INSERT INTO valoracions VALUES (822, 13, '30/03/2009', 5);
INSERT INTO valoracions VALUES (823, 64, '29/01/2006', 9);
INSERT INTO valoracions VALUES (824, 18, '21/07/2007', 8);
INSERT INTO valoracions VALUES (824, 28, '02/09/2008', 6);
INSERT INTO valoracions VALUES (824, 76, '19/02/2002', 8);
INSERT INTO valoracions VALUES (824, 89, '15/12/2003', 10);
INSERT INTO valoracions VALUES (825, 108, '25/10/2002', 7);
INSERT INTO valoracions VALUES (825, 56, '28/08/2001', 7);
INSERT INTO valoracions VALUES (825, 63, '13/09/2001', 5);
INSERT INTO valoracions VALUES (826, 45, '26/10/2008', 4);
INSERT INTO valoracions VALUES (826, 32, '11/09/2005', 8);
INSERT INTO valoracions VALUES (826, 113, '04/05/2004', 5);
INSERT INTO valoracions VALUES (826, 101, '30/08/2003', 2);
INSERT INTO valoracions VALUES (826, 46, '23/08/2006', 3);
INSERT INTO valoracions VALUES (827, 104, '18/01/2009', 8);
INSERT INTO valoracions VALUES (827, 69, '30/05/2003', 4);
INSERT INTO valoracions VALUES (827, 13, '21/08/2010', 9);
INSERT INTO valoracions VALUES (827, 44, '21/10/2002', 4);
INSERT INTO valoracions VALUES (827, 15, '11/09/2002', 8);
INSERT INTO valoracions VALUES (827, 14, '26/06/2004', 10);
INSERT INTO valoracions VALUES (828, 69, '19/06/2005', 6);
INSERT INTO valoracions VALUES (828, 50, '30/04/2001', 9);
INSERT INTO valoracions VALUES (828, 80, '07/08/2004', 7);
INSERT INTO valoracions VALUES (829, 48, '11/03/2005', 4);
INSERT INTO valoracions VALUES (829, 22, '09/07/2008', 9);
INSERT INTO valoracions VALUES (829, 5, '03/02/2009', 5);
INSERT INTO valoracions VALUES (829, 65, '17/04/2007', 10);
INSERT INTO valoracions VALUES (829, 108, '02/03/2003', 7);
INSERT INTO valoracions VALUES (829, 51, '21/05/2004', 5);
INSERT INTO valoracions VALUES (829, 61, '24/08/2009', 4);
INSERT INTO valoracions VALUES (829, 7, '05/09/2006', 7);
INSERT INTO valoracions VALUES (829, 54, '16/03/2008', 6);
INSERT INTO valoracions VALUES (829, 100, '06/09/2005', 4);
INSERT INTO valoracions VALUES (829, 86, '02/12/2007', 4);
INSERT INTO valoracions VALUES (830, 112, '13/06/2009', 3);
INSERT INTO valoracions VALUES (830, 6, '01/02/2009', 6);
INSERT INTO valoracions VALUES (831, 1, '10/01/2009', 5);
INSERT INTO valoracions VALUES (831, 12, '30/07/2001', 6);
INSERT INTO valoracions VALUES (831, 16, '08/06/2003', 7);
INSERT INTO valoracions VALUES (831, 30, '02/06/2008', 6);
INSERT INTO valoracions VALUES (831, 66, '11/08/2010', 5);
INSERT INTO valoracions VALUES (831, 68, '22/06/2003', 4);
INSERT INTO valoracions VALUES (832, 67, '29/09/2008', 8);
INSERT INTO valoracions VALUES (832, 92, '06/08/2007', 6);
INSERT INTO valoracions VALUES (832, 64, '28/10/2001', 5);
INSERT INTO valoracions VALUES (832, 35, '22/08/2001', 6);
INSERT INTO valoracions VALUES (832, 45, '21/10/2001', 9);
INSERT INTO valoracions VALUES (832, 101, '20/01/2002', 10);
INSERT INTO valoracions VALUES (833, 59, '19/09/2009', 5);
INSERT INTO valoracions VALUES (833, 62, '15/05/2002', 8);
INSERT INTO valoracions VALUES (833, 19, '07/12/2004', 6);
INSERT INTO valoracions VALUES (833, 65, '17/07/2005', 6);
INSERT INTO valoracions VALUES (833, 78, '08/02/2003', 9);
INSERT INTO valoracions VALUES (833, 83, '21/05/2003', 10);
INSERT INTO valoracions VALUES (833, 72, '11/03/2003', 2);
INSERT INTO valoracions VALUES (833, 35, '16/06/2003', 6);
INSERT INTO valoracions VALUES (833, 93, '20/07/2004', 8);
INSERT INTO valoracions VALUES (834, 90, '20/03/2002', 10);
INSERT INTO valoracions VALUES (834, 78, '31/08/2006', 6);
INSERT INTO valoracions VALUES (835, 115, '09/11/2009', 4);
INSERT INTO valoracions VALUES (835, 72, '26/09/2001', 9);
INSERT INTO valoracions VALUES (835, 28, '16/09/2009', 8);
INSERT INTO valoracions VALUES (836, 112, '09/04/2004', 2);
INSERT INTO valoracions VALUES (836, 89, '07/07/2001', 6);
INSERT INTO valoracions VALUES (837, 98, '28/08/2009', 5);
INSERT INTO valoracions VALUES (837, 8, '04/02/2003', 9);
INSERT INTO valoracions VALUES (837, 87, '30/12/2007', 4);
INSERT INTO valoracions VALUES (837, 23, '23/12/2008', 5);
INSERT INTO valoracions VALUES (837, 102, '26/06/2003', 3);
INSERT INTO valoracions VALUES (838, 90, '05/11/2008', 5);
INSERT INTO valoracions VALUES (838, 13, '05/03/2007', 8);
INSERT INTO valoracions VALUES (838, 53, '10/02/2005', 6);
INSERT INTO valoracions VALUES (839, 23, '07/06/2001', 5);
INSERT INTO valoracions VALUES (839, 115, '24/03/2007', 5);
INSERT INTO valoracions VALUES (840, 104, '10/10/2006', 8);
INSERT INTO valoracions VALUES (840, 49, '27/08/2008', 4);
INSERT INTO valoracions VALUES (840, 37, '17/09/2003', 5);
INSERT INTO valoracions VALUES (841, 28, '05/11/2006', 7);
INSERT INTO valoracions VALUES (841, 73, '05/04/2002', 8);
INSERT INTO valoracions VALUES (841, 71, '19/10/2005', 8);
INSERT INTO valoracions VALUES (842, 28, '25/05/2001', 7);
INSERT INTO valoracions VALUES (842, 91, '19/10/2010', 9);
INSERT INTO valoracions VALUES (842, 55, '23/06/2004', 9);
INSERT INTO valoracions VALUES (842, 63, '13/11/2001', 5);
INSERT INTO valoracions VALUES (843, 52, '16/12/2008', 8);
INSERT INTO valoracions VALUES (844, 46, '13/07/2010', 9);
INSERT INTO valoracions VALUES (845, 74, '25/06/2009', 6);
INSERT INTO valoracions VALUES (845, 2, '23/12/2002', 9);
INSERT INTO valoracions VALUES (845, 19, '11/05/2010', 4);
INSERT INTO valoracions VALUES (846, 114, '09/06/2002', 9);
INSERT INTO valoracions VALUES (846, 93, '23/08/2006', 4);
INSERT INTO valoracions VALUES (846, 50, '02/09/2001', 5);
INSERT INTO valoracions VALUES (846, 49, '29/11/2009', 8);
INSERT INTO valoracions VALUES (846, 63, '03/06/2007', 4);
INSERT INTO valoracions VALUES (847, 98, '14/08/2010', 4);
INSERT INTO valoracions VALUES (847, 105, '17/11/2005', 4);
INSERT INTO valoracions VALUES (847, 98, '02/02/2006', 5);
INSERT INTO valoracions VALUES (847, 90, '27/07/2009', 6);
INSERT INTO valoracions VALUES (847, 92, '04/04/2006', 1);
INSERT INTO valoracions VALUES (848, 88, '02/08/2008', 9);
INSERT INTO valoracions VALUES (848, 94, '12/08/2004', 4);
INSERT INTO valoracions VALUES (848, 75, '17/12/2002', 7);
INSERT INTO valoracions VALUES (848, 103, '25/06/2002', 9);
INSERT INTO valoracions VALUES (848, 48, '05/06/2005', 8);
INSERT INTO valoracions VALUES (849, 82, '08/10/2009', 7);
INSERT INTO valoracions VALUES (849, 29, '23/03/2010', 9);
INSERT INTO valoracions VALUES (849, 56, '06/12/2007', 8);
INSERT INTO valoracions VALUES (849, 33, '17/06/2009', 4);
INSERT INTO valoracions VALUES (849, 48, '21/10/2009', 5);
INSERT INTO valoracions VALUES (849, 98, '24/07/2007', 10);
INSERT INTO valoracions VALUES (850, 35, '27/09/2009', 9);
INSERT INTO valoracions VALUES (850, 56, '22/09/2007', 6);
INSERT INTO valoracions VALUES (851, 95, '15/10/2001', 5);
INSERT INTO valoracions VALUES (851, 28, '17/07/2009', 9);
INSERT INTO valoracions VALUES (852, 62, '01/10/2007', 5);
INSERT INTO valoracions VALUES (852, 48, '24/03/2003', 9);
INSERT INTO valoracions VALUES (852, 115, '06/05/2008', 10);
INSERT INTO valoracions VALUES (853, 35, '27/04/2007', 9);
INSERT INTO valoracions VALUES (853, 90, '09/10/2010', 6);
INSERT INTO valoracions VALUES (853, 9, '09/05/2008', 9);
INSERT INTO valoracions VALUES (853, 80, '23/01/2003', 9);
INSERT INTO valoracions VALUES (853, 8, '16/06/2010', 9);
INSERT INTO valoracions VALUES (854, 28, '09/01/2002', 8);
INSERT INTO valoracions VALUES (854, 18, '27/02/2003', 6);
INSERT INTO valoracions VALUES (854, 48, '30/09/2003', 7);
INSERT INTO valoracions VALUES (854, 76, '21/08/2010', 5);
INSERT INTO valoracions VALUES (855, 67, '24/04/2010', 7);
INSERT INTO valoracions VALUES (855, 61, '04/08/2009', 8);
INSERT INTO valoracions VALUES (855, 113, '16/11/2005', 10);
INSERT INTO valoracions VALUES (856, 18, '30/04/2008', 7);
INSERT INTO valoracions VALUES (856, 52, '28/02/2010', 5);
INSERT INTO valoracions VALUES (856, 69, '18/02/2003', 4);
INSERT INTO valoracions VALUES (856, 72, '26/02/2006', 8);
INSERT INTO valoracions VALUES (856, 83, '14/12/2006', 2);
INSERT INTO valoracions VALUES (857, 14, '12/10/2005', 10);
INSERT INTO valoracions VALUES (858, 111, '29/05/2003', 10);
INSERT INTO valoracions VALUES (858, 107, '14/05/2008', 5);
INSERT INTO valoracions VALUES (859, 3, '11/11/2009', 5);
INSERT INTO valoracions VALUES (859, 46, '24/10/2006', 7);
INSERT INTO valoracions VALUES (859, 84, '25/10/2005', 4);
INSERT INTO valoracions VALUES (860, 26, '20/07/2006', 9);
INSERT INTO valoracions VALUES (860, 35, '13/06/2003', 7);
INSERT INTO valoracions VALUES (860, 113, '05/01/2009', 9);
INSERT INTO valoracions VALUES (861, 67, '13/08/2010', 8);
INSERT INTO valoracions VALUES (861, 90, '20/10/2001', 1);
INSERT INTO valoracions VALUES (862, 26, '16/06/2009', 5);
INSERT INTO valoracions VALUES (862, 71, '23/11/2009', 8);
INSERT INTO valoracions VALUES (863, 81, '17/12/2005', 5);
INSERT INTO valoracions VALUES (863, 38, '21/10/2002', 7);
INSERT INTO valoracions VALUES (863, 70, '02/08/2009', 4);
INSERT INTO valoracions VALUES (863, 8, '03/12/2003', 9);
INSERT INTO valoracions VALUES (864, 59, '19/09/2004', 8);
INSERT INTO valoracions VALUES (864, 28, '05/07/2009', 7);
INSERT INTO valoracions VALUES (865, 9, '05/05/2010', 7);
INSERT INTO valoracions VALUES (865, 86, '19/10/2008', 3);
INSERT INTO valoracions VALUES (865, 81, '16/10/2008', 7);
INSERT INTO valoracions VALUES (865, 88, '31/03/2002', 7);
INSERT INTO valoracions VALUES (865, 67, '23/08/2004', 3);
INSERT INTO valoracions VALUES (866, 67, '01/06/2004', 5);
INSERT INTO valoracions VALUES (866, 51, '19/07/2009', 9);
INSERT INTO valoracions VALUES (867, 116, '31/01/2010', 7);
INSERT INTO valoracions VALUES (867, 95, '13/05/2004', 4);
INSERT INTO valoracions VALUES (867, 65, '24/08/2009', 8);
INSERT INTO valoracions VALUES (867, 82, '19/08/2009', 9);
INSERT INTO valoracions VALUES (868, 62, '30/05/2003', 4);
INSERT INTO valoracions VALUES (868, 102, '02/03/2009', 8);
INSERT INTO valoracions VALUES (868, 99, '10/09/2007', 8);
INSERT INTO valoracions VALUES (868, 85, '15/12/2004', 3);
INSERT INTO valoracions VALUES (869, 108, '29/05/2001', 2);
INSERT INTO valoracions VALUES (869, 114, '21/04/2001', 3);
INSERT INTO valoracions VALUES (869, 67, '22/04/2001', 8);
INSERT INTO valoracions VALUES (869, 49, '08/06/2005', 3);
INSERT INTO valoracions VALUES (870, 93, '21/08/2006', 1);
INSERT INTO valoracions VALUES (870, 2, '08/04/2005', 5);
INSERT INTO valoracions VALUES (870, 50, '19/11/2001', 4);
INSERT INTO valoracions VALUES (871, 54, '05/08/2004', 9);
INSERT INTO valoracions VALUES (871, 24, '13/11/2003', 7);
INSERT INTO valoracions VALUES (871, 8, '19/11/2002', 7);
INSERT INTO valoracions VALUES (871, 21, '04/11/2008', 9);
INSERT INTO valoracions VALUES (871, 98, '11/10/2005', 4);
INSERT INTO valoracions VALUES (871, 106, '22/10/2009', 2);
INSERT INTO valoracions VALUES (872, 65, '16/09/2006', 6);
INSERT INTO valoracions VALUES (872, 63, '29/09/2008', 9);
INSERT INTO valoracions VALUES (872, 56, '26/01/2009', 4);
INSERT INTO valoracions VALUES (873, 41, '30/12/2006', 9);
INSERT INTO valoracions VALUES (873, 9, '11/06/2007', 9);
INSERT INTO valoracions VALUES (873, 52, '20/11/2006', 8);
INSERT INTO valoracions VALUES (873, 81, '13/12/2003', 6);
INSERT INTO valoracions VALUES (873, 75, '26/07/2008', 7);
INSERT INTO valoracions VALUES (873, 89, '26/01/2004', 5);
INSERT INTO valoracions VALUES (873, 94, '17/08/2006', 1);
INSERT INTO valoracions VALUES (873, 74, '07/11/2001', 8);
INSERT INTO valoracions VALUES (874, 14, '30/04/2002', 6);
INSERT INTO valoracions VALUES (874, 88, '05/03/2009', 6);
INSERT INTO valoracions VALUES (874, 50, '29/07/2007', 7);
INSERT INTO valoracions VALUES (874, 110, '28/08/2010', 6);
INSERT INTO valoracions VALUES (874, 17, '09/06/2009', 8);
INSERT INTO valoracions VALUES (874, 111, '27/11/2005', 7);
INSERT INTO valoracions VALUES (875, 72, '09/10/2009', 8);
INSERT INTO valoracions VALUES (875, 72, '10/02/2006', 3);
INSERT INTO valoracions VALUES (875, 102, '13/07/2004', 9);
INSERT INTO valoracions VALUES (875, 55, '14/06/2002', 3);
INSERT INTO valoracions VALUES (875, 106, '01/09/2003', 9);
INSERT INTO valoracions VALUES (876, 80, '17/07/2003', 7);
INSERT INTO valoracions VALUES (876, 96, '07/10/2009', 5);
INSERT INTO valoracions VALUES (876, 94, '06/10/2004', 5);
INSERT INTO valoracions VALUES (876, 107, '03/10/2009', 9);
INSERT INTO valoracions VALUES (876, 57, '13/05/2007', 5);
INSERT INTO valoracions VALUES (876, 114, '08/01/2004', 6);
INSERT INTO valoracions VALUES (876, 8, '13/05/2002', 6);
INSERT INTO valoracions VALUES (877, 14, '22/02/2002', 6);
INSERT INTO valoracions VALUES (877, 78, '27/04/2001', 9);
INSERT INTO valoracions VALUES (877, 27, '10/04/2006', 9);
INSERT INTO valoracions VALUES (877, 9, '24/03/2008', 8);
INSERT INTO valoracions VALUES (878, 111, '23/06/2010', 1);
INSERT INTO valoracions VALUES (878, 68, '10/05/2010', 4);
INSERT INTO valoracions VALUES (878, 6, '21/05/2006', 8);
INSERT INTO valoracions VALUES (878, 26, '31/05/2007', 8);
INSERT INTO valoracions VALUES (878, 2, '04/01/2007', 8);
INSERT INTO valoracions VALUES (878, 115, '11/11/2009', 3);
INSERT INTO valoracions VALUES (878, 107, '28/06/2001', 5);
INSERT INTO valoracions VALUES (880, 66, '22/12/2009', 3);
INSERT INTO valoracions VALUES (880, 7, '22/09/2005', 9);
INSERT INTO valoracions VALUES (880, 93, '31/10/2004', 6);
INSERT INTO valoracions VALUES (880, 4, '06/12/2003', 6);
INSERT INTO valoracions VALUES (880, 35, '26/09/2003', 5);
INSERT INTO valoracions VALUES (880, 76, '26/11/2006', 9);
INSERT INTO valoracions VALUES (880, 98, '13/10/2004', 10);
INSERT INTO valoracions VALUES (882, 80, '08/06/2007', 7);
INSERT INTO valoracions VALUES (882, 4, '05/09/2007', 9);
INSERT INTO valoracions VALUES (882, 40, '01/05/2001', 5);
INSERT INTO valoracions VALUES (882, 102, '27/01/2009', 7);
INSERT INTO valoracions VALUES (882, 112, '03/12/2007', 9);
INSERT INTO valoracions VALUES (883, 94, '10/05/2003', 5);
INSERT INTO valoracions VALUES (884, 111, '05/02/2003', 1);
INSERT INTO valoracions VALUES (884, 115, '16/10/2010', 4);
INSERT INTO valoracions VALUES (884, 100, '06/02/2003', 9);
INSERT INTO valoracions VALUES (884, 78, '01/05/2008', 8);
INSERT INTO valoracions VALUES (884, 58, '14/01/2008', 3);
INSERT INTO valoracions VALUES (884, 95, '15/02/2008', 5);
INSERT INTO valoracions VALUES (884, 89, '19/02/2007', 6);
INSERT INTO valoracions VALUES (885, 32, '14/04/2010', 8);
INSERT INTO valoracions VALUES (885, 71, '14/07/2007', 9);
INSERT INTO valoracions VALUES (885, 63, '13/10/2004', 7);
INSERT INTO valoracions VALUES (885, 67, '03/11/2009', 8);
INSERT INTO valoracions VALUES (885, 112, '27/08/2008', 8);
INSERT INTO valoracions VALUES (885, 30, '17/01/2006', 4);
INSERT INTO valoracions VALUES (886, 15, '18/01/2007', 8);
INSERT INTO valoracions VALUES (886, 17, '24/02/2002', 7);
INSERT INTO valoracions VALUES (886, 73, '10/11/2002', 8);
INSERT INTO valoracions VALUES (886, 24, '21/04/2010', 9);
INSERT INTO valoracions VALUES (886, 87, '20/01/2008', 5);
INSERT INTO valoracions VALUES (887, 79, '30/05/2001', 6);
INSERT INTO valoracions VALUES (887, 22, '19/09/2004', 9);
INSERT INTO valoracions VALUES (887, 68, '18/01/2010', 8);
INSERT INTO valoracions VALUES (888, 44, '20/06/2009', 5);
INSERT INTO valoracions VALUES (888, 45, '05/08/2007', 5);
INSERT INTO valoracions VALUES (888, 15, '24/09/2008', 7);
INSERT INTO valoracions VALUES (888, 1, '19/04/2009', 7);
INSERT INTO valoracions VALUES (888, 70, '05/02/2004', 2);
INSERT INTO valoracions VALUES (888, 23, '26/04/2008', 6);
INSERT INTO valoracions VALUES (889, 73, '28/05/2006', 4);
INSERT INTO valoracions VALUES (890, 22, '26/05/2004', 7);
INSERT INTO valoracions VALUES (890, 4, '15/02/2005', 9);
INSERT INTO valoracions VALUES (890, 91, '01/12/2009', 6);
INSERT INTO valoracions VALUES (890, 8, '23/07/2007', 6);
INSERT INTO valoracions VALUES (890, 48, '03/06/2010', 3);
INSERT INTO valoracions VALUES (890, 111, '27/01/2009', 9);
INSERT INTO valoracions VALUES (890, 98, '29/09/2005', 7);
INSERT INTO valoracions VALUES (891, 116, '15/03/2004', 5);
INSERT INTO valoracions VALUES (891, 33, '28/10/2001', 8);
INSERT INTO valoracions VALUES (892, 109, '13/02/2004', 1);
INSERT INTO valoracions VALUES (892, 102, '15/03/2006', 10);
INSERT INTO valoracions VALUES (892, 97, '08/01/2002', 6);
INSERT INTO valoracions VALUES (892, 77, '24/08/2008', 8);
INSERT INTO valoracions VALUES (893, 102, '18/03/2010', 5);
INSERT INTO valoracions VALUES (893, 107, '17/02/2009', 6);
INSERT INTO valoracions VALUES (893, 83, '16/07/2006', 9);
INSERT INTO valoracions VALUES (893, 57, '13/12/2001', 4);
INSERT INTO valoracions VALUES (894, 60, '25/05/2006', 7);
INSERT INTO valoracions VALUES (894, 96, '24/07/2003', 9);
INSERT INTO valoracions VALUES (894, 99, '29/07/2009', 10);
INSERT INTO valoracions VALUES (894, 77, '19/06/2003', 9);
INSERT INTO valoracions VALUES (894, 100, '20/07/2007', 3);
INSERT INTO valoracions VALUES (894, 99, '22/06/2004', 7);
INSERT INTO valoracions VALUES (894, 32, '10/01/2006', 9);
INSERT INTO valoracions VALUES (895, 97, '21/04/2005', 7);
INSERT INTO valoracions VALUES (895, 94, '21/12/2004', 9);
INSERT INTO valoracions VALUES (895, 90, '29/03/2007', 7);
INSERT INTO valoracions VALUES (895, 22, '06/08/2008', 8);
INSERT INTO valoracions VALUES (896, 45, '31/01/2005', 6);
INSERT INTO valoracions VALUES (896, 114, '23/10/2009', 5);
INSERT INTO valoracions VALUES (896, 78, '21/05/2001', 10);
INSERT INTO valoracions VALUES (897, 65, '20/04/2010', 8);
INSERT INTO valoracions VALUES (898, 45, '24/10/2010', 5);
INSERT INTO valoracions VALUES (898, 79, '13/04/2004', 4);
INSERT INTO valoracions VALUES (898, 99, '21/10/2006', 4);
INSERT INTO valoracions VALUES (898, 71, '04/08/2008', 8);
INSERT INTO valoracions VALUES (898, 24, '22/06/2010', 6);
INSERT INTO valoracions VALUES (898, 24, '06/04/2005', 6);
INSERT INTO valoracions VALUES (898, 112, '29/07/2003', 2);
INSERT INTO valoracions VALUES (898, 28, '10/01/2005', 4);
INSERT INTO valoracions VALUES (898, 104, '09/02/2010', 3);
INSERT INTO valoracions VALUES (899, 85, '01/09/2005', 1);
INSERT INTO valoracions VALUES (899, 73, '03/06/2009', 8);
INSERT INTO valoracions VALUES (899, 13, '08/04/2001', 9);
INSERT INTO valoracions VALUES (899, 39, '24/04/2009', 7);
INSERT INTO valoracions VALUES (899, 106, '14/10/2006', 9);
INSERT INTO valoracions VALUES (899, 72, '12/08/2002', 8);
INSERT INTO valoracions VALUES (899, 31, '18/07/2007', 4);
INSERT INTO valoracions VALUES (900, 43, '30/12/2008', 8);
INSERT INTO valoracions VALUES (900, 93, '30/10/2002', 2);
INSERT INTO valoracions VALUES (900, 35, '03/07/2002', 9);
INSERT INTO valoracions VALUES (900, 58, '28/10/2009', 5);
INSERT INTO valoracions VALUES (900, 83, '27/02/2004', 6);
INSERT INTO valoracions VALUES (900, 59, '26/05/2001', 7);
INSERT INTO valoracions VALUES (900, 84, '26/03/2002', 5);
INSERT INTO valoracions VALUES (900, 79, '15/04/2009', 2);
INSERT INTO valoracions VALUES (900, 95, '15/07/2004', 3);
INSERT INTO valoracions VALUES (900, 58, '07/03/2010', 3);
INSERT INTO valoracions VALUES (901, 110, '27/04/2004', 2);
INSERT INTO valoracions VALUES (902, 96, '25/01/2007', 7);
INSERT INTO valoracions VALUES (902, 4, '29/05/2006', 7);
INSERT INTO valoracions VALUES (902, 82, '13/02/2007', 2);
INSERT INTO valoracions VALUES (902, 5, '13/01/2005', 6);
INSERT INTO valoracions VALUES (902, 67, '05/01/2010', 2);
INSERT INTO valoracions VALUES (902, 90, '12/11/2007', 6);
INSERT INTO valoracions VALUES (902, 32, '20/12/2009', 6);
INSERT INTO valoracions VALUES (902, 32, '12/12/2008', 6);
INSERT INTO valoracions VALUES (903, 112, '16/08/2008', 6);
INSERT INTO valoracions VALUES (903, 39, '04/03/2009', 9);
INSERT INTO valoracions VALUES (903, 74, '24/01/2003', 8);
INSERT INTO valoracions VALUES (903, 40, '29/09/2004', 5);
INSERT INTO valoracions VALUES (903, 78, '21/08/2002', 4);
INSERT INTO valoracions VALUES (904, 22, '09/08/2009', 5);
INSERT INTO valoracions VALUES (904, 46, '18/02/2006', 9);
INSERT INTO valoracions VALUES (904, 50, '23/09/2007', 5);
INSERT INTO valoracions VALUES (905, 114, '08/07/2006', 9);
INSERT INTO valoracions VALUES (905, 16, '10/09/2005', 7);
INSERT INTO valoracions VALUES (905, 59, '19/09/2010', 6);
INSERT INTO valoracions VALUES (906, 31, '21/09/2006', 10);
INSERT INTO valoracions VALUES (907, 64, '20/09/2001', 5);
INSERT INTO valoracions VALUES (907, 71, '26/08/2006', 3);
INSERT INTO valoracions VALUES (908, 65, '23/06/2004', 8);
INSERT INTO valoracions VALUES (908, 46, '27/03/2007', 10);
INSERT INTO valoracions VALUES (908, 61, '09/04/2004', 5);
INSERT INTO valoracions VALUES (909, 79, '26/10/2009', 2);
INSERT INTO valoracions VALUES (909, 84, '05/03/2004', 3);
INSERT INTO valoracions VALUES (909, 28, '13/04/2008', 5);
INSERT INTO valoracions VALUES (910, 95, '09/07/2006', 9);
INSERT INTO valoracions VALUES (910, 91, '24/03/2003', 7);
INSERT INTO valoracions VALUES (910, 94, '18/07/2008', 1);
INSERT INTO valoracions VALUES (910, 112, '03/12/2003', 3);
INSERT INTO valoracions VALUES (911, 37, '12/01/2010', 8);
INSERT INTO valoracions VALUES (911, 114, '09/03/2009', 6);
INSERT INTO valoracions VALUES (911, 8, '14/06/2007', 7);
INSERT INTO valoracions VALUES (912, 88, '28/04/2005', 7);
INSERT INTO valoracions VALUES (912, 11, '16/08/2004', 5);
INSERT INTO valoracions VALUES (912, 113, '17/04/2003', 3);
INSERT INTO valoracions VALUES (912, 63, '07/04/2010', 8);
INSERT INTO valoracions VALUES (912, 41, '09/10/2001', 10);
INSERT INTO valoracions VALUES (912, 86, '29/11/2008', 3);
INSERT INTO valoracions VALUES (912, 37, '25/04/2001', 5);
INSERT INTO valoracions VALUES (912, 22, '21/01/2010', 8);
INSERT INTO valoracions VALUES (913, 75, '01/04/2004', 7);
INSERT INTO valoracions VALUES (913, 63, '30/10/2001', 5);
INSERT INTO valoracions VALUES (913, 38, '10/01/2005', 5);
INSERT INTO valoracions VALUES (913, 98, '27/12/2009', 6);
INSERT INTO valoracions VALUES (914, 26, '20/07/2005', 5);
INSERT INTO valoracions VALUES (914, 74, '13/09/2005', 6);
INSERT INTO valoracions VALUES (914, 80, '13/01/2002', 6);
INSERT INTO valoracions VALUES (914, 13, '15/10/2006', 8);
INSERT INTO valoracions VALUES (914, 27, '06/01/2004', 8);
INSERT INTO valoracions VALUES (915, 55, '05/11/2008', 8);
INSERT INTO valoracions VALUES (915, 34, '27/01/2007', 8);
INSERT INTO valoracions VALUES (915, 113, '11/08/2006', 7);
INSERT INTO valoracions VALUES (916, 93, '30/08/2004', 6);
INSERT INTO valoracions VALUES (916, 56, '07/12/2008', 3);
INSERT INTO valoracions VALUES (916, 38, '21/01/2007', 5);
INSERT INTO valoracions VALUES (917, 38, '04/02/2008', 4);
INSERT INTO valoracions VALUES (918, 20, '15/07/2004', 5);
INSERT INTO valoracions VALUES (918, 28, '24/01/2003', 10);
INSERT INTO valoracions VALUES (918, 31, '06/11/2003', 8);
INSERT INTO valoracions VALUES (919, 98, '24/07/2001', 8);
INSERT INTO valoracions VALUES (919, 87, '16/08/2009', 8);
INSERT INTO valoracions VALUES (919, 25, '17/02/2007', 9);
INSERT INTO valoracions VALUES (919, 39, '19/12/2005', 7);
INSERT INTO valoracions VALUES (920, 71, '05/06/2010', 7);
INSERT INTO valoracions VALUES (920, 3, '07/05/2004', 9);
INSERT INTO valoracions VALUES (920, 97, '03/02/2008', 5);
INSERT INTO valoracions VALUES (920, 2, '14/02/2003', 7);
INSERT INTO valoracions VALUES (920, 72, '12/10/2007', 7);
INSERT INTO valoracions VALUES (921, 23, '16/11/2008', 8);
INSERT INTO valoracions VALUES (921, 116, '17/01/2005', 5);
INSERT INTO valoracions VALUES (921, 115, '06/06/2004', 8);
INSERT INTO valoracions VALUES (921, 25, '13/08/2002', 6);
INSERT INTO valoracions VALUES (922, 116, '12/04/2005', 5);
INSERT INTO valoracions VALUES (922, 29, '22/02/2003', 6);
INSERT INTO valoracions VALUES (922, 79, '29/11/2003', 7);
INSERT INTO valoracions VALUES (922, 61, '19/06/2001', 6);
INSERT INTO valoracions VALUES (923, 20, '31/03/2005', 6);
INSERT INTO valoracions VALUES (923, 115, '10/05/2004', 5);
INSERT INTO valoracions VALUES (923, 32, '15/10/2005', 8);
INSERT INTO valoracions VALUES (923, 99, '29/07/2007', 6);
INSERT INTO valoracions VALUES (924, 81, '21/08/2010', 6);
INSERT INTO valoracions VALUES (924, 9, '24/03/2010', 5);
INSERT INTO valoracions VALUES (924, 22, '22/03/2005', 9);
INSERT INTO valoracions VALUES (924, 36, '21/09/2009', 8);
INSERT INTO valoracions VALUES (924, 14, '22/03/2004', 4);
INSERT INTO valoracions VALUES (925, 105, '13/06/2007', 5);
INSERT INTO valoracions VALUES (925, 24, '18/10/2006', 7);
INSERT INTO valoracions VALUES (925, 83, '27/08/2009', 4);
INSERT INTO valoracions VALUES (925, 18, '05/09/2001', 10);
INSERT INTO valoracions VALUES (925, 90, '18/04/2008', 4);
INSERT INTO valoracions VALUES (925, 62, '16/01/2007', 8);
INSERT INTO valoracions VALUES (925, 68, '20/09/2008', 9);
INSERT INTO valoracions VALUES (926, 53, '08/09/2007', 4);
INSERT INTO valoracions VALUES (926, 48, '19/02/2009', 7);
INSERT INTO valoracions VALUES (926, 32, '20/01/2004', 9);
INSERT INTO valoracions VALUES (926, 96, '16/09/2005', 7);
INSERT INTO valoracions VALUES (926, 13, '05/12/2005', 7);
INSERT INTO valoracions VALUES (927, 40, '07/02/2010', 5);
INSERT INTO valoracions VALUES (927, 85, '28/06/2002', 7);
INSERT INTO valoracions VALUES (927, 69, '20/05/2003', 5);
INSERT INTO valoracions VALUES (928, 113, '23/10/2010', 5);
INSERT INTO valoracions VALUES (928, 16, '08/06/2004', 9);
INSERT INTO valoracions VALUES (929, 21, '05/12/2006', 8);
INSERT INTO valoracions VALUES (929, 92, '03/03/2010', 6);
INSERT INTO valoracions VALUES (930, 13, '04/12/2003', 9);
INSERT INTO valoracions VALUES (930, 51, '26/06/2007', 3);
INSERT INTO valoracions VALUES (930, 27, '07/03/2006', 5);
INSERT INTO valoracions VALUES (930, 44, '25/12/2008', 7);
INSERT INTO valoracions VALUES (931, 77, '30/03/2002', 3);
INSERT INTO valoracions VALUES (931, 15, '24/06/2004', 7);
INSERT INTO valoracions VALUES (932, 71, '04/05/2010', 9);
INSERT INTO valoracions VALUES (932, 105, '25/07/2004', 5);
INSERT INTO valoracions VALUES (933, 62, '19/11/2007', 8);
INSERT INTO valoracions VALUES (933, 101, '14/11/2003', 4);
INSERT INTO valoracions VALUES (933, 81, '07/08/2001', 8);
INSERT INTO valoracions VALUES (933, 16, '14/03/2006', 9);
INSERT INTO valoracions VALUES (934, 78, '04/06/2002', 3);
INSERT INTO valoracions VALUES (935, 115, '14/07/2003', 7);
INSERT INTO valoracions VALUES (935, 89, '18/10/2007', 5);
INSERT INTO valoracions VALUES (936, 46, '23/11/2006', 4);
INSERT INTO valoracions VALUES (936, 5, '09/08/2004', 7);
INSERT INTO valoracions VALUES (936, 87, '22/04/2005', 8);
INSERT INTO valoracions VALUES (936, 37, '02/04/2010', 9);
INSERT INTO valoracions VALUES (936, 82, '20/11/2002', 6);
INSERT INTO valoracions VALUES (937, 48, '01/12/2005', 4);
INSERT INTO valoracions VALUES (937, 73, '14/03/2010', 5);
INSERT INTO valoracions VALUES (937, 44, '26/03/2003', 4);
INSERT INTO valoracions VALUES (937, 56, '19/05/2010', 6);
INSERT INTO valoracions VALUES (937, 62, '22/06/2010', 5);
INSERT INTO valoracions VALUES (938, 47, '31/08/2001', 4);
INSERT INTO valoracions VALUES (938, 20, '05/05/2008', 6);
INSERT INTO valoracions VALUES (938, 2, '07/04/2010', 6);
INSERT INTO valoracions VALUES (938, 41, '16/08/2008', 5);
INSERT INTO valoracions VALUES (938, 60, '26/02/2006', 7);
INSERT INTO valoracions VALUES (939, 2, '07/05/2007', 8);
INSERT INTO valoracions VALUES (939, 39, '21/02/2006', 7);
INSERT INTO valoracions VALUES (939, 108, '13/05/2002', 4);
INSERT INTO valoracions VALUES (939, 10, '01/04/2010', 7);
INSERT INTO valoracions VALUES (940, 82, '29/10/2002', 9);
INSERT INTO valoracions VALUES (941, 97, '19/10/2003', 5);
INSERT INTO valoracions VALUES (941, 12, '16/11/2005', 9);
INSERT INTO valoracions VALUES (941, 28, '17/06/2003', 9);
INSERT INTO valoracions VALUES (941, 37, '22/05/2003', 4);
INSERT INTO valoracions VALUES (941, 29, '20/08/2007', 6);
INSERT INTO valoracions VALUES (941, 43, '04/11/2003', 6);
INSERT INTO valoracions VALUES (941, 112, '09/05/2006', 2);
INSERT INTO valoracions VALUES (942, 92, '23/04/2003', 5);
INSERT INTO valoracions VALUES (942, 28, '04/08/2003', 8);
INSERT INTO valoracions VALUES (942, 68, '28/04/2010', 4);
INSERT INTO valoracions VALUES (942, 60, '06/02/2004', 7);
INSERT INTO valoracions VALUES (942, 46, '12/03/2006', 4);
INSERT INTO valoracions VALUES (943, 94, '23/02/2004', 6);
INSERT INTO valoracions VALUES (943, 60, '14/05/2005', 8);
INSERT INTO valoracions VALUES (943, 2, '22/08/2006', 6);
INSERT INTO valoracions VALUES (944, 57, '28/07/2005', 9);
INSERT INTO valoracions VALUES (945, 62, '24/03/2005', 9);
INSERT INTO valoracions VALUES (945, 109, '03/12/2008', 3);
INSERT INTO valoracions VALUES (945, 61, '02/08/2003', 10);
INSERT INTO valoracions VALUES (946, 18, '06/08/2008', 8);
INSERT INTO valoracions VALUES (946, 60, '17/10/2006', 8);
INSERT INTO valoracions VALUES (946, 35, '09/08/2008', 8);
INSERT INTO valoracions VALUES (946, 5, '13/05/2007', 7);
INSERT INTO valoracions VALUES (947, 30, '19/04/2010', 8);
INSERT INTO valoracions VALUES (948, 79, '08/06/2004', 4);
INSERT INTO valoracions VALUES (948, 86, '16/07/2010', 1);
INSERT INTO valoracions VALUES (948, 14, '28/10/2001', 6);
INSERT INTO valoracions VALUES (948, 69, '04/08/2007', 9);
INSERT INTO valoracions VALUES (949, 98, '05/04/2004', 4);
INSERT INTO valoracions VALUES (949, 98, '19/04/2007', 10);
INSERT INTO valoracions VALUES (950, 76, '30/09/2004', 8);
INSERT INTO valoracions VALUES (950, 99, '17/03/2002', 2);
INSERT INTO valoracions VALUES (950, 60, '04/06/2002', 3);
INSERT INTO valoracions VALUES (950, 71, '24/10/2001', 7);
INSERT INTO valoracions VALUES (950, 53, '23/03/2002', 5);
INSERT INTO valoracions VALUES (950, 37, '27/04/2009', 10);
INSERT INTO valoracions VALUES (951, 27, '17/01/2006', 9);
INSERT INTO valoracions VALUES (951, 58, '26/05/2009', 8);
INSERT INTO valoracions VALUES (951, 41, '14/07/2005', 10);
INSERT INTO valoracions VALUES (951, 102, '13/04/2001', 4);
INSERT INTO valoracions VALUES (951, 110, '08/03/2007', 7);
INSERT INTO valoracions VALUES (951, 17, '27/05/2008', 8);
INSERT INTO valoracions VALUES (952, 52, '04/03/2003', 5);
INSERT INTO valoracions VALUES (952, 114, '29/10/2004', 1);
INSERT INTO valoracions VALUES (952, 110, '17/03/2005', 6);
INSERT INTO valoracions VALUES (953, 86, '26/09/2007', 4);
INSERT INTO valoracions VALUES (954, 14, '27/08/2003', 8);
INSERT INTO valoracions VALUES (954, 99, '26/08/2010', 6);
INSERT INTO valoracions VALUES (954, 21, '09/12/2002', 7);
INSERT INTO valoracions VALUES (954, 3, '25/07/2009', 10);
INSERT INTO valoracions VALUES (954, 57, '03/08/2002', 4);
INSERT INTO valoracions VALUES (954, 109, '03/01/2004', 4);
INSERT INTO valoracions VALUES (955, 115, '04/07/2006', 8);
INSERT INTO valoracions VALUES (955, 32, '02/02/2003', 9);
INSERT INTO valoracions VALUES (955, 64, '06/08/2005', 8);
INSERT INTO valoracions VALUES (956, 68, '01/06/2007', 9);
INSERT INTO valoracions VALUES (956, 17, '13/03/2008', 7);
INSERT INTO valoracions VALUES (956, 9, '12/06/2003', 7);
INSERT INTO valoracions VALUES (956, 82, '08/09/2002', 8);
INSERT INTO valoracions VALUES (957, 22, '03/10/2009', 5);
INSERT INTO valoracions VALUES (957, 115, '24/02/2009', 4);
INSERT INTO valoracions VALUES (957, 60, '10/05/2009', 6);
INSERT INTO valoracions VALUES (958, 81, '04/04/2008', 4);
INSERT INTO valoracions VALUES (958, 104, '22/06/2008', 1);
INSERT INTO valoracions VALUES (958, 74, '16/11/2009', 6);
INSERT INTO valoracions VALUES (958, 80, '10/09/2008', 5);
INSERT INTO valoracions VALUES (958, 18, '05/12/2006', 10);
INSERT INTO valoracions VALUES (959, 5, '02/02/2010', 5);
INSERT INTO valoracions VALUES (959, 51, '21/11/2005', 7);
INSERT INTO valoracions VALUES (959, 2, '13/02/2004', 7);
INSERT INTO valoracions VALUES (960, 74, '29/03/2008', 6);
INSERT INTO valoracions VALUES (960, 1, '30/08/2001', 6);
INSERT INTO valoracions VALUES (960, 61, '24/01/2003', 3);
INSERT INTO valoracions VALUES (960, 19, '19/02/2008', 5);
INSERT INTO valoracions VALUES (960, 53, '25/07/2001', 4);
INSERT INTO valoracions VALUES (960, 1, '22/02/2006', 6);
INSERT INTO valoracions VALUES (961, 12, '18/04/2002', 9);
INSERT INTO valoracions VALUES (961, 46, '30/12/2006', 7);
INSERT INTO valoracions VALUES (961, 105, '08/01/2007', 5);
INSERT INTO valoracions VALUES (961, 91, '10/11/2007', 7);
INSERT INTO valoracions VALUES (961, 79, '08/02/2009', 6);
INSERT INTO valoracions VALUES (962, 28, '10/05/2009', 4);
INSERT INTO valoracions VALUES (962, 6, '02/02/2008', 8);
INSERT INTO valoracions VALUES (962, 87, '18/09/2005', 7);
INSERT INTO valoracions VALUES (962, 111, '02/06/2006', 8);
INSERT INTO valoracions VALUES (962, 48, '03/11/2002', 7);
INSERT INTO valoracions VALUES (963, 5, '10/11/2009', 7);
INSERT INTO valoracions VALUES (963, 91, '20/07/2005', 1);
INSERT INTO valoracions VALUES (963, 115, '01/01/2007', 5);
INSERT INTO valoracions VALUES (963, 34, '07/11/2009', 10);
INSERT INTO valoracions VALUES (964, 95, '09/11/2008', 5);
INSERT INTO valoracions VALUES (964, 3, '30/08/2004', 9);
INSERT INTO valoracions VALUES (964, 71, '13/12/2006', 8);
INSERT INTO valoracions VALUES (965, 20, '14/05/2003', 6);
INSERT INTO valoracions VALUES (965, 6, '15/06/2009', 10);
INSERT INTO valoracions VALUES (965, 69, '17/06/2009', 9);
INSERT INTO valoracions VALUES (965, 27, '22/06/2004', 5);
INSERT INTO valoracions VALUES (966, 96, '12/10/2009', 2);
INSERT INTO valoracions VALUES (966, 81, '08/12/2003', 3);
INSERT INTO valoracions VALUES (966, 114, '04/07/2005', 8);
INSERT INTO valoracions VALUES (966, 115, '04/11/2003', 5);
INSERT INTO valoracions VALUES (967, 8, '25/07/2005', 5);
INSERT INTO valoracions VALUES (967, 44, '11/07/2007', 10);
INSERT INTO valoracions VALUES (967, 12, '02/09/2002', 8);
INSERT INTO valoracions VALUES (968, 52, '28/11/2008', 6);
INSERT INTO valoracions VALUES (968, 14, '16/05/2002', 10);
INSERT INTO valoracions VALUES (968, 25, '22/07/2009', 4);
INSERT INTO valoracions VALUES (969, 73, '07/05/2002', 4);
INSERT INTO valoracions VALUES (969, 54, '29/10/2007', 9);
INSERT INTO valoracions VALUES (970, 46, '18/08/2005', 9);
INSERT INTO valoracions VALUES (970, 99, '07/09/2002', 10);
INSERT INTO valoracions VALUES (971, 77, '17/11/2005', 7);
INSERT INTO valoracions VALUES (971, 50, '24/06/2002', 6);
INSERT INTO valoracions VALUES (972, 15, '21/02/2009', 6);
INSERT INTO valoracions VALUES (972, 88, '18/10/2004', 10);
INSERT INTO valoracions VALUES (972, 36, '07/03/2009', 4);
INSERT INTO valoracions VALUES (972, 57, '25/04/2005', 8);
INSERT INTO valoracions VALUES (973, 87, '25/05/2010', 7);
INSERT INTO valoracions VALUES (973, 75, '07/02/2009', 4);
INSERT INTO valoracions VALUES (974, 7, '03/04/2002', 7);
INSERT INTO valoracions VALUES (974, 96, '28/01/2010', 3);
INSERT INTO valoracions VALUES (974, 28, '27/08/2002', 5);
INSERT INTO valoracions VALUES (975, 37, '20/09/2002', 7);
INSERT INTO valoracions VALUES (975, 115, '03/06/2006', 7);
INSERT INTO valoracions VALUES (975, 23, '14/08/2003', 9);
INSERT INTO valoracions VALUES (975, 78, '06/05/2010', 7);
INSERT INTO valoracions VALUES (975, 65, '17/04/2005', 3);
INSERT INTO valoracions VALUES (975, 49, '31/05/2002', 8);
INSERT INTO valoracions VALUES (975, 28, '19/07/2001', 4);
INSERT INTO valoracions VALUES (975, 28, '25/10/2006', 8);
INSERT INTO valoracions VALUES (975, 68, '28/07/2006', 4);
INSERT INTO valoracions VALUES (977, 97, '18/09/2006', 7);
INSERT INTO valoracions VALUES (977, 52, '06/03/2003', 9);
INSERT INTO valoracions VALUES (978, 56, '04/09/2001', 9);
INSERT INTO valoracions VALUES (978, 9, '05/12/2001', 9);
INSERT INTO valoracions VALUES (978, 13, '06/04/2005', 7);
INSERT INTO valoracions VALUES (978, 15, '12/09/2006', 6);
INSERT INTO valoracions VALUES (978, 38, '24/01/2005', 10);
INSERT INTO valoracions VALUES (979, 110, '04/10/2005', 0);
INSERT INTO valoracions VALUES (979, 7, '06/09/2001', 7);
INSERT INTO valoracions VALUES (979, 17, '07/01/2008', 9);
INSERT INTO valoracions VALUES (979, 97, '16/04/2003', 5);
INSERT INTO valoracions VALUES (980, 107, '30/03/2009', 3);
INSERT INTO valoracions VALUES (980, 26, '11/05/2001', 6);
INSERT INTO valoracions VALUES (980, 18, '25/06/2008', 5);
INSERT INTO valoracions VALUES (981, 4, '19/08/2008', 7);
INSERT INTO valoracions VALUES (981, 80, '16/08/2010', 6);
INSERT INTO valoracions VALUES (981, 11, '01/09/2005', 6);
INSERT INTO valoracions VALUES (981, 96, '14/06/2005', 6);
INSERT INTO valoracions VALUES (981, 91, '29/12/2008', 4);
INSERT INTO valoracions VALUES (981, 89, '26/02/2004', 2);
INSERT INTO valoracions VALUES (982, 63, '09/01/2007', 7);
INSERT INTO valoracions VALUES (982, 48, '13/10/2004', 6);
INSERT INTO valoracions VALUES (982, 53, '26/08/2008', 9);
INSERT INTO valoracions VALUES (982, 98, '08/01/2005', 4);
INSERT INTO valoracions VALUES (982, 20, '14/10/2008', 9);
INSERT INTO valoracions VALUES (982, 27, '16/05/2001', 6);
INSERT INTO valoracions VALUES (983, 57, '20/04/2003', 4);
INSERT INTO valoracions VALUES (983, 81, '05/04/2008', 8);
INSERT INTO valoracions VALUES (984, 46, '02/10/2010', 4);
INSERT INTO valoracions VALUES (984, 66, '22/09/2009', 6);
INSERT INTO valoracions VALUES (984, 19, '14/11/2001', 9);
INSERT INTO valoracions VALUES (984, 63, '02/04/2001', 9);
INSERT INTO valoracions VALUES (984, 86, '27/08/2009', 10);
INSERT INTO valoracions VALUES (984, 22, '17/04/2010', 8);
INSERT INTO valoracions VALUES (985, 22, '07/01/2005', 6);
INSERT INTO valoracions VALUES (985, 9, '08/12/2005', 6);
INSERT INTO valoracions VALUES (986, 41, '03/04/2008', 8);
INSERT INTO valoracions VALUES (986, 24, '17/07/2010', 7);
INSERT INTO valoracions VALUES (987, 32, '23/08/2010', 4);
INSERT INTO valoracions VALUES (987, 46, '12/07/2006', 9);
INSERT INTO valoracions VALUES (987, 30, '16/09/2010', 9);
INSERT INTO valoracions VALUES (987, 6, '25/11/2004', 8);
INSERT INTO valoracions VALUES (988, 97, '19/10/2007', 5);
INSERT INTO valoracions VALUES (988, 56, '12/11/2008', 6);
INSERT INTO valoracions VALUES (988, 36, '03/11/2007', 9);
INSERT INTO valoracions VALUES (988, 12, '28/04/2004', 9);
INSERT INTO valoracions VALUES (989, 63, '11/05/2007', 8);
INSERT INTO valoracions VALUES (989, 26, '26/09/2008', 5);
INSERT INTO valoracions VALUES (989, 47, '02/06/2001', 5);
INSERT INTO valoracions VALUES (990, 36, '11/08/2010', 9);
INSERT INTO valoracions VALUES (990, 87, '01/01/2005', 3);
INSERT INTO valoracions VALUES (990, 21, '18/10/2006', 10);
INSERT INTO valoracions VALUES (991, 102, '11/09/2003', 9);
INSERT INTO valoracions VALUES (991, 39, '13/12/2003', 8);
INSERT INTO valoracions VALUES (992, 9, '22/09/2004', 8);
INSERT INTO valoracions VALUES (992, 36, '25/02/2004', 9);
INSERT INTO valoracions VALUES (992, 27, '26/05/2002', 8);
INSERT INTO valoracions VALUES (993, 58, '19/02/2004', 3);
INSERT INTO valoracions VALUES (994, 59, '26/10/2005', 9);
INSERT INTO valoracions VALUES (994, 104, '20/03/2004', 2);
INSERT INTO valoracions VALUES (994, 9, '04/08/2005', 7);
INSERT INTO valoracions VALUES (995, 65, '29/09/2003', 5);
INSERT INTO valoracions VALUES (995, 85, '12/05/2001', 5);
INSERT INTO valoracions VALUES (996, 77, '28/04/2009', 3);
INSERT INTO valoracions VALUES (996, 7, '03/12/2008', 7);
INSERT INTO valoracions VALUES (996, 111, '02/08/2004', 3);
INSERT INTO valoracions VALUES (996, 63, '14/12/2001', 7);
INSERT INTO valoracions VALUES (997, 74, '21/08/2003', 3);
INSERT INTO valoracions VALUES (997, 103, '10/11/2004', 5);
INSERT INTO valoracions VALUES (997, 103, '04/02/2008', 7);
INSERT INTO valoracions VALUES (997, 101, '03/10/2010', 9);
INSERT INTO valoracions VALUES (997, 106, '13/05/2008', 5);
INSERT INTO valoracions VALUES (998, 73, '13/06/2001', 6);
INSERT INTO valoracions VALUES (998, 102, '28/03/2010', 5);
INSERT INTO valoracions VALUES (998, 63, '07/02/2008', 3);
INSERT INTO valoracions VALUES (998, 111, '17/03/2003', 9);
INSERT INTO valoracions VALUES (998, 107, '21/05/2001', 5);
INSERT INTO valoracions VALUES (998, 5, '30/11/2001', 5);
INSERT INTO valoracions VALUES (999, 114, '13/08/2006', 4);
INSERT INTO valoracions VALUES (999, 10, '04/06/2007', 5);
INSERT INTO valoracions VALUES (999, 51, '04/05/2003', 4);
INSERT INTO valoracions VALUES (999, 22, '04/08/2001', 8);
INSERT INTO valoracions VALUES (999, 94, '22/05/2002', 6);
INSERT INTO valoracions VALUES (1000, 61, '29/12/2008', 8);
INSERT INTO valoracions VALUES (1000, 53, '26/12/2008', 3);
INSERT INTO valoracions VALUES (1000, 49, '18/08/2003', 5);
INSERT INTO valoracions VALUES (1000, 2, '05/10/2006', 8);
INSERT INTO valoracions VALUES (1000, 33, '03/08/2002', 6);
INSERT INTO valoracions VALUES (1000, 23, '04/10/2009', 7);
INSERT INTO valoracions VALUES (1001, 16, '22/07/2001', 5);
INSERT INTO valoracions VALUES (1001, 25, '23/08/2010', 4);
INSERT INTO valoracions VALUES (1002, 43, '22/07/2009', 10);
INSERT INTO valoracions VALUES (1002, 110, '24/11/2007', 1);
INSERT INTO valoracions VALUES (1002, 102, '28/04/2007', 9);
INSERT INTO valoracions VALUES (1002, 116, '24/05/2010', 0);
INSERT INTO valoracions VALUES (1002, 51, '09/02/2010', 4);
INSERT INTO valoracions VALUES (1003, 105, '15/06/2003', 3);
INSERT INTO valoracions VALUES (1003, 43, '28/10/2006', 9);
INSERT INTO valoracions VALUES (1003, 74, '17/05/2001', 6);
INSERT INTO valoracions VALUES (1003, 65, '21/05/2005', 9);
INSERT INTO valoracions VALUES (1004, 16, '20/07/2001', 5);
INSERT INTO valoracions VALUES (1004, 1, '09/08/2005', 7);
INSERT INTO valoracions VALUES (1004, 100, '11/04/2005', 7);
INSERT INTO valoracions VALUES (1005, 43, '26/11/2005', 3);
INSERT INTO valoracions VALUES (1005, 84, '25/07/2009', 4);
INSERT INTO valoracions VALUES (1005, 39, '09/03/2008', 7);
INSERT INTO valoracions VALUES (1006, 54, '29/05/2009', 9);
INSERT INTO valoracions VALUES (1006, 68, '28/06/2007', 4);
INSERT INTO valoracions VALUES (1006, 68, '05/10/2003', 8);
INSERT INTO valoracions VALUES (1006, 111, '11/06/2002', 8);
INSERT INTO valoracions VALUES (1006, 78, '19/09/2008', 2);
INSERT INTO valoracions VALUES (1006, 116, '28/11/2001', 6);
INSERT INTO valoracions VALUES (1007, 51, '24/06/2002', 4);
INSERT INTO valoracions VALUES (1007, 66, '27/08/2005', 7);
INSERT INTO valoracions VALUES (1008, 93, '11/08/2001', 9);
INSERT INTO valoracions VALUES (1008, 15, '06/01/2002', 7);
INSERT INTO valoracions VALUES (1008, 31, '20/01/2009', 4);
INSERT INTO valoracions VALUES (1008, 95, '28/07/2003', 7);
INSERT INTO valoracions VALUES (1008, 41, '21/10/2004', 10);
INSERT INTO valoracions VALUES (1008, 110, '06/12/2004', 9);
INSERT INTO valoracions VALUES (1009, 28, '12/01/2005', 9);
INSERT INTO valoracions VALUES (1010, 75, '03/07/2004', 9);
INSERT INTO valoracions VALUES (1010, 24, '25/08/2007', 6);
INSERT INTO valoracions VALUES (1010, 82, '16/06/2007', 8);
INSERT INTO valoracions VALUES (1011, 13, '01/07/2010', 8);
INSERT INTO valoracions VALUES (1011, 30, '19/05/2010', 9);
INSERT INTO valoracions VALUES (1011, 115, '19/07/2007', 2);
INSERT INTO valoracions VALUES (1011, 84, '01/05/2005', 9);
INSERT INTO valoracions VALUES (1011, 28, '08/07/2002', 4);
INSERT INTO valoracions VALUES (1011, 32, '27/11/2009', 10);
INSERT INTO valoracions VALUES (1012, 72, '16/06/2009', 8);
INSERT INTO valoracions VALUES (1012, 5, '19/08/2009', 9);
INSERT INTO valoracions VALUES (1012, 31, '18/12/2009', 7);
INSERT INTO valoracions VALUES (1012, 68, '03/02/2002', 6);
INSERT INTO valoracions VALUES (1013, 21, '20/06/2003', 8);
INSERT INTO valoracions VALUES (1013, 5, '08/07/2003', 10);
INSERT INTO valoracions VALUES (1013, 16, '05/02/2002', 5);
INSERT INTO valoracions VALUES (1013, 71, '27/08/2006', 10);
INSERT INTO valoracions VALUES (1013, 72, '23/03/2009', 3);
INSERT INTO valoracions VALUES (1013, 41, '29/09/2010', 5);
INSERT INTO valoracions VALUES (1014, 6, '12/06/2004', 5);
INSERT INTO valoracions VALUES (1014, 111, '08/11/2002', 7);
INSERT INTO valoracions VALUES (1015, 43, '21/07/2006', 5);
INSERT INTO valoracions VALUES (1015, 69, '02/09/2004', 2);
INSERT INTO valoracions VALUES (1015, 1, '13/01/2005', 7);
INSERT INTO valoracions VALUES (1017, 19, '24/07/2004', 9);
INSERT INTO valoracions VALUES (1017, 76, '04/11/2004', 6);
INSERT INTO valoracions VALUES (1018, 110, '11/05/2009', 1);
INSERT INTO valoracions VALUES (1018, 31, '29/10/2005', 9);
INSERT INTO valoracions VALUES (1018, 89, '09/03/2005', 6);
INSERT INTO valoracions VALUES (1019, 114, '12/09/2007', 5);
INSERT INTO valoracions VALUES (1019, 21, '12/05/2010', 6);
INSERT INTO valoracions VALUES (1019, 46, '04/11/2006', 6);
INSERT INTO valoracions VALUES (1019, 96, '05/11/2009', 8);
INSERT INTO valoracions VALUES (1020, 48, '20/03/2008', 9);
INSERT INTO valoracions VALUES (1020, 19, '02/10/2002', 8);
INSERT INTO valoracions VALUES (1021, 26, '25/06/2005', 8);
INSERT INTO valoracions VALUES (1021, 49, '22/02/2009', 9);
INSERT INTO valoracions VALUES (1022, 65, '15/05/2010', 5);
INSERT INTO valoracions VALUES (1023, 55, '05/11/2003', 10);
INSERT INTO valoracions VALUES (1023, 50, '27/04/2004', 4);
INSERT INTO valoracions VALUES (1023, 101, '15/08/2003', 3);
INSERT INTO valoracions VALUES (1023, 83, '14/02/2009', 2);
INSERT INTO valoracions VALUES (1023, 68, '20/03/2002', 8);
INSERT INTO valoracions VALUES (1024, 87, '13/02/2007', 8);
INSERT INTO valoracions VALUES (1024, 65, '24/10/2009', 9);
INSERT INTO valoracions VALUES (1024, 11, '11/04/2005', 7);
INSERT INTO valoracions VALUES (1025, 71, '28/12/2006', 2);
INSERT INTO valoracions VALUES (1025, 78, '22/01/2007', 9);
INSERT INTO valoracions VALUES (1025, 19, '29/03/2006', 5);
INSERT INTO valoracions VALUES (1025, 49, '24/05/2006', 3);
INSERT INTO valoracions VALUES (1025, 25, '14/06/2010', 10);
INSERT INTO valoracions VALUES (1025, 8, '27/10/2009', 6);
INSERT INTO valoracions VALUES (1025, 96, '19/05/2003', 9);
INSERT INTO valoracions VALUES (1025, 112, '03/12/2004', 4);
INSERT INTO valoracions VALUES (1026, 53, '10/04/2004', 6);
INSERT INTO valoracions VALUES (1026, 71, '24/08/2006', 9);
INSERT INTO valoracions VALUES (1026, 65, '11/01/2009', 6);
INSERT INTO valoracions VALUES (1026, 88, '10/09/2007', 7);
INSERT INTO valoracions VALUES (1026, 79, '20/08/2007', 6);
INSERT INTO valoracions VALUES (1027, 96, '29/03/2002', 1);
INSERT INTO valoracions VALUES (1027, 27, '12/06/2009', 5);
INSERT INTO valoracions VALUES (1027, 66, '22/12/2005', 6);
INSERT INTO valoracions VALUES (1028, 73, '09/05/2006', 4);
INSERT INTO valoracions VALUES (1028, 94, '14/12/2004', 1);
INSERT INTO valoracions VALUES (1029, 53, '09/08/2010', 8);
INSERT INTO valoracions VALUES (1029, 105, '17/02/2005', 3);
INSERT INTO valoracions VALUES (1029, 20, '01/05/2007', 7);
INSERT INTO valoracions VALUES (1029, 19, '03/12/2002', 9);
INSERT INTO valoracions VALUES (1029, 66, '06/07/2010', 3);
INSERT INTO valoracions VALUES (1029, 47, '14/08/2010', 8);
INSERT INTO valoracions VALUES (1030, 84, '25/01/2007', 7);
INSERT INTO valoracions VALUES (1030, 60, '16/09/2005', 8);
INSERT INTO valoracions VALUES (1030, 70, '23/04/2009', 8);
INSERT INTO valoracions VALUES (1030, 97, '16/02/2009', 7);
INSERT INTO valoracions VALUES (1030, 62, '03/12/2002', 5);
INSERT INTO valoracions VALUES (1030, 11, '27/01/2002', 5);
INSERT INTO valoracions VALUES (1031, 86, '24/11/2006', 1);
INSERT INTO valoracions VALUES (1031, 38, '02/12/2003', 6);
INSERT INTO valoracions VALUES (1032, 87, '21/03/2009', 5);
INSERT INTO valoracions VALUES (1032, 51, '08/02/2002', 9);
INSERT INTO valoracions VALUES (1032, 9, '16/02/2008', 6);
INSERT INTO valoracions VALUES (1032, 37, '16/07/2010', 3);
INSERT INTO valoracions VALUES (1032, 87, '07/07/2004', 8);
INSERT INTO valoracions VALUES (1033, 90, '10/10/2004', 5);
INSERT INTO valoracions VALUES (1033, 91, '06/11/2007', 2);
INSERT INTO valoracions VALUES (1033, 49, '06/05/2003', 6);
INSERT INTO valoracions VALUES (1034, 66, '25/07/2003', 7);
INSERT INTO valoracions VALUES (1035, 33, '29/09/2001', 6);
INSERT INTO valoracions VALUES (1035, 56, '08/04/2007', 3);
INSERT INTO valoracions VALUES (1036, 32, '04/09/2009', 7);
INSERT INTO valoracions VALUES (1036, 13, '25/05/2003', 8);
INSERT INTO valoracions VALUES (1036, 70, '10/03/2007', 7);
INSERT INTO valoracions VALUES (1037, 103, '16/06/2001', 3);
INSERT INTO valoracions VALUES (1038, 14, '08/11/2004', 4);
INSERT INTO valoracions VALUES (1038, 20, '30/06/2009', 9);
INSERT INTO valoracions VALUES (1038, 89, '09/08/2007', 7);
INSERT INTO valoracions VALUES (1039, 91, '03/01/2007', 7);
INSERT INTO valoracions VALUES (1039, 61, '16/04/2002', 9);
INSERT INTO valoracions VALUES (1039, 73, '11/05/2003', 9);
INSERT INTO valoracions VALUES (1039, 55, '15/02/2002', 3);
INSERT INTO valoracions VALUES (1039, 76, '17/03/2006', 3);
INSERT INTO valoracions VALUES (1039, 24, '18/08/2010', 7);
INSERT INTO valoracions VALUES (1040, 35, '13/09/2002', 7);
INSERT INTO valoracions VALUES (1040, 16, '23/01/2005', 9);
INSERT INTO valoracions VALUES (1040, 28, '30/05/2003', 9);
INSERT INTO valoracions VALUES (1040, 31, '09/06/2006', 7);
INSERT INTO valoracions VALUES (1040, 92, '01/11/2003', 3);
INSERT INTO valoracions VALUES (1040, 38, '09/08/2006', 10);
INSERT INTO valoracions VALUES (1040, 51, '14/08/2004', 6);
INSERT INTO valoracions VALUES (1041, 88, '18/12/2009', 9);
INSERT INTO valoracions VALUES (1041, 68, '01/06/2009', 7);
INSERT INTO valoracions VALUES (1042, 9, '08/03/2009', 8);
INSERT INTO valoracions VALUES (1042, 17, '17/04/2007', 5);
INSERT INTO valoracions VALUES (1042, 20, '06/04/2006', 8);
INSERT INTO valoracions VALUES (1042, 77, '30/09/2008', 5);
INSERT INTO valoracions VALUES (1043, 82, '25/09/2008', 4);
INSERT INTO valoracions VALUES (1043, 22, '17/06/2005', 8);
INSERT INTO valoracions VALUES (1043, 60, '16/02/2004', 3);
INSERT INTO valoracions VALUES (1044, 97, '29/01/2007', 5);
INSERT INTO valoracions VALUES (1044, 51, '31/07/2001', 8);
INSERT INTO valoracions VALUES (1045, 87, '17/10/2009', 2);
INSERT INTO valoracions VALUES (1045, 56, '26/07/2006', 7);
INSERT INTO valoracions VALUES (1045, 37, '18/07/2003', 9);
INSERT INTO valoracions VALUES (1045, 90, '10/01/2006', 1);
INSERT INTO valoracions VALUES (1045, 2, '10/07/2009', 6);
INSERT INTO valoracions VALUES (1045, 6, '16/03/2005', 6);
INSERT INTO valoracions VALUES (1045, 33, '18/10/2008', 6);
INSERT INTO valoracions VALUES (1045, 15, '14/09/2003', 7);
INSERT INTO valoracions VALUES (1045, 75, '31/05/2004', 3);
INSERT INTO valoracions VALUES (1046, 34, '04/06/2009', 9);
INSERT INTO valoracions VALUES (1046, 45, '13/03/2008', 7);
INSERT INTO valoracions VALUES (1046, 59, '20/09/2003', 9);
INSERT INTO valoracions VALUES (1046, 43, '23/11/2003', 7);
INSERT INTO valoracions VALUES (1046, 28, '18/11/2005', 9);
INSERT INTO valoracions VALUES (1046, 23, '18/01/2005', 6);
INSERT INTO valoracions VALUES (1047, 98, '05/09/2001', 5);
INSERT INTO valoracions VALUES (1047, 85, '03/09/2003', 10);
INSERT INTO valoracions VALUES (1047, 13, '03/07/2003', 5);
INSERT INTO valoracions VALUES (1047, 98, '03/09/2010', 4);
INSERT INTO valoracions VALUES (1047, 42, '28/04/2009', 6);
INSERT INTO valoracions VALUES (1047, 54, '08/01/2002', 6);
INSERT INTO valoracions VALUES (1047, 113, '21/02/2008', 1);
INSERT INTO valoracions VALUES (1047, 88, '19/08/2004', 4);
INSERT INTO valoracions VALUES (1048, 97, '31/01/2006', 10);
INSERT INTO valoracions VALUES (1048, 38, '07/01/2003', 5);
INSERT INTO valoracions VALUES (1048, 68, '09/02/2006', 4);
INSERT INTO valoracions VALUES (1048, 37, '14/09/2002', 3);
INSERT INTO valoracions VALUES (1048, 38, '18/10/2007', 7);
INSERT INTO valoracions VALUES (1049, 91, '21/10/2010', 4);
INSERT INTO valoracions VALUES (1049, 102, '30/03/2010', 8);
INSERT INTO valoracions VALUES (1049, 96, '30/12/2004', 7);
INSERT INTO valoracions VALUES (1049, 98, '24/05/2005', 6);
INSERT INTO valoracions VALUES (1050, 19, '22/05/2002', 9);
INSERT INTO valoracions VALUES (1050, 35, '01/10/2005', 6);
INSERT INTO valoracions VALUES (1051, 90, '13/12/2005', 4);
INSERT INTO valoracions VALUES (1051, 26, '23/08/2002', 9);
INSERT INTO valoracions VALUES (1051, 1, '12/09/2008', 9);
INSERT INTO valoracions VALUES (1051, 57, '06/05/2005', 4);
INSERT INTO valoracions VALUES (1051, 10, '01/01/2007', 9);
INSERT INTO valoracions VALUES (1051, 90, '21/10/2004', 3);
INSERT INTO valoracions VALUES (1052, 43, '12/06/2005', 6);
INSERT INTO valoracions VALUES (1052, 97, '26/02/2009', 6);
INSERT INTO valoracions VALUES (1053, 79, '17/03/2010', 3);
INSERT INTO valoracions VALUES (1053, 52, '21/12/2001', 7);
INSERT INTO valoracions VALUES (1054, 50, '25/09/2005', 5);
INSERT INTO valoracions VALUES (1054, 65, '18/03/2006', 9);
INSERT INTO valoracions VALUES (1054, 99, '07/12/2003', 2);
INSERT INTO valoracions VALUES (1054, 85, '04/08/2009', 3);
INSERT INTO valoracions VALUES (1055, 93, '05/12/2008', 1);
INSERT INTO valoracions VALUES (1055, 15, '03/03/2007', 8);
INSERT INTO valoracions VALUES (1056, 82, '16/10/2002', 6);
INSERT INTO valoracions VALUES (1056, 103, '30/11/2008', 4);
INSERT INTO valoracions VALUES (1056, 110, '08/04/2007', 9);
INSERT INTO valoracions VALUES (1056, 92, '19/11/2002', 10);
INSERT INTO valoracions VALUES (1057, 57, '25/08/2010', 4);
INSERT INTO valoracions VALUES (1057, 70, '27/12/2002', 4);
INSERT INTO valoracions VALUES (1057, 32, '08/08/2001', 5);
INSERT INTO valoracions VALUES (1057, 108, '17/05/2009', 10);
INSERT INTO valoracions VALUES (1057, 108, '11/10/2003', 0);
INSERT INTO valoracions VALUES (1058, 13, '12/06/2008', 6);
INSERT INTO valoracions VALUES (1058, 11, '03/09/2005', 5);
INSERT INTO valoracions VALUES (1058, 104, '08/07/2005', 3);
INSERT INTO valoracions VALUES (1058, 76, '10/05/2006', 6);
INSERT INTO valoracions VALUES (1058, 97, '21/03/2005', 9);
INSERT INTO valoracions VALUES (1058, 9, '19/10/2009', 9);
INSERT INTO valoracions VALUES (1059, 45, '08/11/2004', 9);
INSERT INTO valoracions VALUES (1059, 67, '21/12/2005', 5);
INSERT INTO valoracions VALUES (1059, 79, '08/04/2005', 7);
INSERT INTO valoracions VALUES (1059, 18, '20/11/2003', 7);
INSERT INTO valoracions VALUES (1059, 108, '16/06/2007', 4);
INSERT INTO valoracions VALUES (1060, 44, '11/11/2006', 6);
INSERT INTO valoracions VALUES (1060, 112, '01/04/2008', 2);
INSERT INTO valoracions VALUES (1060, 31, '10/03/2006', 6);
INSERT INTO valoracions VALUES (1060, 14, '24/10/2010', 7);
INSERT INTO valoracions VALUES (1060, 58, '19/05/2001', 6);
INSERT INTO valoracions VALUES (1060, 115, '04/02/2005', 4);
INSERT INTO valoracions VALUES (1060, 92, '21/07/2005', 6);
INSERT INTO valoracions VALUES (1061, 15, '13/01/2007', 9);
INSERT INTO valoracions VALUES (1061, 82, '11/11/2005', 2);
INSERT INTO valoracions VALUES (1061, 114, '14/05/2002', 6);
INSERT INTO valoracions VALUES (1061, 48, '03/08/2008', 6);
INSERT INTO valoracions VALUES (1061, 105, '13/04/2010', 7);
INSERT INTO valoracions VALUES (1061, 6, '13/07/2008', 9);
INSERT INTO valoracions VALUES (1062, 16, '11/05/2001', 8);
INSERT INTO valoracions VALUES (1062, 38, '19/10/2003', 5);
INSERT INTO valoracions VALUES (1062, 84, '30/10/2004', 2);
INSERT INTO valoracions VALUES (1062, 91, '09/07/2008', 2);
INSERT INTO valoracions VALUES (1063, 105, '10/04/2006', 5);
INSERT INTO valoracions VALUES (1063, 24, '18/03/2005', 5);
INSERT INTO valoracions VALUES (1063, 48, '18/02/2006', 7);
INSERT INTO valoracions VALUES (1063, 56, '05/08/2006', 3);
INSERT INTO valoracions VALUES (1063, 47, '04/02/2004', 5);
INSERT INTO valoracions VALUES (1063, 81, '14/03/2003', 6);
INSERT INTO valoracions VALUES (1064, 107, '28/12/2005', 6);
INSERT INTO valoracions VALUES (1064, 28, '09/10/2005', 5);
INSERT INTO valoracions VALUES (1064, 111, '16/03/2004', 4);
INSERT INTO valoracions VALUES (1064, 76, '22/03/2008', 2);
INSERT INTO valoracions VALUES (1064, 15, '17/01/2003', 9);
INSERT INTO valoracions VALUES (1065, 26, '24/12/2009', 8);
INSERT INTO valoracions VALUES (1065, 27, '13/04/2004', 4);
INSERT INTO valoracions VALUES (1065, 63, '22/10/2006', 8);
INSERT INTO valoracions VALUES (1065, 28, '24/10/2009', 6);
INSERT INTO valoracions VALUES (1065, 42, '28/11/2003', 8);
INSERT INTO valoracions VALUES (1066, 100, '15/11/2009', 5);
INSERT INTO valoracions VALUES (1066, 98, '16/10/2008', 9);
INSERT INTO valoracions VALUES (1066, 93, '24/03/2010', 6);
INSERT INTO valoracions VALUES (1066, 70, '11/01/2002', 4);
INSERT INTO valoracions VALUES (1066, 19, '07/11/2007', 8);
INSERT INTO valoracions VALUES (1066, 110, '05/02/2002', 6);
INSERT INTO valoracions VALUES (1067, 14, '22/11/2009', 5);
INSERT INTO valoracions VALUES (1067, 48, '02/06/2004', 4);
INSERT INTO valoracions VALUES (1067, 78, '09/05/2004', 8);
INSERT INTO valoracions VALUES (1067, 111, '29/12/2003', 6);
INSERT INTO valoracions VALUES (1068, 96, '28/05/2007', 8);
INSERT INTO valoracions VALUES (1068, 64, '17/06/2002', 7);
INSERT INTO valoracions VALUES (1068, 24, '28/08/2005', 10);
INSERT INTO valoracions VALUES (1068, 113, '20/04/2004', 6);
INSERT INTO valoracions VALUES (1069, 65, '22/02/2006', 8);
INSERT INTO valoracions VALUES (1069, 22, '15/12/2001', 9);
INSERT INTO valoracions VALUES (1070, 82, '12/03/2007', 7);
INSERT INTO valoracions VALUES (1070, 76, '09/10/2007', 7);
INSERT INTO valoracions VALUES (1070, 93, '18/09/2005', 1);
INSERT INTO valoracions VALUES (1070, 94, '10/12/2008', 3);
INSERT INTO valoracions VALUES (1070, 20, '26/12/2004', 7);
INSERT INTO valoracions VALUES (1071, 14, '10/01/2003', 8);
INSERT INTO valoracions VALUES (1071, 20, '10/06/2007', 8);
INSERT INTO valoracions VALUES (1072, 33, '21/04/2006', 8);
INSERT INTO valoracions VALUES (1073, 24, '08/03/2008', 5);
INSERT INTO valoracions VALUES (1073, 23, '10/02/2007', 9);
INSERT INTO valoracions VALUES (1073, 25, '05/11/2007', 6);
INSERT INTO valoracions VALUES (1073, 16, '12/04/2002', 6);
INSERT INTO valoracions VALUES (1074, 84, '20/05/2002', 1);
INSERT INTO valoracions VALUES (1074, 100, '28/11/2001', 3);
INSERT INTO valoracions VALUES (1074, 1, '17/02/2007', 6);
INSERT INTO valoracions VALUES (1074, 51, '14/09/2004', 6);
INSERT INTO valoracions VALUES (1075, 81, '25/03/2004', 4);
INSERT INTO valoracions VALUES (1075, 69, '05/09/2010', 7);
INSERT INTO valoracions VALUES (1076, 67, '02/03/2002', 8);
INSERT INTO valoracions VALUES (1076, 46, '02/02/2008', 4);
INSERT INTO valoracions VALUES (1077, 101, '11/09/2006', 8);
INSERT INTO valoracions VALUES (1077, 73, '24/02/2007', 5);
INSERT INTO valoracions VALUES (1077, 75, '14/10/2002', 7);
INSERT INTO valoracions VALUES (1077, 54, '06/06/2006', 8);
INSERT INTO valoracions VALUES (1077, 6, '05/09/2007', 7);
INSERT INTO valoracions VALUES (1078, 8, '08/01/2009', 8);
INSERT INTO valoracions VALUES (1078, 62, '12/09/2003', 3);
INSERT INTO valoracions VALUES (1078, 104, '20/06/2004', 5);
INSERT INTO valoracions VALUES (1079, 94, '28/02/2005', 10);
INSERT INTO valoracions VALUES (1079, 25, '17/12/2008', 9);
INSERT INTO valoracions VALUES (1079, 23, '24/09/2003', 6);
INSERT INTO valoracions VALUES (1079, 3, '06/09/2002', 7);
INSERT INTO valoracions VALUES (1079, 44, '29/06/2003', 7);
INSERT INTO valoracions VALUES (1079, 67, '02/07/2005', 6);
INSERT INTO valoracions VALUES (1079, 60, '09/03/2008', 4);
INSERT INTO valoracions VALUES (1080, 53, '15/12/2002', 6);
INSERT INTO valoracions VALUES (1080, 92, '19/12/2003', 2);
INSERT INTO valoracions VALUES (1080, 58, '07/10/2003', 9);
INSERT INTO valoracions VALUES (1080, 44, '05/11/2006', 4);
INSERT INTO valoracions VALUES (1080, 110, '25/10/2009', 7);
INSERT INTO valoracions VALUES (1080, 107, '13/05/2009', 2);
INSERT INTO valoracions VALUES (1081, 111, '17/07/2001', 3);
INSERT INTO valoracions VALUES (1081, 96, '09/02/2003', 2);
INSERT INTO valoracions VALUES (1081, 32, '18/09/2009', 4);
INSERT INTO valoracions VALUES (1081, 22, '05/11/2002', 6);
INSERT INTO valoracions VALUES (1081, 78, '18/04/2001', 3);
INSERT INTO valoracions VALUES (1081, 37, '11/12/2008', 5);
INSERT INTO valoracions VALUES (1082, 114, '16/09/2002', 6);
INSERT INTO valoracions VALUES (1082, 62, '22/06/2005', 5);
INSERT INTO valoracions VALUES (1082, 20, '07/07/2004', 10);
INSERT INTO valoracions VALUES (1082, 55, '18/04/2002', 9);
INSERT INTO valoracions VALUES (1082, 50, '02/02/2002', 3);
INSERT INTO valoracions VALUES (1082, 30, '24/12/2006', 7);
INSERT INTO valoracions VALUES (1083, 1, '15/04/2006', 6);
INSERT INTO valoracions VALUES (1083, 10, '12/04/2002', 9);
INSERT INTO valoracions VALUES (1083, 5, '15/09/2005', 6);
INSERT INTO valoracions VALUES (1083, 12, '15/12/2009', 8);
INSERT INTO valoracions VALUES (1083, 7, '07/06/2009', 6);
INSERT INTO valoracions VALUES (1084, 87, '08/05/2003', 9);
INSERT INTO valoracions VALUES (1084, 28, '19/02/2008', 5);
INSERT INTO valoracions VALUES (1084, 78, '19/10/2010', 4);
INSERT INTO valoracions VALUES (1084, 101, '16/04/2001', 8);
INSERT INTO valoracions VALUES (1086, 74, '25/08/2005', 10);
INSERT INTO valoracions VALUES (1086, 3, '07/11/2006', 5);
INSERT INTO valoracions VALUES (1086, 109, '28/06/2008', 2);
INSERT INTO valoracions VALUES (1086, 13, '07/06/2004', 8);
INSERT INTO valoracions VALUES (1086, 116, '23/04/2005', 1);
INSERT INTO valoracions VALUES (1086, 74, '14/02/2003', 6);
INSERT INTO valoracions VALUES (1087, 112, '26/08/2005', 7);
INSERT INTO valoracions VALUES (1087, 96, '22/04/2006', 5);
INSERT INTO valoracions VALUES (1087, 32, '22/03/2004', 7);
INSERT INTO valoracions VALUES (1087, 25, '26/07/2009', 6);
INSERT INTO valoracions VALUES (1087, 5, '20/08/2004', 8);
INSERT INTO valoracions VALUES (1087, 89, '08/04/2010', 7);
INSERT INTO valoracions VALUES (1087, 2, '17/05/2003', 9);
INSERT INTO valoracions VALUES (1087, 6, '24/10/2005', 5);
INSERT INTO valoracions VALUES (1087, 49, '28/05/2001', 8);
INSERT INTO valoracions VALUES (1087, 2, '22/08/2008', 6);
INSERT INTO valoracions VALUES (1088, 108, '23/02/2010', 0);
INSERT INTO valoracions VALUES (1088, 100, '18/04/2005', 2);
INSERT INTO valoracions VALUES (1088, 93, '27/01/2005', 3);
INSERT INTO valoracions VALUES (1088, 59, '16/12/2005', 3);
INSERT INTO valoracions VALUES (1088, 112, '13/05/2010', 9);
INSERT INTO valoracions VALUES (1088, 35, '19/05/2006', 7);
INSERT INTO valoracions VALUES (1088, 53, '01/05/2010', 6);
INSERT INTO valoracions VALUES (1088, 110, '05/11/2004', 9);
INSERT INTO valoracions VALUES (1088, 84, '12/04/2002', 7);
INSERT INTO valoracions VALUES (1088, 81, '11/06/2008', 4);
INSERT INTO valoracions VALUES (1089, 69, '31/05/2006', 6);
INSERT INTO valoracions VALUES (1089, 104, '16/08/2008', 2);
INSERT INTO valoracions VALUES (1089, 23, '13/10/2002', 9);
INSERT INTO valoracions VALUES (1089, 63, '05/03/2007', 5);
INSERT INTO valoracions VALUES (1089, 111, '09/04/2009', 9);
INSERT INTO valoracions VALUES (1090, 43, '14/04/2007', 10);
INSERT INTO valoracions VALUES (1090, 15, '11/03/2010', 7);
INSERT INTO valoracions VALUES (1090, 22, '25/12/2008', 6);
INSERT INTO valoracions VALUES (1090, 5, '25/07/2006', 10);
INSERT INTO valoracions VALUES (1091, 94, '03/09/2010', 9);
INSERT INTO valoracions VALUES (1091, 32, '02/02/2010', 9);
INSERT INTO valoracions VALUES (1091, 63, '26/02/2009', 6);
INSERT INTO valoracions VALUES (1091, 53, '04/08/2003', 3);
INSERT INTO valoracions VALUES (1091, 74, '01/09/2006', 10);
INSERT INTO valoracions VALUES (1092, 51, '11/09/2007', 9);
INSERT INTO valoracions VALUES (1092, 25, '05/12/2008', 4);
INSERT INTO valoracions VALUES (1092, 95, '11/04/2002', 2);
INSERT INTO valoracions VALUES (1092, 112, '03/07/2006', 2);
INSERT INTO valoracions VALUES (1092, 74, '30/05/2001', 4);
INSERT INTO valoracions VALUES (1093, 68, '22/12/2007', 7);
INSERT INTO valoracions VALUES (1093, 71, '21/06/2003', 9);
INSERT INTO valoracions VALUES (1093, 71, '24/01/2008', 4);
INSERT INTO valoracions VALUES (1093, 56, '11/03/2008', 8);
INSERT INTO valoracions VALUES (1093, 88, '25/04/2006', 6);
INSERT INTO valoracions VALUES (1094, 97, '05/03/2005', 5);
INSERT INTO valoracions VALUES (1094, 6, '29/07/2002', 9);
INSERT INTO valoracions VALUES (1094, 89, '07/12/2009', 2);
INSERT INTO valoracions VALUES (1094, 58, '12/04/2001', 6);
INSERT INTO valoracions VALUES (1095, 91, '20/06/2010', 10);
INSERT INTO valoracions VALUES (1095, 48, '13/09/2008', 9);
INSERT INTO valoracions VALUES (1095, 73, '01/03/2004', 8);
INSERT INTO valoracions VALUES (1096, 58, '06/04/2002', 4);
INSERT INTO valoracions VALUES (1096, 8, '09/07/2004', 6);
INSERT INTO valoracions VALUES (1097, 104, '24/09/2003', 2);
INSERT INTO valoracions VALUES (1097, 83, '12/08/2006', 8);
INSERT INTO valoracions VALUES (1097, 74, '07/03/2006', 10);
INSERT INTO valoracions VALUES (1097, 89, '15/05/2005', 6);
INSERT INTO valoracions VALUES (1097, 107, '14/03/2003', 4);
INSERT INTO valoracions VALUES (1097, 38, '02/08/2009', 7);
INSERT INTO valoracions VALUES (1098, 66, '19/03/2008', 5);
INSERT INTO valoracions VALUES (1098, 102, '23/08/2003', 8);
INSERT INTO valoracions VALUES (1098, 115, '24/05/2007', 3);
INSERT INTO valoracions VALUES (1098, 10, '05/08/2003', 5);
INSERT INTO valoracions VALUES (1098, 48, '20/06/2004', 6);
INSERT INTO valoracions VALUES (1098, 111, '15/04/2009', 1);
INSERT INTO valoracions VALUES (1099, 26, '25/01/2010', 9);
INSERT INTO valoracions VALUES (1099, 84, '24/02/2006', 7);
INSERT INTO valoracions VALUES (1099, 38, '20/03/2007', 9);
INSERT INTO valoracions VALUES (1099, 80, '20/12/2002', 2);
INSERT INTO valoracions VALUES (1100, 10, '29/03/2007', 8);
INSERT INTO valoracions VALUES (1100, 88, '29/08/2009', 2);
INSERT INTO valoracions VALUES (1100, 28, '05/01/2004', 6);
INSERT INTO valoracions VALUES (1101, 96, '30/09/2010', 5);
INSERT INTO valoracions VALUES (1101, 57, '22/03/2004', 8);
INSERT INTO valoracions VALUES (1101, 70, '17/12/2002', 7);
INSERT INTO valoracions VALUES (1102, 27, '13/02/2010', 8);
INSERT INTO valoracions VALUES (1102, 86, '26/12/2004', 8);
INSERT INTO valoracions VALUES (1102, 57, '06/03/2009', 8);
INSERT INTO valoracions VALUES (1103, 72, '08/05/2008', 10);
INSERT INTO valoracions VALUES (1103, 62, '28/12/2001', 4);
INSERT INTO valoracions VALUES (1104, 13, '13/11/2004', 8);
INSERT INTO valoracions VALUES (1104, 1, '23/04/2003', 10);
INSERT INTO valoracions VALUES (1104, 13, '16/05/2006', 9);
INSERT INTO valoracions VALUES (1104, 20, '07/12/2002', 7);
INSERT INTO valoracions VALUES (1104, 84, '23/05/2010', 7);
INSERT INTO valoracions VALUES (1104, 53, '05/03/2007', 9);
INSERT INTO valoracions VALUES (1104, 22, '20/05/2005', 5);
INSERT INTO valoracions VALUES (1105, 112, '28/05/2004', 1);
INSERT INTO valoracions VALUES (1105, 101, '01/12/2005', 7);
INSERT INTO valoracions VALUES (1105, 26, '13/04/2007', 9);
INSERT INTO valoracions VALUES (1106, 83, '15/11/2007', 5);
INSERT INTO valoracions VALUES (1106, 4, '17/12/2001', 8);
INSERT INTO valoracions VALUES (1107, 57, '12/06/2005', 6);
INSERT INTO valoracions VALUES (1107, 58, '07/07/2001', 6);
INSERT INTO valoracions VALUES (1107, 68, '06/10/2002', 8);
INSERT INTO valoracions VALUES (1108, 34, '19/12/2003', 9);
INSERT INTO valoracions VALUES (1108, 84, '16/04/2009', 2);
INSERT INTO valoracions VALUES (1108, 50, '21/04/2008', 3);
INSERT INTO valoracions VALUES (1108, 25, '15/07/2010', 9);
INSERT INTO valoracions VALUES (1108, 8, '09/05/2004', 6);
INSERT INTO valoracions VALUES (1108, 42, '30/08/2003', 7);
INSERT INTO valoracions VALUES (1109, 22, '22/03/2002', 6);
INSERT INTO valoracions VALUES (1109, 5, '06/04/2006', 6);
INSERT INTO valoracions VALUES (1109, 39, '18/10/2005', 10);
INSERT INTO valoracions VALUES (1109, 82, '21/11/2009', 5);
INSERT INTO valoracions VALUES (1109, 35, '20/10/2005', 5);
INSERT INTO valoracions VALUES (1109, 77, '26/11/2002', 10);
INSERT INTO valoracions VALUES (1109, 14, '29/05/2003', 8);
INSERT INTO valoracions VALUES (1109, 43, '28/09/2004', 7);
INSERT INTO valoracions VALUES (1109, 73, '12/05/2004', 7);
INSERT INTO valoracions VALUES (1110, 112, '22/05/2005', 8);
INSERT INTO valoracions VALUES (1110, 100, '19/05/2003', 6);
INSERT INTO valoracions VALUES (1110, 63, '02/03/2009', 4);
INSERT INTO valoracions VALUES (1110, 72, '21/06/2009', 8);
INSERT INTO valoracions VALUES (1111, 24, '30/06/2001', 7);
INSERT INTO valoracions VALUES (1111, 22, '09/04/2008', 5);
INSERT INTO valoracions VALUES (1111, 112, '29/04/2005', 8);
INSERT INTO valoracions VALUES (1111, 24, '30/03/2006', 5);
INSERT INTO valoracions VALUES (1112, 84, '12/12/2005', 7);
INSERT INTO valoracions VALUES (1113, 54, '03/11/2001', 6);
INSERT INTO valoracions VALUES (1113, 31, '14/08/2004', 4);
INSERT INTO valoracions VALUES (1113, 66, '08/02/2009', 8);
INSERT INTO valoracions VALUES (1114, 41, '30/03/2002', 4);
INSERT INTO valoracions VALUES (1114, 97, '04/06/2003', 7);
INSERT INTO valoracions VALUES (1115, 113, '07/12/2005', 2);
INSERT INTO valoracions VALUES (1115, 53, '16/07/2009', 4);
INSERT INTO valoracions VALUES (1115, 108, '09/09/2009', 8);
INSERT INTO valoracions VALUES (1116, 38, '11/12/2007', 9);
INSERT INTO valoracions VALUES (1116, 86, '02/02/2002', 9);
INSERT INTO valoracions VALUES (1116, 57, '12/06/2003', 7);
INSERT INTO valoracions VALUES (1117, 113, '03/01/2008', 7);
INSERT INTO valoracions VALUES (1117, 68, '06/03/2007', 9);
INSERT INTO valoracions VALUES (1117, 77, '08/11/2004', 6);
INSERT INTO valoracions VALUES (1117, 20, '03/02/2010', 5);
INSERT INTO valoracions VALUES (1117, 71, '28/01/2007', 5);
INSERT INTO valoracions VALUES (1117, 79, '07/07/2001', 10);
INSERT INTO valoracions VALUES (1117, 60, '05/12/2007', 2);
INSERT INTO valoracions VALUES (1118, 111, '20/05/2010', 3);
INSERT INTO valoracions VALUES (1118, 15, '04/05/2008', 6);
INSERT INTO valoracions VALUES (1118, 88, '02/01/2002', 2);
INSERT INTO valoracions VALUES (1118, 8, '04/02/2010', 9);
INSERT INTO valoracions VALUES (1118, 55, '01/09/2001', 5);
INSERT INTO valoracions VALUES (1119, 20, '13/12/2002', 5);
INSERT INTO valoracions VALUES (1119, 114, '12/07/2008', 3);
INSERT INTO valoracions VALUES (1119, 68, '21/10/2003', 2);
INSERT INTO valoracions VALUES (1120, 80, '03/09/2002', 7);
INSERT INTO valoracions VALUES (1120, 19, '25/02/2007', 8);
INSERT INTO valoracions VALUES (1120, 35, '23/01/2010', 9);
INSERT INTO valoracions VALUES (1120, 76, '12/03/2006', 5);
INSERT INTO valoracions VALUES (1120, 70, '26/05/2001', 7);
INSERT INTO valoracions VALUES (1120, 78, '27/12/2002', 7);
INSERT INTO valoracions VALUES (1121, 63, '31/07/2007', 2);
INSERT INTO valoracions VALUES (1121, 34, '01/03/2008', 4);
INSERT INTO valoracions VALUES (1121, 67, '09/01/2009', 4);
INSERT INTO valoracions VALUES (1122, 19, '06/05/2010', 8);
INSERT INTO valoracions VALUES (1123, 51, '26/12/2009', 5);
INSERT INTO valoracions VALUES (1123, 24, '05/04/2008', 7);
INSERT INTO valoracions VALUES (1123, 87, '20/02/2009', 4);
INSERT INTO valoracions VALUES (1123, 91, '10/07/2008', 4);
INSERT INTO valoracions VALUES (1123, 20, '05/04/2006', 7);
INSERT INTO valoracions VALUES (1123, 49, '24/01/2004', 8);
INSERT INTO valoracions VALUES (1123, 114, '15/02/2010', 7);
INSERT INTO valoracions VALUES (1124, 5, '18/06/2001', 6);
INSERT INTO valoracions VALUES (1124, 94, '10/12/2006', 6);
INSERT INTO valoracions VALUES (1124, 42, '14/11/2006', 10);
INSERT INTO valoracions VALUES (1124, 88, '25/07/2008', 9);
INSERT INTO valoracions VALUES (1125, 18, '14/09/2010', 5);
INSERT INTO valoracions VALUES (1125, 103, '05/05/2007', 8);
INSERT INTO valoracions VALUES (1125, 47, '24/12/2008', 7);
INSERT INTO valoracions VALUES (1126, 39, '19/01/2009', 7);
INSERT INTO valoracions VALUES (1126, 46, '12/03/2008', 9);
INSERT INTO valoracions VALUES (1126, 25, '06/03/2008', 8);
INSERT INTO valoracions VALUES (1126, 57, '26/10/2004', 9);
INSERT INTO valoracions VALUES (1127, 32, '16/07/2002', 8);
INSERT INTO valoracions VALUES (1127, 38, '23/01/2003', 6);
INSERT INTO valoracions VALUES (1127, 4, '10/03/2007', 9);
INSERT INTO valoracions VALUES (1128, 32, '11/05/2004', 8);
INSERT INTO valoracions VALUES (1129, 26, '03/04/2003', 10);
INSERT INTO valoracions VALUES (1129, 32, '11/07/2003', 6);
INSERT INTO valoracions VALUES (1129, 4, '08/08/2004', 9);
INSERT INTO valoracions VALUES (1129, 110, '30/09/2002', 5);
INSERT INTO valoracions VALUES (1129, 85, '17/02/2009', 9);
INSERT INTO valoracions VALUES (1130, 60, '23/06/2001', 8);
INSERT INTO valoracions VALUES (1130, 80, '17/08/2006', 10);
INSERT INTO valoracions VALUES (1131, 56, '13/01/2005', 5);
INSERT INTO valoracions VALUES (1131, 101, '04/01/2003', 3);
INSERT INTO valoracions VALUES (1131, 93, '07/01/2002', 2);
INSERT INTO valoracions VALUES (1131, 36, '21/09/2006', 5);
INSERT INTO valoracions VALUES (1131, 80, '25/05/2005', 4);
INSERT INTO valoracions VALUES (1131, 1, '29/05/2004', 8);
INSERT INTO valoracions VALUES (1132, 57, '11/08/2008', 3);
INSERT INTO valoracions VALUES (1132, 35, '21/09/2005', 5);
INSERT INTO valoracions VALUES (1132, 104, '03/05/2009', 5);
INSERT INTO valoracions VALUES (1132, 50, '13/04/2003', 6);
INSERT INTO valoracions VALUES (1132, 14, '24/01/2003', 6);
INSERT INTO valoracions VALUES (1132, 59, '24/03/2006', 9);
INSERT INTO valoracions VALUES (1132, 102, '26/12/2006', 9);
INSERT INTO valoracions VALUES (1133, 61, '23/02/2007', 4);
INSERT INTO valoracions VALUES (1133, 49, '15/12/2005', 8);
INSERT INTO valoracions VALUES (1134, 11, '04/07/2007', 6);
INSERT INTO valoracions VALUES (1134, 85, '29/05/2004', 1);
INSERT INTO valoracions VALUES (1134, 35, '03/09/2004', 9);
INSERT INTO valoracions VALUES (1134, 53, '25/11/2003', 6);
INSERT INTO valoracions VALUES (1134, 3, '18/02/2006', 9);
INSERT INTO valoracions VALUES (1134, 105, '26/09/2010', 1);
INSERT INTO valoracions VALUES (1134, 35, '16/10/2001', 5);
INSERT INTO valoracions VALUES (1134, 96, '18/04/2007', 4);
INSERT INTO valoracions VALUES (1135, 21, '27/02/2007', 5);
INSERT INTO valoracions VALUES (1135, 12, '19/12/2006', 7);
INSERT INTO valoracions VALUES (1136, 12, '29/12/2006', 7);
INSERT INTO valoracions VALUES (1136, 1, '03/01/2004', 10);
INSERT INTO valoracions VALUES (1136, 99, '02/12/2003', 9);
INSERT INTO valoracions VALUES (1136, 62, '17/09/2002', 8);
INSERT INTO valoracions VALUES (1136, 45, '17/06/2009', 7);
INSERT INTO valoracions VALUES (1136, 19, '29/10/2004', 9);
INSERT INTO valoracions VALUES (1136, 15, '12/07/2009', 6);
INSERT INTO valoracions VALUES (1136, 43, '02/12/2002', 9);
INSERT INTO valoracions VALUES (1137, 86, '20/08/2008', 6);
INSERT INTO valoracions VALUES (1137, 67, '27/05/2001', 6);
INSERT INTO valoracions VALUES (1137, 84, '05/05/2001', 4);
INSERT INTO valoracions VALUES (1137, 88, '16/11/2004', 5);
INSERT INTO valoracions VALUES (1137, 79, '26/01/2007', 7);
INSERT INTO valoracions VALUES (1137, 95, '30/06/2009', 8);
INSERT INTO valoracions VALUES (1137, 90, '17/06/2003', 5);
INSERT INTO valoracions VALUES (1138, 39, '06/12/2004', 9);
INSERT INTO valoracions VALUES (1138, 9, '30/09/2010', 6);
INSERT INTO valoracions VALUES (1139, 23, '05/03/2002', 9);
INSERT INTO valoracions VALUES (1139, 112, '01/07/2010', 2);
INSERT INTO valoracions VALUES (1140, 66, '05/02/2003', 4);
INSERT INTO valoracions VALUES (1140, 6, '12/06/2002', 7);
INSERT INTO valoracions VALUES (1141, 52, '20/05/2002', 8);
INSERT INTO valoracions VALUES (1142, 14, '08/06/2003', 10);
INSERT INTO valoracions VALUES (1142, 31, '26/09/2003', 8);
INSERT INTO valoracions VALUES (1143, 30, '06/08/2010', 5);
INSERT INTO valoracions VALUES (1143, 110, '31/03/2004', 9);
INSERT INTO valoracions VALUES (1143, 43, '26/03/2004', 7);
INSERT INTO valoracions VALUES (1143, 32, '08/06/2005', 4);
INSERT INTO valoracions VALUES (1143, 76, '09/08/2005', 5);
INSERT INTO valoracions VALUES (1144, 15, '21/08/2009', 7);
INSERT INTO valoracions VALUES (1144, 73, '10/01/2010', 8);
INSERT INTO valoracions VALUES (1144, 81, '13/09/2003', 7);
INSERT INTO valoracions VALUES (1144, 65, '13/04/2008', 7);
INSERT INTO valoracions VALUES (1145, 105, '24/07/2007', 6);
INSERT INTO valoracions VALUES (1145, 75, '16/07/2003', 2);
INSERT INTO valoracions VALUES (1145, 28, '27/12/2009', 5);
INSERT INTO valoracions VALUES (1145, 15, '25/05/2009', 7);
INSERT INTO valoracions VALUES (1146, 67, '02/12/2007', 3);
INSERT INTO valoracions VALUES (1146, 29, '03/07/2008', 6);
INSERT INTO valoracions VALUES (1146, 81, '25/09/2009', 2);
INSERT INTO valoracions VALUES (1146, 10, '14/01/2003', 10);
INSERT INTO valoracions VALUES (1147, 80, '16/11/2009', 7);
INSERT INTO valoracions VALUES (1147, 67, '18/03/2002', 8);
INSERT INTO valoracions VALUES (1147, 98, '13/10/2010', 6);
INSERT INTO valoracions VALUES (1147, 107, '04/04/2009', 9);
INSERT INTO valoracions VALUES (1147, 98, '25/02/2005', 6);
INSERT INTO valoracions VALUES (1148, 19, '09/10/2005', 9);
INSERT INTO valoracions VALUES (1148, 62, '03/10/2002', 8);
INSERT INTO valoracions VALUES (1148, 111, '19/08/2010', 9);
INSERT INTO valoracions VALUES (1148, 97, '03/12/2008', 5);
INSERT INTO valoracions VALUES (1148, 107, '21/08/2005', 8);
INSERT INTO valoracions VALUES (1148, 88, '26/12/2009', 7);
INSERT INTO valoracions VALUES (1149, 5, '16/07/2008', 8);
INSERT INTO valoracions VALUES (1150, 81, '16/03/2008', 6);
INSERT INTO valoracions VALUES (1150, 113, '29/08/2006', 2);
INSERT INTO valoracions VALUES (1150, 81, '29/09/2005', 3);
INSERT INTO valoracions VALUES (1150, 11, '10/08/2009', 7);
INSERT INTO valoracions VALUES (1150, 105, '24/07/2008', 9);
INSERT INTO valoracions VALUES (1151, 82, '26/12/2005', 9);
INSERT INTO valoracions VALUES (1151, 40, '23/06/2004', 9);
INSERT INTO valoracions VALUES (1151, 39, '14/01/2009', 7);
INSERT INTO valoracions VALUES (1151, 21, '08/07/2010', 5);
INSERT INTO valoracions VALUES (1151, 88, '09/01/2007', 2);
INSERT INTO valoracions VALUES (1151, 31, '14/12/2001', 8);
INSERT INTO valoracions VALUES (1152, 18, '21/10/2010', 5);
INSERT INTO valoracions VALUES (1152, 68, '19/12/2002', 4);
INSERT INTO valoracions VALUES (1153, 95, '09/11/2009', 4);
INSERT INTO valoracions VALUES (1153, 116, '27/09/2010', 6);
INSERT INTO valoracions VALUES (1153, 45, '17/05/2008', 9);
INSERT INTO valoracions VALUES (1153, 47, '16/08/2009', 8);
INSERT INTO valoracions VALUES (1154, 12, '30/06/2001', 10);
INSERT INTO valoracions VALUES (1154, 84, '06/01/2002', 5);
INSERT INTO valoracions VALUES (1154, 43, '07/03/2006', 4);
INSERT INTO valoracions VALUES (1154, 113, '18/01/2010', 4);
INSERT INTO valoracions VALUES (1154, 114, '07/04/2002', 5);
INSERT INTO valoracions VALUES (1155, 13, '05/01/2002', 6);
INSERT INTO valoracions VALUES (1155, 90, '02/12/2002', 5);
INSERT INTO valoracions VALUES (1155, 48, '25/01/2009', 7);
INSERT INTO valoracions VALUES (1155, 12, '01/02/2007', 5);
INSERT INTO valoracions VALUES (1156, 30, '24/01/2003', 8);
INSERT INTO valoracions VALUES (1156, 59, '15/07/2004', 4);
INSERT INTO valoracions VALUES (1156, 55, '05/08/2010', 5);
INSERT INTO valoracions VALUES (1156, 33, '07/01/2003', 7);
INSERT INTO valoracions VALUES (1156, 23, '12/02/2006', 9);
INSERT INTO valoracions VALUES (1156, 18, '14/04/2009', 9);
INSERT INTO valoracions VALUES (1157, 92, '28/06/2001', 10);
INSERT INTO valoracions VALUES (1157, 26, '07/07/2003', 5);
INSERT INTO valoracions VALUES (1158, 116, '23/07/2008', 3);
INSERT INTO valoracions VALUES (1158, 103, '10/11/2005', 3);
INSERT INTO valoracions VALUES (1158, 23, '15/03/2004', 10);
INSERT INTO valoracions VALUES (1158, 48, '22/06/2009', 4);
INSERT INTO valoracions VALUES (1158, 52, '18/09/2007', 9);
INSERT INTO valoracions VALUES (1158, 87, '10/02/2005', 9);
INSERT INTO valoracions VALUES (1159, 112, '19/07/2008', 5);
INSERT INTO valoracions VALUES (1160, 61, '05/01/2005', 2);
INSERT INTO valoracions VALUES (1160, 51, '02/12/2006', 4);
INSERT INTO valoracions VALUES (1160, 29, '13/10/2003', 7);
INSERT INTO valoracions VALUES (1160, 116, '13/10/2007', 7);
INSERT INTO valoracions VALUES (1160, 80, '17/10/2003', 7);
INSERT INTO valoracions VALUES (1160, 7, '29/07/2009', 5);
INSERT INTO valoracions VALUES (1160, 102, '11/09/2002', 8);
INSERT INTO valoracions VALUES (1160, 91, '14/03/2003', 6);
INSERT INTO valoracions VALUES (1161, 71, '23/07/2004', 3);
INSERT INTO valoracions VALUES (1161, 72, '17/05/2002', 8);
INSERT INTO valoracions VALUES (1161, 50, '31/03/2003', 9);
INSERT INTO valoracions VALUES (1161, 26, '15/08/2009', 6);
INSERT INTO valoracions VALUES (1161, 91, '24/02/2006', 5);
INSERT INTO valoracions VALUES (1161, 94, '02/02/2005', 9);
INSERT INTO valoracions VALUES (1161, 112, '01/08/2004', 9);
INSERT INTO valoracions VALUES (1161, 96, '30/12/2006', 4);
INSERT INTO valoracions VALUES (1161, 106, '10/02/2009', 4);
INSERT INTO valoracions VALUES (1162, 10, '03/11/2002', 6);
INSERT INTO valoracions VALUES (1162, 103, '07/05/2005', 2);
INSERT INTO valoracions VALUES (1162, 29, '05/12/2009', 6);
INSERT INTO valoracions VALUES (1162, 23, '17/10/2005', 8);
INSERT INTO valoracions VALUES (1162, 46, '03/04/2006', 6);
INSERT INTO valoracions VALUES (1163, 11, '12/03/2009', 9);
INSERT INTO valoracions VALUES (1163, 72, '04/12/2007', 4);
INSERT INTO valoracions VALUES (1163, 43, '18/06/2001', 5);
INSERT INTO valoracions VALUES (1163, 73, '02/10/2006', 4);
INSERT INTO valoracions VALUES (1163, 113, '09/07/2008', 1);
INSERT INTO valoracions VALUES (1163, 25, '20/01/2005', 8);
INSERT INTO valoracions VALUES (1163, 53, '27/07/2002', 5);
INSERT INTO valoracions VALUES (1163, 28, '14/11/2008', 7);
INSERT INTO valoracions VALUES (1163, 66, '14/10/2007', 5);
INSERT INTO valoracions VALUES (1164, 103, '01/09/2009', 7);
INSERT INTO valoracions VALUES (1164, 92, '24/06/2003', 2);
INSERT INTO valoracions VALUES (1164, 69, '18/01/2005', 7);
INSERT INTO valoracions VALUES (1164, 107, '13/08/2010', 4);
INSERT INTO valoracions VALUES (1165, 80, '02/08/2010', 6);
INSERT INTO valoracions VALUES (1165, 53, '27/08/2001', 4);
INSERT INTO valoracions VALUES (1165, 14, '08/06/2006', 7);
INSERT INTO valoracions VALUES (1165, 107, '23/05/2006', 1);
INSERT INTO valoracions VALUES (1165, 99, '11/07/2005', 8);
INSERT INTO valoracions VALUES (1165, 16, '17/03/2009', 5);
INSERT INTO valoracions VALUES (1166, 59, '12/04/2006', 7);
INSERT INTO valoracions VALUES (1166, 100, '29/04/2003', 3);
INSERT INTO valoracions VALUES (1166, 111, '23/01/2010', 10);
INSERT INTO valoracions VALUES (1166, 82, '26/06/2010', 2);
INSERT INTO valoracions VALUES (1166, 76, '15/04/2004', 2);
INSERT INTO valoracions VALUES (1167, 109, '03/09/2005', 4);
INSERT INTO valoracions VALUES (1167, 90, '20/03/2008', 4);
INSERT INTO valoracions VALUES (1167, 85, '02/06/2005', 3);
INSERT INTO valoracions VALUES (1167, 29, '19/12/2006', 4);
INSERT INTO valoracions VALUES (1167, 103, '12/07/2010', 9);
INSERT INTO valoracions VALUES (1168, 54, '23/07/2003', 9);
INSERT INTO valoracions VALUES (1168, 62, '24/09/2008', 5);
INSERT INTO valoracions VALUES (1168, 6, '25/04/2010', 7);
INSERT INTO valoracions VALUES (1169, 19, '12/02/2003', 5);
INSERT INTO valoracions VALUES (1169, 21, '17/04/2009', 4);
INSERT INTO valoracions VALUES (1169, 11, '17/10/2008', 7);
INSERT INTO valoracions VALUES (1169, 72, '23/12/2002', 4);
INSERT INTO valoracions VALUES (1169, 75, '19/02/2007', 4);
INSERT INTO valoracions VALUES (1169, 46, '20/10/2008', 8);
INSERT INTO valoracions VALUES (1170, 9, '27/06/2007', 6);
INSERT INTO valoracions VALUES (1170, 49, '28/01/2008', 7);
INSERT INTO valoracions VALUES (1170, 100, '17/07/2001', 1);
INSERT INTO valoracions VALUES (1171, 114, '25/02/2009', 3);
INSERT INTO valoracions VALUES (1171, 13, '08/03/2005', 6);
INSERT INTO valoracions VALUES (1172, 87, '30/06/2009', 8);
INSERT INTO valoracions VALUES (1172, 75, '01/11/2003', 4);
INSERT INTO valoracions VALUES (1172, 58, '20/02/2005', 3);
INSERT INTO valoracions VALUES (1172, 85, '05/03/2006', 9);
INSERT INTO valoracions VALUES (1173, 98, '11/07/2004', 1);
INSERT INTO valoracions VALUES (1174, 19, '18/02/2009', 8);
INSERT INTO valoracions VALUES (1174, 48, '06/09/2008', 7);
INSERT INTO valoracions VALUES (1174, 51, '20/09/2008', 7);
INSERT INTO valoracions VALUES (1174, 72, '29/06/2007', 5);
INSERT INTO valoracions VALUES (1174, 19, '10/07/2004', 5);
INSERT INTO valoracions VALUES (1175, 38, '26/12/2007', 9);
INSERT INTO valoracions VALUES (1175, 33, '16/04/2001', 4);
INSERT INTO valoracions VALUES (1175, 67, '20/12/2002', 5);
INSERT INTO valoracions VALUES (1177, 30, '31/07/2010', 9);
INSERT INTO valoracions VALUES (1177, 79, '22/03/2009', 9);
INSERT INTO valoracions VALUES (1177, 39, '12/07/2010', 7);
INSERT INTO valoracions VALUES (1177, 1, '18/07/2002', 8);
INSERT INTO valoracions VALUES (1177, 56, '09/09/2004', 3);
INSERT INTO valoracions VALUES (1177, 88, '02/08/2005', 7);
INSERT INTO valoracions VALUES (1177, 70, '10/03/2006', 8);
INSERT INTO valoracions VALUES (1178, 7, '23/05/2008', 8);
INSERT INTO valoracions VALUES (1178, 57, '14/11/2007', 6);
INSERT INTO valoracions VALUES (1178, 48, '12/05/2008', 9);
INSERT INTO valoracions VALUES (1178, 53, '09/12/2009', 8);
INSERT INTO valoracions VALUES (1178, 4, '21/11/2007', 10);
INSERT INTO valoracions VALUES (1179, 114, '16/10/2008', 10);
INSERT INTO valoracions VALUES (1179, 85, '08/10/2004', 1);
INSERT INTO valoracions VALUES (1179, 51, '31/12/2006', 9);
INSERT INTO valoracions VALUES (1179, 84, '05/02/2010', 5);
INSERT INTO valoracions VALUES (1179, 69, '02/06/2002', 8);
INSERT INTO valoracions VALUES (1179, 73, '02/12/2005', 7);
INSERT INTO valoracions VALUES (1179, 63, '20/09/2002', 9);
INSERT INTO valoracions VALUES (1180, 101, '08/03/2006', 3);
INSERT INTO valoracions VALUES (1180, 36, '24/03/2010', 9);
INSERT INTO valoracions VALUES (1180, 41, '21/12/2004', 7);
INSERT INTO valoracions VALUES (1181, 51, '31/03/2007', 10);
INSERT INTO valoracions VALUES (1181, 88, '13/04/2009', 5);
INSERT INTO valoracions VALUES (1182, 108, '07/04/2007', 3);
INSERT INTO valoracions VALUES (1183, 15, '18/05/2009', 9);
INSERT INTO valoracions VALUES (1183, 31, '01/07/2010', 5);
INSERT INTO valoracions VALUES (1183, 46, '01/04/2009', 10);
INSERT INTO valoracions VALUES (1184, 65, '13/02/2006', 8);
INSERT INTO valoracions VALUES (1184, 19, '05/12/2006', 6);
INSERT INTO valoracions VALUES (1184, 43, '18/12/2003', 6);
INSERT INTO valoracions VALUES (1184, 26, '07/02/2010', 7);
INSERT INTO valoracions VALUES (1185, 85, '25/09/2007', 7);
INSERT INTO valoracions VALUES (1185, 105, '23/04/2008', 9);
INSERT INTO valoracions VALUES (1185, 98, '28/12/2009', 10);
INSERT INTO valoracions VALUES (1185, 35, '20/09/2002', 5);
INSERT INTO valoracions VALUES (1185, 22, '29/11/2007', 5);
INSERT INTO valoracions VALUES (1186, 69, '02/03/2009', 10);
INSERT INTO valoracions VALUES (1186, 89, '17/06/2001', 7);
INSERT INTO valoracions VALUES (1186, 19, '25/04/2002', 10);
INSERT INTO valoracions VALUES (1187, 4, '30/03/2008', 5);
INSERT INTO valoracions VALUES (1187, 27, '29/08/2008', 8);
INSERT INTO valoracions VALUES (1187, 107, '07/09/2004', 2);
INSERT INTO valoracions VALUES (1187, 9, '24/03/2004', 8);
INSERT INTO valoracions VALUES (1187, 93, '09/02/2007', 4);
INSERT INTO valoracions VALUES (1188, 115, '10/12/2006', 8);
INSERT INTO valoracions VALUES (1188, 57, '08/08/2008', 4);
INSERT INTO valoracions VALUES (1188, 24, '10/06/2010', 8);
INSERT INTO valoracions VALUES (1188, 60, '20/09/2003', 8);
INSERT INTO valoracions VALUES (1189, 7, '24/09/2004', 6);
INSERT INTO valoracions VALUES (1189, 85, '28/05/2008', 2);
INSERT INTO valoracions VALUES (1189, 22, '12/07/2009', 7);
INSERT INTO valoracions VALUES (1189, 108, '28/05/2003', 7);
INSERT INTO valoracions VALUES (1189, 1, '09/05/2009', 6);
INSERT INTO valoracions VALUES (1189, 81, '07/09/2003', 10);
INSERT INTO valoracions VALUES (1189, 100, '03/09/2007', 8);
INSERT INTO valoracions VALUES (1189, 73, '10/02/2003', 9);
INSERT INTO valoracions VALUES (1190, 111, '21/09/2003', 2);
INSERT INTO valoracions VALUES (1190, 44, '27/12/2008', 6);
INSERT INTO valoracions VALUES (1190, 85, '29/06/2010', 5);
INSERT INTO valoracions VALUES (1191, 77, '26/12/2007', 10);
INSERT INTO valoracions VALUES (1191, 88, '20/02/2006', 7);
INSERT INTO valoracions VALUES (1191, 33, '31/03/2005', 6);
INSERT INTO valoracions VALUES (1191, 61, '13/02/2004', 8);
INSERT INTO valoracions VALUES (1191, 63, '27/01/2009', 6);
INSERT INTO valoracions VALUES (1192, 53, '25/08/2006', 9);
INSERT INTO valoracions VALUES (1192, 44, '22/09/2005', 7);
INSERT INTO valoracions VALUES (1192, 57, '02/06/2005', 9);
INSERT INTO valoracions VALUES (1192, 8, '12/02/2008', 5);
INSERT INTO valoracions VALUES (1192, 62, '18/03/2003', 8);
INSERT INTO valoracions VALUES (1192, 114, '20/01/2006', 6);
INSERT INTO valoracions VALUES (1192, 68, '26/05/2001', 4);
INSERT INTO valoracions VALUES (1194, 13, '15/07/2008', 9);
INSERT INTO valoracions VALUES (1194, 109, '30/01/2004', 3);
INSERT INTO valoracions VALUES (1194, 98, '21/11/2002', 8);
INSERT INTO valoracions VALUES (1194, 28, '18/07/2005', 8);
INSERT INTO valoracions VALUES (1194, 48, '29/08/2002', 7);
INSERT INTO valoracions VALUES (1194, 96, '16/04/2002', 5);
INSERT INTO valoracions VALUES (1194, 60, '21/10/2002', 2);
INSERT INTO valoracions VALUES (1194, 98, '21/04/2009', 8);
INSERT INTO valoracions VALUES (1195, 54, '14/11/2003', 8);
INSERT INTO valoracions VALUES (1195, 8, '20/11/2005', 9);
INSERT INTO valoracions VALUES (1195, 29, '23/05/2005', 6);
INSERT INTO valoracions VALUES (1195, 52, '29/04/2005', 9);
INSERT INTO valoracions VALUES (1195, 9, '02/04/2008', 8);
INSERT INTO valoracions VALUES (1195, 26, '29/11/2004', 8);
INSERT INTO valoracions VALUES (1195, 2, '07/10/2008', 10);
INSERT INTO valoracions VALUES (1196, 2, '22/09/2004', 8);
INSERT INTO valoracions VALUES (1196, 39, '17/06/2010', 9);
INSERT INTO valoracions VALUES (1196, 78, '03/09/2004', 7);
INSERT INTO valoracions VALUES (1197, 48, '13/08/2004', 8);
INSERT INTO valoracions VALUES (1197, 12, '03/10/2004', 9);
INSERT INTO valoracions VALUES (1197, 70, '12/09/2008', 8);
INSERT INTO valoracions VALUES (1197, 8, '03/10/2006', 7);
INSERT INTO valoracions VALUES (1197, 69, '29/06/2003', 4);
INSERT INTO valoracions VALUES (1197, 37, '21/04/2004', 5);
INSERT INTO valoracions VALUES (1197, 70, '07/04/2003', 6);
INSERT INTO valoracions VALUES (1197, 71, '05/03/2008', 6);
INSERT INTO valoracions VALUES (1198, 87, '15/11/2009', 4);
INSERT INTO valoracions VALUES (1198, 80, '29/02/2008', 3);
INSERT INTO valoracions VALUES (1198, 23, '13/05/2009', 6);
INSERT INTO valoracions VALUES (1199, 45, '01/04/2010', 5);
INSERT INTO valoracions VALUES (1199, 72, '10/03/2004', 10);
INSERT INTO valoracions VALUES (1199, 102, '08/10/2001', 3);
INSERT INTO valoracions VALUES (1200, 91, '16/04/2009', 4);
INSERT INTO valoracions VALUES (1200, 55, '28/11/2005', 9);
INSERT INTO valoracions VALUES (1200, 32, '05/05/2006', 7);
INSERT INTO valoracions VALUES (1200, 105, '03/02/2004', 7);
INSERT INTO valoracions VALUES (1200, 32, '26/05/2005', 4);
INSERT INTO valoracions VALUES (1200, 58, '07/01/2008', 5);
INSERT INTO valoracions VALUES (1201, 6, '21/02/2005', 8);
INSERT INTO valoracions VALUES (1201, 54, '01/12/2004', 9);
INSERT INTO valoracions VALUES (1201, 41, '03/12/2006', 8);
INSERT INTO valoracions VALUES (1201, 43, '29/05/2003', 9);
INSERT INTO valoracions VALUES (1201, 95, '03/08/2005', 9);
INSERT INTO valoracions VALUES (1202, 11, '07/05/2010', 8);
INSERT INTO valoracions VALUES (1202, 54, '03/04/2004', 6);
INSERT INTO valoracions VALUES (1202, 91, '16/09/2002', 2);
INSERT INTO valoracions VALUES (1203, 102, '17/08/2005', 3);
INSERT INTO valoracions VALUES (1204, 114, '08/07/2005', 1);
INSERT INTO valoracions VALUES (1204, 67, '26/08/2006', 5);
INSERT INTO valoracions VALUES (1204, 97, '07/05/2007', 3);
INSERT INTO valoracions VALUES (1204, 89, '04/10/2009', 2);
INSERT INTO valoracions VALUES (1204, 51, '23/07/2007', 6);
INSERT INTO valoracions VALUES (1204, 82, '30/06/2004', 7);
INSERT INTO valoracions VALUES (1204, 42, '05/12/2007', 4);
INSERT INTO valoracions VALUES (1205, 99, '11/12/2005', 4);
INSERT INTO valoracions VALUES (1205, 17, '13/10/2009', 7);
INSERT INTO valoracions VALUES (1205, 59, '21/03/2003', 6);
INSERT INTO valoracions VALUES (1205, 85, '16/01/2006', 9);
INSERT INTO valoracions VALUES (1205, 31, '09/03/2004', 6);
INSERT INTO valoracions VALUES (1206, 85, '03/12/2003', 3);
INSERT INTO valoracions VALUES (1206, 56, '30/04/2005', 8);
INSERT INTO valoracions VALUES (1207, 65, '21/07/2004', 5);
INSERT INTO valoracions VALUES (1207, 64, '25/04/2008', 6);
INSERT INTO valoracions VALUES (1207, 107, '04/07/2004', 9);
INSERT INTO valoracions VALUES (1208, 34, '15/12/2001', 4);
INSERT INTO valoracions VALUES (1208, 38, '15/04/2003', 5);
INSERT INTO valoracions VALUES (1208, 76, '03/01/2002', 8);
INSERT INTO valoracions VALUES (1208, 30, '24/01/2009', 9);
INSERT INTO valoracions VALUES (1208, 34, '17/07/2003', 5);
INSERT INTO valoracions VALUES (1208, 6, '13/02/2002', 7);
INSERT INTO valoracions VALUES (1209, 79, '03/04/2009', 5);
INSERT INTO valoracions VALUES (1209, 108, '14/12/2001', 2);
INSERT INTO valoracions VALUES (1210, 98, '29/08/2008', 6);
INSERT INTO valoracions VALUES (1210, 26, '28/08/2001', 9);
INSERT INTO valoracions VALUES (1210, 12, '13/07/2004', 5);
INSERT INTO valoracions VALUES (1211, 16, '17/04/2006', 7);
INSERT INTO valoracions VALUES (1211, 90, '26/05/2007', 1);
INSERT INTO valoracions VALUES (1211, 29, '23/05/2001', 4);
INSERT INTO valoracions VALUES (1211, 50, '26/12/2002', 8);
INSERT INTO valoracions VALUES (1211, 29, '20/02/2010', 4);
INSERT INTO valoracions VALUES (1211, 90, '13/08/2004', 8);
INSERT INTO valoracions VALUES (1212, 60, '08/03/2007', 9);
INSERT INTO valoracions VALUES (1212, 14, '12/12/2004', 6);
INSERT INTO valoracions VALUES (1212, 54, '10/02/2009', 6);
INSERT INTO valoracions VALUES (1212, 68, '03/09/2007', 8);
INSERT INTO valoracions VALUES (1212, 15, '30/12/2005', 5);
INSERT INTO valoracions VALUES (1212, 59, '25/03/2007', 6);
INSERT INTO valoracions VALUES (1212, 47, '16/05/2001', 3);
INSERT INTO valoracions VALUES (1212, 76, '07/04/2003', 5);
INSERT INTO valoracions VALUES (1213, 24, '26/09/2004', 8);
INSERT INTO valoracions VALUES (1213, 72, '26/04/2007', 6);
INSERT INTO valoracions VALUES (1213, 41, '02/04/2002', 5);
INSERT INTO valoracions VALUES (1213, 78, '19/03/2009', 9);
INSERT INTO valoracions VALUES (1213, 32, '10/10/2008', 5);
INSERT INTO valoracions VALUES (1213, 93, '04/01/2008', 5);
INSERT INTO valoracions VALUES (1214, 65, '04/10/2006', 7);
INSERT INTO valoracions VALUES (1214, 79, '23/09/2006', 8);
INSERT INTO valoracions VALUES (1214, 114, '31/10/2001', 7);
INSERT INTO valoracions VALUES (1215, 111, '28/09/2004', 3);
INSERT INTO valoracions VALUES (1215, 72, '06/11/2004', 4);
INSERT INTO valoracions VALUES (1215, 93, '07/02/2006', 6);
INSERT INTO valoracions VALUES (1215, 38, '22/04/2006', 10);
INSERT INTO valoracions VALUES (1215, 54, '26/05/2009', 3);
INSERT INTO valoracions VALUES (1215, 77, '19/09/2001', 9);
INSERT INTO valoracions VALUES (1215, 115, '11/04/2007', 10);
INSERT INTO valoracions VALUES (1216, 97, '10/03/2008', 9);
INSERT INTO valoracions VALUES (1216, 5, '17/04/2009', 7);
INSERT INTO valoracions VALUES (1216, 96, '02/02/2009', 6);
INSERT INTO valoracions VALUES (1216, 23, '30/01/2003', 6);
INSERT INTO valoracions VALUES (1216, 62, '09/05/2010', 5);
INSERT INTO valoracions VALUES (1217, 46, '25/08/2009', 5);
INSERT INTO valoracions VALUES (1218, 65, '10/04/2006', 4);
INSERT INTO valoracions VALUES (1218, 104, '08/02/2009', 3);
INSERT INTO valoracions VALUES (1218, 37, '02/06/2002', 5);
INSERT INTO valoracions VALUES (1219, 31, '22/05/2010', 7);
INSERT INTO valoracions VALUES (1219, 46, '04/05/2003', 8);
INSERT INTO valoracions VALUES (1220, 101, '20/06/2007', 3);
INSERT INTO valoracions VALUES (1220, 62, '02/02/2009', 6);
INSERT INTO valoracions VALUES (1220, 100, '10/03/2002', 1);
INSERT INTO valoracions VALUES (1220, 47, '15/01/2005', 9);
INSERT INTO valoracions VALUES (1220, 35, '01/04/2006', 5);
INSERT INTO valoracions VALUES (1220, 114, '10/08/2001', 1);
INSERT INTO valoracions VALUES (1220, 20, '18/10/2004', 7);
INSERT INTO valoracions VALUES (1221, 18, '04/12/2007', 5);
INSERT INTO valoracions VALUES (1221, 66, '26/02/2003', 5);
INSERT INTO valoracions VALUES (1221, 72, '25/04/2008', 9);
INSERT INTO valoracions VALUES (1221, 63, '09/08/2008', 8);
INSERT INTO valoracions VALUES (1221, 11, '30/09/2007', 8);
INSERT INTO valoracions VALUES (1221, 75, '25/05/2006', 5);
INSERT INTO valoracions VALUES (1221, 108, '12/12/2005', 1);
INSERT INTO valoracions VALUES (1222, 79, '03/10/2003', 8);
INSERT INTO valoracions VALUES (1222, 41, '04/11/2001', 5);
INSERT INTO valoracions VALUES (1222, 94, '31/07/2002', 5);
INSERT INTO valoracions VALUES (1223, 73, '05/05/2007', 8);
INSERT INTO valoracions VALUES (1223, 69, '19/05/2010', 8);
INSERT INTO valoracions VALUES (1223, 49, '15/06/2006', 6);
INSERT INTO valoracions VALUES (1224, 32, '02/10/2006', 6);
INSERT INTO valoracions VALUES (1224, 101, '07/02/2008', 6);
INSERT INTO valoracions VALUES (1224, 95, '09/06/2006', 8);
INSERT INTO valoracions VALUES (1225, 50, '21/07/2006', 4);
INSERT INTO valoracions VALUES (1225, 20, '22/07/2003', 5);
INSERT INTO valoracions VALUES (1225, 34, '23/09/2010', 7);
INSERT INTO valoracions VALUES (1225, 45, '30/03/2004', 6);
INSERT INTO valoracions VALUES (1225, 104, '21/12/2001', 4);
INSERT INTO valoracions VALUES (1225, 41, '28/10/2006', 6);
INSERT INTO valoracions VALUES (1226, 88, '05/02/2002', 5);
INSERT INTO valoracions VALUES (1226, 78, '26/07/2010', 2);
INSERT INTO valoracions VALUES (1226, 48, '22/11/2008', 4);
INSERT INTO valoracions VALUES (1226, 3, '26/03/2006', 5);
INSERT INTO valoracions VALUES (1226, 84, '29/01/2003', 3);
INSERT INTO valoracions VALUES (1226, 73, '26/04/2005', 4);
INSERT INTO valoracions VALUES (1226, 64, '22/10/2010', 3);
INSERT INTO valoracions VALUES (1226, 53, '01/09/2001', 9);
INSERT INTO valoracions VALUES (1226, 68, '20/11/2006', 6);
INSERT INTO valoracions VALUES (1226, 24, '14/02/2005', 9);
INSERT INTO valoracions VALUES (1227, 50, '19/04/2008', 4);
INSERT INTO valoracions VALUES (1227, 53, '24/03/2006', 6);
INSERT INTO valoracions VALUES (1227, 101, '20/10/2009', 6);
INSERT INTO valoracions VALUES (1227, 5, '10/01/2007', 9);
INSERT INTO valoracions VALUES (1227, 46, '20/02/2008', 5);
INSERT INTO valoracions VALUES (1227, 39, '02/10/2010', 9);
INSERT INTO valoracions VALUES (1227, 64, '06/07/2009', 9);
INSERT INTO valoracions VALUES (1227, 16, '09/04/2001', 8);
INSERT INTO valoracions VALUES (1228, 63, '16/07/2004', 8);
INSERT INTO valoracions VALUES (1228, 28, '18/04/2006', 6);
INSERT INTO valoracions VALUES (1228, 27, '16/05/2005', 9);
INSERT INTO valoracions VALUES (1228, 59, '08/01/2006', 6);
INSERT INTO valoracions VALUES (1229, 74, '17/06/2008', 5);
INSERT INTO valoracions VALUES (1229, 45, '07/07/2004', 7);
INSERT INTO valoracions VALUES (1229, 46, '10/05/2006', 7);
INSERT INTO valoracions VALUES (1229, 56, '21/08/2009', 4);
INSERT INTO valoracions VALUES (1230, 86, '26/06/2005', 6);
INSERT INTO valoracions VALUES (1230, 50, '07/05/2007', 3);
INSERT INTO valoracions VALUES (1230, 17, '05/06/2002', 9);
INSERT INTO valoracions VALUES (1230, 45, '22/01/2009', 9);
INSERT INTO valoracions VALUES (1231, 43, '18/07/2006', 6);
INSERT INTO valoracions VALUES (1231, 64, '01/01/2010', 9);
INSERT INTO valoracions VALUES (1231, 36, '24/10/2008', 5);
INSERT INTO valoracions VALUES (1233, 63, '04/06/2009', 2);
INSERT INTO valoracions VALUES (1233, 56, '28/01/2008', 7);
INSERT INTO valoracions VALUES (1233, 102, '28/08/2010', 9);
INSERT INTO valoracions VALUES (1233, 31, '15/03/2010', 6);
INSERT INTO valoracions VALUES (1233, 39, '12/11/2009', 6);
INSERT INTO valoracions VALUES (1234, 112, '22/06/2007', 2);
INSERT INTO valoracions VALUES (1234, 112, '01/08/2006', 4);
INSERT INTO valoracions VALUES (1234, 53, '21/09/2003', 4);
INSERT INTO valoracions VALUES (1234, 79, '14/06/2004', 7);
INSERT INTO valoracions VALUES (1235, 109, '14/04/2001', 3);
INSERT INTO valoracions VALUES (1235, 47, '16/06/2004', 4);
INSERT INTO valoracions VALUES (1235, 108, '16/02/2008', 9);
INSERT INTO valoracions VALUES (1235, 30, '20/02/2002', 5);
INSERT INTO valoracions VALUES (1235, 100, '15/04/2009', 9);
INSERT INTO valoracions VALUES (1236, 105, '14/10/2009', 8);
INSERT INTO valoracions VALUES (1236, 25, '24/10/2004', 9);
INSERT INTO valoracions VALUES (1237, 25, '24/08/2009', 4);
INSERT INTO valoracions VALUES (1237, 44, '02/06/2002', 7);
INSERT INTO valoracions VALUES (1238, 38, '20/04/2006', 8);
INSERT INTO valoracions VALUES (1238, 55, '04/09/2005', 6);
INSERT INTO valoracions VALUES (1238, 48, '11/07/2010', 5);
INSERT INTO valoracions VALUES (1238, 49, '09/10/2009', 6);
INSERT INTO valoracions VALUES (1239, 101, '30/12/2001', 7);
INSERT INTO valoracions VALUES (1239, 26, '16/06/2005', 9);
INSERT INTO valoracions VALUES (1240, 6, '10/09/2010', 9);
INSERT INTO valoracions VALUES (1240, 39, '25/08/2005', 10);
INSERT INTO valoracions VALUES (1240, 71, '22/06/2002', 8);
INSERT INTO valoracions VALUES (1241, 58, '25/11/2005', 3);
INSERT INTO valoracions VALUES (1241, 55, '31/12/2001', 8);
INSERT INTO valoracions VALUES (1241, 80, '19/06/2003', 4);
INSERT INTO valoracions VALUES (1241, 55, '28/03/2010', 4);
INSERT INTO valoracions VALUES (1241, 103, '18/04/2008', 2);
INSERT INTO valoracions VALUES (1241, 116, '23/10/2010', 3);
INSERT INTO valoracions VALUES (1242, 36, '15/01/2008', 6);
INSERT INTO valoracions VALUES (1242, 58, '30/10/2005', 8);
INSERT INTO valoracions VALUES (1242, 43, '24/06/2006', 3);
INSERT INTO valoracions VALUES (1242, 65, '29/06/2005', 3);
INSERT INTO valoracions VALUES (1242, 99, '17/10/2001', 6);
INSERT INTO valoracions VALUES (1242, 18, '12/01/2008', 4);
INSERT INTO valoracions VALUES (1243, 55, '07/03/2005', 7);
INSERT INTO valoracions VALUES (1243, 110, '11/09/2008', 4);
INSERT INTO valoracions VALUES (1243, 31, '12/05/2003', 6);
INSERT INTO valoracions VALUES (1244, 31, '27/01/2008', 7);
INSERT INTO valoracions VALUES (1244, 90, '05/08/2009', 8);
INSERT INTO valoracions VALUES (1244, 94, '07/09/2003', 7);
INSERT INTO valoracions VALUES (1244, 92, '21/06/2009', 7);
INSERT INTO valoracions VALUES (1244, 108, '13/04/2009', 5);
INSERT INTO valoracions VALUES (1244, 44, '25/05/2003', 9);
INSERT INTO valoracions VALUES (1245, 65, '26/12/2004', 4);
INSERT INTO valoracions VALUES (1245, 70, '07/04/2010', 8);
INSERT INTO valoracions VALUES (1245, 2, '12/07/2005', 6);
INSERT INTO valoracions VALUES (1246, 67, '29/07/2002', 3);
INSERT INTO valoracions VALUES (1246, 99, '28/11/2005', 5);
INSERT INTO valoracions VALUES (1246, 36, '20/03/2007', 9);
INSERT INTO valoracions VALUES (1246, 54, '25/06/2004', 8);
INSERT INTO valoracions VALUES (1246, 32, '31/03/2003', 9);
INSERT INTO valoracions VALUES (1246, 87, '20/05/2001', 9);
INSERT INTO valoracions VALUES (1247, 82, '21/04/2005', 7);
INSERT INTO valoracions VALUES (1247, 52, '27/04/2009', 9);
INSERT INTO valoracions VALUES (1247, 62, '21/03/2007', 4);
INSERT INTO valoracions VALUES (1247, 52, '03/04/2010', 3);
INSERT INTO valoracions VALUES (1248, 102, '09/04/2008', 10);
INSERT INTO valoracions VALUES (1248, 100, '31/05/2008', 3);
INSERT INTO valoracions VALUES (1248, 48, '15/02/2006', 5);
INSERT INTO valoracions VALUES (1248, 89, '07/08/2001', 1);
INSERT INTO valoracions VALUES (1248, 100, '14/12/2005', 5);
INSERT INTO valoracions VALUES (1249, 18, '11/12/2006', 8);
INSERT INTO valoracions VALUES (1249, 100, '27/12/2006', 9);
INSERT INTO valoracions VALUES (1250, 97, '15/08/2010', 3);
INSERT INTO valoracions VALUES (1251, 34, '08/07/2006', 10);
INSERT INTO valoracions VALUES (1251, 50, '15/04/2010', 9);
INSERT INTO valoracions VALUES (1251, 7, '30/10/2002', 6);
INSERT INTO valoracions VALUES (1251, 72, '16/08/2005', 4);
INSERT INTO valoracions VALUES (1251, 112, '01/07/2001', 0);
INSERT INTO valoracions VALUES (1252, 95, '20/05/2010', 5);
INSERT INTO valoracions VALUES (1252, 82, '21/01/2004', 6);
INSERT INTO valoracions VALUES (1252, 10, '09/07/2003', 8);
INSERT INTO valoracions VALUES (1252, 17, '27/02/2010', 5);
INSERT INTO valoracions VALUES (1252, 2, '04/04/2005', 8);
INSERT INTO valoracions VALUES (1252, 8, '13/09/2003', 5);
INSERT INTO valoracions VALUES (1253, 36, '13/03/2007', 6);
INSERT INTO valoracions VALUES (1253, 86, '26/07/2009', 2);
INSERT INTO valoracions VALUES (1253, 116, '02/11/2005', 6);
INSERT INTO valoracions VALUES (1253, 100, '13/01/2006', 8);
INSERT INTO valoracions VALUES (1254, 60, '04/08/2005', 6);
INSERT INTO valoracions VALUES (1254, 42, '13/01/2008', 9);
INSERT INTO valoracions VALUES (1254, 59, '05/04/2006', 4);
INSERT INTO valoracions VALUES (1255, 16, '20/03/2003', 5);
INSERT INTO valoracions VALUES (1256, 7, '03/02/2006', 7);
INSERT INTO valoracions VALUES (1256, 76, '21/08/2004', 8);
INSERT INTO valoracions VALUES (1256, 26, '27/07/2003', 9);
INSERT INTO valoracions VALUES (1256, 110, '18/08/2002', 5);
INSERT INTO valoracions VALUES (1256, 82, '28/08/2010', 5);
INSERT INTO valoracions VALUES (1256, 72, '07/07/2009', 8);
INSERT INTO valoracions VALUES (1256, 51, '27/11/2005', 8);
INSERT INTO valoracions VALUES (1256, 53, '04/12/2007', 5);
INSERT INTO valoracions VALUES (1256, 94, '30/12/2008', 6);
INSERT INTO valoracions VALUES (1257, 61, '03/03/2007', 9);
INSERT INTO valoracions VALUES (1258, 66, '09/09/2003', 4);
INSERT INTO valoracions VALUES (1258, 38, '21/12/2007', 5);
INSERT INTO valoracions VALUES (1258, 113, '17/02/2010', 8);
INSERT INTO valoracions VALUES (1258, 82, '11/02/2006', 7);
INSERT INTO valoracions VALUES (1258, 79, '03/09/2005', 7);
INSERT INTO valoracions VALUES (1259, 72, '19/04/2009', 8);
INSERT INTO valoracions VALUES (1259, 106, '20/03/2003', 8);
INSERT INTO valoracions VALUES (1259, 69, '12/09/2005', 3);
INSERT INTO valoracions VALUES (1260, 49, '10/09/2005', 7);
INSERT INTO valoracions VALUES (1260, 71, '15/05/2009', 6);
INSERT INTO valoracions VALUES (1260, 71, '30/05/2009', 9);
INSERT INTO valoracions VALUES (1260, 71, '19/01/2002', 8);
INSERT INTO valoracions VALUES (1260, 94, '09/10/2010', 1);
INSERT INTO valoracions VALUES (1260, 69, '29/01/2005', 8);
INSERT INTO valoracions VALUES (1260, 5, '06/10/2002', 5);
INSERT INTO valoracions VALUES (1261, 37, '25/12/2009', 4);
INSERT INTO valoracions VALUES (1261, 75, '31/08/2004', 8);
INSERT INTO valoracions VALUES (1262, 8, '23/11/2004', 6);
INSERT INTO valoracions VALUES (1263, 103, '16/04/2003', 2);
INSERT INTO valoracions VALUES (1263, 61, '05/02/2003', 8);
INSERT INTO valoracions VALUES (1263, 15, '05/08/2002', 5);
INSERT INTO valoracions VALUES (1263, 78, '10/08/2006', 10);
INSERT INTO valoracions VALUES (1264, 2, '30/01/2005', 6);
INSERT INTO valoracions VALUES (1264, 22, '05/01/2005', 5);
INSERT INTO valoracions VALUES (1264, 44, '18/07/2009', 9);
INSERT INTO valoracions VALUES (1264, 61, '15/03/2004', 8);
INSERT INTO valoracions VALUES (1264, 90, '23/11/2006', 3);
INSERT INTO valoracions VALUES (1264, 3, '04/01/2008', 7);
INSERT INTO valoracions VALUES (1264, 51, '22/09/2003', 10);
INSERT INTO valoracions VALUES (1265, 96, '04/08/2010', 8);
INSERT INTO valoracions VALUES (1265, 84, '21/12/2007', 1);
INSERT INTO valoracions VALUES (1266, 88, '04/04/2009', 8);
INSERT INTO valoracions VALUES (1266, 53, '23/09/2002', 5);
INSERT INTO valoracions VALUES (1266, 111, '11/11/2009', 7);
INSERT INTO valoracions VALUES (1266, 11, '15/03/2004', 6);
INSERT INTO valoracions VALUES (1266, 2, '07/10/2008', 6);
INSERT INTO valoracions VALUES (1267, 94, '18/12/2002', 3);
INSERT INTO valoracions VALUES (1267, 41, '20/05/2002', 9);
INSERT INTO valoracions VALUES (1267, 101, '05/06/2005', 9);
INSERT INTO valoracions VALUES (1268, 74, '13/10/2003', 5);
INSERT INTO valoracions VALUES (1268, 7, '10/04/2005', 9);
INSERT INTO valoracions VALUES (1268, 67, '08/08/2010', 8);
INSERT INTO valoracions VALUES (1269, 48, '15/12/2003', 5);
INSERT INTO valoracions VALUES (1269, 34, '27/05/2008', 7);
INSERT INTO valoracions VALUES (1270, 104, '23/07/2004', 6);
INSERT INTO valoracions VALUES (1270, 52, '16/12/2006', 8);
INSERT INTO valoracions VALUES (1270, 32, '19/03/2002', 5);
INSERT INTO valoracions VALUES (1270, 27, '11/03/2010', 9);
INSERT INTO valoracions VALUES (1271, 50, '23/02/2008', 8);
INSERT INTO valoracions VALUES (1271, 113, '25/09/2006', 2);
INSERT INTO valoracions VALUES (1271, 63, '10/06/2008', 5);
INSERT INTO valoracions VALUES (1272, 62, '04/06/2008', 4);
INSERT INTO valoracions VALUES (1272, 88, '26/03/2003', 9);
INSERT INTO valoracions VALUES (1272, 42, '18/06/2002', 5);
INSERT INTO valoracions VALUES (1272, 69, '17/08/2009', 7);
INSERT INTO valoracions VALUES (1272, 72, '06/03/2010', 10);
INSERT INTO valoracions VALUES (1272, 28, '17/05/2002', 5);
INSERT INTO valoracions VALUES (1272, 101, '28/08/2005', 7);
INSERT INTO valoracions VALUES (1272, 15, '25/06/2008', 6);
INSERT INTO valoracions VALUES (1272, 114, '26/12/2009', 2);
INSERT INTO valoracions VALUES (1272, 68, '20/12/2003', 8);
INSERT INTO valoracions VALUES (1273, 19, '17/05/2008', 5);
INSERT INTO valoracions VALUES (1273, 14, '01/01/2004', 8);
INSERT INTO valoracions VALUES (1273, 50, '16/12/2009', 5);
INSERT INTO valoracions VALUES (1273, 24, '02/05/2007', 5);
INSERT INTO valoracions VALUES (1273, 116, '11/05/2010', 3);
INSERT INTO valoracions VALUES (1273, 14, '14/09/2006', 9);
INSERT INTO valoracions VALUES (1273, 59, '30/06/2009', 3);
INSERT INTO valoracions VALUES (1273, 59, '09/06/2006', 5);
INSERT INTO valoracions VALUES (1274, 55, '01/09/2006', 9);
INSERT INTO valoracions VALUES (1274, 94, '05/09/2003', 10);
INSERT INTO valoracions VALUES (1274, 20, '11/12/2007', 10);
INSERT INTO valoracions VALUES (1274, 101, '27/08/2010', 7);
INSERT INTO valoracions VALUES (1275, 83, '21/08/2002', 9);
INSERT INTO valoracions VALUES (1275, 78, '11/09/2004', 8);
INSERT INTO valoracions VALUES (1275, 69, '31/07/2001', 9);
INSERT INTO valoracions VALUES (1275, 10, '19/05/2009', 10);
INSERT INTO valoracions VALUES (1275, 95, '24/02/2007', 10);
INSERT INTO valoracions VALUES (1276, 115, '04/10/2008', 3);
INSERT INTO valoracions VALUES (1276, 8, '04/10/2007', 5);
INSERT INTO valoracions VALUES (1276, 30, '02/07/2003', 4);
INSERT INTO valoracions VALUES (1277, 26, '21/07/2009', 5);
INSERT INTO valoracions VALUES (1277, 62, '01/04/2009', 8);
INSERT INTO valoracions VALUES (1277, 26, '10/05/2010', 6);
INSERT INTO valoracions VALUES (1277, 105, '20/09/2009', 5);
INSERT INTO valoracions VALUES (1278, 41, '05/11/2001', 7);
INSERT INTO valoracions VALUES (1278, 84, '17/07/2001', 7);
INSERT INTO valoracions VALUES (1278, 82, '15/10/2001', 2);
INSERT INTO valoracions VALUES (1278, 116, '07/09/2008', 6);
INSERT INTO valoracions VALUES (1280, 41, '26/11/2002', 4);
INSERT INTO valoracions VALUES (1280, 94, '01/04/2010', 2);
INSERT INTO valoracions VALUES (1280, 85, '23/05/2006', 5);
INSERT INTO valoracions VALUES (1280, 6, '23/05/2002', 5);
INSERT INTO valoracions VALUES (1281, 95, '10/05/2006', 9);
INSERT INTO valoracions VALUES (1281, 74, '19/04/2002', 8);
INSERT INTO valoracions VALUES (1281, 115, '30/12/2009', 6);
INSERT INTO valoracions VALUES (1281, 14, '05/06/2004', 5);
INSERT INTO valoracions VALUES (1282, 23, '19/10/2002', 10);
INSERT INTO valoracions VALUES (1282, 55, '20/04/2001', 6);
INSERT INTO valoracions VALUES (1282, 78, '16/11/2008', 8);
INSERT INTO valoracions VALUES (1283, 104, '13/10/2005', 2);
INSERT INTO valoracions VALUES (1283, 63, '11/11/2001', 8);
INSERT INTO valoracions VALUES (1283, 108, '26/12/2009', 2);
INSERT INTO valoracions VALUES (1283, 21, '02/08/2010', 9);
INSERT INTO valoracions VALUES (1283, 68, '21/10/2009', 8);
INSERT INTO valoracions VALUES (1283, 64, '07/08/2003', 4);
INSERT INTO valoracions VALUES (1284, 113, '30/03/2006', 5);
INSERT INTO valoracions VALUES (1284, 75, '26/09/2002', 8);
INSERT INTO valoracions VALUES (1284, 74, '14/11/2002', 4);
INSERT INTO valoracions VALUES (1284, 3, '26/12/2004', 9);
INSERT INTO valoracions VALUES (1285, 50, '23/01/2005', 9);
INSERT INTO valoracions VALUES (1285, 44, '25/09/2010', 5);
INSERT INTO valoracions VALUES (1285, 115, '27/01/2010', 9);
INSERT INTO valoracions VALUES (1285, 84, '12/09/2008', 5);
INSERT INTO valoracions VALUES (1285, 58, '21/07/2009', 9);
INSERT INTO valoracions VALUES (1285, 75, '25/01/2007', 4);
INSERT INTO valoracions VALUES (1286, 88, '13/09/2009', 3);
INSERT INTO valoracions VALUES (1287, 50, '06/05/2006', 4);
INSERT INTO valoracions VALUES (1288, 6, '23/02/2006', 7);
INSERT INTO valoracions VALUES (1288, 3, '02/05/2006', 8);
INSERT INTO valoracions VALUES (1288, 29, '29/08/2010', 6);
INSERT INTO valoracions VALUES (1289, 36, '05/10/2002', 7);
INSERT INTO valoracions VALUES (1289, 15, '29/05/2002', 6);
INSERT INTO valoracions VALUES (1289, 27, '30/07/2005', 6);
INSERT INTO valoracions VALUES (1289, 76, '02/04/2009', 3);
INSERT INTO valoracions VALUES (1289, 91, '11/06/2006', 5);
INSERT INTO valoracions VALUES (1289, 108, '04/08/2008', 5);
INSERT INTO valoracions VALUES (1289, 60, '07/08/2005', 7);
INSERT INTO valoracions VALUES (1290, 102, '31/07/2005', 3);
INSERT INTO valoracions VALUES (1290, 96, '24/09/2008', 7);
INSERT INTO valoracions VALUES (1290, 99, '26/03/2006', 2);
INSERT INTO valoracions VALUES (1290, 28, '02/01/2008', 9);
INSERT INTO valoracions VALUES (1291, 36, '11/05/2006', 7);
INSERT INTO valoracions VALUES (1291, 109, '27/05/2003', 1);
INSERT INTO valoracions VALUES (1291, 74, '13/07/2010', 6);
INSERT INTO valoracions VALUES (1291, 96, '16/02/2005', 4);
INSERT INTO valoracions VALUES (1291, 67, '09/05/2006', 3);
INSERT INTO valoracions VALUES (1291, 33, '01/08/2005', 6);
INSERT INTO valoracions VALUES (1292, 47, '27/01/2004', 7);
INSERT INTO valoracions VALUES (1292, 114, '27/12/2009', 3);
INSERT INTO valoracions VALUES (1292, 53, '28/08/2003', 6);
INSERT INTO valoracions VALUES (1292, 3, '25/07/2003', 5);
INSERT INTO valoracions VALUES (1292, 90, '30/01/2003', 4);
INSERT INTO valoracions VALUES (1292, 46, '14/10/2007', 6);
INSERT INTO valoracions VALUES (1292, 50, '23/05/2007', 10);
INSERT INTO valoracions VALUES (1292, 63, '20/01/2008', 5);
INSERT INTO valoracions VALUES (1293, 8, '25/06/2001', 7);
INSERT INTO valoracions VALUES (1293, 37, '16/09/2002', 6);
INSERT INTO valoracions VALUES (1293, 68, '29/05/2005', 4);
INSERT INTO valoracions VALUES (1293, 116, '08/10/2004', 9);
INSERT INTO valoracions VALUES (1293, 29, '13/07/2009', 6);
INSERT INTO valoracions VALUES (1293, 98, '22/03/2007', 5);
INSERT INTO valoracions VALUES (1293, 3, '02/09/2006', 5);
INSERT INTO valoracions VALUES (1293, 58, '08/04/2009', 10);
INSERT INTO valoracions VALUES (1293, 81, '30/07/2004', 7);
INSERT INTO valoracions VALUES (1294, 71, '07/05/2007', 8);
INSERT INTO valoracions VALUES (1295, 61, '16/08/2008', 7);
INSERT INTO valoracions VALUES (1295, 8, '01/02/2003', 8);
INSERT INTO valoracions VALUES (1296, 3, '07/09/2001', 5);
INSERT INTO valoracions VALUES (1296, 78, '27/06/2007', 7);
INSERT INTO valoracions VALUES (1297, 65, '23/07/2007', 3);
INSERT INTO valoracions VALUES (1297, 88, '04/08/2009', 7);
INSERT INTO valoracions VALUES (1297, 101, '24/01/2007', 1);
INSERT INTO valoracions VALUES (1298, 10, '09/11/2005', 8);
INSERT INTO valoracions VALUES (1298, 49, '05/04/2003', 5);
INSERT INTO valoracions VALUES (1299, 6, '03/08/2006', 5);
INSERT INTO valoracions VALUES (1299, 23, '07/04/2008', 9);
INSERT INTO valoracions VALUES (1299, 22, '12/08/2010', 5);
INSERT INTO valoracions VALUES (1300, 5, '15/12/2007', 7);
INSERT INTO valoracions VALUES (1300, 13, '23/10/2010', 8);
INSERT INTO valoracions VALUES (1301, 7, '25/08/2003', 6);
INSERT INTO valoracions VALUES (1301, 13, '25/02/2004', 8);
INSERT INTO valoracions VALUES (1301, 89, '26/03/2003', 4);
INSERT INTO valoracions VALUES (1301, 101, '18/06/2007', 7);
INSERT INTO valoracions VALUES (1301, 16, '10/05/2004', 6);
INSERT INTO valoracions VALUES (1301, 97, '26/02/2002', 2);
INSERT INTO valoracions VALUES (1301, 62, '14/07/2001', 8);
INSERT INTO valoracions VALUES (1301, 8, '19/02/2004', 9);
INSERT INTO valoracions VALUES (1302, 113, '13/03/2007', 3);
INSERT INTO valoracions VALUES (1302, 86, '09/10/2001', 7);
INSERT INTO valoracions VALUES (1302, 64, '10/10/2006', 9);
INSERT INTO valoracions VALUES (1302, 113, '20/01/2007', 0);
INSERT INTO valoracions VALUES (1302, 85, '17/08/2003', 1);
INSERT INTO valoracions VALUES (1302, 74, '23/12/2002', 8);
INSERT INTO valoracions VALUES (1302, 100, '26/03/2005', 3);
INSERT INTO valoracions VALUES (1303, 99, '26/06/2004', 7);
INSERT INTO valoracions VALUES (1303, 116, '03/09/2002', 9);
INSERT INTO valoracions VALUES (1303, 4, '17/04/2003', 5);
INSERT INTO valoracions VALUES (1303, 76, '20/01/2010', 9);
INSERT INTO valoracions VALUES (1303, 36, '13/02/2007', 8);
INSERT INTO valoracions VALUES (1303, 4, '28/04/2008', 8);
INSERT INTO valoracions VALUES (1304, 56, '14/01/2002', 3);
INSERT INTO valoracions VALUES (1304, 85, '20/03/2008', 5);
INSERT INTO valoracions VALUES (1304, 62, '17/01/2003', 6);
INSERT INTO valoracions VALUES (1304, 108, '30/03/2002', 1);
INSERT INTO valoracions VALUES (1304, 27, '24/06/2006', 8);
INSERT INTO valoracions VALUES (1304, 20, '26/05/2005', 9);
INSERT INTO valoracions VALUES (1304, 43, '23/11/2004', 9);
INSERT INTO valoracions VALUES (1305, 61, '28/07/2003', 5);
INSERT INTO valoracions VALUES (1305, 79, '15/01/2008', 3);
INSERT INTO valoracions VALUES (1305, 24, '05/06/2005', 5);
INSERT INTO valoracions VALUES (1305, 87, '09/08/2006', 2);
INSERT INTO valoracions VALUES (1306, 5, '26/08/2001', 8);
INSERT INTO valoracions VALUES (1306, 116, '28/10/2007', 1);
INSERT INTO valoracions VALUES (1306, 105, '19/07/2004', 2);
INSERT INTO valoracions VALUES (1306, 114, '10/04/2001', 4);
INSERT INTO valoracions VALUES (1306, 85, '11/06/2005', 9);
INSERT INTO valoracions VALUES (1306, 113, '12/12/2001', 2);
INSERT INTO valoracions VALUES (1307, 112, '25/08/2001', 7);
INSERT INTO valoracions VALUES (1307, 102, '04/05/2008', 9);
INSERT INTO valoracions VALUES (1307, 5, '11/12/2007', 7);
INSERT INTO valoracions VALUES (1307, 33, '26/03/2003', 9);
INSERT INTO valoracions VALUES (1307, 109, '10/07/2009', 7);
INSERT INTO valoracions VALUES (1307, 56, '03/01/2006', 9);
INSERT INTO valoracions VALUES (1308, 54, '10/11/2005', 9);
INSERT INTO valoracions VALUES (1308, 92, '13/06/2010', 4);
INSERT INTO valoracions VALUES (1308, 113, '08/02/2004', 7);
INSERT INTO valoracions VALUES (1309, 14, '13/09/2007', 6);
INSERT INTO valoracions VALUES (1309, 113, '23/03/2004', 9);
INSERT INTO valoracions VALUES (1309, 99, '01/04/2007', 4);
INSERT INTO valoracions VALUES (1309, 99, '18/02/2003', 3);
INSERT INTO valoracions VALUES (1309, 68, '28/01/2008', 9);
INSERT INTO valoracions VALUES (1310, 79, '08/04/2006', 2);
INSERT INTO valoracions VALUES (1310, 12, '02/01/2007', 8);
INSERT INTO valoracions VALUES (1310, 104, '22/08/2007', 5);
INSERT INTO valoracions VALUES (1311, 56, '11/11/2008', 8);
INSERT INTO valoracions VALUES (1311, 5, '27/05/2008', 7);
INSERT INTO valoracions VALUES (1311, 7, '05/06/2010', 6);
INSERT INTO valoracions VALUES (1312, 42, '09/05/2001', 7);
INSERT INTO valoracions VALUES (1312, 71, '18/05/2007', 4);
INSERT INTO valoracions VALUES (1313, 37, '27/02/2005', 7);
INSERT INTO valoracions VALUES (1314, 71, '11/02/2007', 4);
INSERT INTO valoracions VALUES (1314, 103, '07/04/2009', 6);
INSERT INTO valoracions VALUES (1314, 9, '03/07/2006', 8);
INSERT INTO valoracions VALUES (1314, 67, '04/10/2009', 8);
INSERT INTO valoracions VALUES (1314, 10, '17/05/2003', 9);
INSERT INTO valoracions VALUES (1315, 86, '16/01/2002', 6);
INSERT INTO valoracions VALUES (1315, 3, '20/09/2009', 6);
INSERT INTO valoracions VALUES (1315, 9, '14/03/2003', 7);
INSERT INTO valoracions VALUES (1315, 80, '12/07/2008', 4);
INSERT INTO valoracions VALUES (1316, 56, '08/04/2003', 9);
INSERT INTO valoracions VALUES (1316, 84, '30/11/2007', 4);
INSERT INTO valoracions VALUES (1316, 54, '03/04/2004', 8);
INSERT INTO valoracions VALUES (1317, 75, '04/06/2003', 9);
INSERT INTO valoracions VALUES (1317, 93, '11/01/2008', 6);
INSERT INTO valoracions VALUES (1317, 94, '06/09/2010', 6);
INSERT INTO valoracions VALUES (1317, 74, '08/02/2010', 4);
INSERT INTO valoracions VALUES (1318, 8, '29/10/2008', 8);
INSERT INTO valoracions VALUES (1318, 78, '04/01/2002', 5);
INSERT INTO valoracions VALUES (1318, 30, '23/12/2008', 5);
INSERT INTO valoracions VALUES (1318, 50, '20/08/2006', 8);
INSERT INTO valoracions VALUES (1318, 29, '09/04/2001', 5);
INSERT INTO valoracions VALUES (1318, 53, '07/05/2005', 9);
INSERT INTO valoracions VALUES (1318, 19, '09/08/2001', 7);
INSERT INTO valoracions VALUES (1318, 41, '21/11/2002', 10);
INSERT INTO valoracions VALUES (1319, 83, '04/08/2002', 10);
INSERT INTO valoracions VALUES (1320, 61, '28/10/2007', 5);
INSERT INTO valoracions VALUES (1320, 21, '05/10/2008', 8);
INSERT INTO valoracions VALUES (1320, 63, '03/05/2001', 4);
INSERT INTO valoracions VALUES (1320, 51, '29/08/2009', 4);
INSERT INTO valoracions VALUES (1320, 38, '27/12/2007', 10);
INSERT INTO valoracions VALUES (1321, 17, '03/10/2006', 7);
INSERT INTO valoracions VALUES (1321, 19, '25/12/2006', 8);
INSERT INTO valoracions VALUES (1321, 80, '08/10/2009', 6);
INSERT INTO valoracions VALUES (1321, 76, '22/08/2005', 9);
INSERT INTO valoracions VALUES (1322, 2, '29/12/2006', 10);
INSERT INTO valoracions VALUES (1322, 77, '31/08/2001', 3);
INSERT INTO valoracions VALUES (1322, 47, '20/07/2005', 4);
INSERT INTO valoracions VALUES (1322, 38, '26/06/2010', 3);
INSERT INTO valoracions VALUES (1322, 89, '30/06/2010', 8);
INSERT INTO valoracions VALUES (1323, 29, '20/12/2009', 4);
INSERT INTO valoracions VALUES (1323, 57, '29/03/2007', 10);
INSERT INTO valoracions VALUES (1323, 27, '28/08/2002', 8);
INSERT INTO valoracions VALUES (1324, 70, '26/07/2005', 9);
INSERT INTO valoracions VALUES (1324, 13, '29/11/2004', 6);
INSERT INTO valoracions VALUES (1324, 44, '08/11/2009', 5);
INSERT INTO valoracions VALUES (1325, 92, '11/08/2009', 9);
INSERT INTO valoracions VALUES (1325, 23, '30/11/2001', 5);
INSERT INTO valoracions VALUES (1325, 116, '29/04/2010', 9);
INSERT INTO valoracions VALUES (1325, 7, '09/05/2009', 9);
INSERT INTO valoracions VALUES (1325, 112, '22/04/2007', 8);
INSERT INTO valoracions VALUES (1325, 55, '20/02/2009', 4);
INSERT INTO valoracions VALUES (1325, 89, '06/09/2010', 10);
INSERT INTO valoracions VALUES (1325, 100, '28/05/2001', 7);
INSERT INTO valoracions VALUES (1325, 5, '17/01/2003', 9);
INSERT INTO valoracions VALUES (1326, 112, '22/06/2006', 1);
INSERT INTO valoracions VALUES (1326, 55, '22/10/2003', 9);
INSERT INTO valoracions VALUES (1326, 114, '04/08/2002', 10);
INSERT INTO valoracions VALUES (1326, 34, '19/11/2003', 4);
INSERT INTO valoracions VALUES (1326, 107, '08/09/2003', 5);
INSERT INTO valoracions VALUES (1326, 21, '10/08/2001', 6);
INSERT INTO valoracions VALUES (1326, 19, '29/08/2002', 8);
INSERT INTO valoracions VALUES (1326, 115, '07/08/2008', 1);
INSERT INTO valoracions VALUES (1327, 76, '19/11/2002', 4);
INSERT INTO valoracions VALUES (1327, 2, '08/05/2003', 10);
INSERT INTO valoracions VALUES (1328, 15, '30/05/2004', 7);
INSERT INTO valoracions VALUES (1328, 82, '08/08/2004', 5);
INSERT INTO valoracions VALUES (1328, 83, '20/08/2009', 6);
INSERT INTO valoracions VALUES (1328, 24, '12/02/2005', 6);
INSERT INTO valoracions VALUES (1328, 114, '12/04/2007', 10);
INSERT INTO valoracions VALUES (1329, 50, '07/08/2008', 6);
INSERT INTO valoracions VALUES (1329, 91, '22/09/2006', 9);
INSERT INTO valoracions VALUES (1329, 51, '05/03/2006', 6);
INSERT INTO valoracions VALUES (1330, 69, '29/08/2003', 6);
INSERT INTO valoracions VALUES (1330, 47, '10/10/2004', 4);
INSERT INTO valoracions VALUES (1330, 116, '10/09/2007', 2);
INSERT INTO valoracions VALUES (1330, 67, '23/04/2004', 5);
INSERT INTO valoracions VALUES (1330, 51, '01/02/2006', 4);
INSERT INTO valoracions VALUES (1330, 112, '17/10/2009', 8);
INSERT INTO valoracions VALUES (1330, 34, '04/04/2006', 8);
INSERT INTO valoracions VALUES (1330, 11, '14/07/2008', 7);
INSERT INTO valoracions VALUES (1330, 51, '26/04/2004', 3);
INSERT INTO valoracions VALUES (1331, 58, '01/05/2003', 3);
INSERT INTO valoracions VALUES (1332, 34, '21/07/2005', 9);
INSERT INTO valoracions VALUES (1332, 100, '11/05/2007', 6);
INSERT INTO valoracions VALUES (1332, 114, '09/08/2005', 6);
INSERT INTO valoracions VALUES (1333, 49, '02/10/2005', 6);
INSERT INTO valoracions VALUES (1333, 68, '14/03/2008', 8);
INSERT INTO valoracions VALUES (1334, 103, '10/09/2007', 9);
INSERT INTO valoracions VALUES (1334, 76, '06/02/2002', 3);
INSERT INTO valoracions VALUES (1334, 79, '11/05/2009', 4);
INSERT INTO valoracions VALUES (1334, 72, '11/06/2004', 7);
INSERT INTO valoracions VALUES (1334, 4, '11/05/2010', 8);
INSERT INTO valoracions VALUES (1335, 84, '02/06/2002', 7);
INSERT INTO valoracions VALUES (1335, 101, '17/02/2005', 1);
INSERT INTO valoracions VALUES (1335, 112, '11/04/2009', 6);
INSERT INTO valoracions VALUES (1335, 25, '27/04/2001', 9);
INSERT INTO valoracions VALUES (1335, 60, '08/02/2007', 7);
INSERT INTO valoracions VALUES (1335, 86, '25/08/2005', 7);
INSERT INTO valoracions VALUES (1336, 116, '13/05/2003', 4);
INSERT INTO valoracions VALUES (1336, 96, '28/10/2005', 5);
INSERT INTO valoracions VALUES (1336, 8, '25/04/2002', 7);
INSERT INTO valoracions VALUES (1336, 29, '17/08/2004', 8);
INSERT INTO valoracions VALUES (1336, 3, '22/11/2007', 7);
INSERT INTO valoracions VALUES (1337, 111, '19/04/2006', 5);
INSERT INTO valoracions VALUES (1337, 35, '15/03/2004', 9);
INSERT INTO valoracions VALUES (1337, 88, '06/08/2010', 5);
INSERT INTO valoracions VALUES (1337, 4, '06/02/2009', 7);
INSERT INTO valoracions VALUES (1337, 66, '13/10/2007', 9);
INSERT INTO valoracions VALUES (1338, 109, '13/03/2008', 2);
INSERT INTO valoracions VALUES (1338, 30, '13/07/2002', 4);
INSERT INTO valoracions VALUES (1339, 51, '12/06/2001', 4);
INSERT INTO valoracions VALUES (1339, 84, '21/09/2006', 2);
INSERT INTO valoracions VALUES (1339, 51, '07/09/2002', 9);
INSERT INTO valoracions VALUES (1339, 54, '05/05/2006', 3);
INSERT INTO valoracions VALUES (1340, 93, '25/06/2002', 2);
INSERT INTO valoracions VALUES (1340, 87, '23/01/2007', 7);
INSERT INTO valoracions VALUES (1340, 65, '30/01/2008', 5);
INSERT INTO valoracions VALUES (1340, 70, '16/01/2009', 7);
INSERT INTO valoracions VALUES (1340, 105, '26/03/2008', 1);
INSERT INTO valoracions VALUES (1340, 95, '07/02/2004', 5);
INSERT INTO valoracions VALUES (1340, 62, '06/03/2006', 5);
INSERT INTO valoracions VALUES (1340, 37, '30/10/2003', 3);
INSERT INTO valoracions VALUES (1341, 101, '10/08/2002', 5);
INSERT INTO valoracions VALUES (1341, 43, '10/09/2005', 8);
INSERT INTO valoracions VALUES (1341, 91, '26/11/2009', 7);
INSERT INTO valoracions VALUES (1341, 22, '22/04/2004', 8);
INSERT INTO valoracions VALUES (1341, 110, '23/06/2005', 2);
INSERT INTO valoracions VALUES (1341, 69, '28/05/2008', 3);
INSERT INTO valoracions VALUES (1342, 91, '15/11/2001', 9);
INSERT INTO valoracions VALUES (1342, 38, '18/10/2005', 9);
INSERT INTO valoracions VALUES (1342, 19, '09/09/2001', 8);
INSERT INTO valoracions VALUES (1343, 26, '01/03/2003', 10);
INSERT INTO valoracions VALUES (1343, 30, '28/08/2010', 7);
INSERT INTO valoracions VALUES (1343, 32, '29/11/2008', 8);
INSERT INTO valoracions VALUES (1344, 97, '30/03/2002', 9);
INSERT INTO valoracions VALUES (1344, 83, '16/11/2008', 6);
INSERT INTO valoracions VALUES (1344, 53, '07/12/2004', 8);
INSERT INTO valoracions VALUES (1345, 70, '11/04/2010', 4);
INSERT INTO valoracions VALUES (1345, 66, '09/05/2002', 8);
INSERT INTO valoracions VALUES (1345, 28, '21/11/2004', 9);
INSERT INTO valoracions VALUES (1345, 27, '25/10/2006', 8);
INSERT INTO valoracions VALUES (1345, 86, '26/02/2003', 10);
INSERT INTO valoracions VALUES (1346, 115, '08/10/2010', 2);
INSERT INTO valoracions VALUES (1346, 41, '16/11/2004', 9);
INSERT INTO valoracions VALUES (1346, 47, '02/06/2005', 5);
INSERT INTO valoracions VALUES (1346, 9, '02/12/2005', 8);
INSERT INTO valoracions VALUES (1346, 103, '30/05/2003', 3);
INSERT INTO valoracions VALUES (1347, 107, '11/10/2010', 2);
INSERT INTO valoracions VALUES (1347, 100, '22/10/2006', 7);
INSERT INTO valoracions VALUES (1347, 28, '13/01/2006', 4);
INSERT INTO valoracions VALUES (1347, 48, '23/12/2001', 4);
INSERT INTO valoracions VALUES (1348, 64, '14/12/2007', 7);
INSERT INTO valoracions VALUES (1348, 79, '30/01/2003', 5);
INSERT INTO valoracions VALUES (1348, 42, '04/03/2010', 7);
INSERT INTO valoracions VALUES (1348, 102, '05/08/2009', 4);
INSERT INTO valoracions VALUES (1349, 33, '24/03/2003', 5);
INSERT INTO valoracions VALUES (1349, 41, '23/09/2005', 5);
INSERT INTO valoracions VALUES (1349, 50, '03/02/2008', 10);
INSERT INTO valoracions VALUES (1349, 85, '03/11/2001', 8);
INSERT INTO valoracions VALUES (1349, 21, '20/04/2010', 5);
INSERT INTO valoracions VALUES (1350, 29, '15/08/2009', 9);
INSERT INTO valoracions VALUES (1350, 91, '08/02/2009', 6);
INSERT INTO valoracions VALUES (1350, 95, '21/02/2008', 8);
INSERT INTO valoracions VALUES (1350, 99, '26/10/2009', 9);
INSERT INTO valoracions VALUES (1351, 99, '10/08/2006', 7);
INSERT INTO valoracions VALUES (1352, 25, '18/12/2002', 6);
INSERT INTO valoracions VALUES (1352, 35, '20/08/2009', 4);
INSERT INTO valoracions VALUES (1352, 101, '05/02/2008', 4);
INSERT INTO valoracions VALUES (1352, 64, '14/07/2005', 8);
INSERT INTO valoracions VALUES (1352, 35, '27/01/2009', 7);
INSERT INTO valoracions VALUES (1353, 92, '28/09/2005', 7);
INSERT INTO valoracions VALUES (1354, 29, '12/01/2008', 6);
INSERT INTO valoracions VALUES (1354, 85, '30/10/2007', 7);
INSERT INTO valoracions VALUES (1355, 92, '14/09/2005', 9);
INSERT INTO valoracions VALUES (1356, 92, '06/01/2006', 4);
INSERT INTO valoracions VALUES (1357, 26, '08/05/2005', 8);
INSERT INTO valoracions VALUES (1357, 23, '04/06/2003', 8);
INSERT INTO valoracions VALUES (1357, 68, '25/10/2009', 4);
INSERT INTO valoracions VALUES (1357, 36, '17/09/2005', 9);
INSERT INTO valoracions VALUES (1357, 18, '07/10/2006', 8);
INSERT INTO valoracions VALUES (1357, 24, '25/06/2005', 6);
INSERT INTO valoracions VALUES (1357, 86, '16/02/2003', 4);
INSERT INTO valoracions VALUES (1357, 107, '10/09/2007', 9);
INSERT INTO valoracions VALUES (1358, 95, '18/03/2006', 1);
INSERT INTO valoracions VALUES (1358, 97, '02/03/2010', 9);
INSERT INTO valoracions VALUES (1358, 112, '10/09/2006', 3);
INSERT INTO valoracions VALUES (1358, 109, '28/03/2009', 7);
INSERT INTO valoracions VALUES (1358, 108, '19/02/2006', 9);
INSERT INTO valoracions VALUES (1359, 47, '07/10/2009', 9);
INSERT INTO valoracions VALUES (1359, 72, '23/09/2006', 3);
INSERT INTO valoracions VALUES (1359, 59, '03/06/2004', 9);
INSERT INTO valoracions VALUES (1360, 83, '28/02/2002', 7);
INSERT INTO valoracions VALUES (1360, 60, '29/01/2006', 3);
INSERT INTO valoracions VALUES (1361, 96, '29/08/2007', 4);
INSERT INTO valoracions VALUES (1361, 45, '10/06/2001', 8);
INSERT INTO valoracions VALUES (1362, 97, '15/01/2002', 3);
INSERT INTO valoracions VALUES (1362, 50, '08/05/2001', 4);
INSERT INTO valoracions VALUES (1363, 78, '15/11/2005', 3);
INSERT INTO valoracions VALUES (1363, 55, '20/04/2006', 9);
INSERT INTO valoracions VALUES (1363, 82, '23/06/2001', 9);
INSERT INTO valoracions VALUES (1363, 19, '13/08/2003', 6);
INSERT INTO valoracions VALUES (1363, 103, '02/11/2007', 1);
INSERT INTO valoracions VALUES (1363, 55, '06/01/2004', 7);
INSERT INTO valoracions VALUES (1364, 64, '19/01/2006', 7);
INSERT INTO valoracions VALUES (1364, 28, '17/05/2004', 7);
INSERT INTO valoracions VALUES (1364, 27, '04/12/2003', 5);
INSERT INTO valoracions VALUES (1365, 37, '20/07/2005', 4);
INSERT INTO valoracions VALUES (1365, 23, '30/09/2006', 9);
INSERT INTO valoracions VALUES (1365, 9, '25/07/2002', 7);
INSERT INTO valoracions VALUES (1366, 96, '19/06/2009', 3);
INSERT INTO valoracions VALUES (1366, 55, '07/07/2009', 4);
INSERT INTO valoracions VALUES (1366, 4, '24/09/2007', 9);
INSERT INTO valoracions VALUES (1366, 100, '25/07/2004', 4);
INSERT INTO valoracions VALUES (1367, 14, '27/10/2004', 8);
INSERT INTO valoracions VALUES (1367, 52, '01/03/2005', 7);
INSERT INTO valoracions VALUES (1367, 4, '11/06/2002', 5);
INSERT INTO valoracions VALUES (1368, 83, '09/12/2008', 3);
INSERT INTO valoracions VALUES (1368, 77, '15/02/2007', 10);
INSERT INTO valoracions VALUES (1368, 71, '09/05/2001', 5);
INSERT INTO valoracions VALUES (1368, 40, '01/03/2004', 4);
INSERT INTO valoracions VALUES (1369, 84, '07/06/2008', 7);
INSERT INTO valoracions VALUES (1370, 26, '26/03/2004', 4);
INSERT INTO valoracions VALUES (1370, 63, '08/04/2005', 3);
INSERT INTO valoracions VALUES (1370, 80, '19/12/2008', 2);
INSERT INTO valoracions VALUES (1370, 97, '24/08/2003', 8);
INSERT INTO valoracions VALUES (1370, 105, '21/06/2007', 5);
INSERT INTO valoracions VALUES (1370, 94, '18/01/2008', 8);
INSERT INTO valoracions VALUES (1371, 108, '07/09/2010', 8);
INSERT INTO valoracions VALUES (1371, 95, '01/01/2003', 4);
INSERT INTO valoracions VALUES (1371, 32, '28/11/2007', 6);
INSERT INTO valoracions VALUES (1371, 2, '01/05/2005', 6);
INSERT INTO valoracions VALUES (1371, 62, '22/07/2004', 8);
INSERT INTO valoracions VALUES (1372, 96, '27/12/2002', 7);
INSERT INTO valoracions VALUES (1372, 59, '13/08/2002', 6);
INSERT INTO valoracions VALUES (1372, 6, '27/04/2008', 6);
INSERT INTO valoracions VALUES (1372, 19, '29/04/2008', 6);
INSERT INTO valoracions VALUES (1373, 87, '08/07/2004', 6);
INSERT INTO valoracions VALUES (1373, 19, '28/02/2009', 4);
INSERT INTO valoracions VALUES (1373, 9, '05/02/2002', 7);
INSERT INTO valoracions VALUES (1374, 6, '10/06/2007', 7);
INSERT INTO valoracions VALUES (1374, 88, '11/11/2006', 7);
INSERT INTO valoracions VALUES (1374, 29, '13/03/2006', 4);
INSERT INTO valoracions VALUES (1375, 80, '22/09/2009', 6);
INSERT INTO valoracions VALUES (1375, 31, '18/04/2003', 9);
INSERT INTO valoracions VALUES (1375, 55, '10/03/2007', 9);
INSERT INTO valoracions VALUES (1375, 108, '04/11/2006', 10);
INSERT INTO valoracions VALUES (1376, 53, '05/04/2006', 9);
INSERT INTO valoracions VALUES (1376, 79, '09/12/2001', 8);
INSERT INTO valoracions VALUES (1377, 26, '23/01/2002', 6);
INSERT INTO valoracions VALUES (1377, 93, '04/10/2005', 9);
INSERT INTO valoracions VALUES (1377, 5, '01/06/2008', 6);
INSERT INTO valoracions VALUES (1377, 102, '07/12/2008', 3);
INSERT INTO valoracions VALUES (1378, 114, '13/12/2001', 5);
INSERT INTO valoracions VALUES (1378, 11, '11/11/2004', 5);
INSERT INTO valoracions VALUES (1378, 102, '03/09/2001', 2);
INSERT INTO valoracions VALUES (1379, 95, '17/05/2006', 10);
INSERT INTO valoracions VALUES (1379, 22, '24/02/2007', 5);
INSERT INTO valoracions VALUES (1380, 55, '25/09/2002', 5);
INSERT INTO valoracions VALUES (1380, 39, '01/09/2010', 7);
INSERT INTO valoracions VALUES (1381, 45, '18/08/2006', 5);
INSERT INTO valoracions VALUES (1381, 68, '29/05/2001', 5);
INSERT INTO valoracions VALUES (1381, 113, '30/04/2003', 2);
INSERT INTO valoracions VALUES (1382, 109, '10/09/2005', 9);
INSERT INTO valoracions VALUES (1382, 11, '16/09/2009', 6);
INSERT INTO valoracions VALUES (1382, 33, '27/11/2006', 4);
INSERT INTO valoracions VALUES (1382, 20, '20/05/2010', 8);
INSERT INTO valoracions VALUES (1383, 72, '05/07/2005', 5);
INSERT INTO valoracions VALUES (1383, 116, '22/12/2001', 9);
INSERT INTO valoracions VALUES (1383, 110, '20/08/2009', 9);
INSERT INTO valoracions VALUES (1383, 113, '03/06/2009', 3);
INSERT INTO valoracions VALUES (1384, 7, '20/08/2007', 5);
INSERT INTO valoracions VALUES (1384, 6, '25/02/2005', 5);
INSERT INTO valoracions VALUES (1384, 74, '08/05/2003', 8);
INSERT INTO valoracions VALUES (1384, 90, '02/09/2004', 9);
INSERT INTO valoracions VALUES (1384, 85, '27/01/2008', 4);
INSERT INTO valoracions VALUES (1384, 58, '08/02/2010', 5);
INSERT INTO valoracions VALUES (1384, 21, '16/04/2008', 9);
INSERT INTO valoracions VALUES (1385, 45, '15/09/2009', 10);
INSERT INTO valoracions VALUES (1385, 64, '03/06/2004', 9);
INSERT INTO valoracions VALUES (1385, 69, '08/08/2006', 7);
INSERT INTO valoracions VALUES (1385, 10, '24/02/2005', 7);
INSERT INTO valoracions VALUES (1385, 20, '16/07/2004', 5);
INSERT INTO valoracions VALUES (1385, 65, '07/12/2005', 5);
INSERT INTO valoracions VALUES (1386, 15, '16/10/2002', 6);
INSERT INTO valoracions VALUES (1386, 82, '04/06/2006', 2);
INSERT INTO valoracions VALUES (1386, 74, '28/05/2009', 4);
INSERT INTO valoracions VALUES (1386, 18, '08/05/2001', 6);
INSERT INTO valoracions VALUES (1387, 104, '26/12/2006', 1);
INSERT INTO valoracions VALUES (1387, 92, '22/12/2003', 6);
INSERT INTO valoracions VALUES (1387, 31, '25/06/2007', 6);
INSERT INTO valoracions VALUES (1387, 86, '10/06/2009', 2);
INSERT INTO valoracions VALUES (1387, 55, '28/04/2006', 8);
INSERT INTO valoracions VALUES (1388, 114, '04/11/2002', 1);
INSERT INTO valoracions VALUES (1388, 42, '02/07/2009', 5);
INSERT INTO valoracions VALUES (1388, 35, '18/01/2003', 7);
INSERT INTO valoracions VALUES (1388, 49, '23/03/2004', 8);
INSERT INTO valoracions VALUES (1389, 10, '25/07/2009', 7);
INSERT INTO valoracions VALUES (1389, 7, '21/03/2006', 8);
INSERT INTO valoracions VALUES (1389, 61, '25/03/2010', 3);
INSERT INTO valoracions VALUES (1390, 59, '06/12/2008', 9);
INSERT INTO valoracions VALUES (1390, 36, '21/10/2008', 7);
INSERT INTO valoracions VALUES (1390, 73, '02/10/2007', 10);
INSERT INTO valoracions VALUES (1390, 75, '07/03/2003', 5);
INSERT INTO valoracions VALUES (1390, 39, '07/10/2007', 7);
INSERT INTO valoracions VALUES (1391, 65, '04/10/2010', 5);
INSERT INTO valoracions VALUES (1391, 71, '26/11/2009', 9);
INSERT INTO valoracions VALUES (1391, 69, '22/01/2005', 10);
INSERT INTO valoracions VALUES (1391, 46, '20/04/2009', 6);
INSERT INTO valoracions VALUES (1391, 95, '12/07/2002', 5);
INSERT INTO valoracions VALUES (1392, 44, '21/09/2004', 10);
INSERT INTO valoracions VALUES (1392, 43, '15/07/2005', 8);
INSERT INTO valoracions VALUES (1393, 10, '01/11/2005', 5);
INSERT INTO valoracions VALUES (1393, 10, '13/06/2008', 8);
INSERT INTO valoracions VALUES (1393, 88, '14/10/2010', 8);
INSERT INTO valoracions VALUES (1393, 55, '01/04/2002', 5);
INSERT INTO valoracions VALUES (1394, 74, '27/01/2008', 9);
INSERT INTO valoracions VALUES (1394, 106, '18/03/2004', 5);
INSERT INTO valoracions VALUES (1394, 75, '21/01/2005', 8);
INSERT INTO valoracions VALUES (1394, 58, '20/01/2005', 10);
INSERT INTO valoracions VALUES (1395, 82, '22/09/2008', 8);
INSERT INTO valoracions VALUES (1395, 86, '28/11/2002', 8);
INSERT INTO valoracions VALUES (1395, 91, '05/02/2008', 9);
INSERT INTO valoracions VALUES (1395, 92, '20/04/2004', 2);
INSERT INTO valoracions VALUES (1396, 36, '30/11/2008', 9);
INSERT INTO valoracions VALUES (1397, 93, '08/06/2008', 8);
INSERT INTO valoracions VALUES (1397, 108, '22/04/2007', 4);
INSERT INTO valoracions VALUES (1397, 10, '10/11/2001', 5);
INSERT INTO valoracions VALUES (1397, 22, '30/08/2004', 5);
INSERT INTO valoracions VALUES (1397, 107, '01/02/2003', 8);
INSERT INTO valoracions VALUES (1397, 78, '26/11/2003', 2);
INSERT INTO valoracions VALUES (1397, 2, '22/11/2006', 9);
INSERT INTO valoracions VALUES (1397, 10, '05/05/2003', 6);
INSERT INTO valoracions VALUES (1398, 31, '13/02/2009', 7);
INSERT INTO valoracions VALUES (1398, 104, '03/08/2003', 10);
INSERT INTO valoracions VALUES (1399, 9, '24/11/2006', 7);
INSERT INTO valoracions VALUES (1399, 30, '16/04/2007', 8);
INSERT INTO valoracions VALUES (1400, 110, '24/07/2005', 10);
INSERT INTO valoracions VALUES (1400, 21, '16/04/2001', 10);
INSERT INTO valoracions VALUES (1400, 15, '12/11/2008', 6);
INSERT INTO valoracions VALUES (1401, 47, '31/07/2007', 3);
INSERT INTO valoracions VALUES (1401, 59, '02/03/2008', 9);
INSERT INTO valoracions VALUES (1401, 46, '07/11/2007', 7);
INSERT INTO valoracions VALUES (1401, 33, '30/10/2002', 7);
INSERT INTO valoracions VALUES (1401, 90, '25/10/2009', 9);
INSERT INTO valoracions VALUES (1401, 99, '23/09/2004', 2);
INSERT INTO valoracions VALUES (1401, 4, '12/05/2001', 7);
INSERT INTO valoracions VALUES (1401, 53, '03/12/2001', 4);
INSERT INTO valoracions VALUES (1402, 50, '19/02/2005', 4);
INSERT INTO valoracions VALUES (1402, 98, '31/12/2009', 9);
INSERT INTO valoracions VALUES (1403, 50, '01/11/2005', 4);
INSERT INTO valoracions VALUES (1403, 15, '08/10/2010', 5);
INSERT INTO valoracions VALUES (1404, 40, '29/02/2004', 7);
INSERT INTO valoracions VALUES (1404, 9, '27/05/2007', 5);
INSERT INTO valoracions VALUES (1404, 73, '12/05/2002', 5);
INSERT INTO valoracions VALUES (1404, 98, '04/10/2005', 9);
INSERT INTO valoracions VALUES (1404, 49, '14/03/2009', 4);
INSERT INTO valoracions VALUES (1405, 80, '26/01/2004', 5);
INSERT INTO valoracions VALUES (1405, 8, '22/04/2003', 9);
INSERT INTO valoracions VALUES (1405, 33, '07/04/2008', 9);
INSERT INTO valoracions VALUES (1405, 10, '30/10/2007', 7);
INSERT INTO valoracions VALUES (1405, 63, '18/08/2009', 5);
INSERT INTO valoracions VALUES (1405, 47, '27/12/2008', 4);
INSERT INTO valoracions VALUES (1405, 28, '05/01/2003', 6);
INSERT INTO valoracions VALUES (1406, 4, '16/03/2005', 6);
INSERT INTO valoracions VALUES (1406, 69, '16/04/2009', 9);
INSERT INTO valoracions VALUES (1407, 3, '25/08/2008', 6);
INSERT INTO valoracions VALUES (1407, 28, '04/12/2007', 9);
INSERT INTO valoracions VALUES (1407, 30, '17/10/2007', 6);
INSERT INTO valoracions VALUES (1407, 82, '06/09/2006', 6);
INSERT INTO valoracions VALUES (1408, 55, '21/04/2008', 6);
INSERT INTO valoracions VALUES (1408, 16, '15/03/2003', 6);
INSERT INTO valoracions VALUES (1408, 50, '10/06/2010', 6);
INSERT INTO valoracions VALUES (1408, 103, '05/02/2005', 8);
INSERT INTO valoracions VALUES (1409, 9, '24/05/2009', 5);
INSERT INTO valoracions VALUES (1409, 2, '14/07/2009', 9);
INSERT INTO valoracions VALUES (1409, 31, '06/08/2003', 5);
INSERT INTO valoracions VALUES (1409, 98, '06/11/2005', 4);
INSERT INTO valoracions VALUES (1409, 74, '30/08/2008', 3);
INSERT INTO valoracions VALUES (1410, 20, '09/08/2003', 5);
INSERT INTO valoracions VALUES (1410, 66, '04/02/2004', 5);
INSERT INTO valoracions VALUES (1410, 50, '31/07/2010', 6);
INSERT INTO valoracions VALUES (1410, 15, '27/10/2008', 9);
INSERT INTO valoracions VALUES (1410, 55, '12/02/2005', 9);
INSERT INTO valoracions VALUES (1410, 100, '01/08/2010', 4);
INSERT INTO valoracions VALUES (1411, 94, '09/06/2010', 3);
INSERT INTO valoracions VALUES (1411, 109, '20/05/2003', 5);
INSERT INTO valoracions VALUES (1411, 24, '24/01/2004', 6);
INSERT INTO valoracions VALUES (1411, 7, '06/03/2010', 7);
INSERT INTO valoracions VALUES (1412, 92, '09/08/2005', 8);
INSERT INTO valoracions VALUES (1412, 71, '15/05/2003', 9);
INSERT INTO valoracions VALUES (1412, 48, '10/10/2002', 9);
INSERT INTO valoracions VALUES (1412, 114, '12/02/2005', 6);
INSERT INTO valoracions VALUES (1412, 28, '14/05/2009', 9);
INSERT INTO valoracions VALUES (1412, 84, '08/03/2003', 8);
INSERT INTO valoracions VALUES (1412, 38, '26/07/2005', 6);
INSERT INTO valoracions VALUES (1413, 91, '14/10/2003', 2);
INSERT INTO valoracions VALUES (1413, 78, '20/09/2009', 8);
INSERT INTO valoracions VALUES (1413, 63, '02/08/2010', 2);
INSERT INTO valoracions VALUES (1413, 20, '30/07/2004', 9);
INSERT INTO valoracions VALUES (1413, 58, '08/01/2008', 9);
INSERT INTO valoracions VALUES (1414, 66, '09/01/2004', 8);
INSERT INTO valoracions VALUES (1414, 95, '26/07/2005', 2);
INSERT INTO valoracions VALUES (1414, 11, '01/08/2008', 7);
INSERT INTO valoracions VALUES (1414, 107, '15/05/2005', 3);
INSERT INTO valoracions VALUES (1415, 55, '08/07/2003', 4);
INSERT INTO valoracions VALUES (1415, 33, '14/06/2010', 5);
INSERT INTO valoracions VALUES (1415, 6, '05/11/2007', 8);
INSERT INTO valoracions VALUES (1416, 60, '28/05/2010', 3);
INSERT INTO valoracions VALUES (1416, 13, '05/11/2006', 6);
INSERT INTO valoracions VALUES (1417, 88, '23/03/2009', 2);
INSERT INTO valoracions VALUES (1417, 112, '01/08/2002', 8);
INSERT INTO valoracions VALUES (1417, 104, '03/11/2008', 4);
INSERT INTO valoracions VALUES (1417, 107, '20/04/2007', 1);
INSERT INTO valoracions VALUES (1418, 109, '17/11/2007', 6);
INSERT INTO valoracions VALUES (1418, 16, '28/06/2003', 6);
INSERT INTO valoracions VALUES (1418, 28, '05/10/2003', 6);
INSERT INTO valoracions VALUES (1418, 21, '09/10/2005', 5);
INSERT INTO valoracions VALUES (1419, 55, '12/02/2008', 9);
INSERT INTO valoracions VALUES (1419, 105, '22/04/2007', 5);
INSERT INTO valoracions VALUES (1420, 46, '27/09/2005', 7);
INSERT INTO valoracions VALUES (1421, 71, '08/11/2004', 2);
INSERT INTO valoracions VALUES (1421, 32, '08/05/2003', 6);
INSERT INTO valoracions VALUES (1421, 20, '06/12/2006', 10);
INSERT INTO valoracions VALUES (1421, 109, '25/09/2003', 1);
INSERT INTO valoracions VALUES (1421, 71, '26/09/2002', 4);
INSERT INTO valoracions VALUES (1421, 11, '19/06/2005', 8);
INSERT INTO valoracions VALUES (1421, 80, '13/07/2002', 4);
INSERT INTO valoracions VALUES (1421, 48, '14/12/2003', 7);
INSERT INTO valoracions VALUES (1422, 61, '12/04/2007', 3);
INSERT INTO valoracions VALUES (1422, 81, '22/04/2006', 3);
INSERT INTO valoracions VALUES (1422, 64, '12/01/2008', 4);
INSERT INTO valoracions VALUES (1422, 3, '30/08/2010', 10);
INSERT INTO valoracions VALUES (1422, 98, '23/03/2005', 8);
INSERT INTO valoracions VALUES (1422, 32, '03/10/2003', 6);
INSERT INTO valoracions VALUES (1422, 33, '28/06/2010', 7);
INSERT INTO valoracions VALUES (1423, 116, '12/12/2008', 1);
INSERT INTO valoracions VALUES (1424, 27, '30/05/2004', 4);
INSERT INTO valoracions VALUES (1424, 104, '26/01/2009', 9);
INSERT INTO valoracions VALUES (1424, 82, '17/09/2010', 5);
INSERT INTO valoracions VALUES (1424, 13, '16/05/2009', 8);
INSERT INTO valoracions VALUES (1425, 89, '24/09/2007', 3);
INSERT INTO valoracions VALUES (1425, 35, '21/01/2009', 8);
INSERT INTO valoracions VALUES (1425, 105, '06/01/2004', 2);
INSERT INTO valoracions VALUES (1426, 113, '19/06/2009', 2);
INSERT INTO valoracions VALUES (1426, 14, '01/01/2004', 5);
INSERT INTO valoracions VALUES (1427, 51, '25/03/2009', 6);
INSERT INTO valoracions VALUES (1427, 84, '11/07/2006', 6);
INSERT INTO valoracions VALUES (1427, 48, '22/12/2009', 9);
INSERT INTO valoracions VALUES (1427, 31, '20/10/2006', 10);
INSERT INTO valoracions VALUES (1428, 97, '01/03/2004', 6);
INSERT INTO valoracions VALUES (1428, 48, '23/09/2008', 9);
INSERT INTO valoracions VALUES (1428, 102, '17/12/2008', 10);
INSERT INTO valoracions VALUES (1428, 17, '27/04/2005', 7);
INSERT INTO valoracions VALUES (1428, 1, '15/05/2001', 10);
INSERT INTO valoracions VALUES (1429, 61, '09/05/2010', 9);
INSERT INTO valoracions VALUES (1429, 38, '13/02/2005', 9);
INSERT INTO valoracions VALUES (1429, 91, '31/01/2002', 9);
INSERT INTO valoracions VALUES (1429, 101, '07/01/2003', 4);
INSERT INTO valoracions VALUES (1429, 4, '12/07/2001', 6);
INSERT INTO valoracions VALUES (1429, 101, '27/07/2005', 1);
INSERT INTO valoracions VALUES (1430, 75, '07/09/2003', 9);
INSERT INTO valoracions VALUES (1430, 106, '13/05/2005', 6);
INSERT INTO valoracions VALUES (1430, 29, '26/05/2003', 6);
INSERT INTO valoracions VALUES (1430, 65, '16/08/2004', 8);
INSERT INTO valoracions VALUES (1430, 3, '16/09/2003', 9);
INSERT INTO valoracions VALUES (1430, 95, '26/04/2004', 1);
INSERT INTO valoracions VALUES (1431, 3, '23/02/2004', 9);
INSERT INTO valoracions VALUES (1431, 3, '18/06/2003', 9);
INSERT INTO valoracions VALUES (1431, 107, '29/09/2007', 6);
INSERT INTO valoracions VALUES (1431, 66, '03/10/2003', 8);
INSERT INTO valoracions VALUES (1432, 98, '12/05/2007', 2);
INSERT INTO valoracions VALUES (1432, 47, '06/10/2007', 4);
INSERT INTO valoracions VALUES (1432, 69, '26/02/2006', 3);
INSERT INTO valoracions VALUES (1433, 19, '03/07/2008', 5);
INSERT INTO valoracions VALUES (1433, 42, '03/11/2001', 9);
INSERT INTO valoracions VALUES (1433, 101, '24/01/2003', 3);
INSERT INTO valoracions VALUES (1433, 45, '04/11/2003', 9);
INSERT INTO valoracions VALUES (1433, 44, '20/12/2004', 3);
INSERT INTO valoracions VALUES (1433, 10, '23/09/2001', 8);
INSERT INTO valoracions VALUES (1433, 109, '22/07/2010', 9);
INSERT INTO valoracions VALUES (1433, 68, '28/06/2010', 4);
INSERT INTO valoracions VALUES (1434, 20, '24/04/2008', 5);
INSERT INTO valoracions VALUES (1434, 10, '22/03/2008', 5);
INSERT INTO valoracions VALUES (1434, 61, '03/09/2004', 3);
INSERT INTO valoracions VALUES (1434, 30, '28/08/2001', 4);
INSERT INTO valoracions VALUES (1434, 66, '01/07/2005', 5);
INSERT INTO valoracions VALUES (1435, 81, '20/05/2005', 7);
INSERT INTO valoracions VALUES (1435, 30, '23/07/2006', 7);
INSERT INTO valoracions VALUES (1436, 30, '16/07/2001', 9);
INSERT INTO valoracions VALUES (1436, 28, '26/12/2002', 4);
INSERT INTO valoracions VALUES (1436, 35, '11/09/2006', 7);
INSERT INTO valoracions VALUES (1436, 79, '23/08/2006', 8);
INSERT INTO valoracions VALUES (1437, 59, '26/07/2008', 5);
INSERT INTO valoracions VALUES (1437, 103, '09/01/2003', 2);
INSERT INTO valoracions VALUES (1438, 14, '29/08/2004', 10);
INSERT INTO valoracions VALUES (1438, 31, '18/09/2009', 9);
INSERT INTO valoracions VALUES (1438, 12, '25/05/2001', 8);
INSERT INTO valoracions VALUES (1439, 113, '17/04/2003', 3);
INSERT INTO valoracions VALUES (1439, 87, '15/06/2001', 3);
INSERT INTO valoracions VALUES (1439, 50, '12/11/2008', 9);
INSERT INTO valoracions VALUES (1439, 29, '02/11/2007', 5);
INSERT INTO valoracions VALUES (1440, 111, '31/12/2002', 3);
INSERT INTO valoracions VALUES (1441, 1, '07/03/2008', 10);
INSERT INTO valoracions VALUES (1441, 72, '02/11/2003', 4);
INSERT INTO valoracions VALUES (1442, 93, '18/05/2001', 4);
INSERT INTO valoracions VALUES (1442, 61, '09/06/2005', 5);
INSERT INTO valoracions VALUES (1442, 22, '19/04/2004', 8);
INSERT INTO valoracions VALUES (1443, 2, '27/06/2009', 10);
INSERT INTO valoracions VALUES (1443, 108, '22/09/2009', 9);
INSERT INTO valoracions VALUES (1443, 69, '27/01/2009', 7);
INSERT INTO valoracions VALUES (1444, 21, '14/04/2004', 8);
INSERT INTO valoracions VALUES (1444, 40, '28/04/2004', 4);
INSERT INTO valoracions VALUES (1444, 60, '21/05/2004', 2);
INSERT INTO valoracions VALUES (1444, 60, '02/04/2008', 8);
INSERT INTO valoracions VALUES (1445, 40, '21/09/2009', 4);
INSERT INTO valoracions VALUES (1445, 4, '22/05/2001', 7);
INSERT INTO valoracions VALUES (1446, 80, '19/12/2001', 7);
INSERT INTO valoracions VALUES (1446, 95, '25/12/2005', 7);
INSERT INTO valoracions VALUES (1446, 48, '07/10/2009', 6);
INSERT INTO valoracions VALUES (1446, 32, '09/05/2010', 6);
INSERT INTO valoracions VALUES (1446, 90, '24/06/2002', 6);
INSERT INTO valoracions VALUES (1446, 85, '17/07/2009', 3);
INSERT INTO valoracions VALUES (1448, 52, '25/10/2009', 9);
INSERT INTO valoracions VALUES (1449, 33, '07/10/2001', 7);
INSERT INTO valoracions VALUES (1449, 92, '20/09/2008', 3);
INSERT INTO valoracions VALUES (1449, 93, '16/06/2006', 6);
INSERT INTO valoracions VALUES (1449, 49, '21/07/2001', 6);
INSERT INTO valoracions VALUES (1449, 42, '25/07/2002', 7);
INSERT INTO valoracions VALUES (1449, 73, '23/01/2005', 10);
INSERT INTO valoracions VALUES (1450, 73, '18/09/2009', 8);
INSERT INTO valoracions VALUES (1450, 82, '30/10/2005', 7);
INSERT INTO valoracions VALUES (1450, 88, '05/11/2005', 5);
INSERT INTO valoracions VALUES (1451, 14, '02/12/2009', 8);
INSERT INTO valoracions VALUES (1451, 9, '05/12/2009', 6);
INSERT INTO valoracions VALUES (1451, 50, '18/01/2010', 4);
INSERT INTO valoracions VALUES (1453, 83, '06/01/2004', 1);
INSERT INTO valoracions VALUES (1453, 63, '12/03/2005', 5);
INSERT INTO valoracions VALUES (1453, 97, '21/12/2002', 7);
INSERT INTO valoracions VALUES (1453, 56, '19/08/2001', 7);
INSERT INTO valoracions VALUES (1453, 75, '09/12/2003', 4);
INSERT INTO valoracions VALUES (1453, 93, '30/07/2001', 2);
INSERT INTO valoracions VALUES (1453, 114, '11/10/2004', 4);
INSERT INTO valoracions VALUES (1454, 66, '01/04/2008', 3);
INSERT INTO valoracions VALUES (1454, 3, '29/07/2001', 6);
INSERT INTO valoracions VALUES (1454, 63, '15/03/2003', 5);
INSERT INTO valoracions VALUES (1454, 64, '10/11/2002', 9);
INSERT INTO valoracions VALUES (1454, 103, '04/02/2009', 7);
INSERT INTO valoracions VALUES (1455, 68, '07/04/2006', 4);
INSERT INTO valoracions VALUES (1455, 100, '03/01/2003', 7);
INSERT INTO valoracions VALUES (1455, 88, '19/08/2009', 9);
INSERT INTO valoracions VALUES (1455, 65, '12/05/2010', 8);
INSERT INTO valoracions VALUES (1456, 9, '17/04/2002', 5);
INSERT INTO valoracions VALUES (1456, 44, '21/07/2009', 7);
INSERT INTO valoracions VALUES (1456, 104, '09/10/2007', 4);
INSERT INTO valoracions VALUES (1456, 74, '28/08/2005', 3);
INSERT INTO valoracions VALUES (1456, 58, '06/08/2002', 10);
INSERT INTO valoracions VALUES (1456, 114, '12/02/2009', 5);
INSERT INTO valoracions VALUES (1456, 91, '27/01/2006', 6);
INSERT INTO valoracions VALUES (1456, 81, '01/07/2003', 6);
INSERT INTO valoracions VALUES (1457, 42, '04/05/2008', 8);
INSERT INTO valoracions VALUES (1457, 79, '15/06/2005', 7);
INSERT INTO valoracions VALUES (1457, 98, '19/07/2004', 8);
INSERT INTO valoracions VALUES (1458, 43, '14/05/2007', 5);
INSERT INTO valoracions VALUES (1458, 39, '23/01/2002', 7);
INSERT INTO valoracions VALUES (1458, 99, '08/03/2010', 5);
INSERT INTO valoracions VALUES (1458, 22, '10/12/2003', 6);
INSERT INTO valoracions VALUES (1458, 114, '24/10/2003', 3);
INSERT INTO valoracions VALUES (1459, 8, '01/08/2004', 10);
INSERT INTO valoracions VALUES (1459, 61, '08/09/2010', 9);
INSERT INTO valoracions VALUES (1459, 36, '13/07/2003', 5);
INSERT INTO valoracions VALUES (1459, 4, '22/09/2001', 7);
INSERT INTO valoracions VALUES (1460, 101, '15/02/2004', 9);
INSERT INTO valoracions VALUES (1460, 36, '24/10/2002', 9);
INSERT INTO valoracions VALUES (1460, 58, '16/04/2007', 8);
INSERT INTO valoracions VALUES (1460, 68, '15/09/2007', 9);
INSERT INTO valoracions VALUES (1461, 70, '28/11/2006', 4);
INSERT INTO valoracions VALUES (1461, 115, '23/11/2001', 0);
INSERT INTO valoracions VALUES (1463, 47, '19/07/2005', 10);
INSERT INTO valoracions VALUES (1463, 17, '17/10/2010', 5);
INSERT INTO valoracions VALUES (1463, 83, '30/01/2009', 8);
INSERT INTO valoracions VALUES (1463, 102, '30/08/2010', 10);
INSERT INTO valoracions VALUES (1463, 54, '08/06/2003', 5);
INSERT INTO valoracions VALUES (1463, 83, '17/02/2009', 2);
INSERT INTO valoracions VALUES (1463, 79, '13/02/2004', 4);
INSERT INTO valoracions VALUES (1463, 73, '21/10/2002', 9);
INSERT INTO valoracions VALUES (1463, 11, '15/02/2010', 6);
INSERT INTO valoracions VALUES (1464, 106, '25/10/2001', 2);
INSERT INTO valoracions VALUES (1464, 15, '07/01/2009', 8);
INSERT INTO valoracions VALUES (1464, 42, '13/01/2004', 9);
INSERT INTO valoracions VALUES (1465, 94, '01/03/2009', 7);
INSERT INTO valoracions VALUES (1465, 67, '12/06/2007', 8);
INSERT INTO valoracions VALUES (1465, 1, '28/04/2005', 5);
INSERT INTO valoracions VALUES (1466, 11, '03/01/2009', 6);
INSERT INTO valoracions VALUES (1466, 7, '01/04/2003', 6);
INSERT INTO valoracions VALUES (1466, 72, '14/03/2008', 10);
INSERT INTO valoracions VALUES (1466, 66, '10/10/2009', 9);
INSERT INTO valoracions VALUES (1466, 91, '28/09/2008', 8);
INSERT INTO valoracions VALUES (1466, 30, '27/07/2003', 8);
INSERT INTO valoracions VALUES (1466, 55, '05/07/2008', 5);
INSERT INTO valoracions VALUES (1467, 69, '01/04/2005', 8);
INSERT INTO valoracions VALUES (1467, 70, '25/08/2001', 6);
INSERT INTO valoracions VALUES (1467, 88, '22/08/2007', 2);
INSERT INTO valoracions VALUES (1467, 7, '17/05/2010', 6);
INSERT INTO valoracions VALUES (1467, 93, '15/03/2002', 6);
INSERT INTO valoracions VALUES (1468, 57, '25/10/2010', 3);
INSERT INTO valoracions VALUES (1468, 16, '14/03/2005', 9);
INSERT INTO valoracions VALUES (1468, 33, '27/09/2006', 4);
INSERT INTO valoracions VALUES (1468, 20, '27/08/2009', 10);
INSERT INTO valoracions VALUES (1468, 49, '03/03/2006', 4);
INSERT INTO valoracions VALUES (1468, 32, '08/10/2003', 4);
INSERT INTO valoracions VALUES (1469, 84, '16/04/2008', 1);
INSERT INTO valoracions VALUES (1469, 97, '20/03/2007', 5);
INSERT INTO valoracions VALUES (1469, 49, '01/12/2008', 6);
INSERT INTO valoracions VALUES (1470, 87, '27/02/2008', 10);
INSERT INTO valoracions VALUES (1470, 12, '23/12/2006', 5);
INSERT INTO valoracions VALUES (1470, 23, '11/08/2006', 4);
INSERT INTO valoracions VALUES (1470, 15, '03/04/2006', 6);
INSERT INTO valoracions VALUES (1471, 91, '12/12/2004', 6);
INSERT INTO valoracions VALUES (1472, 30, '31/08/2006', 9);
INSERT INTO valoracions VALUES (1472, 65, '08/02/2003', 4);
INSERT INTO valoracions VALUES (1472, 33, '18/02/2010', 8);
INSERT INTO valoracions VALUES (1472, 81, '09/11/2006', 2);
INSERT INTO valoracions VALUES (1473, 24, '08/07/2004', 6);
INSERT INTO valoracions VALUES (1473, 13, '01/07/2010', 10);
INSERT INTO valoracions VALUES (1473, 63, '12/08/2009', 6);
INSERT INTO valoracions VALUES (1473, 73, '09/12/2008', 2);
INSERT INTO valoracions VALUES (1474, 1, '17/06/2009', 8);
INSERT INTO valoracions VALUES (1474, 55, '13/05/2009', 5);
INSERT INTO valoracions VALUES (1475, 86, '09/12/2008', 4);
INSERT INTO valoracions VALUES (1475, 90, '16/08/2010', 9);
INSERT INTO valoracions VALUES (1475, 8, '23/11/2006', 7);
INSERT INTO valoracions VALUES (1476, 20, '17/04/2008', 6);
INSERT INTO valoracions VALUES (1476, 78, '01/03/2005', 7);
INSERT INTO valoracions VALUES (1476, 2, '23/05/2008', 8);
INSERT INTO valoracions VALUES (1476, 35, '31/08/2009', 7);
INSERT INTO valoracions VALUES (1477, 59, '30/06/2009', 7);
INSERT INTO valoracions VALUES (1477, 59, '04/04/2009', 6);
INSERT INTO valoracions VALUES (1477, 101, '18/06/2004', 10);
INSERT INTO valoracions VALUES (1477, 70, '16/07/2003', 3);
INSERT INTO valoracions VALUES (1477, 13, '12/12/2004', 6);
INSERT INTO valoracions VALUES (1478, 48, '30/10/2006', 9);
INSERT INTO valoracions VALUES (1478, 94, '17/05/2004', 6);
INSERT INTO valoracions VALUES (1478, 13, '17/04/2007', 5);
INSERT INTO valoracions VALUES (1478, 92, '06/11/2002', 5);
INSERT INTO valoracions VALUES (1479, 54, '25/08/2009', 5);
INSERT INTO valoracions VALUES (1479, 105, '24/10/2009', 3);
INSERT INTO valoracions VALUES (1479, 11, '17/12/2003', 6);
INSERT INTO valoracions VALUES (1479, 32, '27/05/2008', 9);
INSERT INTO valoracions VALUES (1480, 47, '08/04/2002', 5);
INSERT INTO valoracions VALUES (1480, 106, '29/05/2007', 0);
INSERT INTO valoracions VALUES (1480, 35, '21/03/2003', 4);
INSERT INTO valoracions VALUES (1481, 5, '25/06/2009', 7);
INSERT INTO valoracions VALUES (1481, 71, '09/06/2002', 9);
INSERT INTO valoracions VALUES (1481, 90, '29/06/2006', 10);
INSERT INTO valoracions VALUES (1481, 86, '05/09/2006', 6);
INSERT INTO valoracions VALUES (1481, 81, '27/06/2008', 2);
INSERT INTO valoracions VALUES (1481, 32, '28/04/2002', 10);
INSERT INTO valoracions VALUES (1481, 38, '29/12/2007', 5);
INSERT INTO valoracions VALUES (1481, 92, '15/10/2008', 7);
INSERT INTO valoracions VALUES (1481, 65, '24/06/2007', 5);
INSERT INTO valoracions VALUES (1482, 12, '16/04/2009', 9);
INSERT INTO valoracions VALUES (1482, 20, '21/12/2006', 9);
INSERT INTO valoracions VALUES (1483, 41, '07/08/2001', 6);
INSERT INTO valoracions VALUES (1483, 104, '29/08/2003', 3);
INSERT INTO valoracions VALUES (1483, 54, '02/05/2008', 4);
INSERT INTO valoracions VALUES (1483, 107, '01/12/2006', 10);
INSERT INTO valoracions VALUES (1483, 7, '19/04/2004', 5);
INSERT INTO valoracions VALUES (1483, 65, '26/10/2008', 5);
INSERT INTO valoracions VALUES (1484, 5, '09/12/2006', 9);
INSERT INTO valoracions VALUES (1485, 116, '16/09/2003', 6);
INSERT INTO valoracions VALUES (1485, 114, '01/04/2002', 6);
INSERT INTO valoracions VALUES (1486, 63, '02/04/2005', 5);
INSERT INTO valoracions VALUES (1486, 62, '18/09/2006', 4);
INSERT INTO valoracions VALUES (1486, 71, '23/12/2005', 3);
INSERT INTO valoracions VALUES (1486, 43, '21/05/2006', 8);
INSERT INTO valoracions VALUES (1486, 52, '18/11/2001', 5);
INSERT INTO valoracions VALUES (1487, 61, '06/05/2001', 7);
INSERT INTO valoracions VALUES (1487, 67, '22/12/2002', 10);
INSERT INTO valoracions VALUES (1487, 64, '18/12/2009', 8);
INSERT INTO valoracions VALUES (1487, 15, '01/07/2006', 7);
INSERT INTO valoracions VALUES (1487, 79, '19/06/2001', 7);
INSERT INTO valoracions VALUES (1487, 68, '30/09/2010', 4);
INSERT INTO valoracions VALUES (1488, 27, '28/10/2006', 8);
INSERT INTO valoracions VALUES (1488, 60, '19/02/2002', 6);
INSERT INTO valoracions VALUES (1488, 101, '21/09/2006', 8);
INSERT INTO valoracions VALUES (1489, 50, '05/12/2001', 7);
INSERT INTO valoracions VALUES (1489, 116, '18/08/2010', 6);
INSERT INTO valoracions VALUES (1489, 76, '10/03/2008', 8);
INSERT INTO valoracions VALUES (1489, 76, '01/02/2010', 6);
INSERT INTO valoracions VALUES (1489, 111, '28/07/2004', 3);
INSERT INTO valoracions VALUES (1490, 36, '27/07/2005', 7);
INSERT INTO valoracions VALUES (1490, 92, '27/09/2008', 2);
INSERT INTO valoracions VALUES (1490, 89, '15/09/2008', 3);
INSERT INTO valoracions VALUES (1490, 81, '04/12/2008', 9);
INSERT INTO valoracions VALUES (1490, 116, '18/02/2002', 3);
INSERT INTO valoracions VALUES (1491, 21, '06/05/2008', 9);
INSERT INTO valoracions VALUES (1491, 106, '03/07/2006', 6);
INSERT INTO valoracions VALUES (1492, 110, '26/09/2006', 7);
INSERT INTO valoracions VALUES (1492, 69, '16/09/2002', 10);
INSERT INTO valoracions VALUES (1492, 64, '31/05/2010', 2);
INSERT INTO valoracions VALUES (1492, 88, '13/10/2002', 4);
INSERT INTO valoracions VALUES (1492, 49, '21/09/2002', 6);
INSERT INTO valoracions VALUES (1492, 3, '09/12/2005', 5);
INSERT INTO valoracions VALUES (1492, 32, '11/06/2009', 9);
INSERT INTO valoracions VALUES (1492, 1, '11/09/2009', 9);
INSERT INTO valoracions VALUES (1492, 35, '19/08/2007', 9);
INSERT INTO valoracions VALUES (1493, 42, '03/07/2006', 9);
INSERT INTO valoracions VALUES (1493, 21, '15/03/2003', 9);
INSERT INTO valoracions VALUES (1493, 47, '23/03/2008', 5);
INSERT INTO valoracions VALUES (1493, 46, '20/04/2009', 4);
INSERT INTO valoracions VALUES (1493, 42, '21/09/2006', 9);
INSERT INTO valoracions VALUES (1493, 24, '16/04/2001', 5);
INSERT INTO valoracions VALUES (1494, 13, '23/04/2005', 7);
INSERT INTO valoracions VALUES (1494, 68, '24/08/2010', 4);
INSERT INTO valoracions VALUES (1494, 114, '20/01/2009', 7);
INSERT INTO valoracions VALUES (1494, 80, '21/11/2008', 4);
INSERT INTO valoracions VALUES (1495, 72, '29/09/2007', 4);
INSERT INTO valoracions VALUES (1495, 109, '16/04/2008', 1);
INSERT INTO valoracions VALUES (1495, 69, '18/09/2001', 6);
INSERT INTO valoracions VALUES (1495, 100, '03/11/2006', 3);
INSERT INTO valoracions VALUES (1496, 111, '05/11/2008', 9);
INSERT INTO valoracions VALUES (1496, 101, '04/05/2001', 5);
INSERT INTO valoracions VALUES (1496, 109, '22/06/2007', 5);
INSERT INTO valoracions VALUES (1496, 106, '11/10/2004', 4);
INSERT INTO valoracions VALUES (1497, 32, '21/10/2002', 7);
INSERT INTO valoracions VALUES (1497, 96, '18/11/2006', 5);
INSERT INTO valoracions VALUES (1497, 113, '03/01/2003', 3);
INSERT INTO valoracions VALUES (1497, 115, '13/05/2005', 5);
INSERT INTO valoracions VALUES (1497, 100, '03/04/2007', 4);
INSERT INTO valoracions VALUES (1498, 63, '21/02/2003', 8);
INSERT INTO valoracions VALUES (1500, 105, '11/10/2006', 1);
INSERT INTO valoracions VALUES (1500, 106, '26/11/2006', 10);
INSERT INTO valoracions VALUES (1500, 78, '05/08/2002', 4);
INSERT INTO valoracions VALUES (1501, 103, '19/04/2005', 3);
INSERT INTO valoracions VALUES (1501, 60, '13/12/2007', 7);
INSERT INTO valoracions VALUES (1501, 91, '07/02/2006', 3);
INSERT INTO valoracions VALUES (1501, 66, '08/06/2007', 9);
INSERT INTO valoracions VALUES (1502, 30, '22/08/2001', 9);
INSERT INTO valoracions VALUES (1503, 55, '14/05/2003', 7);
INSERT INTO valoracions VALUES (1503, 5, '05/04/2001', 8);
INSERT INTO valoracions VALUES (1503, 70, '24/09/2003', 5);
INSERT INTO valoracions VALUES (1503, 105, '25/11/2006', 10);
INSERT INTO valoracions VALUES (1503, 45, '09/04/2004', 3);
INSERT INTO valoracions VALUES (1504, 35, '26/03/2004', 5);
INSERT INTO valoracions VALUES (1504, 30, '30/08/2007', 7);
INSERT INTO valoracions VALUES (1504, 42, '20/08/2008', 8);
INSERT INTO valoracions VALUES (1504, 28, '24/01/2003', 9);
INSERT INTO valoracions VALUES (1504, 8, '06/01/2010', 9);
INSERT INTO valoracions VALUES (1504, 26, '25/07/2001', 4);
INSERT INTO valoracions VALUES (1504, 37, '03/07/2002', 10);
INSERT INTO valoracions VALUES (1504, 91, '28/10/2008', 4);
INSERT INTO valoracions VALUES (1505, 70, '01/08/2010', 4);
INSERT INTO valoracions VALUES (1505, 94, '31/12/2008', 6);
INSERT INTO valoracions VALUES (1505, 51, '09/04/2007', 5);
INSERT INTO valoracions VALUES (1505, 83, '06/10/2001', 5);
INSERT INTO valoracions VALUES (1505, 43, '06/08/2003', 5);
INSERT INTO valoracions VALUES (1505, 4, '23/04/2008', 6);
INSERT INTO valoracions VALUES (1505, 108, '03/11/2007', 2);
INSERT INTO valoracions VALUES (1505, 72, '18/07/2004', 8);
INSERT INTO valoracions VALUES (1506, 104, '12/01/2009', 3);
INSERT INTO valoracions VALUES (1507, 22, '23/12/2005', 4);
INSERT INTO valoracions VALUES (1507, 41, '12/07/2009', 7);
INSERT INTO valoracions VALUES (1507, 72, '04/12/2001', 5);
INSERT INTO valoracions VALUES (1508, 60, '10/02/2008', 4);
INSERT INTO valoracions VALUES (1508, 102, '20/10/2009', 7);
INSERT INTO valoracions VALUES (1508, 95, '02/03/2008', 3);
INSERT INTO valoracions VALUES (1509, 65, '24/06/2006', 8);
INSERT INTO valoracions VALUES (1509, 40, '23/03/2003', 5);
INSERT INTO valoracions VALUES (1509, 93, '01/01/2009', 4);
INSERT INTO valoracions VALUES (1509, 114, '21/01/2005', 9);
INSERT INTO valoracions VALUES (1509, 13, '17/09/2003', 5);
INSERT INTO valoracions VALUES (1509, 89, '23/10/2005', 9);
INSERT INTO valoracions VALUES (1509, 102, '06/01/2004', 3);
INSERT INTO valoracions VALUES (1509, 36, '10/12/2009', 9);
INSERT INTO valoracions VALUES (1509, 14, '27/06/2007', 7);
INSERT INTO valoracions VALUES (1510, 48, '27/07/2009', 8);
INSERT INTO valoracions VALUES (1510, 72, '27/04/2002', 4);
INSERT INTO valoracions VALUES (1510, 99, '18/08/2006', 4);
INSERT INTO valoracions VALUES (1510, 106, '18/01/2006', 9);
INSERT INTO valoracions VALUES (1510, 57, '27/04/2002', 7);
INSERT INTO valoracions VALUES (1510, 84, '18/03/2005', 7);
INSERT INTO valoracions VALUES (1510, 101, '17/07/2002', 4);
INSERT INTO valoracions VALUES (1511, 114, '02/03/2008', 0);
INSERT INTO valoracions VALUES (1511, 10, '18/07/2007', 5);
INSERT INTO valoracions VALUES (1511, 33, '02/12/2001', 10);
INSERT INTO valoracions VALUES (1511, 9, '29/08/2005', 7);
INSERT INTO valoracions VALUES (1511, 78, '19/01/2007', 8);
INSERT INTO valoracions VALUES (1511, 26, '26/11/2008', 4);
INSERT INTO valoracions VALUES (1512, 16, '16/06/2004', 4);
INSERT INTO valoracions VALUES (1512, 13, '24/02/2008', 5);
INSERT INTO valoracions VALUES (1512, 45, '28/05/2007', 5);
INSERT INTO valoracions VALUES (1512, 25, '27/11/2007', 7);
INSERT INTO valoracions VALUES (1512, 50, '14/09/2007', 4);
INSERT INTO valoracions VALUES (1512, 10, '01/08/2009', 6);
INSERT INTO valoracions VALUES (1512, 71, '18/12/2008', 9);
INSERT INTO valoracions VALUES (1512, 85, '22/03/2006', 9);
INSERT INTO valoracions VALUES (1513, 71, '22/02/2010', 10);
INSERT INTO valoracions VALUES (1513, 68, '07/07/2010', 2);
INSERT INTO valoracions VALUES (1514, 59, '26/07/2009', 6);
INSERT INTO valoracions VALUES (1514, 51, '06/02/2008', 9);
INSERT INTO valoracions VALUES (1514, 68, '16/03/2002', 2);
INSERT INTO valoracions VALUES (1514, 13, '19/08/2009', 6);
INSERT INTO valoracions VALUES (1515, 61, '19/04/2003', 8);
INSERT INTO valoracions VALUES (1515, 77, '12/06/2001', 8);
INSERT INTO valoracions VALUES (1515, 100, '18/07/2008', 4);
INSERT INTO valoracions VALUES (1515, 108, '15/05/2001', 1);
INSERT INTO valoracions VALUES (1515, 5, '14/10/2005', 7);
INSERT INTO valoracions VALUES (1515, 113, '02/01/2004', 1);
INSERT INTO valoracions VALUES (1515, 62, '20/10/2004', 2);
INSERT INTO valoracions VALUES (1515, 48, '14/08/2007', 7);
INSERT INTO valoracions VALUES (1515, 81, '12/02/2003', 5);
INSERT INTO valoracions VALUES (1515, 83, '02/08/2003', 6);
INSERT INTO valoracions VALUES (1516, 32, '30/04/2007', 5);
INSERT INTO valoracions VALUES (1516, 5, '16/02/2009', 9);
INSERT INTO valoracions VALUES (1516, 71, '20/09/2002', 3);
INSERT INTO valoracions VALUES (1516, 46, '05/09/2006', 4);
INSERT INTO valoracions VALUES (1516, 45, '14/10/2003', 9);
INSERT INTO valoracions VALUES (1517, 94, '17/10/2007', 10);
INSERT INTO valoracions VALUES (1517, 9, '26/07/2010', 10);
INSERT INTO valoracions VALUES (1517, 17, '11/02/2008', 4);
INSERT INTO valoracions VALUES (1518, 44, '07/02/2004', 6);
INSERT INTO valoracions VALUES (1518, 109, '09/04/2001', 4);
INSERT INTO valoracions VALUES (1518, 14, '24/05/2009', 7);
INSERT INTO valoracions VALUES (1518, 23, '30/11/2004', 4);
INSERT INTO valoracions VALUES (1518, 105, '01/07/2008', 10);
INSERT INTO valoracions VALUES (1519, 75, '20/11/2001', 4);
INSERT INTO valoracions VALUES (1519, 116, '28/05/2007', 9);
INSERT INTO valoracions VALUES (1519, 25, '25/08/2006', 9);
INSERT INTO valoracions VALUES (1520, 55, '31/07/2009', 9);
INSERT INTO valoracions VALUES (1520, 80, '23/05/2006', 3);
INSERT INTO valoracions VALUES (1520, 21, '14/04/2007', 9);
INSERT INTO valoracions VALUES (1520, 45, '17/10/2003', 6);
INSERT INTO valoracions VALUES (1520, 11, '24/10/2004', 8);
INSERT INTO valoracions VALUES (1521, 56, '10/03/2010', 8);
INSERT INTO valoracions VALUES (1521, 81, '29/06/2002', 9);
INSERT INTO valoracions VALUES (1522, 69, '10/09/2005', 9);
INSERT INTO valoracions VALUES (1523, 62, '06/06/2008', 5);
INSERT INTO valoracions VALUES (1523, 109, '21/06/2005', 6);
INSERT INTO valoracions VALUES (1524, 26, '10/07/2001', 7);
INSERT INTO valoracions VALUES (1524, 95, '21/07/2004', 6);
INSERT INTO valoracions VALUES (1524, 24, '19/05/2009', 6);
INSERT INTO valoracions VALUES (1524, 42, '01/01/2004', 6);
INSERT INTO valoracions VALUES (1525, 12, '07/06/2009', 6);
INSERT INTO valoracions VALUES (1525, 47, '28/07/2001', 7);
INSERT INTO valoracions VALUES (1525, 30, '26/03/2009', 5);
INSERT INTO valoracions VALUES (1526, 6, '11/09/2006', 9);
INSERT INTO valoracions VALUES (1526, 59, '02/10/2007', 8);
INSERT INTO valoracions VALUES (1527, 69, '01/06/2003', 8);
INSERT INTO valoracions VALUES (1527, 81, '04/06/2006', 2);
INSERT INTO valoracions VALUES (1527, 101, '06/06/2006', 5);
INSERT INTO valoracions VALUES (1527, 108, '08/01/2004', 8);
INSERT INTO valoracions VALUES (1528, 112, '19/05/2010', 1);
INSERT INTO valoracions VALUES (1528, 19, '25/06/2002', 5);
INSERT INTO valoracions VALUES (1528, 53, '12/10/2001', 9);
INSERT INTO valoracions VALUES (1528, 106, '08/12/2001', 10);
INSERT INTO valoracions VALUES (1528, 96, '02/09/2004', 4);
INSERT INTO valoracions VALUES (1529, 40, '13/10/2005', 7);
INSERT INTO valoracions VALUES (1529, 102, '03/05/2005', 2);
INSERT INTO valoracions VALUES (1529, 3, '23/11/2006', 5);
INSERT INTO valoracions VALUES (1529, 46, '18/01/2003', 6);
INSERT INTO valoracions VALUES (1529, 50, '23/04/2008', 6);
INSERT INTO valoracions VALUES (1529, 43, '08/01/2003', 8);
INSERT INTO valoracions VALUES (1530, 3, '16/02/2009', 8);
INSERT INTO valoracions VALUES (1531, 47, '16/04/2010', 8);
INSERT INTO valoracions VALUES (1531, 45, '07/06/2002', 8);
INSERT INTO valoracions VALUES (1533, 111, '17/07/2009', 9);
INSERT INTO valoracions VALUES (1533, 64, '04/06/2006', 10);
INSERT INTO valoracions VALUES (1533, 90, '18/12/2005', 6);
INSERT INTO valoracions VALUES (1533, 46, '10/09/2006', 6);
INSERT INTO valoracions VALUES (1533, 53, '31/05/2002', 9);
INSERT INTO valoracions VALUES (1534, 47, '25/10/2006', 3);
INSERT INTO valoracions VALUES (1534, 116, '04/03/2002', 3);
INSERT INTO valoracions VALUES (1535, 27, '03/09/2002', 6);
INSERT INTO valoracions VALUES (1535, 47, '12/07/2009', 6);
INSERT INTO valoracions VALUES (1536, 63, '10/04/2007', 4);
INSERT INTO valoracions VALUES (1536, 42, '11/06/2005', 7);
INSERT INTO valoracions VALUES (1536, 104, '08/06/2002', 1);
INSERT INTO valoracions VALUES (1536, 20, '05/11/2001', 7);
INSERT INTO valoracions VALUES (1536, 112, '03/10/2009', 7);
INSERT INTO valoracions VALUES (1536, 57, '12/08/2002', 9);
INSERT INTO valoracions VALUES (1537, 29, '23/09/2008', 8);
INSERT INTO valoracions VALUES (1537, 97, '12/04/2007', 3);
INSERT INTO valoracions VALUES (1537, 89, '25/06/2007', 6);
INSERT INTO valoracions VALUES (1537, 116, '03/06/2004', 3);
INSERT INTO valoracions VALUES (1537, 99, '03/12/2007', 9);
INSERT INTO valoracions VALUES (1537, 66, '23/03/2009', 5);
INSERT INTO valoracions VALUES (1538, 41, '15/01/2009', 3);
INSERT INTO valoracions VALUES (1538, 9, '04/06/2001', 9);
INSERT INTO valoracions VALUES (1538, 73, '14/08/2004', 6);
INSERT INTO valoracions VALUES (1539, 5, '14/04/2008', 6);
INSERT INTO valoracions VALUES (1539, 1, '27/12/2009', 8);
INSERT INTO valoracions VALUES (1539, 66, '29/12/2005', 8);
INSERT INTO valoracions VALUES (1539, 70, '11/09/2009', 3);
INSERT INTO valoracions VALUES (1540, 39, '20/08/2002', 10);
INSERT INTO valoracions VALUES (1540, 54, '28/01/2010', 9);
INSERT INTO valoracions VALUES (1540, 52, '16/03/2008', 4);
INSERT INTO valoracions VALUES (1540, 18, '13/08/2003', 7);
INSERT INTO valoracions VALUES (1540, 107, '17/06/2003', 2);
INSERT INTO valoracions VALUES (1541, 98, '24/10/2009', 8);
INSERT INTO valoracions VALUES (1541, 79, '08/04/2002', 6);
INSERT INTO valoracions VALUES (1541, 26, '04/06/2010', 5);
INSERT INTO valoracions VALUES (1542, 110, '14/11/2005', 8);
INSERT INTO valoracions VALUES (1542, 45, '09/11/2005', 5);
INSERT INTO valoracions VALUES (1542, 10, '21/12/2004', 6);
INSERT INTO valoracions VALUES (1543, 49, '05/09/2010', 4);
INSERT INTO valoracions VALUES (1544, 94, '05/02/2007', 8);
INSERT INTO valoracions VALUES (1544, 18, '23/05/2002', 7);
INSERT INTO valoracions VALUES (1544, 17, '24/11/2009', 8);
INSERT INTO valoracions VALUES (1544, 24, '06/03/2006', 6);
INSERT INTO valoracions VALUES (1544, 99, '26/02/2003', 5);
INSERT INTO valoracions VALUES (1545, 5, '03/03/2005', 6);
INSERT INTO valoracions VALUES (1545, 94, '23/04/2006', 2);
INSERT INTO valoracions VALUES (1545, 14, '30/04/2001', 6);
INSERT INTO valoracions VALUES (1545, 116, '19/02/2003', 2);
INSERT INTO valoracions VALUES (1545, 86, '22/08/2009', 10);
INSERT INTO valoracions VALUES (1546, 111, '23/04/2010', 7);
INSERT INTO valoracions VALUES (1546, 109, '21/12/2005', 0);
INSERT INTO valoracions VALUES (1546, 115, '28/11/2003', 5);
INSERT INTO valoracions VALUES (1546, 74, '27/10/2004', 6);
INSERT INTO valoracions VALUES (1546, 112, '16/02/2009', 9);
INSERT INTO valoracions VALUES (1546, 72, '08/12/2008', 4);
INSERT INTO valoracions VALUES (1546, 104, '12/09/2008', 5);
INSERT INTO valoracions VALUES (1546, 97, '26/03/2010', 5);
INSERT INTO valoracions VALUES (1547, 13, '20/11/2005', 7);
INSERT INTO valoracions VALUES (1547, 67, '12/11/2007', 8);
INSERT INTO valoracions VALUES (1547, 59, '11/12/2006', 8);
INSERT INTO valoracions VALUES (1547, 114, '26/04/2010', 2);
INSERT INTO valoracions VALUES (1547, 39, '26/11/2006', 7);
INSERT INTO valoracions VALUES (1548, 8, '15/10/2007', 6);
INSERT INTO valoracions VALUES (1548, 14, '31/07/2006', 6);
INSERT INTO valoracions VALUES (1549, 112, '06/12/2004', 6);
INSERT INTO valoracions VALUES (1549, 110, '12/11/2005', 9);
INSERT INTO valoracions VALUES (1549, 91, '02/01/2006', 10);
INSERT INTO valoracions VALUES (1549, 10, '05/10/2004', 6);
INSERT INTO valoracions VALUES (1549, 91, '16/07/2008', 5);
INSERT INTO valoracions VALUES (1549, 42, '19/05/2009', 9);
INSERT INTO valoracions VALUES (1550, 87, '22/01/2010', 6);
INSERT INTO valoracions VALUES (1550, 32, '20/03/2009', 8);
INSERT INTO valoracions VALUES (1550, 35, '02/04/2004', 5);
INSERT INTO valoracions VALUES (1550, 9, '26/05/2003', 6);
INSERT INTO valoracions VALUES (1551, 71, '27/09/2008', 6);
INSERT INTO valoracions VALUES (1552, 3, '04/05/2006', 9);
INSERT INTO valoracions VALUES (1552, 25, '23/09/2008', 7);
INSERT INTO valoracions VALUES (1552, 97, '28/06/2008', 3);
INSERT INTO valoracions VALUES (1552, 107, '19/05/2009', 4);
INSERT INTO valoracions VALUES (1552, 28, '14/08/2001', 7);
INSERT INTO valoracions VALUES (1552, 97, '30/11/2007', 5);
INSERT INTO valoracions VALUES (1553, 24, '31/01/2004', 6);
INSERT INTO valoracions VALUES (1553, 56, '24/12/2002', 10);
INSERT INTO valoracions VALUES (1553, 73, '30/08/2001', 4);
INSERT INTO valoracions VALUES (1553, 48, '16/12/2007', 8);
INSERT INTO valoracions VALUES (1553, 83, '22/05/2003', 7);
INSERT INTO valoracions VALUES (1554, 67, '16/06/2006', 3);
INSERT INTO valoracions VALUES (1554, 31, '06/07/2008', 4);
INSERT INTO valoracions VALUES (1555, 43, '16/09/2003', 9);
INSERT INTO valoracions VALUES (1555, 47, '12/08/2004', 4);
INSERT INTO valoracions VALUES (1555, 113, '14/02/2004', 8);
INSERT INTO valoracions VALUES (1555, 96, '18/09/2002', 4);
INSERT INTO valoracions VALUES (1555, 91, '29/08/2004', 2);
INSERT INTO valoracions VALUES (1556, 9, '22/10/2009', 7);
INSERT INTO valoracions VALUES (1556, 54, '17/08/2002', 7);
INSERT INTO valoracions VALUES (1556, 112, '10/06/2008', 2);
INSERT INTO valoracions VALUES (1556, 28, '22/08/2006', 6);
INSERT INTO valoracions VALUES (1557, 99, '26/08/2009', 5);
INSERT INTO valoracions VALUES (1557, 14, '08/03/2006', 8);
INSERT INTO valoracions VALUES (1557, 54, '28/11/2009', 3);
INSERT INTO valoracions VALUES (1557, 105, '25/11/2007', 10);
INSERT INTO valoracions VALUES (1557, 115, '05/01/2003', 8);
INSERT INTO valoracions VALUES (1557, 98, '02/09/2004', 6);
INSERT INTO valoracions VALUES (1557, 54, '02/12/2004', 9);
INSERT INTO valoracions VALUES (1558, 26, '02/06/2004', 7);
INSERT INTO valoracions VALUES (1558, 39, '07/04/2010', 7);
INSERT INTO valoracions VALUES (1558, 98, '04/08/2006', 9);
INSERT INTO valoracions VALUES (1558, 44, '19/10/2001', 7);
INSERT INTO valoracions VALUES (1558, 29, '11/08/2010', 5);
INSERT INTO valoracions VALUES (1558, 17, '17/12/2006', 5);
INSERT INTO valoracions VALUES (1558, 22, '10/09/2007', 5);
INSERT INTO valoracions VALUES (1558, 80, '22/08/2003', 4);
INSERT INTO valoracions VALUES (1559, 1, '03/01/2002', 10);
INSERT INTO valoracions VALUES (1559, 105, '06/02/2002', 5);
INSERT INTO valoracions VALUES (1559, 112, '05/08/2001', 2);
INSERT INTO valoracions VALUES (1559, 57, '20/10/2007', 7);
INSERT INTO valoracions VALUES (1559, 60, '28/11/2002', 4);
INSERT INTO valoracions VALUES (1560, 55, '05/05/2006', 3);
INSERT INTO valoracions VALUES (1560, 3, '06/02/2009', 6);
INSERT INTO valoracions VALUES (1560, 92, '02/03/2005', 8);
INSERT INTO valoracions VALUES (1560, 32, '05/08/2001', 9);
INSERT INTO valoracions VALUES (1561, 56, '28/11/2002', 9);
INSERT INTO valoracions VALUES (1561, 2, '16/06/2010', 6);
INSERT INTO valoracions VALUES (1561, 49, '25/06/2003', 7);
INSERT INTO valoracions VALUES (1561, 76, '31/08/2002', 5);
INSERT INTO valoracions VALUES (1562, 48, '25/02/2009', 4);
INSERT INTO valoracions VALUES (1562, 114, '10/03/2007', 8);
INSERT INTO valoracions VALUES (1562, 31, '28/09/2007', 5);
INSERT INTO valoracions VALUES (1562, 46, '04/02/2010', 6);
INSERT INTO valoracions VALUES (1562, 98, '14/11/2008', 4);
INSERT INTO valoracions VALUES (1562, 42, '01/10/2001', 5);
INSERT INTO valoracions VALUES (1562, 110, '16/03/2005', 6);
INSERT INTO valoracions VALUES (1563, 107, '29/10/2005', 9);
INSERT INTO valoracions VALUES (1563, 62, '12/12/2001', 5);
INSERT INTO valoracions VALUES (1563, 67, '03/02/2009', 4);
INSERT INTO valoracions VALUES (1563, 68, '31/01/2008', 4);
INSERT INTO valoracions VALUES (1563, 4, '22/04/2010', 6);
INSERT INTO valoracions VALUES (1563, 51, '05/01/2003', 9);
INSERT INTO valoracions VALUES (1564, 13, '05/11/2005', 8);
INSERT INTO valoracions VALUES (1564, 90, '14/04/2009', 9);
INSERT INTO valoracions VALUES (1564, 88, '31/05/2009', 7);
INSERT INTO valoracions VALUES (1564, 53, '13/09/2010', 9);
INSERT INTO valoracions VALUES (1565, 52, '04/09/2004', 6);
INSERT INTO valoracions VALUES (1565, 38, '05/10/2006', 6);
INSERT INTO valoracions VALUES (1565, 67, '20/10/2007', 5);
INSERT INTO valoracions VALUES (1565, 114, '08/09/2003', 1);
INSERT INTO valoracions VALUES (1565, 42, '12/10/2002', 9);
INSERT INTO valoracions VALUES (1566, 13, '06/11/2006', 9);
INSERT INTO valoracions VALUES (1566, 18, '17/12/2004', 5);
INSERT INTO valoracions VALUES (1566, 76, '24/10/2007', 7);
INSERT INTO valoracions VALUES (1566, 34, '02/09/2004', 10);
INSERT INTO valoracions VALUES (1567, 84, '12/01/2004', 10);
INSERT INTO valoracions VALUES (1567, 59, '06/12/2001', 6);
INSERT INTO valoracions VALUES (1567, 53, '23/10/2002', 4);
INSERT INTO valoracions VALUES (1567, 90, '17/01/2003', 1);
INSERT INTO valoracions VALUES (1568, 90, '20/01/2002', 9);
INSERT INTO valoracions VALUES (1568, 45, '28/12/2006', 5);
INSERT INTO valoracions VALUES (1568, 19, '18/12/2004', 5);
INSERT INTO valoracions VALUES (1568, 11, '02/06/2003', 9);
INSERT INTO valoracions VALUES (1568, 1, '02/11/2002', 8);
INSERT INTO valoracions VALUES (1568, 69, '19/04/2010', 4);
INSERT INTO valoracions VALUES (1568, 17, '04/08/2009', 7);
INSERT INTO valoracions VALUES (1568, 97, '14/03/2004', 5);
INSERT INTO valoracions VALUES (1569, 69, '16/02/2010', 5);
INSERT INTO valoracions VALUES (1569, 32, '01/08/2002', 6);
INSERT INTO valoracions VALUES (1569, 82, '06/04/2002', 5);
INSERT INTO valoracions VALUES (1570, 22, '21/06/2006', 5);
INSERT INTO valoracions VALUES (1570, 116, '09/02/2009', 1);
INSERT INTO valoracions VALUES (1570, 106, '15/06/2008', 4);
INSERT INTO valoracions VALUES (1570, 39, '30/08/2010', 7);
INSERT INTO valoracions VALUES (1570, 111, '07/04/2004', 6);
INSERT INTO valoracions VALUES (1570, 24, '24/10/2005', 8);
INSERT INTO valoracions VALUES (1570, 13, '18/10/2009', 6);
INSERT INTO valoracions VALUES (1571, 24, '17/02/2007', 6);
INSERT INTO valoracions VALUES (1571, 20, '30/04/2005', 6);
INSERT INTO valoracions VALUES (1572, 1, '22/11/2003', 8);
INSERT INTO valoracions VALUES (1572, 62, '20/08/2008', 5);
INSERT INTO valoracions VALUES (1572, 76, '06/08/2001', 5);
INSERT INTO valoracions VALUES (1572, 94, '31/01/2007', 9);
INSERT INTO valoracions VALUES (1572, 103, '06/07/2002', 2);
INSERT INTO valoracions VALUES (1572, 82, '04/10/2003', 8);
INSERT INTO valoracions VALUES (1573, 104, '06/02/2003', 7);
INSERT INTO valoracions VALUES (1573, 67, '19/03/2010', 3);
INSERT INTO valoracions VALUES (1573, 37, '21/01/2003', 9);
INSERT INTO valoracions VALUES (1573, 4, '07/09/2002', 7);
INSERT INTO valoracions VALUES (1573, 79, '26/02/2009', 6);
INSERT INTO valoracions VALUES (1574, 113, '16/10/2005', 7);
INSERT INTO valoracions VALUES (1574, 74, '16/01/2002', 3);
INSERT INTO valoracions VALUES (1575, 90, '21/12/2009', 9);
INSERT INTO valoracions VALUES (1575, 15, '07/04/2005', 5);
INSERT INTO valoracions VALUES (1576, 19, '29/11/2003', 8);
INSERT INTO valoracions VALUES (1576, 33, '01/12/2003', 4);
INSERT INTO valoracions VALUES (1576, 98, '22/01/2004', 5);
INSERT INTO valoracions VALUES (1576, 55, '19/01/2002', 5);
INSERT INTO valoracions VALUES (1576, 112, '20/12/2004', 6);
INSERT INTO valoracions VALUES (1576, 11, '09/02/2004', 6);
INSERT INTO valoracions VALUES (1577, 30, '30/06/2008', 6);
INSERT INTO valoracions VALUES (1577, 102, '18/07/2008', 8);
INSERT INTO valoracions VALUES (1577, 105, '01/07/2001', 6);
INSERT INTO valoracions VALUES (1577, 101, '26/11/2006', 7);
INSERT INTO valoracions VALUES (1577, 107, '07/05/2004', 7);
INSERT INTO valoracions VALUES (1578, 64, '10/12/2002', 6);
INSERT INTO valoracions VALUES (1578, 23, '13/09/2002', 8);
INSERT INTO valoracions VALUES (1578, 75, '10/08/2003', 2);
INSERT INTO valoracions VALUES (1578, 56, '05/06/2006', 9);
INSERT INTO valoracions VALUES (1579, 39, '13/08/2010', 5);
INSERT INTO valoracions VALUES (1579, 92, '01/11/2001', 6);
INSERT INTO valoracions VALUES (1579, 16, '10/12/2005', 5);
INSERT INTO valoracions VALUES (1579, 46, '27/07/2007', 4);
INSERT INTO valoracions VALUES (1579, 75, '22/08/2010', 3);
INSERT INTO valoracions VALUES (1580, 55, '20/09/2005', 7);
INSERT INTO valoracions VALUES (1580, 12, '30/12/2006', 6);
INSERT INTO valoracions VALUES (1580, 20, '19/03/2002', 7);
INSERT INTO valoracions VALUES (1580, 82, '02/09/2003', 8);
INSERT INTO valoracions VALUES (1580, 13, '14/04/2010', 8);
INSERT INTO valoracions VALUES (1581, 92, '14/12/2004', 4);
INSERT INTO valoracions VALUES (1581, 2, '22/03/2009', 7);
INSERT INTO valoracions VALUES (1581, 78, '09/01/2005', 3);
INSERT INTO valoracions VALUES (1581, 70, '18/07/2002', 8);
INSERT INTO valoracions VALUES (1581, 61, '21/08/2008', 4);
INSERT INTO valoracions VALUES (1581, 105, '04/07/2003', 7);
INSERT INTO valoracions VALUES (1583, 63, '15/11/2002', 9);
INSERT INTO valoracions VALUES (1583, 53, '13/01/2007', 6);
INSERT INTO valoracions VALUES (1583, 113, '28/02/2004', 3);
INSERT INTO valoracions VALUES (1583, 12, '07/06/2010', 9);
INSERT INTO valoracions VALUES (1584, 90, '05/06/2008', 2);
INSERT INTO valoracions VALUES (1584, 64, '29/07/2005', 5);
INSERT INTO valoracions VALUES (1584, 84, '18/09/2004', 3);
INSERT INTO valoracions VALUES (1584, 24, '11/06/2008', 5);
INSERT INTO valoracions VALUES (1585, 41, '22/07/2010', 5);
INSERT INTO valoracions VALUES (1585, 78, '13/04/2007', 8);
INSERT INTO valoracions VALUES (1585, 67, '31/01/2004', 3);
INSERT INTO valoracions VALUES (1586, 25, '23/07/2009', 9);
INSERT INTO valoracions VALUES (1586, 46, '03/09/2007', 6);
INSERT INTO valoracions VALUES (1586, 70, '05/01/2009', 8);
INSERT INTO valoracions VALUES (1586, 52, '09/10/2007', 4);
INSERT INTO valoracions VALUES (1587, 50, '09/10/2001', 5);
INSERT INTO valoracions VALUES (1587, 81, '20/10/2005', 3);
INSERT INTO valoracions VALUES (1588, 62, '12/01/2002', 4);
INSERT INTO valoracions VALUES (1588, 74, '07/08/2008', 8);
INSERT INTO valoracions VALUES (1588, 39, '24/07/2003', 3);
INSERT INTO valoracions VALUES (1588, 107, '28/05/2001', 8);
INSERT INTO valoracions VALUES (1588, 14, '12/03/2003', 7);
INSERT INTO valoracions VALUES (1589, 113, '09/04/2007', 6);
INSERT INTO valoracions VALUES (1589, 12, '20/06/2003', 8);
INSERT INTO valoracions VALUES (1589, 92, '16/12/2003', 9);
INSERT INTO valoracions VALUES (1590, 54, '08/03/2009', 9);
INSERT INTO valoracions VALUES (1591, 51, '27/09/2008', 9);
INSERT INTO valoracions VALUES (1591, 6, '23/02/2010', 10);
INSERT INTO valoracions VALUES (1591, 66, '12/12/2002', 5);
INSERT INTO valoracions VALUES (1592, 56, '11/01/2005', 9);
INSERT INTO valoracions VALUES (1592, 104, '12/06/2006', 9);
INSERT INTO valoracions VALUES (1592, 49, '06/09/2003', 4);
INSERT INTO valoracions VALUES (1593, 44, '24/07/2003', 3);
INSERT INTO valoracions VALUES (1593, 2, '19/10/2001', 7);
INSERT INTO valoracions VALUES (1593, 9, '29/09/2001', 9);
INSERT INTO valoracions VALUES (1594, 38, '19/08/2002', 3);
INSERT INTO valoracions VALUES (1594, 49, '17/02/2008', 4);
INSERT INTO valoracions VALUES (1595, 66, '08/12/2003', 4);
INSERT INTO valoracions VALUES (1595, 102, '09/07/2009', 4);
INSERT INTO valoracions VALUES (1595, 101, '14/12/2008', 7);
INSERT INTO valoracions VALUES (1595, 86, '12/11/2006', 2);
INSERT INTO valoracions VALUES (1596, 28, '07/03/2002', 6);
INSERT INTO valoracions VALUES (1596, 53, '08/05/2009', 6);
INSERT INTO valoracions VALUES (1597, 26, '09/02/2007', 10);
INSERT INTO valoracions VALUES (1597, 2, '27/05/2002', 9);
INSERT INTO valoracions VALUES (1597, 49, '14/02/2006', 6);
INSERT INTO valoracions VALUES (1597, 61, '26/05/2001', 10);
INSERT INTO valoracions VALUES (1597, 13, '28/07/2006', 9);
INSERT INTO valoracions VALUES (1598, 86, '18/11/2003', 4);
INSERT INTO valoracions VALUES (1598, 108, '08/03/2007', 4);
INSERT INTO valoracions VALUES (1598, 92, '22/12/2009', 5);
INSERT INTO valoracions VALUES (1598, 111, '06/01/2004', 5);
INSERT INTO valoracions VALUES (1599, 57, '24/06/2008', 7);
INSERT INTO valoracions VALUES (1599, 81, '13/02/2003', 7);
INSERT INTO valoracions VALUES (1599, 21, '31/10/2004', 5);
INSERT INTO valoracions VALUES (1600, 114, '07/10/2007', 10);
INSERT INTO valoracions VALUES (1600, 95, '05/05/2010', 3);
INSERT INTO valoracions VALUES (1600, 75, '03/01/2003', 6);
INSERT INTO valoracions VALUES (1601, 76, '01/12/2001', 6);
INSERT INTO valoracions VALUES (1601, 114, '03/02/2004', 5);
INSERT INTO valoracions VALUES (1601, 19, '24/10/2007', 8);
INSERT INTO valoracions VALUES (1601, 100, '15/10/2006', 6);
INSERT INTO valoracions VALUES (1601, 15, '15/11/2009', 8);
INSERT INTO valoracions VALUES (1601, 45, '23/10/2010', 5);
INSERT INTO valoracions VALUES (1602, 94, '20/01/2006', 7);
INSERT INTO valoracions VALUES (1602, 88, '15/09/2010', 9);
INSERT INTO valoracions VALUES (1602, 5, '07/01/2010', 7);
INSERT INTO valoracions VALUES (1603, 28, '01/11/2004', 9);
INSERT INTO valoracions VALUES (1603, 93, '16/10/2007', 4);
INSERT INTO valoracions VALUES (1603, 91, '10/12/2008', 7);
INSERT INTO valoracions VALUES (1603, 65, '08/02/2004', 2);
INSERT INTO valoracions VALUES (1603, 76, '24/03/2002', 7);
INSERT INTO valoracions VALUES (1603, 44, '04/06/2009', 5);
INSERT INTO valoracions VALUES (1604, 77, '04/07/2006', 9);
INSERT INTO valoracions VALUES (1604, 94, '28/10/2004', 8);
INSERT INTO valoracions VALUES (1605, 85, '10/09/2003', 6);
INSERT INTO valoracions VALUES (1605, 39, '17/08/2010', 7);
INSERT INTO valoracions VALUES (1605, 43, '08/05/2006', 10);
INSERT INTO valoracions VALUES (1605, 40, '26/06/2008', 5);
INSERT INTO valoracions VALUES (1605, 3, '12/05/2001', 7);
INSERT INTO valoracions VALUES (1605, 41, '02/03/2004', 6);
INSERT INTO valoracions VALUES (1605, 84, '22/04/2008', 1);
INSERT INTO valoracions VALUES (1606, 72, '02/12/2009', 4);
INSERT INTO valoracions VALUES (1606, 104, '12/01/2006', 5);
INSERT INTO valoracions VALUES (1606, 55, '22/03/2003', 9);
INSERT INTO valoracions VALUES (1606, 14, '10/01/2005', 6);
INSERT INTO valoracions VALUES (1606, 88, '20/02/2007', 5);
INSERT INTO valoracions VALUES (1607, 36, '11/02/2010', 5);
INSERT INTO valoracions VALUES (1607, 42, '11/02/2005', 4);
INSERT INTO valoracions VALUES (1607, 70, '29/10/2007', 4);
INSERT INTO valoracions VALUES (1607, 47, '06/12/2003', 6);
INSERT INTO valoracions VALUES (1607, 98, '19/04/2009', 6);
INSERT INTO valoracions VALUES (1608, 89, '22/06/2005', 10);
INSERT INTO valoracions VALUES (1608, 107, '16/03/2008', 1);
INSERT INTO valoracions VALUES (1608, 54, '01/08/2003', 7);
INSERT INTO valoracions VALUES (1609, 109, '29/12/2001', 7);
INSERT INTO valoracions VALUES (1609, 38, '25/02/2007', 4);
INSERT INTO valoracions VALUES (1609, 74, '20/06/2006', 4);
INSERT INTO valoracions VALUES (1609, 35, '26/06/2003', 9);
INSERT INTO valoracions VALUES (1609, 111, '15/06/2004', 7);
INSERT INTO valoracions VALUES (1611, 18, '30/01/2007', 6);
INSERT INTO valoracions VALUES (1611, 14, '30/01/2008', 7);
INSERT INTO valoracions VALUES (1612, 108, '03/04/2008', 3);
INSERT INTO valoracions VALUES (1612, 26, '15/01/2005', 6);
INSERT INTO valoracions VALUES (1612, 40, '16/02/2003', 9);
INSERT INTO valoracions VALUES (1613, 29, '13/06/2004', 4);
INSERT INTO valoracions VALUES (1613, 90, '11/12/2007', 3);
INSERT INTO valoracions VALUES (1613, 49, '31/08/2008', 4);
INSERT INTO valoracions VALUES (1614, 50, '17/12/2002', 6);
INSERT INTO valoracions VALUES (1614, 41, '29/03/2009', 4);
INSERT INTO valoracions VALUES (1614, 31, '06/10/2008', 5);
INSERT INTO valoracions VALUES (1614, 31, '13/07/2006', 10);
INSERT INTO valoracions VALUES (1614, 76, '18/12/2004', 4);
INSERT INTO valoracions VALUES (1614, 19, '01/07/2010', 5);
INSERT INTO valoracions VALUES (1614, 73, '18/06/2006', 8);
INSERT INTO valoracions VALUES (1615, 32, '21/04/2006', 7);
INSERT INTO valoracions VALUES (1615, 36, '12/02/2006', 9);
INSERT INTO valoracions VALUES (1615, 108, '21/11/2005', 3);
INSERT INTO valoracions VALUES (1616, 105, '15/04/2010', 3);
INSERT INTO valoracions VALUES (1616, 13, '11/05/2006', 6);
INSERT INTO valoracions VALUES (1616, 34, '20/08/2009', 6);
INSERT INTO valoracions VALUES (1616, 57, '07/08/2003', 9);
INSERT INTO valoracions VALUES (1617, 103, '29/11/2008', 7);
INSERT INTO valoracions VALUES (1618, 42, '30/04/2008', 6);
INSERT INTO valoracions VALUES (1618, 10, '10/09/2007', 6);
INSERT INTO valoracions VALUES (1618, 16, '24/05/2007', 9);
INSERT INTO valoracions VALUES (1618, 112, '07/06/2005', 7);
INSERT INTO valoracions VALUES (1619, 106, '27/02/2009', 6);
INSERT INTO valoracions VALUES (1619, 26, '28/10/2001', 5);
INSERT INTO valoracions VALUES (1619, 28, '10/08/2001', 6);
INSERT INTO valoracions VALUES (1620, 12, '23/09/2010', 5);
INSERT INTO valoracions VALUES (1621, 64, '12/01/2008', 6);
INSERT INTO valoracions VALUES (1621, 98, '22/05/2005', 10);
INSERT INTO valoracions VALUES (1622, 75, '14/01/2008', 4);
INSERT INTO valoracions VALUES (1622, 50, '02/07/2007', 9);
INSERT INTO valoracions VALUES (1622, 29, '14/05/2010', 7);
INSERT INTO valoracions VALUES (1622, 49, '15/06/2006', 8);
INSERT INTO valoracions VALUES (1622, 44, '11/07/2009', 5);
INSERT INTO valoracions VALUES (1623, 7, '10/01/2005', 9);
INSERT INTO valoracions VALUES (1623, 74, '06/08/2003', 8);
INSERT INTO valoracions VALUES (1623, 79, '25/08/2004', 8);
INSERT INTO valoracions VALUES (1623, 8, '04/10/2003', 5);
INSERT INTO valoracions VALUES (1623, 56, '18/06/2009', 9);
INSERT INTO valoracions VALUES (1623, 21, '03/01/2009', 5);
INSERT INTO valoracions VALUES (1623, 41, '12/03/2004', 3);
INSERT INTO valoracions VALUES (1623, 6, '31/05/2001', 6);
INSERT INTO valoracions VALUES (1623, 67, '31/05/2007', 8);
INSERT INTO valoracions VALUES (1623, 50, '27/08/2005', 4);
INSERT INTO valoracions VALUES (1623, 115, '10/07/2005', 7);
INSERT INTO valoracions VALUES (1624, 35, '23/08/2005', 9);
INSERT INTO valoracions VALUES (1624, 40, '09/04/2008', 4);
INSERT INTO valoracions VALUES (1624, 38, '10/07/2009', 4);
INSERT INTO valoracions VALUES (1625, 85, '23/04/2010', 3);
INSERT INTO valoracions VALUES (1625, 70, '22/02/2006', 3);
INSERT INTO valoracions VALUES (1625, 111, '14/05/2007', 3);
INSERT INTO valoracions VALUES (1626, 17, '16/12/2009', 9);
INSERT INTO valoracions VALUES (1626, 74, '04/07/2010', 5);
INSERT INTO valoracions VALUES (1626, 12, '11/02/2006', 8);
INSERT INTO valoracions VALUES (1626, 54, '15/12/2005', 3);
INSERT INTO valoracions VALUES (1626, 57, '17/07/2001', 6);
INSERT INTO valoracions VALUES (1626, 111, '25/09/2003', 1);
INSERT INTO valoracions VALUES (1626, 43, '19/12/2005', 10);
INSERT INTO valoracions VALUES (1628, 86, '10/11/2009', 7);
INSERT INTO valoracions VALUES (1628, 72, '02/10/2006', 3);
INSERT INTO valoracions VALUES (1628, 50, '27/09/2002', 5);
INSERT INTO valoracions VALUES (1628, 85, '21/09/2002', 5);
INSERT INTO valoracions VALUES (1628, 93, '02/04/2006', 9);
INSERT INTO valoracions VALUES (1628, 1, '10/05/2008', 9);
INSERT INTO valoracions VALUES (1628, 85, '10/03/2005', 7);
INSERT INTO valoracions VALUES (1629, 113, '13/04/2008', 5);
INSERT INTO valoracions VALUES (1629, 25, '30/07/2002', 5);
INSERT INTO valoracions VALUES (1629, 104, '21/09/2009', 9);
INSERT INTO valoracions VALUES (1629, 71, '12/04/2009', 6);
INSERT INTO valoracions VALUES (1629, 39, '14/06/2006', 8);
INSERT INTO valoracions VALUES (1629, 80, '23/05/2007', 7);
INSERT INTO valoracions VALUES (1629, 100, '08/07/2008', 8);
INSERT INTO valoracions VALUES (1629, 94, '26/08/2003', 2);
INSERT INTO valoracions VALUES (1629, 40, '18/08/2001', 5);
INSERT INTO valoracions VALUES (1630, 96, '12/06/2007', 3);
INSERT INTO valoracions VALUES (1630, 73, '06/01/2006', 9);
INSERT INTO valoracions VALUES (1630, 24, '03/02/2003', 9);
INSERT INTO valoracions VALUES (1630, 114, '10/11/2001', 6);
INSERT INTO valoracions VALUES (1630, 102, '24/08/2008', 7);
INSERT INTO valoracions VALUES (1631, 37, '09/07/2001', 5);
INSERT INTO valoracions VALUES (1631, 37, '01/04/2008', 9);
INSERT INTO valoracions VALUES (1631, 75, '23/12/2008', 6);
INSERT INTO valoracions VALUES (1631, 25, '04/12/2009', 5);
INSERT INTO valoracions VALUES (1631, 68, '02/07/2001', 9);
INSERT INTO valoracions VALUES (1631, 12, '26/03/2007', 5);
INSERT INTO valoracions VALUES (1631, 3, '05/10/2005', 9);
INSERT INTO valoracions VALUES (1631, 66, '14/12/2008', 6);
INSERT INTO valoracions VALUES (1632, 69, '22/04/2004', 5);
INSERT INTO valoracions VALUES (1632, 28, '06/12/2007', 5);
INSERT INTO valoracions VALUES (1633, 99, '29/04/2004', 6);
INSERT INTO valoracions VALUES (1633, 18, '27/12/2005', 7);
INSERT INTO valoracions VALUES (1633, 2, '20/04/2008', 6);
INSERT INTO valoracions VALUES (1633, 77, '22/04/2001', 4);
INSERT INTO valoracions VALUES (1634, 57, '24/11/2003', 8);
INSERT INTO valoracions VALUES (1634, 70, '16/12/2007', 4);
INSERT INTO valoracions VALUES (1634, 59, '02/06/2003', 3);
INSERT INTO valoracions VALUES (1634, 109, '26/11/2004', 4);
INSERT INTO valoracions VALUES (1634, 45, '21/03/2006', 5);
INSERT INTO valoracions VALUES (1635, 43, '01/06/2006', 5);
INSERT INTO valoracions VALUES (1635, 80, '04/12/2007', 8);
INSERT INTO valoracions VALUES (1635, 83, '24/09/2010', 9);
INSERT INTO valoracions VALUES (1635, 71, '05/07/2002', 3);
INSERT INTO valoracions VALUES (1635, 74, '16/06/2007', 7);
INSERT INTO valoracions VALUES (1636, 90, '18/04/2010', 3);
INSERT INTO valoracions VALUES (1636, 32, '03/11/2002', 4);
INSERT INTO valoracions VALUES (1636, 47, '21/01/2002', 4);
INSERT INTO valoracions VALUES (1636, 43, '19/04/2006', 7);
INSERT INTO valoracions VALUES (1636, 99, '17/08/2009', 1);
INSERT INTO valoracions VALUES (1637, 50, '28/01/2006', 4);
INSERT INTO valoracions VALUES (1637, 110, '19/09/2004', 1);
INSERT INTO valoracions VALUES (1637, 74, '05/01/2008', 3);
INSERT INTO valoracions VALUES (1637, 93, '27/04/2002', 7);
INSERT INTO valoracions VALUES (1638, 73, '19/06/2002', 4);
INSERT INTO valoracions VALUES (1638, 93, '11/02/2003', 8);
INSERT INTO valoracions VALUES (1638, 96, '25/07/2007', 7);
INSERT INTO valoracions VALUES (1639, 61, '20/01/2005', 8);
INSERT INTO valoracions VALUES (1640, 115, '02/02/2004', 3);
INSERT INTO valoracions VALUES (1640, 78, '11/07/2008', 6);
INSERT INTO valoracions VALUES (1640, 9, '10/03/2002', 7);
INSERT INTO valoracions VALUES (1640, 104, '25/03/2006', 3);
INSERT INTO valoracions VALUES (1640, 53, '24/04/2004', 8);
INSERT INTO valoracions VALUES (1640, 95, '06/07/2002', 7);
INSERT INTO valoracions VALUES (1640, 50, '29/07/2004', 3);
INSERT INTO valoracions VALUES (1641, 97, '23/07/2009', 5);
INSERT INTO valoracions VALUES (1641, 61, '27/03/2005', 3);
INSERT INTO valoracions VALUES (1641, 27, '08/12/2009', 9);
INSERT INTO valoracions VALUES (1641, 27, '24/11/2003', 5);
INSERT INTO valoracions VALUES (1642, 65, '09/03/2006', 6);
INSERT INTO valoracions VALUES (1642, 64, '20/04/2009', 9);
INSERT INTO valoracions VALUES (1642, 43, '07/02/2007', 7);
INSERT INTO valoracions VALUES (1642, 13, '28/07/2003', 5);
INSERT INTO valoracions VALUES (1642, 70, '12/02/2010', 5);
INSERT INTO valoracions VALUES (1642, 96, '10/11/2009', 10);
INSERT INTO valoracions VALUES (1642, 32, '25/11/2008', 10);
INSERT INTO valoracions VALUES (1643, 45, '12/10/2007', 7);
INSERT INTO valoracions VALUES (1643, 40, '14/03/2007', 4);
INSERT INTO valoracions VALUES (1643, 13, '16/05/2003', 9);
INSERT INTO valoracions VALUES (1643, 61, '16/07/2005', 8);
INSERT INTO valoracions VALUES (1643, 28, '18/06/2010', 4);
INSERT INTO valoracions VALUES (1643, 38, '08/07/2002', 5);
INSERT INTO valoracions VALUES (1644, 39, '24/01/2009', 6);
INSERT INTO valoracions VALUES (1644, 9, '07/03/2008', 5);
INSERT INTO valoracions VALUES (1644, 83, '07/07/2010', 7);
INSERT INTO valoracions VALUES (1644, 75, '20/04/2004', 4);
INSERT INTO valoracions VALUES (1644, 31, '31/10/2005', 9);
INSERT INTO valoracions VALUES (1645, 102, '15/03/2002', 9);
INSERT INTO valoracions VALUES (1645, 9, '16/10/2009', 5);
INSERT INTO valoracions VALUES (1645, 56, '05/01/2006', 8);
INSERT INTO valoracions VALUES (1646, 12, '12/05/2009', 6);
INSERT INTO valoracions VALUES (1646, 55, '23/12/2004', 3);
INSERT INTO valoracions VALUES (1646, 34, '29/12/2003', 10);
INSERT INTO valoracions VALUES (1647, 57, '19/12/2005', 9);
INSERT INTO valoracions VALUES (1647, 17, '11/01/2005', 10);
INSERT INTO valoracions VALUES (1647, 70, '14/11/2003', 3);
INSERT INTO valoracions VALUES (1647, 14, '12/01/2009', 5);
INSERT INTO valoracions VALUES (1647, 109, '28/12/2009', 5);
INSERT INTO valoracions VALUES (1647, 99, '21/05/2007', 6);
INSERT INTO valoracions VALUES (1647, 97, '06/09/2006', 7);
INSERT INTO valoracions VALUES (1648, 76, '07/09/2004', 10);
INSERT INTO valoracions VALUES (1648, 72, '17/11/2009', 5);
INSERT INTO valoracions VALUES (1648, 13, '14/11/2004', 9);
INSERT INTO valoracions VALUES (1648, 2, '28/11/2007', 7);
INSERT INTO valoracions VALUES (1648, 23, '12/07/2007', 9);
INSERT INTO valoracions VALUES (1648, 93, '19/09/2001', 5);
INSERT INTO valoracions VALUES (1649, 35, '25/08/2006', 5);
INSERT INTO valoracions VALUES (1649, 79, '07/12/2008', 9);
INSERT INTO valoracions VALUES (1649, 49, '09/04/2009', 9);
INSERT INTO valoracions VALUES (1649, 85, '15/05/2005', 5);
INSERT INTO valoracions VALUES (1649, 108, '10/01/2002', 4);
INSERT INTO valoracions VALUES (1650, 54, '31/10/2008', 9);
INSERT INTO valoracions VALUES (1650, 97, '15/04/2004', 4);
INSERT INTO valoracions VALUES (1650, 36, '21/11/2008', 5);
INSERT INTO valoracions VALUES (1650, 4, '30/12/2006', 8);
INSERT INTO valoracions VALUES (1650, 59, '16/01/2010', 9);
INSERT INTO valoracions VALUES (1650, 40, '24/12/2007', 7);
INSERT INTO valoracions VALUES (1650, 33, '19/10/2001', 9);
INSERT INTO valoracions VALUES (1650, 4, '05/01/2009', 7);
INSERT INTO valoracions VALUES (1651, 82, '13/04/2010', 6);
INSERT INTO valoracions VALUES (1651, 3, '20/01/2008', 8);
INSERT INTO valoracions VALUES (1652, 76, '21/11/2009', 6);
INSERT INTO valoracions VALUES (1653, 15, '15/11/2004', 5);
INSERT INTO valoracions VALUES (1653, 116, '17/05/2006', 4);
INSERT INTO valoracions VALUES (1653, 97, '04/09/2007', 9);
INSERT INTO valoracions VALUES (1654, 99, '06/07/2002', 10);
INSERT INTO valoracions VALUES (1654, 65, '31/10/2004', 3);
INSERT INTO valoracions VALUES (1654, 56, '14/12/2003', 3);
INSERT INTO valoracions VALUES (1654, 72, '15/09/2003', 8);
INSERT INTO valoracions VALUES (1654, 5, '22/01/2005', 9);
INSERT INTO valoracions VALUES (1655, 78, '17/07/2009', 7);
INSERT INTO valoracions VALUES (1655, 39, '17/06/2008', 5);
INSERT INTO valoracions VALUES (1656, 74, '15/05/2007', 8);
INSERT INTO valoracions VALUES (1656, 9, '27/05/2003', 6);
INSERT INTO valoracions VALUES (1656, 54, '12/06/2005', 6);
INSERT INTO valoracions VALUES (1656, 81, '24/01/2006', 6);
INSERT INTO valoracions VALUES (1656, 85, '17/07/2008', 7);
INSERT INTO valoracions VALUES (1657, 105, '27/03/2004', 5);
INSERT INTO valoracions VALUES (1657, 23, '12/10/2008', 5);
INSERT INTO valoracions VALUES (1658, 80, '30/09/2004', 7);
INSERT INTO valoracions VALUES (1658, 23, '01/05/2005', 9);
INSERT INTO valoracions VALUES (1658, 97, '19/10/2004', 5);
INSERT INTO valoracions VALUES (1658, 64, '31/07/2004', 8);
INSERT INTO valoracions VALUES (1658, 81, '07/04/2003', 4);
INSERT INTO valoracions VALUES (1658, 64, '25/04/2009', 4);
INSERT INTO valoracions VALUES (1659, 59, '20/10/2010', 9);
INSERT INTO valoracions VALUES (1659, 65, '21/03/2007', 10);
INSERT INTO valoracions VALUES (1659, 18, '31/08/2010', 6);
INSERT INTO valoracions VALUES (1659, 101, '16/04/2006', 9);
INSERT INTO valoracions VALUES (1660, 24, '25/01/2005', 7);
INSERT INTO valoracions VALUES (1660, 9, '10/02/2002', 5);
INSERT INTO valoracions VALUES (1660, 78, '23/10/2005', 10);
INSERT INTO valoracions VALUES (1660, 72, '16/02/2009', 3);
INSERT INTO valoracions VALUES (1660, 115, '15/07/2009', 10);
INSERT INTO valoracions VALUES (1660, 111, '05/06/2002', 4);
INSERT INTO valoracions VALUES (1661, 66, '02/08/2005', 8);
INSERT INTO valoracions VALUES (1661, 76, '13/04/2004', 4);
INSERT INTO valoracions VALUES (1661, 7, '09/08/2003', 6);
INSERT INTO valoracions VALUES (1661, 109, '09/04/2005', 8);
INSERT INTO valoracions VALUES (1662, 45, '11/09/2004', 5);
INSERT INTO valoracions VALUES (1662, 105, '04/07/2010', 7);
INSERT INTO valoracions VALUES (1662, 26, '15/05/2004', 9);
INSERT INTO valoracions VALUES (1663, 77, '15/01/2008', 4);
INSERT INTO valoracions VALUES (1663, 102, '27/11/2009', 3);
INSERT INTO valoracions VALUES (1663, 10, '10/10/2008', 6);
INSERT INTO valoracions VALUES (1664, 109, '11/11/2007', 5);
INSERT INTO valoracions VALUES (1665, 71, '17/04/2003', 9);
INSERT INTO valoracions VALUES (1665, 81, '16/08/2008', 10);
INSERT INTO valoracions VALUES (1665, 94, '26/10/2004', 4);
INSERT INTO valoracions VALUES (1665, 33, '20/05/2007', 5);
INSERT INTO valoracions VALUES (1665, 51, '10/11/2001', 4);
INSERT INTO valoracions VALUES (1666, 74, '21/06/2002', 9);
INSERT INTO valoracions VALUES (1666, 27, '06/12/2007', 9);
INSERT INTO valoracions VALUES (1666, 53, '09/12/2005', 9);
INSERT INTO valoracions VALUES (1667, 104, '08/03/2007', 5);
INSERT INTO valoracions VALUES (1668, 111, '13/06/2010', 9);
INSERT INTO valoracions VALUES (1669, 36, '17/08/2004', 4);
INSERT INTO valoracions VALUES (1669, 93, '25/08/2004', 3);
INSERT INTO valoracions VALUES (1669, 115, '27/12/2009', 7);
INSERT INTO valoracions VALUES (1669, 51, '08/06/2009', 9);
INSERT INTO valoracions VALUES (1669, 89, '22/10/2008', 4);
INSERT INTO valoracions VALUES (1669, 74, '21/03/2008', 8);
INSERT INTO valoracions VALUES (1670, 51, '31/05/2008', 8);
INSERT INTO valoracions VALUES (1670, 36, '09/07/2003', 6);
INSERT INTO valoracions VALUES (1670, 39, '15/02/2002', 7);
INSERT INTO valoracions VALUES (1671, 110, '28/09/2001', 9);
INSERT INTO valoracions VALUES (1671, 73, '24/06/2010', 8);
INSERT INTO valoracions VALUES (1671, 72, '09/11/2007', 2);
INSERT INTO valoracions VALUES (1672, 23, '08/06/2009', 6);
INSERT INTO valoracions VALUES (1672, 52, '05/11/2004', 4);
INSERT INTO valoracions VALUES (1672, 110, '25/02/2008', 8);
INSERT INTO valoracions VALUES (1673, 65, '04/06/2009', 5);
INSERT INTO valoracions VALUES (1673, 6, '17/11/2007', 7);
INSERT INTO valoracions VALUES (1674, 25, '18/05/2005', 8);
INSERT INTO valoracions VALUES (1674, 16, '08/12/2004', 7);
INSERT INTO valoracions VALUES (1674, 37, '08/04/2001', 7);
INSERT INTO valoracions VALUES (1674, 28, '30/05/2006', 6);
INSERT INTO valoracions VALUES (1675, 94, '07/07/2003', 9);
INSERT INTO valoracions VALUES (1675, 78, '06/08/2007', 8);
INSERT INTO valoracions VALUES (1675, 108, '10/08/2007', 9);
INSERT INTO valoracions VALUES (1675, 108, '20/01/2007', 2);
INSERT INTO valoracions VALUES (1675, 70, '26/02/2009', 9);
INSERT INTO valoracions VALUES (1676, 40, '05/09/2008', 9);
INSERT INTO valoracions VALUES (1676, 69, '11/04/2006', 7);
INSERT INTO valoracions VALUES (1676, 17, '14/01/2003', 7);
INSERT INTO valoracions VALUES (1676, 103, '04/10/2006', 2);
INSERT INTO valoracions VALUES (1676, 85, '26/05/2008', 8);
INSERT INTO valoracions VALUES (1676, 60, '19/09/2004', 10);
INSERT INTO valoracions VALUES (1677, 85, '06/09/2008', 6);
INSERT INTO valoracions VALUES (1677, 112, '15/08/2009', 3);
INSERT INTO valoracions VALUES (1677, 81, '04/04/2004', 5);
INSERT INTO valoracions VALUES (1678, 92, '02/05/2004', 3);
INSERT INTO valoracions VALUES (1678, 64, '16/11/2009', 8);
INSERT INTO valoracions VALUES (1678, 36, '12/05/2004', 5);
INSERT INTO valoracions VALUES (1678, 87, '06/10/2008', 2);
INSERT INTO valoracions VALUES (1678, 95, '23/05/2006', 5);
INSERT INTO valoracions VALUES (1679, 101, '27/01/2002', 2);
INSERT INTO valoracions VALUES (1679, 25, '24/04/2001', 4);
INSERT INTO valoracions VALUES (1679, 81, '19/11/2002', 5);
INSERT INTO valoracions VALUES (1679, 69, '09/10/2007', 8);
INSERT INTO valoracions VALUES (1680, 8, '24/08/2007', 5);
INSERT INTO valoracions VALUES (1680, 96, '08/09/2010', 2);
INSERT INTO valoracions VALUES (1681, 83, '01/11/2006', 10);
INSERT INTO valoracions VALUES (1681, 91, '24/02/2008', 3);
INSERT INTO valoracions VALUES (1681, 99, '27/07/2009', 6);
INSERT INTO valoracions VALUES (1681, 103, '09/03/2009', 2);
INSERT INTO valoracions VALUES (1682, 79, '18/01/2007', 9);
INSERT INTO valoracions VALUES (1682, 108, '26/08/2002', 5);
INSERT INTO valoracions VALUES (1682, 39, '01/10/2008', 9);
INSERT INTO valoracions VALUES (1682, 18, '31/01/2010', 9);
INSERT INTO valoracions VALUES (1682, 15, '23/10/2003', 7);
INSERT INTO valoracions VALUES (1682, 65, '09/02/2006', 3);
INSERT INTO valoracions VALUES (1682, 9, '19/03/2002', 10);
INSERT INTO valoracions VALUES (1682, 87, '19/11/2007', 8);
INSERT INTO valoracions VALUES (1683, 60, '11/08/2007', 7);
INSERT INTO valoracions VALUES (1683, 19, '29/12/2007', 10);
INSERT INTO valoracions VALUES (1683, 57, '17/11/2008', 6);
INSERT INTO valoracions VALUES (1684, 52, '09/10/2006', 4);
INSERT INTO valoracions VALUES (1684, 38, '23/10/2010', 8);
INSERT INTO valoracions VALUES (1684, 115, '24/04/2009', 1);
INSERT INTO valoracions VALUES (1685, 95, '11/06/2002', 5);
INSERT INTO valoracions VALUES (1685, 62, '20/01/2009', 8);
INSERT INTO valoracions VALUES (1685, 59, '21/02/2008', 8);
INSERT INTO valoracions VALUES (1685, 65, '24/07/2001', 4);
INSERT INTO valoracions VALUES (1685, 84, '29/07/2010', 7);
INSERT INTO valoracions VALUES (1685, 69, '21/03/2007', 3);
INSERT INTO valoracions VALUES (1685, 54, '18/05/2009', 9);
INSERT INTO valoracions VALUES (1685, 44, '10/12/2008', 7);
INSERT INTO valoracions VALUES (1685, 91, '31/01/2010', 6);
INSERT INTO valoracions VALUES (1686, 12, '01/07/2004', 6);
INSERT INTO valoracions VALUES (1686, 73, '01/07/2001', 4);
INSERT INTO valoracions VALUES (1686, 77, '28/02/2007', 9);
INSERT INTO valoracions VALUES (1686, 40, '16/10/2007', 3);
INSERT INTO valoracions VALUES (1687, 105, '13/01/2006', 9);
INSERT INTO valoracions VALUES (1687, 64, '21/04/2006', 5);
INSERT INTO valoracions VALUES (1687, 63, '18/02/2010', 5);
INSERT INTO valoracions VALUES (1688, 88, '17/11/2005', 7);
INSERT INTO valoracions VALUES (1688, 87, '23/07/2001', 9);
INSERT INTO valoracions VALUES (1689, 75, '31/07/2004', 8);
INSERT INTO valoracions VALUES (1689, 4, '21/04/2009', 10);
INSERT INTO valoracions VALUES (1689, 79, '01/10/2008', 5);
INSERT INTO valoracions VALUES (1689, 22, '11/01/2008', 5);
INSERT INTO valoracions VALUES (1689, 99, '23/07/2001', 3);
INSERT INTO valoracions VALUES (1689, 116, '03/09/2010', 2);
INSERT INTO valoracions VALUES (1690, 113, '24/05/2004', 7);
INSERT INTO valoracions VALUES (1690, 36, '30/06/2009', 9);
INSERT INTO valoracions VALUES (1690, 63, '08/02/2006', 5);
INSERT INTO valoracions VALUES (1690, 55, '10/08/2005', 3);
INSERT INTO valoracions VALUES (1690, 110, '23/01/2002', 2);
INSERT INTO valoracions VALUES (1690, 96, '19/11/2001', 2);
INSERT INTO valoracions VALUES (1690, 26, '14/10/2001', 6);
INSERT INTO valoracions VALUES (1690, 110, '28/12/2009', 1);
INSERT INTO valoracions VALUES (1691, 106, '10/05/2007', 2);
INSERT INTO valoracions VALUES (1691, 6, '20/02/2002', 6);
INSERT INTO valoracions VALUES (1691, 61, '11/05/2007', 3);
INSERT INTO valoracions VALUES (1691, 113, '18/10/2009', 6);
INSERT INTO valoracions VALUES (1692, 4, '06/09/2008', 7);
INSERT INTO valoracions VALUES (1692, 87, '10/02/2006', 5);
INSERT INTO valoracions VALUES (1692, 97, '14/11/2001', 3);
INSERT INTO valoracions VALUES (1693, 46, '14/05/2004', 6);
INSERT INTO valoracions VALUES (1693, 50, '04/11/2001', 7);
INSERT INTO valoracions VALUES (1694, 71, '22/06/2008', 7);
INSERT INTO valoracions VALUES (1694, 6, '17/07/2002', 10);
INSERT INTO valoracions VALUES (1695, 115, '24/01/2010', 9);
INSERT INTO valoracions VALUES (1695, 65, '23/05/2002', 8);
INSERT INTO valoracions VALUES (1695, 111, '02/06/2008', 5);
INSERT INTO valoracions VALUES (1695, 87, '10/10/2003', 5);
INSERT INTO valoracions VALUES (1695, 27, '26/11/2007', 10);
INSERT INTO valoracions VALUES (1696, 48, '31/12/2002', 4);
INSERT INTO valoracions VALUES (1696, 26, '28/08/2007', 5);
INSERT INTO valoracions VALUES (1696, 73, '16/05/2008', 7);
INSERT INTO valoracions VALUES (1696, 78, '28/12/2006', 8);
INSERT INTO valoracions VALUES (1697, 45, '11/05/2006', 3);
INSERT INTO valoracions VALUES (1697, 24, '08/07/2003', 9);
INSERT INTO valoracions VALUES (1697, 72, '08/02/2003', 9);
INSERT INTO valoracions VALUES (1698, 34, '04/06/2005', 6);
INSERT INTO valoracions VALUES (1698, 64, '26/05/2010', 8);
INSERT INTO valoracions VALUES (1698, 87, '13/08/2003', 6);
INSERT INTO valoracions VALUES (1698, 82, '19/10/2007', 9);
INSERT INTO valoracions VALUES (1699, 21, '10/09/2003', 5);
INSERT INTO valoracions VALUES (1699, 92, '30/09/2007', 3);
INSERT INTO valoracions VALUES (1700, 2, '18/10/2007', 9);
INSERT INTO valoracions VALUES (1700, 59, '18/10/2008', 7);
INSERT INTO valoracions VALUES (1701, 11, '25/03/2006', 10);
INSERT INTO valoracions VALUES (1701, 72, '01/12/2009', 4);
INSERT INTO valoracions VALUES (1701, 81, '22/09/2004', 7);
INSERT INTO valoracions VALUES (1701, 97, '31/10/2005', 5);
INSERT INTO valoracions VALUES (1702, 11, '10/06/2004', 5);
INSERT INTO valoracions VALUES (1702, 38, '28/02/2002', 5);
INSERT INTO valoracions VALUES (1702, 28, '05/07/2006', 8);
INSERT INTO valoracions VALUES (1702, 103, '20/06/2007', 2);
INSERT INTO valoracions VALUES (1702, 108, '01/11/2004', 8);
INSERT INTO valoracions VALUES (1702, 76, '01/04/2007', 8);
INSERT INTO valoracions VALUES (1703, 88, '08/05/2006', 5);
INSERT INTO valoracions VALUES (1703, 61, '24/08/2005', 8);
INSERT INTO valoracions VALUES (1703, 66, '27/04/2002', 8);
INSERT INTO valoracions VALUES (1703, 21, '15/06/2007', 8);
INSERT INTO valoracions VALUES (1703, 58, '22/11/2008', 3);
INSERT INTO valoracions VALUES (1704, 98, '27/07/2005', 2);
INSERT INTO valoracions VALUES (1704, 97, '19/08/2005', 2);
INSERT INTO valoracions VALUES (1704, 108, '11/06/2002', 7);
INSERT INTO valoracions VALUES (1704, 80, '31/03/2009', 8);
INSERT INTO valoracions VALUES (1704, 78, '30/05/2001', 8);
INSERT INTO valoracions VALUES (1705, 93, '06/04/2003', 6);
INSERT INTO valoracions VALUES (1705, 43, '27/04/2006', 9);
INSERT INTO valoracions VALUES (1705, 105, '19/02/2008', 3);
INSERT INTO valoracions VALUES (1705, 70, '18/11/2002', 9);
INSERT INTO valoracions VALUES (1705, 93, '17/08/2005', 6);
INSERT INTO valoracions VALUES (1705, 3, '25/06/2009', 5);
INSERT INTO valoracions VALUES (1706, 53, '27/03/2010', 10);
INSERT INTO valoracions VALUES (1706, 57, '11/01/2005', 6);
INSERT INTO valoracions VALUES (1706, 74, '17/12/2008', 8);
INSERT INTO valoracions VALUES (1706, 63, '04/04/2009', 4);
INSERT INTO valoracions VALUES (1706, 83, '16/05/2006', 6);
INSERT INTO valoracions VALUES (1706, 36, '04/09/2002', 5);
INSERT INTO valoracions VALUES (1707, 62, '17/03/2003', 8);
INSERT INTO valoracions VALUES (1707, 71, '10/04/2009', 7);
INSERT INTO valoracions VALUES (1707, 52, '22/08/2005', 5);
INSERT INTO valoracions VALUES (1707, 116, '18/08/2010', 2);
INSERT INTO valoracions VALUES (1707, 22, '05/06/2001', 8);
INSERT INTO valoracions VALUES (1707, 101, '19/12/2007', 1);
INSERT INTO valoracions VALUES (1707, 92, '09/05/2006', 5);
INSERT INTO valoracions VALUES (1707, 23, '07/07/2009', 10);
INSERT INTO valoracions VALUES (1709, 52, '07/08/2004', 6);
INSERT INTO valoracions VALUES (1709, 62, '21/07/2006', 7);
INSERT INTO valoracions VALUES (1709, 67, '06/08/2008', 4);
INSERT INTO valoracions VALUES (1709, 16, '04/10/2010', 9);
INSERT INTO valoracions VALUES (1709, 108, '11/12/2004', 6);
INSERT INTO valoracions VALUES (1709, 1, '29/08/2001', 7);
INSERT INTO valoracions VALUES (1710, 29, '13/05/2010', 4);
INSERT INTO valoracions VALUES (1710, 64, '01/11/2008', 5);
INSERT INTO valoracions VALUES (1710, 14, '03/03/2008', 5);
INSERT INTO valoracions VALUES (1710, 13, '12/09/2004', 9);
INSERT INTO valoracions VALUES (1711, 111, '08/08/2002', 9);
INSERT INTO valoracions VALUES (1711, 10, '02/10/2009', 5);
INSERT INTO valoracions VALUES (1711, 51, '16/11/2006', 6);
INSERT INTO valoracions VALUES (1711, 31, '12/09/2006', 8);
INSERT INTO valoracions VALUES (1712, 29, '31/08/2005', 8);
INSERT INTO valoracions VALUES (1712, 71, '18/02/2008', 7);
INSERT INTO valoracions VALUES (1712, 86, '03/05/2010', 4);
INSERT INTO valoracions VALUES (1712, 91, '03/08/2002', 3);
INSERT INTO valoracions VALUES (1712, 62, '06/01/2009', 3);
INSERT INTO valoracions VALUES (1713, 52, '07/03/2007', 8);
INSERT INTO valoracions VALUES (1713, 6, '23/09/2003', 8);
INSERT INTO valoracions VALUES (1714, 75, '24/05/2001', 9);
INSERT INTO valoracions VALUES (1714, 8, '05/04/2005', 5);
INSERT INTO valoracions VALUES (1714, 12, '24/09/2004', 9);
INSERT INTO valoracions VALUES (1715, 47, '12/01/2008', 4);
INSERT INTO valoracions VALUES (1715, 71, '28/03/2008', 4);
INSERT INTO valoracions VALUES (1715, 16, '14/07/2008', 8);
INSERT INTO valoracions VALUES (1715, 45, '17/10/2008', 5);
INSERT INTO valoracions VALUES (1716, 15, '13/09/2010', 7);
INSERT INTO valoracions VALUES (1716, 87, '29/03/2004', 4);
INSERT INTO valoracions VALUES (1716, 75, '29/12/2001', 10);
INSERT INTO valoracions VALUES (1716, 68, '07/02/2009', 4);
INSERT INTO valoracions VALUES (1716, 46, '11/04/2005', 4);
INSERT INTO valoracions VALUES (1717, 65, '24/09/2005', 8);
INSERT INTO valoracions VALUES (1717, 16, '13/11/2008', 8);
INSERT INTO valoracions VALUES (1717, 56, '01/11/2003', 7);
INSERT INTO valoracions VALUES (1718, 28, '26/04/2004', 6);
INSERT INTO valoracions VALUES (1718, 106, '31/05/2004', 10);
INSERT INTO valoracions VALUES (1718, 113, '08/04/2007', 3);
INSERT INTO valoracions VALUES (1718, 56, '19/11/2007', 6);
INSERT INTO valoracions VALUES (1718, 39, '07/04/2009', 9);
INSERT INTO valoracions VALUES (1719, 3, '20/01/2008', 5);
INSERT INTO valoracions VALUES (1719, 27, '05/01/2007', 4);
INSERT INTO valoracions VALUES (1719, 26, '12/05/2006', 8);
INSERT INTO valoracions VALUES (1719, 3, '28/04/2008', 7);
INSERT INTO valoracions VALUES (1719, 85, '22/03/2002', 7);
INSERT INTO valoracions VALUES (1720, 14, '15/02/2010', 6);
INSERT INTO valoracions VALUES (1720, 90, '17/09/2009', 6);
INSERT INTO valoracions VALUES (1720, 116, '11/11/2007', 5);
INSERT INTO valoracions VALUES (1721, 77, '25/12/2005', 9);
INSERT INTO valoracions VALUES (1721, 16, '13/01/2009', 8);
INSERT INTO valoracions VALUES (1721, 115, '04/03/2010', 1);
INSERT INTO valoracions VALUES (1721, 108, '23/02/2010', 1);
INSERT INTO valoracions VALUES (1722, 72, '01/01/2007', 8);
INSERT INTO valoracions VALUES (1722, 49, '20/02/2005', 6);
INSERT INTO valoracions VALUES (1722, 16, '04/03/2008', 9);
INSERT INTO valoracions VALUES (1722, 7, '18/04/2001', 5);
INSERT INTO valoracions VALUES (1723, 51, '13/06/2006', 6);
INSERT INTO valoracions VALUES (1723, 75, '14/06/2004', 8);
INSERT INTO valoracions VALUES (1723, 12, '03/10/2002', 7);
INSERT INTO valoracions VALUES (1723, 92, '11/01/2010', 8);
INSERT INTO valoracions VALUES (1724, 25, '25/07/2002', 6);
INSERT INTO valoracions VALUES (1724, 59, '10/01/2008', 4);
INSERT INTO valoracions VALUES (1724, 14, '18/11/2001', 6);
INSERT INTO valoracions VALUES (1724, 93, '04/10/2005', 8);
INSERT INTO valoracions VALUES (1724, 87, '05/03/2008', 4);
INSERT INTO valoracions VALUES (1724, 65, '20/12/2003', 4);
INSERT INTO valoracions VALUES (1724, 70, '22/02/2007', 6);
INSERT INTO valoracions VALUES (1724, 93, '05/09/2003', 4);
INSERT INTO valoracions VALUES (1725, 50, '20/05/2007', 8);
INSERT INTO valoracions VALUES (1726, 27, '06/09/2009', 8);
INSERT INTO valoracions VALUES (1726, 21, '02/05/2005', 7);
INSERT INTO valoracions VALUES (1726, 48, '04/06/2010', 4);
INSERT INTO valoracions VALUES (1726, 30, '28/10/2006', 7);
INSERT INTO valoracions VALUES (1726, 84, '04/04/2008', 2);
INSERT INTO valoracions VALUES (1726, 70, '15/02/2005', 7);
INSERT INTO valoracions VALUES (1727, 42, '05/02/2005', 5);
INSERT INTO valoracions VALUES (1727, 115, '30/09/2003', 6);
INSERT INTO valoracions VALUES (1727, 53, '12/05/2004', 10);
INSERT INTO valoracions VALUES (1727, 106, '06/10/2007', 5);
INSERT INTO valoracions VALUES (1727, 38, '17/04/2007', 6);
INSERT INTO valoracions VALUES (1728, 46, '19/04/2004', 7);
INSERT INTO valoracions VALUES (1728, 70, '12/03/2009', 4);
INSERT INTO valoracions VALUES (1729, 77, '13/12/2006', 3);
INSERT INTO valoracions VALUES (1729, 44, '05/10/2004', 10);
INSERT INTO valoracions VALUES (1729, 92, '21/10/2001', 2);
INSERT INTO valoracions VALUES (1729, 57, '30/03/2007', 9);
INSERT INTO valoracions VALUES (1729, 92, '28/04/2003', 8);
INSERT INTO valoracions VALUES (1730, 5, '13/12/2001', 8);
INSERT INTO valoracions VALUES (1730, 69, '01/03/2003', 8);
INSERT INTO valoracions VALUES (1730, 25, '13/06/2001', 5);
INSERT INTO valoracions VALUES (1730, 18, '17/07/2010', 9);
INSERT INTO valoracions VALUES (1731, 97, '17/03/2003', 2);
INSERT INTO valoracions VALUES (1731, 55, '20/07/2001', 5);
INSERT INTO valoracions VALUES (1731, 84, '12/05/2007', 5);
INSERT INTO valoracions VALUES (1731, 44, '14/11/2007', 8);
INSERT INTO valoracions VALUES (1731, 6, '20/08/2008', 8);
INSERT INTO valoracions VALUES (1731, 24, '06/04/2005', 4);
INSERT INTO valoracions VALUES (1732, 84, '30/08/2009', 3);
INSERT INTO valoracions VALUES (1733, 22, '04/10/2002', 5);
INSERT INTO valoracions VALUES (1735, 5, '01/11/2006', 9);
INSERT INTO valoracions VALUES (1735, 45, '15/10/2008', 3);
INSERT INTO valoracions VALUES (1735, 55, '05/12/2005', 4);
INSERT INTO valoracions VALUES (1735, 46, '10/12/2002', 6);
INSERT INTO valoracions VALUES (1736, 17, '04/09/2002', 4);
INSERT INTO valoracions VALUES (1736, 67, '01/05/2007', 3);
INSERT INTO valoracions VALUES (1737, 73, '11/11/2004', 4);
INSERT INTO valoracions VALUES (1737, 62, '28/12/2008', 8);
INSERT INTO valoracions VALUES (1737, 114, '21/10/2001', 5);
INSERT INTO valoracions VALUES (1737, 75, '13/05/2001', 8);
INSERT INTO valoracions VALUES (1738, 17, '21/11/2001', 8);
INSERT INTO valoracions VALUES (1738, 26, '18/10/2008', 5);
INSERT INTO valoracions VALUES (1738, 110, '24/07/2006', 3);
INSERT INTO valoracions VALUES (1738, 79, '17/12/2001', 9);
INSERT INTO valoracions VALUES (1738, 38, '12/11/2008', 5);
INSERT INTO valoracions VALUES (1738, 71, '17/07/2008', 3);
INSERT INTO valoracions VALUES (1738, 102, '29/08/2006', 5);
INSERT INTO valoracions VALUES (1738, 68, '28/12/2003', 4);
INSERT INTO valoracions VALUES (1738, 29, '24/12/2009', 4);
INSERT INTO valoracions VALUES (1738, 31, '16/04/2007', 5);
INSERT INTO valoracions VALUES (1739, 17, '13/02/2004', 9);
INSERT INTO valoracions VALUES (1739, 69, '24/03/2003', 4);
INSERT INTO valoracions VALUES (1739, 42, '05/03/2010', 9);
INSERT INTO valoracions VALUES (1739, 12, '10/12/2002', 7);
INSERT INTO valoracions VALUES (1740, 28, '25/02/2010', 8);
INSERT INTO valoracions VALUES (1740, 10, '12/06/2006', 10);
INSERT INTO valoracions VALUES (1740, 49, '09/11/2004', 6);
INSERT INTO valoracions VALUES (1740, 67, '06/06/2005', 10);
INSERT INTO valoracions VALUES (1740, 116, '11/10/2002', 4);
INSERT INTO valoracions VALUES (1740, 65, '19/03/2003', 3);
INSERT INTO valoracions VALUES (1740, 111, '09/05/2007', 7);
INSERT INTO valoracions VALUES (1741, 50, '12/10/2001', 9);
INSERT INTO valoracions VALUES (1741, 67, '10/09/2005', 5);
INSERT INTO valoracions VALUES (1741, 86, '06/07/2006', 8);
INSERT INTO valoracions VALUES (1741, 110, '04/01/2006', 2);
INSERT INTO valoracions VALUES (1742, 110, '03/04/2003', 9);
INSERT INTO valoracions VALUES (1742, 116, '29/07/2004', 10);
INSERT INTO valoracions VALUES (1742, 17, '16/02/2005', 8);
INSERT INTO valoracions VALUES (1742, 5, '14/04/2006', 9);
INSERT INTO valoracions VALUES (1742, 109, '04/04/2003', 4);
INSERT INTO valoracions VALUES (1742, 32, '10/02/2005', 4);
INSERT INTO valoracions VALUES (1743, 80, '30/11/2003', 9);
INSERT INTO valoracions VALUES (1743, 17, '27/07/2001', 7);
INSERT INTO valoracions VALUES (1743, 68, '25/09/2009', 7);
INSERT INTO valoracions VALUES (1743, 18, '14/09/2004', 6);
INSERT INTO valoracions VALUES (1743, 57, '08/08/2003', 6);
INSERT INTO valoracions VALUES (1743, 67, '10/02/2008', 3);
INSERT INTO valoracions VALUES (1744, 13, '05/01/2009', 6);
INSERT INTO valoracions VALUES (1744, 47, '10/03/2004', 9);
INSERT INTO valoracions VALUES (1744, 53, '17/02/2006', 8);
INSERT INTO valoracions VALUES (1745, 61, '18/11/2008', 4);
INSERT INTO valoracions VALUES (1745, 70, '20/05/2002', 8);
INSERT INTO valoracions VALUES (1745, 24, '09/05/2006', 8);
INSERT INTO valoracions VALUES (1745, 67, '25/05/2001', 9);
INSERT INTO valoracions VALUES (1745, 21, '29/11/2006', 10);
INSERT INTO valoracions VALUES (1745, 73, '03/09/2001', 9);
INSERT INTO valoracions VALUES (1745, 34, '23/02/2007', 9);
INSERT INTO valoracions VALUES (1745, 82, '27/09/2002', 4);
INSERT INTO valoracions VALUES (1745, 38, '14/01/2004', 9);
INSERT INTO valoracions VALUES (1746, 49, '01/08/2007', 9);
INSERT INTO valoracions VALUES (1746, 26, '04/04/2003', 5);
INSERT INTO valoracions VALUES (1746, 23, '12/04/2006', 5);
INSERT INTO valoracions VALUES (1747, 41, '13/08/2006', 5);
INSERT INTO valoracions VALUES (1747, 40, '22/09/2006', 8);
INSERT INTO valoracions VALUES (1747, 23, '10/08/2008', 5);
INSERT INTO valoracions VALUES (1747, 84, '27/01/2009', 5);
INSERT INTO valoracions VALUES (1747, 101, '27/06/2002', 8);
INSERT INTO valoracions VALUES (1748, 15, '04/11/2008', 5);
INSERT INTO valoracions VALUES (1748, 29, '16/10/2007', 9);
INSERT INTO valoracions VALUES (1748, 59, '21/04/2002', 5);
INSERT INTO valoracions VALUES (1748, 116, '31/01/2007', 8);
INSERT INTO valoracions VALUES (1748, 39, '16/08/2001', 7);
INSERT INTO valoracions VALUES (1748, 35, '24/07/2007', 5);
INSERT INTO valoracions VALUES (1749, 73, '21/03/2002', 6);
INSERT INTO valoracions VALUES (1749, 5, '26/05/2003', 6);
INSERT INTO valoracions VALUES (1750, 18, '10/07/2005', 5);
INSERT INTO valoracions VALUES (1750, 41, '13/04/2006', 6);
INSERT INTO valoracions VALUES (1750, 44, '29/07/2003', 9);
INSERT INTO valoracions VALUES (1750, 110, '03/01/2004', 3);
INSERT INTO valoracions VALUES (1750, 2, '14/06/2001', 8);
INSERT INTO valoracions VALUES (1751, 44, '12/03/2006', 9);
INSERT INTO valoracions VALUES (1751, 33, '08/02/2009', 8);
INSERT INTO valoracions VALUES (1751, 63, '22/02/2009', 3);
INSERT INTO valoracions VALUES (1752, 84, '31/05/2001', 1);
INSERT INTO valoracions VALUES (1752, 15, '24/01/2005', 6);
INSERT INTO valoracions VALUES (1752, 35, '06/09/2004', 5);
INSERT INTO valoracions VALUES (1752, 4, '09/09/2008', 7);
INSERT INTO valoracions VALUES (1752, 17, '03/11/2003', 9);
INSERT INTO valoracions VALUES (1752, 112, '12/08/2002', 8);
INSERT INTO valoracions VALUES (1753, 63, '24/09/2010', 4);
INSERT INTO valoracions VALUES (1753, 81, '05/03/2004', 10);
INSERT INTO valoracions VALUES (1753, 94, '02/06/2003', 9);
INSERT INTO valoracions VALUES (1754, 82, '09/01/2008', 3);
INSERT INTO valoracions VALUES (1754, 72, '14/12/2001', 9);
INSERT INTO valoracions VALUES (1755, 92, '20/07/2003', 4);
INSERT INTO valoracions VALUES (1755, 35, '06/07/2006', 8);
INSERT INTO valoracions VALUES (1755, 64, '20/06/2005', 9);
INSERT INTO valoracions VALUES (1755, 113, '12/01/2002', 4);
INSERT INTO valoracions VALUES (1755, 85, '28/08/2003', 10);
INSERT INTO valoracions VALUES (1755, 79, '31/08/2004', 7);
INSERT INTO valoracions VALUES (1756, 93, '11/11/2007', 5);
INSERT INTO valoracions VALUES (1756, 92, '24/05/2002', 2);
INSERT INTO valoracions VALUES (1756, 7, '09/11/2001', 8);
INSERT INTO valoracions VALUES (1758, 80, '10/08/2009', 3);
INSERT INTO valoracions VALUES (1758, 96, '26/03/2004', 8);
INSERT INTO valoracions VALUES (1758, 36, '15/01/2009', 7);
INSERT INTO valoracions VALUES (1758, 81, '06/06/2002', 3);
INSERT INTO valoracions VALUES (1758, 46, '26/09/2003', 6);
INSERT INTO valoracions VALUES (1758, 99, '22/08/2005', 2);
INSERT INTO valoracions VALUES (1758, 36, '25/09/2001', 5);
INSERT INTO valoracions VALUES (1758, 89, '30/09/2005', 5);
INSERT INTO valoracions VALUES (1758, 1, '08/10/2005', 10);
INSERT INTO valoracions VALUES (1758, 18, '24/08/2009', 8);
INSERT INTO valoracions VALUES (1758, 73, '17/12/2002', 6);
INSERT INTO valoracions VALUES (1758, 4, '26/11/2003', 8);
INSERT INTO valoracions VALUES (1759, 6, '25/03/2007', 7);
INSERT INTO valoracions VALUES (1759, 8, '19/05/2003', 5);
INSERT INTO valoracions VALUES (1760, 66, '13/08/2001', 8);
INSERT INTO valoracions VALUES (1760, 30, '10/07/2005', 8);
INSERT INTO valoracions VALUES (1760, 44, '20/05/2010', 7);
INSERT INTO valoracions VALUES (1760, 69, '08/11/2007', 5);
INSERT INTO valoracions VALUES (1760, 66, '16/10/2007', 5);
INSERT INTO valoracions VALUES (1761, 81, '12/07/2005', 8);
INSERT INTO valoracions VALUES (1761, 60, '27/05/2003', 4);
INSERT INTO valoracions VALUES (1761, 85, '14/02/2004', 4);
INSERT INTO valoracions VALUES (1761, 41, '08/09/2007', 4);
INSERT INTO valoracions VALUES (1761, 63, '14/08/2002', 9);
INSERT INTO valoracions VALUES (1761, 68, '28/08/2005', 6);
INSERT INTO valoracions VALUES (1761, 51, '16/02/2008', 9);
INSERT INTO valoracions VALUES (1761, 42, '07/03/2006', 4);
INSERT INTO valoracions VALUES (1761, 115, '01/06/2010', 2);
INSERT INTO valoracions VALUES (1761, 51, '19/12/2004', 4);
INSERT INTO valoracions VALUES (1762, 111, '24/08/2002', 6);
INSERT INTO valoracions VALUES (1762, 72, '08/07/2009', 2);
INSERT INTO valoracions VALUES (1762, 42, '16/07/2010', 7);
INSERT INTO valoracions VALUES (1762, 12, '11/05/2003', 8);
INSERT INTO valoracions VALUES (1763, 77, '27/04/2005', 2);
INSERT INTO valoracions VALUES (1763, 19, '02/08/2007', 8);
INSERT INTO valoracions VALUES (1763, 108, '20/12/2009', 8);
INSERT INTO valoracions VALUES (1764, 31, '11/12/2008', 6);
INSERT INTO valoracions VALUES (1764, 2, '18/11/2005', 8);
INSERT INTO valoracions VALUES (1764, 87, '28/07/2004', 7);
INSERT INTO valoracions VALUES (1765, 40, '11/07/2003', 5);
INSERT INTO valoracions VALUES (1765, 111, '19/10/2004', 4);
INSERT INTO valoracions VALUES (1765, 102, '26/06/2005', 7);
INSERT INTO valoracions VALUES (1765, 84, '22/01/2002', 9);
INSERT INTO valoracions VALUES (1766, 31, '11/01/2007', 9);
INSERT INTO valoracions VALUES (1766, 66, '14/02/2007', 5);
INSERT INTO valoracions VALUES (1767, 61, '20/06/2003', 10);
INSERT INTO valoracions VALUES (1768, 96, '11/10/2002', 7);
INSERT INTO valoracions VALUES (1768, 93, '24/01/2002', 6);
INSERT INTO valoracions VALUES (1768, 54, '29/10/2006', 6);
INSERT INTO valoracions VALUES (1768, 3, '23/07/2007', 6);
INSERT INTO valoracions VALUES (1768, 40, '02/05/2005', 9);
INSERT INTO valoracions VALUES (1768, 78, '20/10/2006', 2);
INSERT INTO valoracions VALUES (1769, 34, '02/04/2005', 9);
INSERT INTO valoracions VALUES (1769, 23, '30/01/2002', 8);
INSERT INTO valoracions VALUES (1769, 61, '27/01/2003', 9);
INSERT INTO valoracions VALUES (1769, 16, '19/01/2004', 6);
INSERT INTO valoracions VALUES (1770, 23, '04/03/2009', 10);
INSERT INTO valoracions VALUES (1770, 76, '11/09/2006', 8);
INSERT INTO valoracions VALUES (1770, 95, '01/08/2002', 5);
INSERT INTO valoracions VALUES (1770, 6, '28/11/2007', 10);
INSERT INTO valoracions VALUES (1770, 72, '25/05/2009', 8);
INSERT INTO valoracions VALUES (1771, 64, '23/09/2010', 6);
INSERT INTO valoracions VALUES (1771, 15, '24/04/2007', 7);
INSERT INTO valoracions VALUES (1771, 105, '04/07/2009', 2);
INSERT INTO valoracions VALUES (1771, 14, '20/03/2002', 9);
INSERT INTO valoracions VALUES (1771, 20, '24/02/2010', 8);
INSERT INTO valoracions VALUES (1771, 21, '03/08/2002', 5);
INSERT INTO valoracions VALUES (1772, 42, '15/05/2001', 9);
INSERT INTO valoracions VALUES (1773, 51, '11/03/2002', 3);
INSERT INTO valoracions VALUES (1773, 54, '30/10/2007', 3);
INSERT INTO valoracions VALUES (1773, 55, '31/01/2007', 3);
INSERT INTO valoracions VALUES (1773, 32, '13/03/2010', 9);
INSERT INTO valoracions VALUES (1774, 92, '05/07/2007', 5);
INSERT INTO valoracions VALUES (1774, 18, '28/11/2009', 9);
INSERT INTO valoracions VALUES (1775, 116, '31/03/2004', 0);
INSERT INTO valoracions VALUES (1775, 38, '09/08/2007', 9);
INSERT INTO valoracions VALUES (1776, 18, '08/09/2005', 5);
INSERT INTO valoracions VALUES (1777, 106, '01/02/2006', 3);
INSERT INTO valoracions VALUES (1777, 67, '01/02/2007', 7);
INSERT INTO valoracions VALUES (1778, 45, '18/03/2010', 7);
INSERT INTO valoracions VALUES (1778, 7, '04/03/2003', 5);
INSERT INTO valoracions VALUES (1779, 66, '30/10/2007', 3);
INSERT INTO valoracions VALUES (1779, 87, '18/02/2006', 4);
INSERT INTO valoracions VALUES (1779, 66, '30/04/2003', 7);
INSERT INTO valoracions VALUES (1779, 12, '07/01/2007', 7);
INSERT INTO valoracions VALUES (1780, 22, '13/07/2009', 5);
INSERT INTO valoracions VALUES (1780, 74, '20/10/2001', 4);
INSERT INTO valoracions VALUES (1780, 45, '29/01/2008', 7);
INSERT INTO valoracions VALUES (1781, 32, '23/10/2005', 10);
INSERT INTO valoracions VALUES (1781, 73, '22/02/2007', 4);
INSERT INTO valoracions VALUES (1781, 86, '05/01/2002', 2);
INSERT INTO valoracions VALUES (1781, 45, '20/05/2005', 6);
INSERT INTO valoracions VALUES (1781, 45, '11/10/2008', 4);
INSERT INTO valoracions VALUES (1781, 69, '05/12/2002', 8);
INSERT INTO valoracions VALUES (1782, 110, '16/01/2007', 10);
INSERT INTO valoracions VALUES (1783, 57, '23/07/2010', 6);
INSERT INTO valoracions VALUES (1783, 87, '27/10/2008', 3);
INSERT INTO valoracions VALUES (1783, 51, '26/08/2005', 4);
INSERT INTO valoracions VALUES (1784, 63, '05/04/2009', 2);
INSERT INTO valoracions VALUES (1784, 53, '05/08/2009', 3);
INSERT INTO valoracions VALUES (1784, 3, '03/11/2001', 8);
INSERT INTO valoracions VALUES (1784, 43, '21/01/2004', 8);
INSERT INTO valoracions VALUES (1785, 67, '31/08/2010', 8);
INSERT INTO valoracions VALUES (1785, 28, '21/06/2005', 6);
INSERT INTO valoracions VALUES (1785, 91, '04/10/2002', 8);
INSERT INTO valoracions VALUES (1785, 29, '16/08/2010', 8);
INSERT INTO valoracions VALUES (1785, 45, '11/06/2003', 9);
INSERT INTO valoracions VALUES (1785, 54, '17/05/2007', 6);
INSERT INTO valoracions VALUES (1786, 21, '28/12/2001', 9);
INSERT INTO valoracions VALUES (1786, 8, '21/07/2006', 7);
INSERT INTO valoracions VALUES (1786, 20, '13/07/2001', 10);
INSERT INTO valoracions VALUES (1786, 94, '08/11/2008', 9);
INSERT INTO valoracions VALUES (1786, 87, '29/10/2005', 2);
INSERT INTO valoracions VALUES (1787, 60, '03/02/2004', 7);
INSERT INTO valoracions VALUES (1787, 21, '01/11/2002', 8);
INSERT INTO valoracions VALUES (1787, 15, '24/10/2007', 10);
INSERT INTO valoracions VALUES (1788, 89, '01/09/2002', 6);
INSERT INTO valoracions VALUES (1788, 30, '02/11/2009', 6);
INSERT INTO valoracions VALUES (1788, 63, '10/03/2006', 5);
INSERT INTO valoracions VALUES (1789, 71, '22/09/2008', 5);
INSERT INTO valoracions VALUES (1789, 4, '17/05/2010', 8);
INSERT INTO valoracions VALUES (1789, 55, '07/12/2004', 5);
INSERT INTO valoracions VALUES (1789, 33, '25/08/2007', 7);
INSERT INTO valoracions VALUES (1789, 60, '01/12/2003', 8);
INSERT INTO valoracions VALUES (1790, 63, '09/03/2004', 9);
INSERT INTO valoracions VALUES (1790, 9, '04/05/2010', 7);
INSERT INTO valoracions VALUES (1790, 112, '28/04/2008', 1);
INSERT INTO valoracions VALUES (1790, 78, '26/07/2009', 5);
INSERT INTO valoracions VALUES (1790, 10, '14/08/2003', 9);
INSERT INTO valoracions VALUES (1790, 41, '29/05/2006', 7);
INSERT INTO valoracions VALUES (1790, 23, '19/02/2008', 5);
INSERT INTO valoracions VALUES (1791, 86, '23/04/2005', 8);
INSERT INTO valoracions VALUES (1791, 22, '07/04/2007', 7);
INSERT INTO valoracions VALUES (1792, 44, '05/12/2002', 5);
INSERT INTO valoracions VALUES (1792, 94, '31/12/2003', 2);
INSERT INTO valoracions VALUES (1792, 35, '17/10/2007', 8);
INSERT INTO valoracions VALUES (1792, 15, '30/05/2007', 5);
INSERT INTO valoracions VALUES (1792, 104, '20/02/2010', 6);
INSERT INTO valoracions VALUES (1793, 110, '16/10/2010', 1);
INSERT INTO valoracions VALUES (1793, 102, '05/05/2008', 4);
INSERT INTO valoracions VALUES (1793, 111, '27/01/2005', 10);
INSERT INTO valoracions VALUES (1793, 61, '27/11/2008', 8);
INSERT INTO valoracions VALUES (1794, 6, '09/02/2002', 9);
INSERT INTO valoracions VALUES (1794, 71, '26/01/2007', 4);
INSERT INTO valoracions VALUES (1794, 36, '10/07/2007', 9);
INSERT INTO valoracions VALUES (1794, 110, '09/06/2005', 9);
INSERT INTO valoracions VALUES (1794, 86, '13/05/2005', 5);
INSERT INTO valoracions VALUES (1795, 46, '22/02/2006', 3);
INSERT INTO valoracions VALUES (1795, 70, '07/09/2003', 8);
INSERT INTO valoracions VALUES (1795, 82, '21/09/2003', 7);
INSERT INTO valoracions VALUES (1795, 91, '04/10/2004', 3);
INSERT INTO valoracions VALUES (1795, 71, '12/04/2003', 7);
INSERT INTO valoracions VALUES (1795, 48, '26/01/2003', 8);
INSERT INTO valoracions VALUES (1795, 1, '17/06/2004', 9);
INSERT INTO valoracions VALUES (1796, 10, '10/08/2007', 9);
INSERT INTO valoracions VALUES (1796, 42, '18/06/2008', 3);
INSERT INTO valoracions VALUES (1796, 20, '06/06/2002', 7);
INSERT INTO valoracions VALUES (1796, 63, '12/02/2004', 7);
INSERT INTO valoracions VALUES (1797, 102, '25/05/2001', 4);
INSERT INTO valoracions VALUES (1797, 69, '20/05/2007', 9);
INSERT INTO valoracions VALUES (1797, 92, '10/04/2005', 5);
INSERT INTO valoracions VALUES (1797, 83, '10/05/2008', 9);
INSERT INTO valoracions VALUES (1798, 46, '18/05/2005', 4);
INSERT INTO valoracions VALUES (1798, 63, '03/10/2006', 7);
INSERT INTO valoracions VALUES (1798, 116, '17/01/2007', 2);
INSERT INTO valoracions VALUES (1798, 111, '23/07/2007', 6);
INSERT INTO valoracions VALUES (1798, 94, '22/06/2009', 9);
INSERT INTO valoracions VALUES (1798, 3, '12/12/2004', 9);
INSERT INTO valoracions VALUES (1798, 45, '29/03/2010', 9);
INSERT INTO valoracions VALUES (1799, 44, '16/07/2009', 4);
INSERT INTO valoracions VALUES (1799, 61, '03/03/2004', 9);
INSERT INTO valoracions VALUES (1799, 74, '08/10/2003', 3);
INSERT INTO valoracions VALUES (1799, 80, '12/07/2006', 4);
INSERT INTO valoracions VALUES (1799, 59, '27/12/2008', 9);
INSERT INTO valoracions VALUES (1799, 106, '17/03/2006', 7);
INSERT INTO valoracions VALUES (1800, 112, '03/06/2001', 9);
INSERT INTO valoracions VALUES (1800, 97, '06/09/2002', 9);
INSERT INTO valoracions VALUES (1800, 21, '11/06/2010', 9);
INSERT INTO valoracions VALUES (1800, 37, '04/05/2007', 6);
INSERT INTO valoracions VALUES (1800, 70, '12/02/2007', 8);
INSERT INTO valoracions VALUES (1800, 41, '30/04/2008', 7);
INSERT INTO valoracions VALUES (1800, 62, '08/02/2007', 9);
INSERT INTO valoracions VALUES (1801, 32, '17/02/2006', 7);
INSERT INTO valoracions VALUES (1801, 73, '06/03/2002', 2);
INSERT INTO valoracions VALUES (1801, 26, '25/09/2004', 9);
INSERT INTO valoracions VALUES (1801, 59, '20/12/2006', 6);
INSERT INTO valoracions VALUES (1801, 72, '29/06/2001', 8);
INSERT INTO valoracions VALUES (1801, 53, '28/01/2010', 6);
INSERT INTO valoracions VALUES (1802, 22, '08/11/2006', 4);
INSERT INTO valoracions VALUES (1802, 90, '30/06/2001', 2);
INSERT INTO valoracions VALUES (1802, 65, '31/12/2009', 3);
INSERT INTO valoracions VALUES (1802, 60, '21/11/2001', 7);
INSERT INTO valoracions VALUES (1802, 99, '14/09/2007', 9);
INSERT INTO valoracions VALUES (1802, 22, '19/06/2004', 5);
INSERT INTO valoracions VALUES (1802, 31, '01/07/2010', 6);
INSERT INTO valoracions VALUES (1803, 27, '12/08/2001', 8);
INSERT INTO valoracions VALUES (1803, 8, '23/04/2004', 7);
INSERT INTO valoracions VALUES (1803, 2, '27/01/2005', 7);
INSERT INTO valoracions VALUES (1803, 38, '10/10/2004', 5);
INSERT INTO valoracions VALUES (1803, 95, '15/03/2003', 8);
INSERT INTO valoracions VALUES (1804, 12, '07/10/2003', 7);
INSERT INTO valoracions VALUES (1804, 67, '02/08/2005', 7);
INSERT INTO valoracions VALUES (1804, 50, '18/11/2003', 9);
INSERT INTO valoracions VALUES (1804, 55, '20/09/2004', 7);
INSERT INTO valoracions VALUES (1805, 43, '14/10/2005', 6);
INSERT INTO valoracions VALUES (1805, 36, '28/11/2008', 7);
INSERT INTO valoracions VALUES (1805, 104, '17/07/2003', 4);
INSERT INTO valoracions VALUES (1805, 54, '06/04/2009', 3);
INSERT INTO valoracions VALUES (1805, 28, '05/02/2008', 4);
INSERT INTO valoracions VALUES (1806, 22, '29/07/2006', 8);
INSERT INTO valoracions VALUES (1806, 15, '21/09/2001', 4);
INSERT INTO valoracions VALUES (1806, 35, '23/12/2007', 4);
INSERT INTO valoracions VALUES (1806, 100, '31/03/2007', 8);
INSERT INTO valoracions VALUES (1806, 81, '15/08/2002', 3);
INSERT INTO valoracions VALUES (1807, 20, '14/10/2010', 7);
INSERT INTO valoracions VALUES (1807, 33, '27/04/2005', 8);
INSERT INTO valoracions VALUES (1807, 75, '19/11/2001', 3);
INSERT INTO valoracions VALUES (1808, 19, '17/10/2005', 5);
INSERT INTO valoracions VALUES (1808, 103, '31/05/2003', 7);
INSERT INTO valoracions VALUES (1808, 99, '30/06/2002', 8);
INSERT INTO valoracions VALUES (1809, 41, '27/06/2009', 10);
INSERT INTO valoracions VALUES (1809, 45, '22/10/2003', 8);
INSERT INTO valoracions VALUES (1809, 92, '24/10/2004', 4);
INSERT INTO valoracions VALUES (1809, 23, '31/12/2003', 6);
INSERT INTO valoracions VALUES (1809, 75, '27/02/2006', 6);
INSERT INTO valoracions VALUES (1809, 67, '01/07/2004', 7);
INSERT INTO valoracions VALUES (1810, 110, '25/10/2006', 1);
INSERT INTO valoracions VALUES (1810, 40, '20/07/2006', 5);
INSERT INTO valoracions VALUES (1810, 97, '07/07/2002', 2);
INSERT INTO valoracions VALUES (1810, 23, '05/07/2007', 8);
INSERT INTO valoracions VALUES (1810, 49, '22/09/2006', 4);
INSERT INTO valoracions VALUES (1810, 11, '20/06/2010', 8);
INSERT INTO valoracions VALUES (1810, 75, '29/05/2010', 6);
INSERT INTO valoracions VALUES (1811, 6, '09/06/2006', 6);
INSERT INTO valoracions VALUES (1811, 79, '27/09/2006', 2);
INSERT INTO valoracions VALUES (1811, 25, '03/08/2002', 9);
INSERT INTO valoracions VALUES (1812, 104, '16/08/2005', 9);
INSERT INTO valoracions VALUES (1812, 24, '03/07/2005', 8);
INSERT INTO valoracions VALUES (1812, 10, '15/12/2004', 10);
INSERT INTO valoracions VALUES (1812, 61, '29/05/2007', 8);
INSERT INTO valoracions VALUES (1812, 89, '15/12/2006', 1);
INSERT INTO valoracions VALUES (1813, 75, '02/08/2008', 3);
INSERT INTO valoracions VALUES (1814, 85, '18/05/2010', 3);
INSERT INTO valoracions VALUES (1814, 7, '28/05/2004', 9);
INSERT INTO valoracions VALUES (1814, 87, '18/08/2001', 5);
INSERT INTO valoracions VALUES (1814, 77, '03/05/2001', 3);
INSERT INTO valoracions VALUES (1814, 31, '05/01/2010', 4);
INSERT INTO valoracions VALUES (1815, 32, '16/03/2008', 7);
INSERT INTO valoracions VALUES (1815, 42, '11/12/2002', 8);
INSERT INTO valoracions VALUES (1815, 61, '04/11/2009', 8);
INSERT INTO valoracions VALUES (1815, 78, '31/10/2002', 8);
INSERT INTO valoracions VALUES (1815, 104, '12/09/2006', 7);
INSERT INTO valoracions VALUES (1816, 98, '29/12/2006', 8);
INSERT INTO valoracions VALUES (1816, 5, '30/06/2009', 5);
INSERT INTO valoracions VALUES (1816, 57, '21/11/2005', 9);
INSERT INTO valoracions VALUES (1816, 114, '05/06/2008', 10);
INSERT INTO valoracions VALUES (1816, 24, '18/12/2009', 9);
INSERT INTO valoracions VALUES (1816, 114, '31/03/2003', 2);
INSERT INTO valoracions VALUES (1817, 5, '29/05/2005', 6);
INSERT INTO valoracions VALUES (1817, 55, '28/11/2009', 8);
INSERT INTO valoracions VALUES (1818, 18, '19/02/2007', 7);
INSERT INTO valoracions VALUES (1818, 111, '08/08/2001', 5);
INSERT INTO valoracions VALUES (1818, 52, '18/06/2010', 4);
INSERT INTO valoracions VALUES (1818, 54, '30/05/2002', 3);
INSERT INTO valoracions VALUES (1819, 75, '19/05/2004', 3);
INSERT INTO valoracions VALUES (1819, 109, '07/06/2003', 2);
INSERT INTO valoracions VALUES (1819, 14, '30/01/2010', 9);
INSERT INTO valoracions VALUES (1819, 49, '15/10/2004', 8);
INSERT INTO valoracions VALUES (1819, 48, '22/03/2010', 7);
INSERT INTO valoracions VALUES (1819, 20, '17/08/2007', 8);
INSERT INTO valoracions VALUES (1819, 40, '17/09/2008', 4);
INSERT INTO valoracions VALUES (1820, 10, '25/01/2004', 8);
INSERT INTO valoracions VALUES (1820, 110, '10/08/2002', 7);
INSERT INTO valoracions VALUES (1820, 2, '03/03/2002', 6);
INSERT INTO valoracions VALUES (1820, 95, '13/08/2005', 9);
INSERT INTO valoracions VALUES (1820, 44, '14/08/2007', 7);
INSERT INTO valoracions VALUES (1820, 78, '09/02/2005', 4);
INSERT INTO valoracions VALUES (1821, 89, '13/10/2008', 2);
INSERT INTO valoracions VALUES (1821, 97, '10/04/2005', 5);
INSERT INTO valoracions VALUES (1821, 18, '23/01/2008', 9);
INSERT INTO valoracions VALUES (1822, 61, '10/06/2008', 2);
INSERT INTO valoracions VALUES (1822, 8, '08/06/2007', 10);
INSERT INTO valoracions VALUES (1822, 81, '27/08/2003', 4);
INSERT INTO valoracions VALUES (1823, 97, '16/02/2009', 5);
INSERT INTO valoracions VALUES (1823, 77, '01/10/2001', 8);
INSERT INTO valoracions VALUES (1823, 2, '02/03/2010', 6);
INSERT INTO valoracions VALUES (1823, 49, '23/12/2009', 4);
INSERT INTO valoracions VALUES (1824, 114, '28/04/2004', 4);
INSERT INTO valoracions VALUES (1824, 99, '20/04/2005', 8);
INSERT INTO valoracions VALUES (1824, 10, '10/06/2001', 6);
INSERT INTO valoracions VALUES (1824, 77, '28/06/2008', 4);
INSERT INTO valoracions VALUES (1826, 3, '19/03/2007', 9);
INSERT INTO valoracions VALUES (1826, 19, '17/08/2006', 6);
INSERT INTO valoracions VALUES (1826, 111, '17/09/2010', 3);
INSERT INTO valoracions VALUES (1826, 32, '15/01/2006', 8);
INSERT INTO valoracions VALUES (1826, 52, '28/04/2009', 7);
INSERT INTO valoracions VALUES (1826, 112, '26/08/2002', 9);
INSERT INTO valoracions VALUES (1827, 1, '26/04/2001', 7);
INSERT INTO valoracions VALUES (1827, 110, '21/08/2004', 5);
INSERT INTO valoracions VALUES (1827, 99, '24/04/2007', 7);
INSERT INTO valoracions VALUES (1827, 36, '31/12/2003', 6);
INSERT INTO valoracions VALUES (1827, 39, '19/11/2008', 7);
INSERT INTO valoracions VALUES (1828, 3, '15/07/2002', 9);
INSERT INTO valoracions VALUES (1828, 87, '26/03/2008', 2);
INSERT INTO valoracions VALUES (1828, 80, '23/09/2001', 7);
INSERT INTO valoracions VALUES (1829, 60, '21/06/2006', 5);
INSERT INTO valoracions VALUES (1829, 56, '09/08/2009', 9);
INSERT INTO valoracions VALUES (1829, 74, '15/01/2005', 6);
INSERT INTO valoracions VALUES (1829, 18, '30/06/2002', 8);
INSERT INTO valoracions VALUES (1829, 58, '01/11/2007', 7);
INSERT INTO valoracions VALUES (1829, 53, '12/07/2006', 5);
INSERT INTO valoracions VALUES (1830, 53, '10/09/2010', 8);
INSERT INTO valoracions VALUES (1830, 90, '11/08/2008', 8);
INSERT INTO valoracions VALUES (1830, 106, '23/06/2006', 1);
INSERT INTO valoracions VALUES (1831, 9, '30/08/2006', 6);
INSERT INTO valoracions VALUES (1831, 34, '26/02/2003', 4);
INSERT INTO valoracions VALUES (1831, 1, '06/05/2008', 7);
INSERT INTO valoracions VALUES (1831, 23, '18/10/2007', 5);
INSERT INTO valoracions VALUES (1831, 29, '16/04/2005', 9);
INSERT INTO valoracions VALUES (1832, 106, '28/09/2010', 9);
INSERT INTO valoracions VALUES (1832, 116, '16/06/2007', 9);
INSERT INTO valoracions VALUES (1832, 113, '28/10/2001', 0);
INSERT INTO valoracions VALUES (1832, 102, '30/09/2005', 1);
INSERT INTO valoracions VALUES (1832, 103, '20/11/2002', 2);
INSERT INTO valoracions VALUES (1832, 51, '31/12/2005', 6);
INSERT INTO valoracions VALUES (1832, 110, '11/05/2005', 8);
INSERT INTO valoracions VALUES (1833, 80, '28/09/2009', 9);
INSERT INTO valoracions VALUES (1833, 60, '24/06/2005', 8);
INSERT INTO valoracions VALUES (1833, 84, '22/04/2002', 7);
INSERT INTO valoracions VALUES (1834, 105, '21/05/2004', 7);
INSERT INTO valoracions VALUES (1834, 68, '24/04/2003', 5);
INSERT INTO valoracions VALUES (1834, 54, '25/09/2003', 6);
INSERT INTO valoracions VALUES (1834, 92, '28/12/2008', 3);
INSERT INTO valoracions VALUES (1835, 28, '21/08/2001', 6);
INSERT INTO valoracions VALUES (1836, 7, '24/04/2008', 9);
INSERT INTO valoracions VALUES (1836, 77, '04/06/2007', 10);
INSERT INTO valoracions VALUES (1836, 32, '14/09/2005', 7);
INSERT INTO valoracions VALUES (1836, 49, '09/04/2008', 6);
INSERT INTO valoracions VALUES (1837, 106, '15/12/2007', 0);
INSERT INTO valoracions VALUES (1837, 20, '22/03/2004', 8);
INSERT INTO valoracions VALUES (1837, 102, '13/03/2005', 5);
INSERT INTO valoracions VALUES (1837, 3, '31/03/2007', 7);
INSERT INTO valoracions VALUES (1837, 108, '04/08/2006', 3);
INSERT INTO valoracions VALUES (1837, 11, '05/05/2008', 8);
INSERT INTO valoracions VALUES (1838, 106, '17/11/2005', 6);
INSERT INTO valoracions VALUES (1838, 108, '28/04/2008', 4);
INSERT INTO valoracions VALUES (1838, 64, '09/07/2007', 7);
INSERT INTO valoracions VALUES (1838, 63, '05/11/2008', 7);
INSERT INTO valoracions VALUES (1838, 72, '18/01/2010', 2);
INSERT INTO valoracions VALUES (1838, 22, '18/07/2006', 6);
INSERT INTO valoracions VALUES (1838, 37, '31/01/2004', 5);
INSERT INTO valoracions VALUES (1839, 11, '22/01/2003', 5);
INSERT INTO valoracions VALUES (1839, 91, '08/07/2002', 8);
INSERT INTO valoracions VALUES (1839, 73, '26/01/2008', 2);
INSERT INTO valoracions VALUES (1840, 33, '27/07/2006', 5);
INSERT INTO valoracions VALUES (1840, 42, '08/03/2009', 6);
INSERT INTO valoracions VALUES (1840, 90, '08/05/2006', 8);
INSERT INTO valoracions VALUES (1840, 96, '09/10/2003', 7);
INSERT INTO valoracions VALUES (1840, 38, '01/03/2006', 4);
INSERT INTO valoracions VALUES (1840, 12, '30/09/2005', 6);
INSERT INTO valoracions VALUES (1840, 3, '18/01/2007', 6);
INSERT INTO valoracions VALUES (1841, 14, '11/05/2005', 8);
INSERT INTO valoracions VALUES (1841, 68, '24/11/2009', 4);
INSERT INTO valoracions VALUES (1841, 50, '22/01/2005', 7);
INSERT INTO valoracions VALUES (1842, 85, '06/01/2006', 7);
INSERT INTO valoracions VALUES (1842, 47, '04/06/2004', 7);
INSERT INTO valoracions VALUES (1842, 66, '13/10/2006', 8);
INSERT INTO valoracions VALUES (1842, 91, '22/11/2002', 4);
INSERT INTO valoracions VALUES (1842, 4, '04/10/2007', 5);
INSERT INTO valoracions VALUES (1842, 16, '19/07/2005', 8);
INSERT INTO valoracions VALUES (1842, 67, '29/06/2010', 9);
INSERT INTO valoracions VALUES (1842, 52, '19/10/2004', 9);
INSERT INTO valoracions VALUES (1843, 64, '03/01/2005', 3);
INSERT INTO valoracions VALUES (1843, 53, '05/11/2001', 5);
INSERT INTO valoracions VALUES (1843, 10, '01/03/2006', 5);
INSERT INTO valoracions VALUES (1843, 69, '13/09/2008', 4);
INSERT INTO valoracions VALUES (1843, 59, '13/07/2009', 3);
INSERT INTO valoracions VALUES (1843, 75, '02/11/2007', 7);
INSERT INTO valoracions VALUES (1844, 6, '20/03/2010', 7);
INSERT INTO valoracions VALUES (1844, 37, '20/12/2004', 8);
INSERT INTO valoracions VALUES (1844, 9, '28/04/2008', 6);
INSERT INTO valoracions VALUES (1845, 42, '12/04/2007', 7);
INSERT INTO valoracions VALUES (1845, 56, '06/02/2008', 8);
INSERT INTO valoracions VALUES (1845, 78, '22/09/2004', 3);
INSERT INTO valoracions VALUES (1846, 7, '11/03/2005', 7);
INSERT INTO valoracions VALUES (1846, 21, '19/11/2008', 8);
INSERT INTO valoracions VALUES (1846, 56, '02/06/2004', 5);
INSERT INTO valoracions VALUES (1846, 66, '28/08/2005', 8);
INSERT INTO valoracions VALUES (1846, 56, '23/10/2003', 10);
INSERT INTO valoracions VALUES (1846, 29, '28/11/2009', 4);
INSERT INTO valoracions VALUES (1847, 91, '18/02/2007', 2);
INSERT INTO valoracions VALUES (1847, 10, '30/07/2003', 5);
INSERT INTO valoracions VALUES (1848, 19, '08/10/2008', 9);
INSERT INTO valoracions VALUES (1848, 42, '07/02/2009', 9);
INSERT INTO valoracions VALUES (1849, 74, '07/08/2006', 9);
INSERT INTO valoracions VALUES (1849, 41, '26/12/2005', 5);
INSERT INTO valoracions VALUES (1849, 24, '03/05/2007', 6);
INSERT INTO valoracions VALUES (1849, 60, '18/12/2001', 6);
INSERT INTO valoracions VALUES (1849, 52, '19/06/2002', 6);
INSERT INTO valoracions VALUES (1849, 29, '06/01/2003', 6);
INSERT INTO valoracions VALUES (1850, 25, '18/08/2007', 5);
INSERT INTO valoracions VALUES (1850, 99, '17/08/2006', 2);
INSERT INTO valoracions VALUES (1850, 73, '11/11/2001', 5);
INSERT INTO valoracions VALUES (1850, 17, '03/07/2006', 8);
INSERT INTO valoracions VALUES (1850, 89, '01/01/2002', 6);
INSERT INTO valoracions VALUES (1851, 39, '20/02/2006', 4);
INSERT INTO valoracions VALUES (1851, 69, '13/01/2009', 6);
INSERT INTO valoracions VALUES (1851, 108, '02/01/2007', 9);
INSERT INTO valoracions VALUES (1851, 13, '15/09/2010', 5);
INSERT INTO valoracions VALUES (1852, 74, '02/06/2005', 9);
INSERT INTO valoracions VALUES (1852, 20, '28/09/2005', 7);
INSERT INTO valoracions VALUES (1852, 40, '17/09/2006', 4);
INSERT INTO valoracions VALUES (1852, 50, '12/08/2002', 9);
INSERT INTO valoracions VALUES (1852, 21, '12/02/2010', 7);
INSERT INTO valoracions VALUES (1853, 35, '24/11/2001', 9);
INSERT INTO valoracions VALUES (1853, 82, '05/06/2004', 2);
INSERT INTO valoracions VALUES (1853, 79, '05/09/2010', 7);
INSERT INTO valoracions VALUES (1854, 75, '19/05/2003', 8);
INSERT INTO valoracions VALUES (1854, 40, '21/07/2004', 7);
INSERT INTO valoracions VALUES (1854, 84, '14/10/2009', 7);
INSERT INTO valoracions VALUES (1854, 58, '01/11/2003', 9);
INSERT INTO valoracions VALUES (1854, 23, '30/10/2005', 6);
INSERT INTO valoracions VALUES (1854, 29, '04/04/2006', 8);
INSERT INTO valoracions VALUES (1855, 13, '20/08/2004', 8);
INSERT INTO valoracions VALUES (1855, 22, '26/06/2010', 8);
INSERT INTO valoracions VALUES (1855, 71, '04/01/2003', 4);
INSERT INTO valoracions VALUES (1855, 44, '25/11/2005', 5);
INSERT INTO valoracions VALUES (1856, 37, '08/06/2004', 9);
INSERT INTO valoracions VALUES (1856, 32, '19/02/2003', 7);
INSERT INTO valoracions VALUES (1856, 83, '25/07/2008', 2);
INSERT INTO valoracions VALUES (1856, 23, '27/07/2006', 5);
INSERT INTO valoracions VALUES (1857, 31, '24/12/2002', 9);
INSERT INTO valoracions VALUES (1857, 20, '13/05/2010', 5);
INSERT INTO valoracions VALUES (1858, 67, '29/05/2002', 6);
INSERT INTO valoracions VALUES (1858, 54, '27/02/2010', 3);
INSERT INTO valoracions VALUES (1858, 104, '15/04/2008', 3);
INSERT INTO valoracions VALUES (1858, 15, '12/02/2010', 7);
INSERT INTO valoracions VALUES (1858, 38, '02/06/2010', 8);
INSERT INTO valoracions VALUES (1858, 89, '17/08/2009', 6);
INSERT INTO valoracions VALUES (1859, 55, '31/01/2002', 10);
INSERT INTO valoracions VALUES (1859, 14, '24/06/2008', 9);
INSERT INTO valoracions VALUES (1860, 31, '18/10/2001', 9);
INSERT INTO valoracions VALUES (1860, 18, '21/04/2001', 9);
INSERT INTO valoracions VALUES (1860, 24, '23/07/2010', 5);
INSERT INTO valoracions VALUES (1861, 10, '17/07/2007', 9);
INSERT INTO valoracions VALUES (1861, 38, '06/12/2008', 8);
INSERT INTO valoracions VALUES (1861, 27, '03/05/2005', 6);
INSERT INTO valoracions VALUES (1861, 4, '28/01/2006', 8);
INSERT INTO valoracions VALUES (1861, 59, '03/12/2009', 7);
INSERT INTO valoracions VALUES (1861, 58, '11/03/2004', 5);
INSERT INTO valoracions VALUES (1861, 4, '18/01/2010', 6);
INSERT INTO valoracions VALUES (1861, 26, '08/08/2009', 8);
INSERT INTO valoracions VALUES (1862, 30, '09/07/2009', 8);
INSERT INTO valoracions VALUES (1862, 68, '27/05/2001', 8);
INSERT INTO valoracions VALUES (1862, 17, '19/05/2001', 5);
INSERT INTO valoracions VALUES (1862, 47, '14/08/2001', 6);
INSERT INTO valoracions VALUES (1863, 64, '07/07/2007', 8);
INSERT INTO valoracions VALUES (1863, 47, '04/11/2004', 10);
INSERT INTO valoracions VALUES (1863, 11, '22/01/2003', 8);
INSERT INTO valoracions VALUES (1864, 43, '10/03/2007', 8);
INSERT INTO valoracions VALUES (1864, 63, '17/02/2008', 7);
INSERT INTO valoracions VALUES (1864, 73, '02/10/2001', 9);
INSERT INTO valoracions VALUES (1864, 51, '18/07/2003', 5);
INSERT INTO valoracions VALUES (1864, 73, '25/12/2006', 6);
INSERT INTO valoracions VALUES (1864, 100, '18/06/2004', 8);
INSERT INTO valoracions VALUES (1864, 41, '02/01/2004', 9);
INSERT INTO valoracions VALUES (1864, 47, '05/10/2007', 7);
INSERT INTO valoracions VALUES (1865, 67, '09/03/2009', 8);
INSERT INTO valoracions VALUES (1865, 30, '07/03/2005', 10);
INSERT INTO valoracions VALUES (1865, 95, '06/09/2009', 10);
INSERT INTO valoracions VALUES (1865, 45, '10/05/2008', 6);
INSERT INTO valoracions VALUES (1865, 106, '13/05/2006', 6);
INSERT INTO valoracions VALUES (1865, 53, '22/03/2002', 5);
INSERT INTO valoracions VALUES (1866, 86, '10/08/2008', 8);
INSERT INTO valoracions VALUES (1866, 36, '25/06/2008', 8);
INSERT INTO valoracions VALUES (1866, 15, '07/06/2010', 9);
INSERT INTO valoracions VALUES (1866, 12, '27/04/2001', 7);
INSERT INTO valoracions VALUES (1866, 48, '26/09/2005', 4);
INSERT INTO valoracions VALUES (1866, 44, '28/02/2006', 9);
INSERT INTO valoracions VALUES (1867, 84, '09/10/2002', 1);
INSERT INTO valoracions VALUES (1867, 22, '02/10/2006', 9);
INSERT INTO valoracions VALUES (1867, 77, '21/02/2010', 3);
INSERT INTO valoracions VALUES (1868, 15, '21/08/2004', 7);
INSERT INTO valoracions VALUES (1868, 92, '21/10/2010', 4);
INSERT INTO valoracions VALUES (1869, 7, '17/09/2010', 9);
INSERT INTO valoracions VALUES (1869, 66, '17/09/2006', 9);
INSERT INTO valoracions VALUES (1869, 98, '07/03/2005', 6);
INSERT INTO valoracions VALUES (1870, 72, '13/04/2005', 10);
INSERT INTO valoracions VALUES (1870, 34, '25/03/2005', 5);
INSERT INTO valoracions VALUES (1870, 45, '21/10/2009', 9);
INSERT INTO valoracions VALUES (1870, 82, '29/11/2009', 5);
INSERT INTO valoracions VALUES (1870, 113, '20/06/2006', 8);
INSERT INTO valoracions VALUES (1871, 32, '08/03/2006', 8);
INSERT INTO valoracions VALUES (1871, 110, '10/10/2006', 1);
INSERT INTO valoracions VALUES (1871, 86, '04/05/2003', 9);
INSERT INTO valoracions VALUES (1872, 55, '01/02/2003', 9);
INSERT INTO valoracions VALUES (1872, 1, '25/07/2009', 7);
INSERT INTO valoracions VALUES (1872, 43, '24/08/2005', 9);
INSERT INTO valoracions VALUES (1872, 75, '03/05/2008', 7);
INSERT INTO valoracions VALUES (1873, 96, '04/10/2008', 3);
INSERT INTO valoracions VALUES (1873, 40, '06/02/2004', 8);
INSERT INTO valoracions VALUES (1873, 99, '20/09/2008', 4);
INSERT INTO valoracions VALUES (1874, 45, '01/04/2002', 9);
INSERT INTO valoracions VALUES (1874, 81, '12/10/2010', 7);
INSERT INTO valoracions VALUES (1874, 18, '14/07/2003', 7);
INSERT INTO valoracions VALUES (1874, 96, '03/06/2005', 9);
INSERT INTO valoracions VALUES (1875, 48, '17/06/2006', 9);
INSERT INTO valoracions VALUES (1875, 45, '27/04/2006', 9);
INSERT INTO valoracions VALUES (1875, 8, '29/05/2008', 5);
INSERT INTO valoracions VALUES (1875, 66, '03/03/2003', 7);
INSERT INTO valoracions VALUES (1875, 48, '23/04/2006', 4);
INSERT INTO valoracions VALUES (1876, 15, '06/08/2001', 4);
INSERT INTO valoracions VALUES (1876, 94, '31/03/2003', 6);
INSERT INTO valoracions VALUES (1876, 1, '07/05/2010', 8);
INSERT INTO valoracions VALUES (1876, 42, '10/01/2006', 5);
INSERT INTO valoracions VALUES (1877, 42, '25/10/2005', 3);
INSERT INTO valoracions VALUES (1877, 41, '08/03/2006', 5);
INSERT INTO valoracions VALUES (1877, 77, '29/10/2008', 7);
INSERT INTO valoracions VALUES (1877, 79, '21/10/2001', 7);
INSERT INTO valoracions VALUES (1878, 106, '26/09/2008', 2);
INSERT INTO valoracions VALUES (1878, 66, '27/01/2004', 3);
INSERT INTO valoracions VALUES (1878, 10, '27/08/2006', 8);
INSERT INTO valoracions VALUES (1879, 35, '23/01/2008', 5);
INSERT INTO valoracions VALUES (1879, 22, '26/10/2001', 6);
INSERT INTO valoracions VALUES (1879, 51, '20/04/2004', 9);
INSERT INTO valoracions VALUES (1879, 79, '30/08/2003', 9);
INSERT INTO valoracions VALUES (1879, 108, '21/07/2005', 0);
INSERT INTO valoracions VALUES (1879, 82, '14/03/2010', 10);
INSERT INTO valoracions VALUES (1879, 86, '08/07/2010', 5);
INSERT INTO valoracions VALUES (1879, 92, '26/04/2009', 6);
INSERT INTO valoracions VALUES (1880, 94, '23/10/2001', 2);
INSERT INTO valoracions VALUES (1880, 8, '04/08/2004', 9);
INSERT INTO valoracions VALUES (1881, 77, '08/04/2005', 10);
INSERT INTO valoracions VALUES (1881, 6, '10/07/2002', 6);
INSERT INTO valoracions VALUES (1881, 47, '15/08/2009', 6);
INSERT INTO valoracions VALUES (1882, 46, '16/01/2007', 3);
INSERT INTO valoracions VALUES (1882, 5, '18/02/2002', 5);
INSERT INTO valoracions VALUES (1882, 84, '02/12/2005', 7);
INSERT INTO valoracions VALUES (1882, 92, '03/09/2010', 5);
INSERT INTO valoracions VALUES (1883, 86, '02/06/2009', 4);
INSERT INTO valoracions VALUES (1883, 36, '19/08/2006', 7);
INSERT INTO valoracions VALUES (1883, 112, '14/07/2004', 9);
INSERT INTO valoracions VALUES (1883, 58, '26/06/2002', 9);
INSERT INTO valoracions VALUES (1884, 51, '23/06/2003', 4);
INSERT INTO valoracions VALUES (1884, 21, '13/06/2008', 5);
INSERT INTO valoracions VALUES (1884, 35, '31/01/2003', 7);
INSERT INTO valoracions VALUES (1884, 73, '31/07/2001', 4);
INSERT INTO valoracions VALUES (1884, 82, '10/05/2002', 3);
INSERT INTO valoracions VALUES (1884, 76, '20/09/2010', 8);
INSERT INTO valoracions VALUES (1884, 58, '29/04/2008', 3);
INSERT INTO valoracions VALUES (1885, 111, '25/01/2006', 10);
INSERT INTO valoracions VALUES (1885, 8, '20/09/2006', 8);
INSERT INTO valoracions VALUES (1886, 42, '25/09/2006', 7);
INSERT INTO valoracions VALUES (1887, 47, '03/02/2008', 4);
INSERT INTO valoracions VALUES (1887, 43, '21/12/2002', 8);
INSERT INTO valoracions VALUES (1888, 87, '07/07/2006', 9);
INSERT INTO valoracions VALUES (1888, 10, '30/08/2004', 7);
INSERT INTO valoracions VALUES (1888, 111, '06/10/2007', 4);
INSERT INTO valoracions VALUES (1888, 54, '08/04/2002', 3);
INSERT INTO valoracions VALUES (1888, 87, '24/08/2005', 7);
INSERT INTO valoracions VALUES (1888, 21, '06/08/2002', 10);
INSERT INTO valoracions VALUES (1889, 68, '18/12/2001', 8);
INSERT INTO valoracions VALUES (1889, 22, '24/03/2004', 8);
INSERT INTO valoracions VALUES (1889, 52, '09/11/2004', 3);
INSERT INTO valoracions VALUES (1889, 91, '27/06/2005', 7);
INSERT INTO valoracions VALUES (1889, 10, '20/08/2002', 8);
INSERT INTO valoracions VALUES (1889, 72, '02/07/2004', 4);
INSERT INTO valoracions VALUES (1890, 2, '01/02/2008', 8);
INSERT INTO valoracions VALUES (1890, 92, '29/01/2006', 7);
INSERT INTO valoracions VALUES (1890, 110, '15/02/2007', 8);
INSERT INTO valoracions VALUES (1891, 82, '08/07/2008', 5);
INSERT INTO valoracions VALUES (1891, 17, '29/05/2003', 5);
INSERT INTO valoracions VALUES (1892, 111, '22/12/2001', 1);
INSERT INTO valoracions VALUES (1892, 112, '05/09/2007', 7);
INSERT INTO valoracions VALUES (1892, 74, '04/05/2001', 8);
INSERT INTO valoracions VALUES (1892, 104, '08/05/2006', 2);
INSERT INTO valoracions VALUES (1892, 114, '08/10/2003', 8);
INSERT INTO valoracions VALUES (1892, 88, '22/01/2010', 4);
INSERT INTO valoracions VALUES (1893, 36, '08/01/2005', 4);
INSERT INTO valoracions VALUES (1893, 58, '01/09/2008', 9);
INSERT INTO valoracions VALUES (1893, 13, '14/04/2002', 9);
INSERT INTO valoracions VALUES (1894, 38, '18/07/2006', 3);
INSERT INTO valoracions VALUES (1894, 111, '27/08/2007', 5);
INSERT INTO valoracions VALUES (1895, 37, '29/03/2003', 8);
INSERT INTO valoracions VALUES (1895, 105, '05/10/2005', 1);
INSERT INTO valoracions VALUES (1895, 79, '04/05/2008', 3);
INSERT INTO valoracions VALUES (1896, 29, '19/05/2004', 9);
INSERT INTO valoracions VALUES (1896, 71, '07/11/2007', 2);
INSERT INTO valoracions VALUES (1896, 44, '09/06/2009', 5);
INSERT INTO valoracions VALUES (1896, 114, '20/06/2006', 1);
INSERT INTO valoracions VALUES (1897, 36, '21/09/2004', 9);
INSERT INTO valoracions VALUES (1897, 25, '11/09/2003', 6);
INSERT INTO valoracions VALUES (1897, 96, '08/09/2004', 5);
INSERT INTO valoracions VALUES (1897, 1, '09/11/2003', 9);
INSERT INTO valoracions VALUES (1897, 53, '03/12/2007', 4);
INSERT INTO valoracions VALUES (1897, 70, '08/10/2007', 4);
INSERT INTO valoracions VALUES (1897, 67, '19/08/2010', 7);
INSERT INTO valoracions VALUES (1897, 3, '13/02/2008', 9);
INSERT INTO valoracions VALUES (1898, 37, '12/03/2009', 5);
INSERT INTO valoracions VALUES (1898, 62, '25/09/2005', 5);
INSERT INTO valoracions VALUES (1898, 69, '23/07/2005', 5);
INSERT INTO valoracions VALUES (1898, 69, '09/01/2002', 5);
INSERT INTO valoracions VALUES (1898, 77, '10/04/2001', 4);
INSERT INTO valoracions VALUES (1898, 79, '11/01/2005', 7);
INSERT INTO valoracions VALUES (1898, 4, '24/04/2010', 5);
INSERT INTO valoracions VALUES (1898, 10, '08/04/2001', 9);
INSERT INTO valoracions VALUES (1898, 27, '07/06/2005', 6);
INSERT INTO valoracions VALUES (1898, 32, '27/04/2007', 9);
INSERT INTO valoracions VALUES (1898, 56, '28/05/2004', 7);
INSERT INTO valoracions VALUES (1899, 8, '02/03/2007', 5);
INSERT INTO valoracions VALUES (1899, 65, '15/08/2003', 10);
INSERT INTO valoracions VALUES (1899, 115, '18/12/2008', 5);
INSERT INTO valoracions VALUES (1900, 12, '14/09/2002', 6);
INSERT INTO valoracions VALUES (1900, 105, '19/05/2008', 1);
INSERT INTO valoracions VALUES (1900, 90, '12/12/2005', 9);
INSERT INTO valoracions VALUES (1900, 107, '16/03/2007', 7);
INSERT INTO valoracions VALUES (1900, 101, '25/10/2009', 3);
INSERT INTO valoracions VALUES (1900, 44, '26/06/2010', 7);
INSERT INTO valoracions VALUES (1901, 98, '04/12/2009', 9);
INSERT INTO valoracions VALUES (1901, 51, '27/01/2004', 7);
INSERT INTO valoracions VALUES (1901, 59, '10/02/2004', 8);
INSERT INTO valoracions VALUES (1902, 95, '25/01/2002', 8);
INSERT INTO valoracions VALUES (1902, 66, '04/01/2008', 7);
INSERT INTO valoracions VALUES (1903, 10, '07/07/2009', 7);
INSERT INTO valoracions VALUES (1903, 63, '21/09/2010', 9);
INSERT INTO valoracions VALUES (1903, 101, '01/06/2007', 9);
INSERT INTO valoracions VALUES (1903, 22, '02/10/2009', 8);
INSERT INTO valoracions VALUES (1903, 91, '10/05/2009', 9);
INSERT INTO valoracions VALUES (1904, 86, '03/02/2010', 4);
INSERT INTO valoracions VALUES (1904, 62, '25/03/2005', 6);
INSERT INTO valoracions VALUES (1904, 45, '06/07/2005', 9);
INSERT INTO valoracions VALUES (1904, 37, '16/10/2006', 7);
INSERT INTO valoracions VALUES (1904, 36, '15/04/2009', 8);
INSERT INTO valoracions VALUES (1905, 91, '04/08/2004', 8);
INSERT INTO valoracions VALUES (1905, 14, '15/08/2005', 8);
INSERT INTO valoracions VALUES (1905, 8, '14/02/2004', 6);
INSERT INTO valoracions VALUES (1906, 30, '01/01/2009', 6);
INSERT INTO valoracions VALUES (1906, 79, '21/09/2005', 8);
INSERT INTO valoracions VALUES (1906, 35, '01/09/2001', 5);
INSERT INTO valoracions VALUES (1906, 54, '02/10/2009', 10);
INSERT INTO valoracions VALUES (1906, 3, '02/06/2007', 5);
INSERT INTO valoracions VALUES (1906, 101, '01/12/2006', 2);
INSERT INTO valoracions VALUES (1906, 113, '14/03/2003', 8);
INSERT INTO valoracions VALUES (1906, 54, '07/08/2010', 6);
INSERT INTO valoracions VALUES (1907, 91, '15/11/2005', 6);
INSERT INTO valoracions VALUES (1907, 41, '21/10/2001', 4);
INSERT INTO valoracions VALUES (1907, 5, '21/03/2003', 9);
INSERT INTO valoracions VALUES (1907, 48, '19/06/2010', 9);
INSERT INTO valoracions VALUES (1907, 113, '23/01/2007', 4);
INSERT INTO valoracions VALUES (1908, 105, '17/01/2007', 9);
INSERT INTO valoracions VALUES (1908, 43, '15/11/2001', 7);
INSERT INTO valoracions VALUES (1908, 64, '20/06/2008', 5);
INSERT INTO valoracions VALUES (1908, 16, '27/09/2006', 7);
INSERT INTO valoracions VALUES (1909, 12, '22/11/2006', 8);
INSERT INTO valoracions VALUES (1909, 48, '19/05/2008', 7);
INSERT INTO valoracions VALUES (1909, 60, '27/06/2009', 9);
INSERT INTO valoracions VALUES (1909, 28, '27/04/2004', 6);
INSERT INTO valoracions VALUES (1910, 108, '26/02/2006', 6);
INSERT INTO valoracions VALUES (1910, 68, '13/09/2001', 4);
INSERT INTO valoracions VALUES (1910, 21, '26/10/2003', 8);
INSERT INTO valoracions VALUES (1910, 58, '04/11/2001', 10);
INSERT INTO valoracions VALUES (1910, 115, '15/08/2006', 5);
INSERT INTO valoracions VALUES (1913, 14, '25/03/2007', 7);
INSERT INTO valoracions VALUES (1913, 27, '04/05/2006', 8);
INSERT INTO valoracions VALUES (1913, 48, '07/05/2006', 10);
INSERT INTO valoracions VALUES (1913, 63, '02/05/2003', 3);
INSERT INTO valoracions VALUES (1914, 79, '16/04/2005', 5);
INSERT INTO valoracions VALUES (1914, 2, '22/04/2007', 6);
INSERT INTO valoracions VALUES (1915, 12, '21/02/2002', 9);
INSERT INTO valoracions VALUES (1916, 18, '08/01/2005', 9);
INSERT INTO valoracions VALUES (1916, 74, '10/07/2002', 9);
INSERT INTO valoracions VALUES (1916, 51, '09/07/2010', 6);
INSERT INTO valoracions VALUES (1917, 77, '16/09/2002', 4);
INSERT INTO valoracions VALUES (1917, 69, '09/08/2008', 3);
INSERT INTO valoracions VALUES (1918, 15, '10/09/2005', 5);
INSERT INTO valoracions VALUES (1919, 101, '24/02/2010', 3);
INSERT INTO valoracions VALUES (1919, 97, '26/09/2009', 2);
INSERT INTO valoracions VALUES (1919, 60, '07/03/2003', 8);
INSERT INTO valoracions VALUES (1919, 77, '12/06/2006', 5);
INSERT INTO valoracions VALUES (1920, 73, '06/08/2009', 8);
INSERT INTO valoracions VALUES (1920, 17, '23/12/2002', 9);
INSERT INTO valoracions VALUES (1920, 6, '08/09/2001', 8);
INSERT INTO valoracions VALUES (1920, 45, '21/06/2002', 9);
INSERT INTO valoracions VALUES (1920, 66, '18/03/2006', 4);
INSERT INTO valoracions VALUES (1920, 19, '24/11/2008', 6);
INSERT INTO valoracions VALUES (1921, 91, '28/09/2007', 7);
INSERT INTO valoracions VALUES (1921, 89, '04/07/2002', 1);
INSERT INTO valoracions VALUES (1921, 20, '29/11/2007', 7);
INSERT INTO valoracions VALUES (1922, 27, '03/07/2003', 9);
INSERT INTO valoracions VALUES (1922, 2, '05/09/2008', 8);
INSERT INTO valoracions VALUES (1922, 40, '17/06/2002', 7);
INSERT INTO valoracions VALUES (1922, 80, '30/05/2001', 7);
INSERT INTO valoracions VALUES (1922, 113, '15/06/2008', 4);
INSERT INTO valoracions VALUES (1922, 35, '19/01/2002', 9);
INSERT INTO valoracions VALUES (1923, 39, '19/04/2003', 4);
INSERT INTO valoracions VALUES (1923, 33, '24/10/2007', 8);
INSERT INTO valoracions VALUES (1923, 109, '25/07/2006', 4);
INSERT INTO valoracions VALUES (1924, 45, '16/09/2001', 9);
INSERT INTO valoracions VALUES (1925, 99, '25/01/2005', 2);
INSERT INTO valoracions VALUES (1925, 70, '14/01/2008', 3);
INSERT INTO valoracions VALUES (1925, 21, '08/03/2003', 5);
INSERT INTO valoracions VALUES (1925, 47, '03/03/2002', 6);
INSERT INTO valoracions VALUES (1925, 13, '07/08/2009', 7);
INSERT INTO valoracions VALUES (1926, 59, '01/07/2008', 7);
INSERT INTO valoracions VALUES (1926, 38, '15/11/2005', 5);
INSERT INTO valoracions VALUES (1926, 60, '01/02/2002', 8);
INSERT INTO valoracions VALUES (1926, 113, '06/05/2008', 2);
INSERT INTO valoracions VALUES (1926, 10, '25/06/2007', 8);
INSERT INTO valoracions VALUES (1927, 115, '10/09/2001', 2);
INSERT INTO valoracions VALUES (1927, 31, '14/07/2002', 7);
INSERT INTO valoracions VALUES (1928, 111, '29/12/2001', 4);
INSERT INTO valoracions VALUES (1928, 52, '02/08/2002', 9);
INSERT INTO valoracions VALUES (1929, 85, '30/08/2005', 4);
INSERT INTO valoracions VALUES (1929, 55, '18/07/2007', 5);
INSERT INTO valoracions VALUES (1929, 109, '17/05/2003', 2);
INSERT INTO valoracions VALUES (1929, 49, '19/11/2009', 9);
INSERT INTO valoracions VALUES (1930, 3, '22/05/2005', 5);
INSERT INTO valoracions VALUES (1930, 89, '31/10/2006', 7);
INSERT INTO valoracions VALUES (1930, 82, '08/02/2002', 8);
INSERT INTO valoracions VALUES (1931, 62, '12/04/2006', 2);
INSERT INTO valoracions VALUES (1931, 8, '13/04/2010', 9);
INSERT INTO valoracions VALUES (1931, 63, '21/07/2002', 5);
INSERT INTO valoracions VALUES (1931, 17, '19/06/2008', 7);
INSERT INTO valoracions VALUES (1931, 34, '12/11/2003', 9);
INSERT INTO valoracions VALUES (1931, 87, '02/08/2007', 2);
INSERT INTO valoracions VALUES (1931, 89, '12/06/2002', 2);
INSERT INTO valoracions VALUES (1931, 2, '05/01/2003', 7);
INSERT INTO valoracions VALUES (1932, 52, '13/07/2008', 4);
INSERT INTO valoracions VALUES (1932, 18, '15/12/2004', 7);
INSERT INTO valoracions VALUES (1933, 52, '11/04/2005', 5);
INSERT INTO valoracions VALUES (1933, 102, '12/10/2007', 8);
INSERT INTO valoracions VALUES (1933, 71, '22/02/2002', 7);
INSERT INTO valoracions VALUES (1933, 5, '24/05/2007', 9);
INSERT INTO valoracions VALUES (1933, 85, '22/05/2003', 3);
INSERT INTO valoracions VALUES (1933, 25, '16/02/2009', 8);
INSERT INTO valoracions VALUES (1933, 25, '10/01/2004', 5);
INSERT INTO valoracions VALUES (1933, 34, '24/06/2010', 6);
INSERT INTO valoracions VALUES (1934, 72, '20/05/2003', 4);
INSERT INTO valoracions VALUES (1934, 46, '30/10/2005', 7);
INSERT INTO valoracions VALUES (1934, 22, '22/01/2005', 10);
INSERT INTO valoracions VALUES (1934, 72, '01/04/2005', 7);
INSERT INTO valoracions VALUES (1934, 92, '27/05/2005', 4);
INSERT INTO valoracions VALUES (1935, 67, '19/01/2008', 4);
INSERT INTO valoracions VALUES (1935, 115, '08/11/2007', 1);
INSERT INTO valoracions VALUES (1935, 14, '20/08/2009', 7);
INSERT INTO valoracions VALUES (1935, 53, '14/06/2003', 9);
INSERT INTO valoracions VALUES (1935, 74, '02/09/2001', 6);
INSERT INTO valoracions VALUES (1935, 65, '23/02/2004', 4);
INSERT INTO valoracions VALUES (1936, 68, '31/05/2002', 8);
INSERT INTO valoracions VALUES (1936, 50, '26/02/2007', 6);
INSERT INTO valoracions VALUES (1936, 21, '22/06/2005', 8);
INSERT INTO valoracions VALUES (1936, 109, '27/03/2008', 2);
INSERT INTO valoracions VALUES (1936, 82, '15/01/2010', 7);
INSERT INTO valoracions VALUES (1937, 103, '18/05/2002', 2);
INSERT INTO valoracions VALUES (1937, 38, '15/02/2005', 9);
INSERT INTO valoracions VALUES (1937, 37, '28/04/2010', 7);
INSERT INTO valoracions VALUES (1937, 103, '20/02/2002', 5);
INSERT INTO valoracions VALUES (1938, 47, '06/07/2007', 7);
INSERT INTO valoracions VALUES (1938, 20, '06/12/2004', 10);
INSERT INTO valoracions VALUES (1938, 54, '30/01/2010', 6);
INSERT INTO valoracions VALUES (1938, 77, '14/07/2004', 9);
INSERT INTO valoracions VALUES (1938, 28, '23/02/2003', 4);
INSERT INTO valoracions VALUES (1938, 111, '04/06/2001', 9);
INSERT INTO valoracions VALUES (1938, 103, '11/01/2009', 8);
INSERT INTO valoracions VALUES (1939, 10, '12/08/2007', 5);
INSERT INTO valoracions VALUES (1939, 43, '02/02/2004', 4);
INSERT INTO valoracions VALUES (1939, 22, '24/06/2009', 5);
INSERT INTO valoracions VALUES (1940, 102, '22/11/2009', 7);
INSERT INTO valoracions VALUES (1940, 43, '05/02/2008', 5);
INSERT INTO valoracions VALUES (1940, 19, '23/06/2009', 8);
INSERT INTO valoracions VALUES (1941, 77, '19/09/2006', 2);
INSERT INTO valoracions VALUES (1941, 45, '21/09/2007', 9);
INSERT INTO valoracions VALUES (1941, 12, '19/09/2005', 8);
INSERT INTO valoracions VALUES (1941, 22, '09/08/2010', 8);
INSERT INTO valoracions VALUES (1942, 8, '19/06/2002', 5);
INSERT INTO valoracions VALUES (1942, 33, '15/06/2003', 9);
INSERT INTO valoracions VALUES (1942, 18, '31/03/2003', 8);
INSERT INTO valoracions VALUES (1942, 67, '28/10/2004', 3);
INSERT INTO valoracions VALUES (1942, 90, '28/05/2002', 5);
INSERT INTO valoracions VALUES (1942, 1, '10/12/2006', 8);
INSERT INTO valoracions VALUES (1942, 64, '05/05/2001', 5);
INSERT INTO valoracions VALUES (1942, 106, '20/12/2007', 9);
INSERT INTO valoracions VALUES (1942, 61, '07/10/2003', 5);
INSERT INTO valoracions VALUES (1942, 17, '04/04/2005', 10);
INSERT INTO valoracions VALUES (1943, 98, '12/12/2001', 6);
INSERT INTO valoracions VALUES (1943, 17, '02/08/2002', 7);
INSERT INTO valoracions VALUES (1943, 48, '12/01/2009', 9);
INSERT INTO valoracions VALUES (1944, 35, '06/08/2007', 8);
INSERT INTO valoracions VALUES (1944, 108, '24/08/2003', 8);
INSERT INTO valoracions VALUES (1944, 100, '05/07/2001', 1);
INSERT INTO valoracions VALUES (1944, 84, '09/02/2009', 5);
INSERT INTO valoracions VALUES (1944, 37, '27/03/2007', 9);
INSERT INTO valoracions VALUES (1944, 74, '15/08/2003', 10);
INSERT INTO valoracions VALUES (1945, 115, '22/11/2002', 10);
INSERT INTO valoracions VALUES (1945, 114, '06/07/2001', 7);
INSERT INTO valoracions VALUES (1945, 115, '24/02/2009', 9);
INSERT INTO valoracions VALUES (1945, 50, '31/01/2004', 10);
INSERT INTO valoracions VALUES (1945, 109, '01/09/2010', 1);
INSERT INTO valoracions VALUES (1946, 34, '28/11/2004', 6);
INSERT INTO valoracions VALUES (1946, 20, '13/08/2001', 7);
INSERT INTO valoracions VALUES (1946, 78, '13/09/2001', 4);
INSERT INTO valoracions VALUES (1946, 61, '24/07/2007', 6);
INSERT INTO valoracions VALUES (1946, 37, '14/11/2007', 4);
INSERT INTO valoracions VALUES (1946, 98, '10/06/2002', 5);
INSERT INTO valoracions VALUES (1946, 46, '16/06/2002', 4);
INSERT INTO valoracions VALUES (1947, 84, '20/04/2007', 7);
INSERT INTO valoracions VALUES (1947, 52, '08/04/2009', 7);
INSERT INTO valoracions VALUES (1947, 61, '26/05/2007', 6);
INSERT INTO valoracions VALUES (1947, 28, '09/07/2002', 9);
INSERT INTO valoracions VALUES (1948, 103, '16/04/2004', 10);
INSERT INTO valoracions VALUES (1948, 66, '26/03/2006', 2);
INSERT INTO valoracions VALUES (1948, 54, '13/11/2001', 7);
INSERT INTO valoracions VALUES (1948, 17, '03/10/2007', 5);
INSERT INTO valoracions VALUES (1948, 16, '26/09/2006', 6);
INSERT INTO valoracions VALUES (1949, 40, '05/09/2001', 6);
INSERT INTO valoracions VALUES (1949, 58, '07/05/2009', 5);
INSERT INTO valoracions VALUES (1950, 52, '26/01/2007', 4);
INSERT INTO valoracions VALUES (1951, 65, '08/07/2006', 5);
INSERT INTO valoracions VALUES (1951, 6, '26/02/2002', 7);
INSERT INTO valoracions VALUES (1951, 86, '09/02/2004', 1);
INSERT INTO valoracions VALUES (1951, 95, '21/10/2006', 4);
INSERT INTO valoracions VALUES (1951, 108, '15/07/2001', 8);
INSERT INTO valoracions VALUES (1952, 64, '05/01/2004', 7);
INSERT INTO valoracions VALUES (1953, 96, '22/07/2008', 3);
INSERT INTO valoracions VALUES (1953, 76, '26/08/2006', 3);
INSERT INTO valoracions VALUES (1954, 15, '25/04/2004', 8);
INSERT INTO valoracions VALUES (1954, 89, '21/01/2009', 9);
INSERT INTO valoracions VALUES (1955, 76, '31/03/2009', 9);
INSERT INTO valoracions VALUES (1955, 6, '13/10/2007', 5);
INSERT INTO valoracions VALUES (1956, 70, '17/12/2001', 6);
INSERT INTO valoracions VALUES (1956, 42, '13/06/2002', 5);
INSERT INTO valoracions VALUES (1956, 9, '25/02/2008', 9);
INSERT INTO valoracions VALUES (1957, 60, '20/10/2001', 7);
INSERT INTO valoracions VALUES (1957, 27, '09/09/2001', 9);
INSERT INTO valoracions VALUES (1957, 65, '31/03/2006', 6);
INSERT INTO valoracions VALUES (1957, 66, '28/08/2008', 6);
INSERT INTO valoracions VALUES (1958, 42, '08/01/2007', 4);
INSERT INTO valoracions VALUES (1958, 46, '16/01/2004', 10);
INSERT INTO valoracions VALUES (1958, 80, '03/10/2001', 2);
INSERT INTO valoracions VALUES (1959, 40, '15/01/2002', 10);
INSERT INTO valoracions VALUES (1959, 115, '22/01/2009', 10);
INSERT INTO valoracions VALUES (1959, 46, '26/02/2003', 9);
INSERT INTO valoracions VALUES (1960, 79, '19/08/2006', 6);
INSERT INTO valoracions VALUES (1961, 32, '18/02/2005', 10);
INSERT INTO valoracions VALUES (1961, 38, '31/07/2004', 8);
INSERT INTO valoracions VALUES (1961, 42, '22/11/2008', 7);
INSERT INTO valoracions VALUES (1962, 23, '20/10/2002', 6);
INSERT INTO valoracions VALUES (1962, 84, '29/11/2002', 6);
INSERT INTO valoracions VALUES (1962, 87, '21/05/2002', 8);
INSERT INTO valoracions VALUES (1962, 73, '10/02/2008', 6);
INSERT INTO valoracions VALUES (1962, 101, '07/03/2009', 10);
INSERT INTO valoracions VALUES (1962, 22, '08/01/2003', 6);
INSERT INTO valoracions VALUES (1962, 2, '25/09/2005', 10);
INSERT INTO valoracions VALUES (1964, 25, '23/04/2009', 7);
INSERT INTO valoracions VALUES (1964, 45, '23/10/2006', 7);
INSERT INTO valoracions VALUES (1964, 105, '22/10/2005', 2);
INSERT INTO valoracions VALUES (1965, 55, '12/12/2008', 7);
INSERT INTO valoracions VALUES (1965, 100, '22/10/2010', 6);
INSERT INTO valoracions VALUES (1965, 10, '22/10/2004', 7);
INSERT INTO valoracions VALUES (1965, 13, '20/07/2008', 10);
INSERT INTO valoracions VALUES (1965, 23, '07/03/2005', 5);
INSERT INTO valoracions VALUES (1965, 91, '03/09/2006', 10);
INSERT INTO valoracions VALUES (1965, 104, '19/12/2004', 3);
INSERT INTO valoracions VALUES (1965, 13, '20/11/2002', 8);
INSERT INTO valoracions VALUES (1965, 2, '18/09/2003', 8);
INSERT INTO valoracions VALUES (1966, 34, '04/05/2004', 6);
INSERT INTO valoracions VALUES (1966, 55, '06/08/2001', 4);
INSERT INTO valoracions VALUES (1967, 66, '28/02/2010', 2);
INSERT INTO valoracions VALUES (1967, 47, '05/01/2007', 3);
INSERT INTO valoracions VALUES (1968, 12, '29/12/2008', 8);
INSERT INTO valoracions VALUES (1968, 85, '21/07/2007', 4);
INSERT INTO valoracions VALUES (1968, 41, '08/12/2003', 9);
INSERT INTO valoracions VALUES (1968, 15, '10/08/2009', 9);
INSERT INTO valoracions VALUES (1969, 65, '26/04/2008', 7);
INSERT INTO valoracions VALUES (1969, 12, '22/09/2004', 6);
INSERT INTO valoracions VALUES (1969, 66, '06/07/2009', 8);
INSERT INTO valoracions VALUES (1969, 44, '10/05/2010', 3);
INSERT INTO valoracions VALUES (1970, 22, '26/11/2003', 5);
INSERT INTO valoracions VALUES (1970, 87, '24/12/2002', 3);
INSERT INTO valoracions VALUES (1970, 16, '04/10/2005', 6);
INSERT INTO valoracions VALUES (1970, 109, '05/05/2009', 1);
INSERT INTO valoracions VALUES (1971, 86, '26/02/2010', 9);
INSERT INTO valoracions VALUES (1971, 28, '13/03/2007', 6);
INSERT INTO valoracions VALUES (1971, 104, '28/04/2009', 4);
INSERT INTO valoracions VALUES (1972, 98, '16/06/2002', 10);
INSERT INTO valoracions VALUES (1972, 65, '19/02/2007', 8);
INSERT INTO valoracions VALUES (1973, 92, '10/03/2003', 6);
INSERT INTO valoracions VALUES (1973, 103, '01/04/2009', 5);
INSERT INTO valoracions VALUES (1973, 15, '03/09/2005', 6);
INSERT INTO valoracions VALUES (1973, 31, '01/07/2001', 5);
INSERT INTO valoracions VALUES (1973, 48, '27/10/2010', 7);
INSERT INTO valoracions VALUES (1974, 100, '07/10/2009', 7);
INSERT INTO valoracions VALUES (1974, 35, '21/04/2003', 5);
INSERT INTO valoracions VALUES (1974, 108, '27/06/2009', 7);
INSERT INTO valoracions VALUES (1974, 43, '02/01/2007', 10);
INSERT INTO valoracions VALUES (1975, 45, '26/08/2002', 9);
INSERT INTO valoracions VALUES (1976, 70, '27/07/2006', 8);
INSERT INTO valoracions VALUES (1976, 103, '09/02/2006', 7);
INSERT INTO valoracions VALUES (1977, 102, '17/02/2002', 2);
INSERT INTO valoracions VALUES (1977, 112, '21/09/2001', 5);
INSERT INTO valoracions VALUES (1977, 16, '11/12/2004', 9);
INSERT INTO valoracions VALUES (1977, 21, '31/08/2005', 5);
INSERT INTO valoracions VALUES (1977, 112, '27/10/2002', 1);
INSERT INTO valoracions VALUES (1977, 25, '03/03/2006', 8);
INSERT INTO valoracions VALUES (1978, 39, '13/08/2002', 7);
INSERT INTO valoracions VALUES (1978, 104, '21/05/2004', 9);
INSERT INTO valoracions VALUES (1978, 24, '27/06/2005', 5);
INSERT INTO valoracions VALUES (1979, 28, '05/03/2004', 9);
INSERT INTO valoracions VALUES (1979, 86, '11/05/2010', 2);
INSERT INTO valoracions VALUES (1979, 85, '15/06/2003', 7);
INSERT INTO valoracions VALUES (1979, 12, '18/11/2007', 7);
INSERT INTO valoracions VALUES (1979, 79, '04/10/2003', 7);
INSERT INTO valoracions VALUES (1980, 31, '02/08/2003', 10);
INSERT INTO valoracions VALUES (1980, 109, '04/12/2003', 5);
INSERT INTO valoracions VALUES (1980, 62, '11/12/2007', 5);
INSERT INTO valoracions VALUES (1980, 41, '26/11/2003', 8);
INSERT INTO valoracions VALUES (1980, 31, '12/01/2002', 4);
INSERT INTO valoracions VALUES (1981, 80, '24/08/2003', 7);
INSERT INTO valoracions VALUES (1981, 62, '01/10/2001', 10);
INSERT INTO valoracions VALUES (1981, 16, '06/05/2001', 6);
INSERT INTO valoracions VALUES (1982, 64, '05/03/2008', 5);
INSERT INTO valoracions VALUES (1982, 73, '21/07/2001', 7);
INSERT INTO valoracions VALUES (1982, 65, '08/12/2007', 8);
INSERT INTO valoracions VALUES (1982, 27, '20/09/2007', 5);
INSERT INTO valoracions VALUES (1983, 19, '27/09/2006', 9);
INSERT INTO valoracions VALUES (1983, 7, '02/03/2007', 6);
INSERT INTO valoracions VALUES (1983, 108, '05/03/2002', 4);
INSERT INTO valoracions VALUES (1983, 111, '20/01/2010', 4);
INSERT INTO valoracions VALUES (1983, 46, '29/11/2003', 7);
INSERT INTO valoracions VALUES (1983, 60, '03/02/2007', 7);
INSERT INTO valoracions VALUES (1984, 24, '03/02/2008', 9);
INSERT INTO valoracions VALUES (1984, 95, '19/10/2003', 9);
INSERT INTO valoracions VALUES (1984, 116, '15/07/2008', 7);
INSERT INTO valoracions VALUES (1984, 30, '07/02/2005', 8);
INSERT INTO valoracions VALUES (1984, 106, '24/02/2006', 6);
INSERT INTO valoracions VALUES (1985, 49, '08/07/2003', 4);
INSERT INTO valoracions VALUES (1985, 83, '31/03/2003', 5);
INSERT INTO valoracions VALUES (1985, 102, '13/09/2002', 9);
INSERT INTO valoracions VALUES (1985, 114, '25/05/2003', 2);
INSERT INTO valoracions VALUES (1985, 47, '14/07/2007', 10);
INSERT INTO valoracions VALUES (1986, 62, '10/05/2003', 4);
INSERT INTO valoracions VALUES (1986, 92, '07/04/2007', 9);
INSERT INTO valoracions VALUES (1986, 30, '25/09/2009', 6);
INSERT INTO valoracions VALUES (1986, 21, '24/04/2005', 9);
INSERT INTO valoracions VALUES (1986, 116, '04/07/2002', 4);
INSERT INTO valoracions VALUES (1986, 31, '17/08/2008', 5);
INSERT INTO valoracions VALUES (1986, 81, '25/11/2006', 2);
INSERT INTO valoracions VALUES (1987, 16, '22/06/2008', 5);
INSERT INTO valoracions VALUES (1988, 52, '16/11/2004', 9);
INSERT INTO valoracions VALUES (1988, 8, '18/11/2003', 9);
INSERT INTO valoracions VALUES (1988, 35, '16/04/2008', 9);
INSERT INTO valoracions VALUES (1988, 41, '05/10/2003', 9);
INSERT INTO valoracions VALUES (1988, 102, '29/11/2002', 5);
INSERT INTO valoracions VALUES (1989, 104, '22/01/2004', 2);
INSERT INTO valoracions VALUES (1989, 33, '10/03/2008', 6);
INSERT INTO valoracions VALUES (1989, 17, '09/03/2005', 9);
INSERT INTO valoracions VALUES (1990, 67, '05/05/2004', 8);
INSERT INTO valoracions VALUES (1990, 102, '23/06/2002', 3);
INSERT INTO valoracions VALUES (1990, 76, '22/09/2003', 6);
INSERT INTO valoracions VALUES (1990, 72, '05/04/2001', 2);
INSERT INTO valoracions VALUES (1991, 94, '16/07/2010', 4);
INSERT INTO valoracions VALUES (1991, 85, '27/03/2003', 4);
INSERT INTO valoracions VALUES (1991, 3, '27/03/2005', 9);
INSERT INTO valoracions VALUES (1991, 71, '03/11/2005', 8);
INSERT INTO valoracions VALUES (1992, 91, '14/04/2010', 8);
INSERT INTO valoracions VALUES (1992, 101, '11/05/2010', 3);
INSERT INTO valoracions VALUES (1992, 55, '10/01/2010', 9);
INSERT INTO valoracions VALUES (1992, 17, '11/05/2003', 9);
INSERT INTO valoracions VALUES (1992, 10, '16/03/2007', 8);
INSERT INTO valoracions VALUES (1993, 67, '21/07/2007', 9);
INSERT INTO valoracions VALUES (1993, 20, '20/01/2006', 9);
INSERT INTO valoracions VALUES (1993, 113, '18/07/2003', 1);
INSERT INTO valoracions VALUES (1993, 100, '24/05/2002', 5);
INSERT INTO valoracions VALUES (1994, 81, '29/08/2001', 2);
INSERT INTO valoracions VALUES (1994, 11, '29/06/2009', 5);
INSERT INTO valoracions VALUES (1994, 97, '04/09/2007', 2);
INSERT INTO valoracions VALUES (1995, 42, '06/07/2002', 8);
INSERT INTO valoracions VALUES (1995, 67, '24/10/2010', 3);
INSERT INTO valoracions VALUES (1995, 45, '09/05/2005', 4);
INSERT INTO valoracions VALUES (1996, 23, '17/11/2007', 7);
INSERT INTO valoracions VALUES (1996, 32, '16/02/2005', 7);
INSERT INTO valoracions VALUES (1996, 73, '05/04/2008', 4);
INSERT INTO valoracions VALUES (1997, 1, '13/09/2006', 10);
INSERT INTO valoracions VALUES (1997, 46, '31/07/2001', 5);
INSERT INTO valoracions VALUES (1997, 44, '11/03/2009', 6);
INSERT INTO valoracions VALUES (1998, 88, '11/12/2005', 7);
INSERT INTO valoracions VALUES (1998, 50, '22/06/2009', 5);
INSERT INTO valoracions VALUES (1999, 7, '25/03/2009', 9);
INSERT INTO valoracions VALUES (1999, 38, '17/06/2008', 7);
INSERT INTO valoracions VALUES (1999, 112, '24/09/2001', 9);
INSERT INTO valoracions VALUES (2000, 39, '27/05/2006', 7);
INSERT INTO valoracions VALUES (2000, 116, '20/10/2009', 1);
INSERT INTO valoracions VALUES (2001, 47, '18/11/2005', 4);
INSERT INTO valoracions VALUES (2001, 116, '02/04/2009', 3);
INSERT INTO valoracions VALUES (2001, 116, '15/07/2004', 0);
INSERT INTO valoracions VALUES (2001, 72, '17/07/2008', 8);
INSERT INTO valoracions VALUES (2001, 47, '01/07/2002', 6);
INSERT INTO valoracions VALUES (2001, 32, '12/02/2009', 4);
INSERT INTO valoracions VALUES (2002, 107, '28/09/2010', 9);
INSERT INTO valoracions VALUES (2002, 3, '10/09/2008', 6);
INSERT INTO valoracions VALUES (2002, 10, '09/04/2003', 6);
INSERT INTO valoracions VALUES (2002, 57, '11/03/2005', 7);
INSERT INTO valoracions VALUES (2003, 38, '23/10/2002', 4);
INSERT INTO valoracions VALUES (2003, 71, '01/12/2006', 4);
INSERT INTO valoracions VALUES (2003, 36, '10/01/2010', 7);
INSERT INTO valoracions VALUES (2003, 77, '11/05/2009', 10);
INSERT INTO valoracions VALUES (2003, 48, '02/12/2004', 7);
INSERT INTO valoracions VALUES (2004, 41, '04/09/2002', 4);
INSERT INTO valoracions VALUES (2004, 2, '27/08/2005', 6);
INSERT INTO valoracions VALUES (2004, 7, '13/12/2008', 8);
INSERT INTO valoracions VALUES (2005, 48, '01/07/2003', 4);
INSERT INTO valoracions VALUES (2005, 43, '09/05/2004', 5);
INSERT INTO valoracions VALUES (2005, 94, '08/09/2009', 8);
INSERT INTO valoracions VALUES (2005, 58, '12/01/2008', 7);
INSERT INTO valoracions VALUES (2005, 93, '18/03/2005', 5);
INSERT INTO valoracions VALUES (2005, 12, '05/03/2004', 5);
INSERT INTO valoracions VALUES (2006, 7, '12/01/2002', 6);
INSERT INTO valoracions VALUES (2006, 77, '21/02/2002', 7);
INSERT INTO valoracions VALUES (2007, 116, '24/05/2004', 8);
INSERT INTO valoracions VALUES (2007, 76, '12/04/2004', 8);
INSERT INTO valoracions VALUES (2007, 49, '21/05/2009', 4);
INSERT INTO valoracions VALUES (2007, 27, '27/09/2004', 4);
INSERT INTO valoracions VALUES (2008, 82, '25/06/2008', 6);
INSERT INTO valoracions VALUES (2008, 24, '18/11/2003', 7);
INSERT INTO valoracions VALUES (2008, 31, '07/06/2010', 7);
INSERT INTO valoracions VALUES (2009, 94, '08/02/2004', 8);
INSERT INTO valoracions VALUES (2009, 77, '03/02/2010', 9);
INSERT INTO valoracions VALUES (2009, 48, '28/09/2004', 9);
INSERT INTO valoracions VALUES (2009, 101, '12/01/2009', 4);
INSERT INTO valoracions VALUES (2009, 41, '18/01/2004', 6);
INSERT INTO valoracions VALUES (2010, 6, '16/05/2005', 7);
INSERT INTO valoracions VALUES (2011, 14, '12/08/2002', 7);
INSERT INTO valoracions VALUES (2011, 42, '12/08/2003', 7);
INSERT INTO valoracions VALUES (2012, 54, '17/12/2003', 4);
INSERT INTO valoracions VALUES (2012, 16, '18/07/2001', 9);
INSERT INTO valoracions VALUES (2012, 13, '12/09/2002', 9);
INSERT INTO valoracions VALUES (2012, 72, '04/02/2005', 5);
INSERT INTO valoracions VALUES (2012, 47, '10/11/2008', 4);
INSERT INTO valoracions VALUES (2012, 115, '24/08/2003', 7);
INSERT INTO valoracions VALUES (2012, 85, '22/05/2005', 8);
INSERT INTO valoracions VALUES (2013, 47, '27/06/2003', 6);
INSERT INTO valoracions VALUES (2013, 16, '05/03/2006', 7);
INSERT INTO valoracions VALUES (2013, 48, '16/09/2009', 6);
INSERT INTO valoracions VALUES (2013, 80, '04/04/2009', 5);
INSERT INTO valoracions VALUES (2013, 108, '05/05/2003', 1);
INSERT INTO valoracions VALUES (2015, 79, '26/09/2006', 7);
INSERT INTO valoracions VALUES (2015, 7, '30/05/2004', 5);
INSERT INTO valoracions VALUES (2015, 31, '23/09/2009', 8);
INSERT INTO valoracions VALUES (2015, 48, '24/03/2007', 8);
INSERT INTO valoracions VALUES (2015, 97, '23/07/2004', 8);
INSERT INTO valoracions VALUES (2015, 78, '05/08/2004', 6);
INSERT INTO valoracions VALUES (2015, 89, '25/04/2010', 3);
INSERT INTO valoracions VALUES (2015, 1, '04/12/2005', 6);
INSERT INTO valoracions VALUES (2016, 87, '04/11/2006', 9);
INSERT INTO valoracions VALUES (2016, 78, '17/04/2005', 3);
INSERT INTO valoracions VALUES (2016, 108, '16/01/2005', 2);
INSERT INTO valoracions VALUES (2016, 114, '30/10/2008', 3);
INSERT INTO valoracions VALUES (2016, 75, '09/05/2004', 8);
INSERT INTO valoracions VALUES (2016, 3, '30/07/2009', 6);
INSERT INTO valoracions VALUES (2016, 83, '09/12/2006', 1);
INSERT INTO valoracions VALUES (2017, 5, '11/01/2006', 6);
INSERT INTO valoracions VALUES (2017, 42, '19/10/2009', 10);
INSERT INTO valoracions VALUES (2017, 60, '09/05/2002', 3);
INSERT INTO valoracions VALUES (2017, 66, '12/03/2008', 8);
INSERT INTO valoracions VALUES (2018, 81, '29/04/2003', 3);
INSERT INTO valoracions VALUES (2018, 16, '07/05/2009', 7);
INSERT INTO valoracions VALUES (2018, 31, '13/10/2004', 7);
INSERT INTO valoracions VALUES (2019, 40, '01/03/2004', 10);
INSERT INTO valoracions VALUES (2019, 105, '02/02/2009', 5);
INSERT INTO valoracions VALUES (2019, 81, '11/09/2007', 4);
INSERT INTO valoracions VALUES (2020, 83, '06/08/2004', 2);
INSERT INTO valoracions VALUES (2020, 43, '16/01/2002', 7);
INSERT INTO valoracions VALUES (2020, 60, '05/05/2006', 3);
INSERT INTO valoracions VALUES (2020, 2, '30/05/2008', 7);
INSERT INTO valoracions VALUES (2020, 97, '14/03/2006', 8);
INSERT INTO valoracions VALUES (2020, 94, '15/08/2005', 3);
INSERT INTO valoracions VALUES (2021, 103, '17/10/2001', 10);
INSERT INTO valoracions VALUES (2021, 25, '07/07/2001', 6);
INSERT INTO valoracions VALUES (2021, 108, '18/12/2007', 9);
INSERT INTO valoracions VALUES (2021, 58, '21/09/2010', 9);
INSERT INTO valoracions VALUES (2022, 50, '06/01/2004', 6);
INSERT INTO valoracions VALUES (2022, 109, '23/05/2001', 6);
INSERT INTO valoracions VALUES (2023, 63, '16/03/2003', 5);
INSERT INTO valoracions VALUES (2023, 1, '29/04/2005', 8);
INSERT INTO valoracions VALUES (2023, 78, '20/01/2004', 6);
INSERT INTO valoracions VALUES (2023, 72, '30/06/2008', 5);
INSERT INTO valoracions VALUES (2023, 108, '11/08/2005', 1);
INSERT INTO valoracions VALUES (2024, 2, '13/09/2007', 8);
INSERT INTO valoracions VALUES (2024, 97, '14/04/2008', 7);
INSERT INTO valoracions VALUES (2024, 84, '20/08/2002', 8);
INSERT INTO valoracions VALUES (2025, 85, '22/09/2007', 4);
INSERT INTO valoracions VALUES (2025, 102, '11/06/2005', 6);
INSERT INTO valoracions VALUES (2025, 112, '16/01/2005', 8);
INSERT INTO valoracions VALUES (2026, 71, '07/09/2002', 5);
INSERT INTO valoracions VALUES (2026, 57, '30/08/2010', 6);
INSERT INTO valoracions VALUES (2026, 34, '04/07/2006', 6);
INSERT INTO valoracions VALUES (2026, 5, '17/09/2007', 5);
INSERT INTO valoracions VALUES (2026, 76, '04/12/2003', 8);
INSERT INTO valoracions VALUES (2026, 56, '06/05/2004', 9);
INSERT INTO valoracions VALUES (2027, 89, '05/06/2005', 5);
INSERT INTO valoracions VALUES (2027, 26, '10/11/2007', 9);
INSERT INTO valoracions VALUES (2028, 27, '07/12/2001', 4);
INSERT INTO valoracions VALUES (2029, 96, '12/02/2007', 6);
INSERT INTO valoracions VALUES (2029, 39, '11/12/2004', 4);
INSERT INTO valoracions VALUES (2029, 115, '26/10/2005', 9);
INSERT INTO valoracions VALUES (2029, 82, '08/08/2003', 2);
INSERT INTO valoracions VALUES (2030, 33, '11/09/2006', 9);
INSERT INTO valoracions VALUES (2030, 115, '01/07/2006', 2);
INSERT INTO valoracions VALUES (2030, 32, '24/08/2007', 10);
INSERT INTO valoracions VALUES (2031, 104, '22/08/2009', 9);
INSERT INTO valoracions VALUES (2031, 81, '15/05/2007', 9);
INSERT INTO valoracions VALUES (2031, 41, '14/07/2005', 9);
INSERT INTO valoracions VALUES (2031, 84, '17/11/2006', 5);
INSERT INTO valoracions VALUES (2031, 26, '29/03/2004', 5);
INSERT INTO valoracions VALUES (2031, 32, '26/07/2008', 7);
INSERT INTO valoracions VALUES (2031, 32, '26/03/2009', 4);
INSERT INTO valoracions VALUES (2032, 31, '23/09/2010', 8);
INSERT INTO valoracions VALUES (2032, 44, '19/01/2006', 5);
INSERT INTO valoracions VALUES (2033, 50, '06/05/2003', 9);
INSERT INTO valoracions VALUES (2033, 18, '18/03/2008', 8);
INSERT INTO valoracions VALUES (2033, 75, '22/11/2002', 4);
INSERT INTO valoracions VALUES (2034, 18, '21/08/2006', 5);
INSERT INTO valoracions VALUES (2034, 101, '27/11/2002', 5);
INSERT INTO valoracions VALUES (2034, 64, '27/07/2004', 4);
INSERT INTO valoracions VALUES (2034, 92, '05/05/2003', 6);
INSERT INTO valoracions VALUES (2034, 9, '06/05/2003', 9);
INSERT INTO valoracions VALUES (2034, 67, '30/08/2005', 7);
INSERT INTO valoracions VALUES (2034, 27, '12/08/2008', 6);
INSERT INTO valoracions VALUES (2034, 13, '08/07/2004', 10);
INSERT INTO valoracions VALUES (2035, 107, '09/07/2003', 4);
INSERT INTO valoracions VALUES (2035, 90, '03/09/2008', 5);
INSERT INTO valoracions VALUES (2036, 86, '02/05/2001', 2);
INSERT INTO valoracions VALUES (2036, 25, '16/11/2001', 6);
INSERT INTO valoracions VALUES (2036, 104, '02/11/2006', 5);
INSERT INTO valoracions VALUES (2037, 99, '17/08/2009', 1);
INSERT INTO valoracions VALUES (2037, 39, '25/10/2004', 8);
INSERT INTO valoracions VALUES (2038, 89, '03/03/2008', 8);
INSERT INTO valoracions VALUES (2038, 13, '19/10/2010', 5);
INSERT INTO valoracions VALUES (2039, 55, '14/02/2005', 4);
INSERT INTO valoracions VALUES (2039, 39, '20/06/2010', 3);
INSERT INTO valoracions VALUES (2039, 26, '21/12/2005', 8);
INSERT INTO valoracions VALUES (2040, 17, '28/04/2005', 5);
INSERT INTO valoracions VALUES (2040, 82, '02/07/2003', 5);
INSERT INTO valoracions VALUES (2040, 47, '06/10/2007', 9);
INSERT INTO valoracions VALUES (2040, 47, '13/12/2006', 7);
INSERT INTO valoracions VALUES (2040, 81, '24/06/2007', 7);
INSERT INTO valoracions VALUES (2040, 92, '23/06/2006', 6);
INSERT INTO valoracions VALUES (2040, 100, '18/11/2001', 2);
INSERT INTO valoracions VALUES (2040, 22, '14/07/2007', 6);
INSERT INTO valoracions VALUES (2041, 36, '14/12/2009', 5);
INSERT INTO valoracions VALUES (2041, 59, '08/08/2009', 10);
INSERT INTO valoracions VALUES (2041, 15, '11/12/2003', 10);
INSERT INTO valoracions VALUES (2042, 26, '07/06/2008', 9);
INSERT INTO valoracions VALUES (2042, 31, '02/05/2007', 6);
INSERT INTO valoracions VALUES (2042, 67, '18/09/2005', 4);
INSERT INTO valoracions VALUES (2042, 79, '16/10/2003', 3);
INSERT INTO valoracions VALUES (2042, 100, '05/06/2006', 8);
INSERT INTO valoracions VALUES (2042, 35, '25/02/2007', 9);
INSERT INTO valoracions VALUES (2043, 70, '07/07/2001', 5);
INSERT INTO valoracions VALUES (2043, 2, '05/08/2002', 6);
INSERT INTO valoracions VALUES (2043, 88, '11/12/2002', 8);
INSERT INTO valoracions VALUES (2044, 75, '19/11/2009', 10);
INSERT INTO valoracions VALUES (2044, 29, '20/12/2004', 4);
INSERT INTO valoracions VALUES (2044, 68, '12/10/2003', 9);
INSERT INTO valoracions VALUES (2044, 2, '13/01/2006', 10);
INSERT INTO valoracions VALUES (2044, 92, '16/08/2008', 6);
INSERT INTO valoracions VALUES (2045, 115, '23/01/2008', 2);
INSERT INTO valoracions VALUES (2045, 109, '29/07/2009', 6);
INSERT INTO valoracions VALUES (2045, 60, '19/06/2006', 6);
INSERT INTO valoracions VALUES (2045, 18, '02/07/2010', 5);
INSERT INTO valoracions VALUES (2045, 3, '07/08/2001', 8);
INSERT INTO valoracions VALUES (2045, 66, '02/01/2004', 7);
INSERT INTO valoracions VALUES (2046, 73, '19/12/2002', 2);
INSERT INTO valoracions VALUES (2046, 77, '08/08/2008', 4);
INSERT INTO valoracions VALUES (2046, 79, '03/12/2008', 9);
INSERT INTO valoracions VALUES (2046, 62, '11/05/2004', 8);
INSERT INTO valoracions VALUES (2046, 99, '04/09/2001', 5);
INSERT INTO valoracions VALUES (2046, 69, '30/08/2009', 8);
INSERT INTO valoracions VALUES (2046, 63, '10/07/2005', 8);
INSERT INTO valoracions VALUES (2047, 77, '03/10/2007', 7);
INSERT INTO valoracions VALUES (2047, 88, '02/02/2004', 7);
INSERT INTO valoracions VALUES (2047, 12, '17/09/2009', 8);
INSERT INTO valoracions VALUES (2047, 39, '28/05/2007', 7);
INSERT INTO valoracions VALUES (2047, 42, '20/12/2008', 10);
INSERT INTO valoracions VALUES (2047, 29, '07/03/2005', 7);
INSERT INTO valoracions VALUES (2047, 109, '22/04/2004', 7);
INSERT INTO valoracions VALUES (2048, 10, '21/12/2009', 9);
INSERT INTO valoracions VALUES (2048, 42, '28/04/2007', 6);
INSERT INTO valoracions VALUES (2048, 21, '21/01/2004', 7);
INSERT INTO valoracions VALUES (2049, 109, '06/09/2003', 9);
INSERT INTO valoracions VALUES (2049, 66, '21/12/2003', 3);
INSERT INTO valoracions VALUES (2049, 64, '16/03/2010', 6);
INSERT INTO valoracions VALUES (2049, 41, '02/11/2001', 8);
INSERT INTO valoracions VALUES (2049, 43, '05/07/2007', 7);
INSERT INTO valoracions VALUES (2050, 85, '30/04/2005', 1);
INSERT INTO valoracions VALUES (2050, 16, '06/12/2003', 4);
INSERT INTO valoracions VALUES (2050, 8, '17/12/2007', 8);
INSERT INTO valoracions VALUES (2050, 18, '09/01/2004', 7);
INSERT INTO valoracions VALUES (2050, 29, '17/06/2008', 9);
INSERT INTO valoracions VALUES (2050, 103, '30/04/2008', 4);
INSERT INTO valoracions VALUES (2051, 95, '02/11/2008', 5);
INSERT INTO valoracions VALUES (2051, 76, '22/03/2006', 4);
INSERT INTO valoracions VALUES (2051, 51, '17/10/2002', 7);
INSERT INTO valoracions VALUES (2051, 26, '16/11/2006', 6);
INSERT INTO valoracions VALUES (2051, 69, '15/10/2006', 9);
INSERT INTO valoracions VALUES (2052, 92, '10/11/2006', 5);
INSERT INTO valoracions VALUES (2052, 32, '23/12/2009', 7);
INSERT INTO valoracions VALUES (2052, 109, '08/09/2009', 5);
INSERT INTO valoracions VALUES (2052, 13, '30/07/2009', 8);
INSERT INTO valoracions VALUES (2052, 3, '08/03/2004', 6);
INSERT INTO valoracions VALUES (2052, 96, '12/11/2003', 5);
INSERT INTO valoracions VALUES (2052, 11, '03/04/2006', 8);
INSERT INTO valoracions VALUES (2052, 2, '05/04/2010', 8);
INSERT INTO valoracions VALUES (2053, 33, '13/02/2002', 4);
INSERT INTO valoracions VALUES (2053, 70, '19/08/2009', 7);
INSERT INTO valoracions VALUES (2053, 105, '29/01/2002', 8);
INSERT INTO valoracions VALUES (2053, 31, '14/03/2002', 5);
INSERT INTO valoracions VALUES (2053, 108, '27/09/2008', 4);
INSERT INTO valoracions VALUES (2053, 90, '20/07/2002', 4);
INSERT INTO valoracions VALUES (2054, 8, '03/12/2007', 9);
INSERT INTO valoracions VALUES (2054, 63, '30/08/2010', 5);
INSERT INTO valoracions VALUES (2054, 35, '02/08/2002', 4);
INSERT INTO valoracions VALUES (2055, 89, '13/11/2003', 4);
INSERT INTO valoracions VALUES (2055, 14, '15/03/2003', 9);
INSERT INTO valoracions VALUES (2055, 67, '17/09/2005', 2);
INSERT INTO valoracions VALUES (2055, 61, '19/03/2007', 8);
INSERT INTO valoracions VALUES (2056, 46, '29/04/2005', 7);
INSERT INTO valoracions VALUES (2056, 6, '07/10/2008', 7);
INSERT INTO valoracions VALUES (2056, 15, '28/12/2007', 4);
INSERT INTO valoracions VALUES (2057, 65, '29/12/2004', 8);
INSERT INTO valoracions VALUES (2057, 22, '20/06/2009', 9);
INSERT INTO valoracions VALUES (2058, 112, '19/04/2008', 8);
INSERT INTO valoracions VALUES (2058, 2, '09/04/2003', 7);
INSERT INTO valoracions VALUES (2058, 38, '02/09/2006', 6);
INSERT INTO valoracions VALUES (2058, 50, '19/05/2006', 4);
INSERT INTO valoracions VALUES (2058, 89, '06/01/2004', 6);
INSERT INTO valoracions VALUES (2059, 114, '17/12/2004', 5);
INSERT INTO valoracions VALUES (2059, 65, '15/04/2001', 6);
INSERT INTO valoracions VALUES (2059, 106, '29/03/2005', 9);
INSERT INTO valoracions VALUES (2060, 87, '21/11/2009', 9);
INSERT INTO valoracions VALUES (2060, 57, '22/10/2007', 9);
INSERT INTO valoracions VALUES (2060, 26, '07/01/2008', 4);
INSERT INTO valoracions VALUES (2060, 72, '04/05/2006', 4);
INSERT INTO valoracions VALUES (2061, 42, '23/02/2006', 4);
INSERT INTO valoracions VALUES (2061, 114, '11/12/2007', 5);
INSERT INTO valoracions VALUES (2062, 40, '24/07/2007', 10);
INSERT INTO valoracions VALUES (2062, 23, '17/12/2005', 5);
INSERT INTO valoracions VALUES (2062, 92, '17/12/2004', 9);
INSERT INTO valoracions VALUES (2063, 116, '21/08/2004', 8);
INSERT INTO valoracions VALUES (2063, 106, '02/11/2006', 1);
INSERT INTO valoracions VALUES (2064, 62, '26/10/2001', 8);
INSERT INTO valoracions VALUES (2064, 23, '27/05/2001', 5);
INSERT INTO valoracions VALUES (2064, 62, '11/06/2001', 8);
INSERT INTO valoracions VALUES (2064, 27, '26/08/2007', 5);
INSERT INTO valoracions VALUES (2064, 73, '22/12/2007', 4);
INSERT INTO valoracions VALUES (2065, 107, '27/09/2003', 8);
INSERT INTO valoracions VALUES (2065, 101, '17/11/2004', 8);
INSERT INTO valoracions VALUES (2065, 56, '17/12/2007', 3);
INSERT INTO valoracions VALUES (2066, 12, '21/05/2004', 8);
INSERT INTO valoracions VALUES (2066, 9, '20/01/2002', 9);
INSERT INTO valoracions VALUES (2066, 17, '27/11/2006', 8);
INSERT INTO valoracions VALUES (2067, 41, '02/11/2004', 9);
INSERT INTO valoracions VALUES (2067, 5, '16/12/2006', 10);
INSERT INTO valoracions VALUES (2067, 9, '01/08/2007', 6);
INSERT INTO valoracions VALUES (2067, 64, '29/12/2006', 3);
INSERT INTO valoracions VALUES (2068, 33, '20/01/2004', 8);
INSERT INTO valoracions VALUES (2068, 19, '13/12/2008', 5);
INSERT INTO valoracions VALUES (2069, 23, '05/07/2010', 5);
INSERT INTO valoracions VALUES (2069, 97, '20/01/2008', 9);
INSERT INTO valoracions VALUES (2070, 32, '04/07/2008', 10);
INSERT INTO valoracions VALUES (2070, 49, '10/04/2010', 9);
INSERT INTO valoracions VALUES (2070, 28, '11/02/2007', 5);
INSERT INTO valoracions VALUES (2071, 26, '13/11/2006', 6);
INSERT INTO valoracions VALUES (2071, 97, '14/07/2007', 7);
INSERT INTO valoracions VALUES (2072, 92, '13/06/2010', 8);
INSERT INTO valoracions VALUES (2072, 50, '12/11/2005', 3);
INSERT INTO valoracions VALUES (2072, 1, '09/05/2004', 8);
INSERT INTO valoracions VALUES (2073, 13, '30/05/2001', 5);
INSERT INTO valoracions VALUES (2073, 52, '11/09/2003', 4);
INSERT INTO valoracions VALUES (2074, 114, '27/02/2003', 8);
INSERT INTO valoracions VALUES (2074, 4, '25/01/2004', 8);
INSERT INTO valoracions VALUES (2074, 94, '29/10/2008', 2);
INSERT INTO valoracions VALUES (2074, 5, '16/10/2004', 9);
INSERT INTO valoracions VALUES (2074, 92, '12/10/2002', 9);
INSERT INTO valoracions VALUES (2074, 56, '03/10/2001', 6);
INSERT INTO valoracions VALUES (2075, 48, '19/04/2003', 7);
INSERT INTO valoracions VALUES (2075, 8, '15/03/2007', 8);
INSERT INTO valoracions VALUES (2076, 113, '10/08/2007', 5);
INSERT INTO valoracions VALUES (2076, 38, '24/08/2004', 5);
INSERT INTO valoracions VALUES (2076, 30, '24/09/2005', 8);
INSERT INTO valoracions VALUES (2077, 115, '11/12/2006', 6);
INSERT INTO valoracions VALUES (2077, 108, '13/06/2002', 6);
INSERT INTO valoracions VALUES (2077, 7, '07/09/2009', 8);
INSERT INTO valoracions VALUES (2078, 10, '30/11/2006', 9);
INSERT INTO valoracions VALUES (2078, 61, '21/08/2004', 5);
INSERT INTO valoracions VALUES (2078, 34, '24/10/2002', 8);
INSERT INTO valoracions VALUES (2079, 26, '26/06/2006', 4);
INSERT INTO valoracions VALUES (2079, 58, '29/10/2009', 7);
INSERT INTO valoracions VALUES (2079, 74, '08/12/2008', 7);
INSERT INTO valoracions VALUES (2079, 21, '18/09/2009', 4);
INSERT INTO valoracions VALUES (2079, 54, '05/03/2006', 6);
INSERT INTO valoracions VALUES (2079, 57, '27/05/2003', 6);
INSERT INTO valoracions VALUES (2079, 40, '28/11/2006', 6);
INSERT INTO valoracions VALUES (2080, 23, '01/12/2005', 5);
INSERT INTO valoracions VALUES (2080, 108, '09/12/2008', 7);
INSERT INTO valoracions VALUES (2080, 25, '18/09/2004', 6);
INSERT INTO valoracions VALUES (2080, 43, '30/01/2008', 4);
INSERT INTO valoracions VALUES (2080, 42, '26/10/2004', 6);
INSERT INTO valoracions VALUES (2080, 88, '26/05/2002', 5);
INSERT INTO valoracions VALUES (2080, 45, '02/01/2003', 10);
INSERT INTO valoracions VALUES (2081, 9, '11/10/2001', 6);
INSERT INTO valoracions VALUES (2081, 5, '16/08/2010', 5);
INSERT INTO valoracions VALUES (2081, 96, '15/02/2007', 8);
INSERT INTO valoracions VALUES (2081, 52, '13/11/2009', 6);
INSERT INTO valoracions VALUES (2082, 11, '26/04/2004', 8);
INSERT INTO valoracions VALUES (2082, 55, '13/11/2009', 8);
INSERT INTO valoracions VALUES (2083, 75, '15/06/2001', 6);
INSERT INTO valoracions VALUES (2083, 11, '01/07/2002', 5);
INSERT INTO valoracions VALUES (2084, 101, '01/07/2006', 7);
INSERT INTO valoracions VALUES (2084, 88, '28/09/2002', 7);
INSERT INTO valoracions VALUES (2085, 70, '06/05/2003', 6);
INSERT INTO valoracions VALUES (2085, 45, '28/10/2002', 5);
INSERT INTO valoracions VALUES (2086, 43, '20/06/2007', 5);
INSERT INTO valoracions VALUES (2086, 22, '12/02/2006', 8);
INSERT INTO valoracions VALUES (2086, 40, '20/12/2002', 9);
INSERT INTO valoracions VALUES (2086, 23, '11/07/2007', 5);
INSERT INTO valoracions VALUES (2086, 69, '10/08/2004', 8);
INSERT INTO valoracions VALUES (2086, 32, '15/12/2009', 4);
INSERT INTO valoracions VALUES (2086, 86, '28/07/2004', 5);
INSERT INTO valoracions VALUES (2086, 52, '08/01/2006', 8);
INSERT INTO valoracions VALUES (2087, 109, '08/02/2010', 8);
INSERT INTO valoracions VALUES (2087, 36, '05/02/2009', 7);
INSERT INTO valoracions VALUES (2088, 97, '27/02/2003', 3);
INSERT INTO valoracions VALUES (2088, 83, '03/09/2009', 2);
INSERT INTO valoracions VALUES (2088, 69, '24/08/2005', 5);
INSERT INTO valoracions VALUES (2088, 47, '06/05/2005', 5);
INSERT INTO valoracions VALUES (2088, 59, '27/11/2002', 7);
INSERT INTO valoracions VALUES (2089, 29, '08/05/2010', 8);
INSERT INTO valoracions VALUES (2090, 66, '06/08/2010', 5);
INSERT INTO valoracions VALUES (2090, 49, '18/05/2002', 6);
INSERT INTO valoracions VALUES (2090, 44, '25/04/2008', 5);
INSERT INTO valoracions VALUES (2090, 41, '26/12/2006', 8);
INSERT INTO valoracions VALUES (2091, 79, '30/12/2009', 9);
INSERT INTO valoracions VALUES (2091, 63, '20/04/2006', 2);
INSERT INTO valoracions VALUES (2091, 109, '12/04/2002', 2);
INSERT INTO valoracions VALUES (2092, 52, '03/10/2009', 4);
INSERT INTO valoracions VALUES (2092, 20, '07/08/2006', 5);
INSERT INTO valoracions VALUES (2092, 86, '05/10/2006', 5);
INSERT INTO valoracions VALUES (2092, 65, '24/10/2006', 8);
INSERT INTO valoracions VALUES (2092, 83, '08/05/2002', 9);
INSERT INTO valoracions VALUES (2092, 72, '22/02/2005', 8);
INSERT INTO valoracions VALUES (2092, 68, '18/10/2003', 4);
INSERT INTO valoracions VALUES (2093, 30, '10/06/2005', 7);
INSERT INTO valoracions VALUES (2093, 91, '12/10/2009', 9);
INSERT INTO valoracions VALUES (2094, 82, '03/12/2002', 5);
INSERT INTO valoracions VALUES (2094, 61, '09/03/2009', 8);
INSERT INTO valoracions VALUES (2094, 10, '31/01/2006', 6);
INSERT INTO valoracions VALUES (2094, 18, '13/07/2009', 9);
INSERT INTO valoracions VALUES (2094, 43, '10/03/2008', 9);
INSERT INTO valoracions VALUES (2095, 58, '16/10/2002', 7);
INSERT INTO valoracions VALUES (2095, 89, '15/01/2003', 4);
INSERT INTO valoracions VALUES (2095, 64, '07/01/2008', 5);
INSERT INTO valoracions VALUES (2095, 36, '01/11/2006', 8);
INSERT INTO valoracions VALUES (2095, 81, '14/01/2005', 7);
INSERT INTO valoracions VALUES (2095, 74, '10/02/2008', 8);
INSERT INTO valoracions VALUES (2096, 110, '08/10/2001', 8);
INSERT INTO valoracions VALUES (2096, 30, '07/08/2008', 7);
INSERT INTO valoracions VALUES (2096, 111, '22/10/2006', 6);
INSERT INTO valoracions VALUES (2096, 78, '13/01/2003', 3);
INSERT INTO valoracions VALUES (2097, 22, '03/01/2010', 4);
INSERT INTO valoracions VALUES (2097, 3, '25/05/2005', 5);
INSERT INTO valoracions VALUES (2097, 103, '14/03/2008', 8);
INSERT INTO valoracions VALUES (2097, 111, '05/02/2002', 9);
INSERT INTO valoracions VALUES (2098, 16, '28/03/2004', 7);
INSERT INTO valoracions VALUES (2098, 5, '22/03/2009', 9);
INSERT INTO valoracions VALUES (2098, 29, '25/03/2006', 9);
INSERT INTO valoracions VALUES (2099, 8, '30/03/2005', 6);
INSERT INTO valoracions VALUES (2099, 46, '31/07/2002', 4);
INSERT INTO valoracions VALUES (2099, 65, '29/03/2003', 3);
INSERT INTO valoracions VALUES (2099, 72, '03/02/2007', 9);
INSERT INTO valoracions VALUES (2101, 89, '20/02/2004', 7);
INSERT INTO valoracions VALUES (2101, 51, '08/05/2010', 7);
INSERT INTO valoracions VALUES (2101, 6, '09/01/2007', 9);
INSERT INTO valoracions VALUES (2101, 108, '01/06/2010', 7);
INSERT INTO valoracions VALUES (2101, 4, '30/04/2005', 9);
INSERT INTO valoracions VALUES (2102, 37, '02/05/2006', 7);
INSERT INTO valoracions VALUES (2102, 14, '20/02/2003', 5);
INSERT INTO valoracions VALUES (2102, 84, '03/02/2005', 3);
INSERT INTO valoracions VALUES (2103, 16, '29/03/2008', 7);
INSERT INTO valoracions VALUES (2104, 102, '10/09/2009', 3);
INSERT INTO valoracions VALUES (2105, 48, '15/01/2003', 5);
INSERT INTO valoracions VALUES (2105, 96, '23/12/2005', 1);
INSERT INTO valoracions VALUES (2105, 40, '10/01/2009', 5);
INSERT INTO valoracions VALUES (2105, 2, '18/04/2007', 8);
INSERT INTO valoracions VALUES (2105, 97, '19/02/2003', 3);
INSERT INTO valoracions VALUES (2105, 89, '04/02/2008', 7);
INSERT INTO valoracions VALUES (2106, 57, '10/11/2005', 4);
INSERT INTO valoracions VALUES (2108, 32, '13/04/2002', 4);
INSERT INTO valoracions VALUES (2108, 102, '14/08/2006', 9);
INSERT INTO valoracions VALUES (2108, 32, '20/08/2005', 7);
INSERT INTO valoracions VALUES (2108, 101, '04/05/2010', 8);
INSERT INTO valoracions VALUES (2108, 6, '23/10/2001', 7);
INSERT INTO valoracions VALUES (2109, 18, '17/12/2003', 7);
INSERT INTO valoracions VALUES (2109, 20, '31/07/2007', 5);
INSERT INTO valoracions VALUES (2109, 15, '21/01/2004', 8);
INSERT INTO valoracions VALUES (2109, 70, '01/03/2006', 9);
INSERT INTO valoracions VALUES (2110, 22, '29/06/2010', 5);
INSERT INTO valoracions VALUES (2110, 86, '16/06/2004', 7);
INSERT INTO valoracions VALUES (2110, 5, '17/03/2009', 9);
INSERT INTO valoracions VALUES (2110, 85, '09/02/2005', 5);
INSERT INTO valoracions VALUES (2111, 116, '16/08/2003', 1);
INSERT INTO valoracions VALUES (2111, 16, '27/04/2005', 10);
INSERT INTO valoracions VALUES (2112, 37, '30/08/2009', 7);
INSERT INTO valoracions VALUES (2113, 62, '13/10/2001', 4);
INSERT INTO valoracions VALUES (2113, 107, '01/08/2004', 5);
INSERT INTO valoracions VALUES (2113, 51, '19/02/2009', 3);
INSERT INTO valoracions VALUES (2113, 18, '05/02/2003', 6);
INSERT INTO valoracions VALUES (2113, 109, '27/07/2004', 4);
INSERT INTO valoracions VALUES (2113, 97, '08/11/2004', 4);
INSERT INTO valoracions VALUES (2114, 39, '30/04/2010', 5);
INSERT INTO valoracions VALUES (2114, 5, '05/08/2002', 7);
INSERT INTO valoracions VALUES (2114, 62, '23/09/2004', 9);
INSERT INTO valoracions VALUES (2115, 25, '29/12/2005', 8);
INSERT INTO valoracions VALUES (2115, 93, '18/03/2005', 9);
INSERT INTO valoracions VALUES (2115, 38, '08/08/2006', 5);
INSERT INTO valoracions VALUES (2115, 74, '17/12/2001', 7);
INSERT INTO valoracions VALUES (2115, 107, '27/04/2002', 0);
INSERT INTO valoracions VALUES (2115, 45, '10/09/2010', 4);
INSERT INTO valoracions VALUES (2115, 83, '26/04/2003', 5);
INSERT INTO valoracions VALUES (2115, 53, '13/07/2002', 9);
INSERT INTO valoracions VALUES (2116, 111, '13/06/2002', 8);
INSERT INTO valoracions VALUES (2116, 111, '15/09/2004', 7);
INSERT INTO valoracions VALUES (2116, 112, '24/01/2008', 3);
INSERT INTO valoracions VALUES (2117, 106, '09/10/2003', 9);
INSERT INTO valoracions VALUES (2117, 86, '16/02/2007', 7);
INSERT INTO valoracions VALUES (2117, 77, '14/03/2003', 7);
INSERT INTO valoracions VALUES (2117, 30, '01/01/2008', 4);
INSERT INTO valoracions VALUES (2117, 101, '04/08/2004', 6);
INSERT INTO valoracions VALUES (2118, 104, '25/06/2009', 4);
INSERT INTO valoracions VALUES (2118, 45, '12/07/2008', 5);
INSERT INTO valoracions VALUES (2118, 87, '02/06/2009', 5);
INSERT INTO valoracions VALUES (2118, 20, '04/06/2005', 7);
INSERT INTO valoracions VALUES (2118, 100, '23/11/2009', 2);
INSERT INTO valoracions VALUES (2118, 97, '23/08/2001', 6);
INSERT INTO valoracions VALUES (2118, 77, '04/03/2003', 10);
INSERT INTO valoracions VALUES (2119, 112, '07/02/2002', 4);
INSERT INTO valoracions VALUES (2119, 38, '13/05/2005', 6);
INSERT INTO valoracions VALUES (2120, 50, '10/12/2007', 6);
INSERT INTO valoracions VALUES (2120, 38, '29/12/2009', 8);
INSERT INTO valoracions VALUES (2120, 95, '19/11/2008', 9);
INSERT INTO valoracions VALUES (2120, 27, '01/08/2008', 6);
INSERT INTO valoracions VALUES (2120, 25, '25/10/2002', 6);
INSERT INTO valoracions VALUES (2120, 19, '20/01/2004', 5);
INSERT INTO valoracions VALUES (2120, 109, '20/09/2002', 8);
INSERT INTO valoracions VALUES (2121, 32, '21/03/2004', 7);
INSERT INTO valoracions VALUES (2121, 9, '11/06/2006', 9);
INSERT INTO valoracions VALUES (2121, 86, '10/06/2002', 6);
INSERT INTO valoracions VALUES (2121, 61, '14/08/2010', 8);
INSERT INTO valoracions VALUES (2121, 26, '14/04/2008', 6);
INSERT INTO valoracions VALUES (2121, 113, '21/09/2002', 4);
INSERT INTO valoracions VALUES (2122, 50, '05/10/2003', 5);
INSERT INTO valoracions VALUES (2123, 56, '18/09/2010', 10);
INSERT INTO valoracions VALUES (2123, 74, '31/10/2002', 8);
INSERT INTO valoracions VALUES (2124, 84, '13/07/2003', 3);
INSERT INTO valoracions VALUES (2124, 31, '05/09/2008', 7);
INSERT INTO valoracions VALUES (2124, 69, '09/07/2001', 10);
INSERT INTO valoracions VALUES (2125, 71, '12/11/2007', 9);
INSERT INTO valoracions VALUES (2125, 96, '01/12/2009', 1);
INSERT INTO valoracions VALUES (2126, 4, '15/05/2001', 10);
INSERT INTO valoracions VALUES (2126, 58, '08/02/2003', 5);
INSERT INTO valoracions VALUES (2126, 102, '07/05/2006', 5);
INSERT INTO valoracions VALUES (2126, 14, '31/12/2003', 7);
INSERT INTO valoracions VALUES (2126, 113, '23/10/2002', 7);
INSERT INTO valoracions VALUES (2126, 60, '01/03/2005', 8);
INSERT INTO valoracions VALUES (2126, 72, '27/12/2002', 4);
INSERT INTO valoracions VALUES (2126, 112, '14/10/2001', 5);
INSERT INTO valoracions VALUES (2126, 72, '06/09/2006', 6);
INSERT INTO valoracions VALUES (2127, 97, '23/03/2010', 4);
INSERT INTO valoracions VALUES (2127, 38, '01/08/2007', 9);
INSERT INTO valoracions VALUES (2127, 71, '23/09/2005', 2);
INSERT INTO valoracions VALUES (2127, 75, '23/07/2010', 6);
INSERT INTO valoracions VALUES (2127, 20, '27/11/2003', 4);
INSERT INTO valoracions VALUES (2127, 46, '22/05/2006', 5);
INSERT INTO valoracions VALUES (2127, 16, '06/11/2004', 8);
INSERT INTO valoracions VALUES (2128, 37, '02/11/2006', 10);
INSERT INTO valoracions VALUES (2128, 70, '26/03/2004', 8);
INSERT INTO valoracions VALUES (2128, 108, '28/08/2001', 3);
INSERT INTO valoracions VALUES (2128, 72, '19/10/2002', 4);
INSERT INTO valoracions VALUES (2129, 63, '26/12/2004', 6);
INSERT INTO valoracions VALUES (2129, 63, '03/10/2001', 5);
INSERT INTO valoracions VALUES (2129, 51, '28/04/2009', 9);
INSERT INTO valoracions VALUES (2129, 113, '22/04/2001', 4);
INSERT INTO valoracions VALUES (2129, 88, '23/04/2002', 5);
INSERT INTO valoracions VALUES (2129, 41, '08/04/2006', 6);
INSERT INTO valoracions VALUES (2129, 8, '25/10/2004', 7);
INSERT INTO valoracions VALUES (2129, 62, '25/07/2003', 5);
INSERT INTO valoracions VALUES (2129, 11, '02/04/2008', 8);
INSERT INTO valoracions VALUES (2130, 51, '27/10/2009', 6);
INSERT INTO valoracions VALUES (2130, 15, '17/11/2003', 8);
INSERT INTO valoracions VALUES (2130, 75, '17/09/2005', 5);
INSERT INTO valoracions VALUES (2130, 116, '22/12/2009', 3);
INSERT INTO valoracions VALUES (2130, 10, '06/10/2009', 7);
INSERT INTO valoracions VALUES (2130, 22, '04/06/2001', 9);
INSERT INTO valoracions VALUES (2130, 69, '27/10/2007', 4);
INSERT INTO valoracions VALUES (2131, 17, '30/03/2002', 7);
INSERT INTO valoracions VALUES (2132, 61, '15/12/2006', 6);
INSERT INTO valoracions VALUES (2132, 100, '14/01/2010', 7);
INSERT INTO valoracions VALUES (2132, 43, '20/01/2003', 9);
INSERT INTO valoracions VALUES (2132, 68, '24/10/2002', 4);
INSERT INTO valoracions VALUES (2132, 36, '16/04/2003', 5);
INSERT INTO valoracions VALUES (2133, 98, '15/09/2009', 6);
INSERT INTO valoracions VALUES (2133, 45, '04/09/2006', 8);
INSERT INTO valoracions VALUES (2133, 83, '06/05/2008', 6);
INSERT INTO valoracions VALUES (2133, 40, '16/07/2006', 9);
INSERT INTO valoracions VALUES (2133, 70, '22/07/2006', 8);
INSERT INTO valoracions VALUES (2133, 78, '17/06/2002', 5);
INSERT INTO valoracions VALUES (2133, 60, '24/07/2001', 6);
INSERT INTO valoracions VALUES (2133, 35, '27/09/2001', 9);
INSERT INTO valoracions VALUES (2134, 50, '07/08/2005', 10);
INSERT INTO valoracions VALUES (2134, 25, '18/08/2007', 4);
INSERT INTO valoracions VALUES (2134, 33, '27/07/2008', 4);
INSERT INTO valoracions VALUES (2134, 44, '17/07/2006', 5);
INSERT INTO valoracions VALUES (2135, 11, '13/07/2001', 8);
INSERT INTO valoracions VALUES (2135, 17, '19/06/2010', 8);
INSERT INTO valoracions VALUES (2135, 59, '01/11/2005', 8);
INSERT INTO valoracions VALUES (2135, 38, '19/08/2008', 9);
INSERT INTO valoracions VALUES (2135, 83, '24/10/2009', 7);
INSERT INTO valoracions VALUES (2136, 71, '29/08/2002', 10);
INSERT INTO valoracions VALUES (2136, 80, '07/03/2009', 4);
INSERT INTO valoracions VALUES (2136, 38, '27/04/2009', 10);
INSERT INTO valoracions VALUES (2137, 112, '20/11/2002', 8);
INSERT INTO valoracions VALUES (2137, 104, '20/04/2010', 4);
INSERT INTO valoracions VALUES (2137, 115, '26/05/2002', 3);
INSERT INTO valoracions VALUES (2137, 89, '08/05/2002', 3);
INSERT INTO valoracions VALUES (2138, 98, '22/05/2008', 1);
INSERT INTO valoracions VALUES (2138, 3, '23/12/2003', 10);
INSERT INTO valoracions VALUES (2138, 107, '30/10/2010', 6);
INSERT INTO valoracions VALUES (2139, 24, '19/11/2003', 4);
INSERT INTO valoracions VALUES (2139, 67, '13/05/2007', 5);
INSERT INTO valoracions VALUES (2139, 98, '05/02/2008', 9);
INSERT INTO valoracions VALUES (2139, 100, '03/04/2001', 4);
INSERT INTO valoracions VALUES (2139, 13, '11/08/2006', 7);
INSERT INTO valoracions VALUES (2139, 62, '10/08/2005', 5);
INSERT INTO valoracions VALUES (2140, 78, '02/08/2003', 10);
INSERT INTO valoracions VALUES (2140, 63, '07/05/2007', 7);
INSERT INTO valoracions VALUES (2140, 45, '15/02/2006', 10);
INSERT INTO valoracions VALUES (2140, 2, '16/11/2003', 9);
INSERT INTO valoracions VALUES (2141, 18, '20/07/2008', 5);
INSERT INTO valoracions VALUES (2141, 108, '11/01/2006', 5);
INSERT INTO valoracions VALUES (2142, 43, '26/11/2005', 4);
INSERT INTO valoracions VALUES (2142, 80, '02/12/2009', 2);
INSERT INTO valoracions VALUES (2142, 14, '23/09/2003', 8);
INSERT INTO valoracions VALUES (2143, 110, '17/08/2009', 7);
INSERT INTO valoracions VALUES (2143, 46, '16/02/2005', 4);
INSERT INTO valoracions VALUES (2143, 36, '26/02/2006', 5);
INSERT INTO valoracions VALUES (2143, 2, '25/06/2003', 6);
INSERT INTO valoracions VALUES (2143, 2, '14/09/2007', 6);
INSERT INTO valoracions VALUES (2144, 35, '10/09/2008', 8);
INSERT INTO valoracions VALUES (2144, 84, '18/03/2004', 9);
INSERT INTO valoracions VALUES (2144, 105, '23/04/2002', 6);
INSERT INTO valoracions VALUES (2144, 88, '05/01/2007', 2);
INSERT INTO valoracions VALUES (2145, 64, '04/11/2007', 5);
INSERT INTO valoracions VALUES (2145, 71, '13/06/2005', 9);
INSERT INTO valoracions VALUES (2145, 9, '20/10/2008', 8);
INSERT INTO valoracions VALUES (2145, 108, '21/05/2006', 7);
INSERT INTO valoracions VALUES (2146, 60, '04/04/2003', 6);
INSERT INTO valoracions VALUES (2146, 4, '08/02/2009', 8);
INSERT INTO valoracions VALUES (2147, 71, '13/01/2002', 8);
INSERT INTO valoracions VALUES (2147, 97, '18/08/2003', 9);
INSERT INTO valoracions VALUES (2147, 10, '15/02/2004', 7);
INSERT INTO valoracions VALUES (2147, 25, '02/09/2009', 7);
INSERT INTO valoracions VALUES (2147, 104, '24/12/2008', 2);
INSERT INTO valoracions VALUES (2148, 19, '02/03/2008', 8);
INSERT INTO valoracions VALUES (2148, 20, '30/01/2002', 10);
INSERT INTO valoracions VALUES (2148, 113, '23/11/2001', 9);
INSERT INTO valoracions VALUES (2148, 113, '26/06/2004', 3);
INSERT INTO valoracions VALUES (2149, 103, '21/07/2002', 2);
INSERT INTO valoracions VALUES (2149, 37, '17/01/2007', 9);
INSERT INTO valoracions VALUES (2149, 114, '07/04/2009', 2);
INSERT INTO valoracions VALUES (2149, 13, '08/09/2002', 7);
INSERT INTO valoracions VALUES (2150, 77, '03/02/2004', 6);
INSERT INTO valoracions VALUES (2150, 90, '19/07/2010', 2);
INSERT INTO valoracions VALUES (2150, 99, '14/09/2005', 3);
INSERT INTO valoracions VALUES (2150, 2, '11/01/2006', 10);
INSERT INTO valoracions VALUES (2151, 65, '26/12/2003', 8);
INSERT INTO valoracions VALUES (2151, 6, '15/04/2010', 8);
INSERT INTO valoracions VALUES (2151, 61, '18/06/2005', 5);
INSERT INTO valoracions VALUES (2152, 101, '01/07/2001', 2);
INSERT INTO valoracions VALUES (2152, 112, '31/03/2008', 8);
INSERT INTO valoracions VALUES (2152, 52, '22/02/2004', 3);
INSERT INTO valoracions VALUES (2152, 105, '02/03/2005', 2);
INSERT INTO valoracions VALUES (2153, 8, '04/05/2009', 6);
INSERT INTO valoracions VALUES (2153, 91, '16/03/2008', 6);
INSERT INTO valoracions VALUES (2153, 3, '27/04/2006', 10);
INSERT INTO valoracions VALUES (2154, 113, '24/06/2008', 9);
INSERT INTO valoracions VALUES (2154, 109, '16/01/2006', 4);
INSERT INTO valoracions VALUES (2154, 42, '20/12/2002', 5);
INSERT INTO valoracions VALUES (2154, 35, '12/12/2001', 8);
INSERT INTO valoracions VALUES (2155, 83, '04/10/2003', 6);
INSERT INTO valoracions VALUES (2155, 102, '04/10/2004', 6);
INSERT INTO valoracions VALUES (2155, 45, '30/08/2001', 8);
INSERT INTO valoracions VALUES (2156, 44, '06/03/2004', 7);
INSERT INTO valoracions VALUES (2156, 26, '13/03/2002', 5);
INSERT INTO valoracions VALUES (2156, 6, '22/09/2008', 10);
INSERT INTO valoracions VALUES (2156, 58, '16/07/2009', 5);
INSERT INTO valoracions VALUES (2157, 96, '28/06/2008', 7);
INSERT INTO valoracions VALUES (2158, 77, '06/06/2008', 2);
INSERT INTO valoracions VALUES (2158, 81, '18/03/2007', 7);
INSERT INTO valoracions VALUES (2158, 75, '04/05/2003', 7);
INSERT INTO valoracions VALUES (2158, 73, '02/02/2002', 8);
INSERT INTO valoracions VALUES (2158, 50, '05/04/2006', 7);
INSERT INTO valoracions VALUES (2158, 91, '27/10/2003', 9);
INSERT INTO valoracions VALUES (2159, 65, '27/03/2009', 5);
INSERT INTO valoracions VALUES (2159, 76, '30/07/2010', 3);
INSERT INTO valoracions VALUES (2160, 116, '17/02/2008', 0);
INSERT INTO valoracions VALUES (2161, 79, '06/03/2003', 2);
INSERT INTO valoracions VALUES (2161, 43, '18/11/2009', 9);
INSERT INTO valoracions VALUES (2161, 28, '12/07/2001', 6);
INSERT INTO valoracions VALUES (2161, 82, '24/05/2009', 6);
INSERT INTO valoracions VALUES (2161, 44, '03/02/2004', 4);
INSERT INTO valoracions VALUES (2161, 2, '25/04/2009', 6);
INSERT INTO valoracions VALUES (2161, 113, '17/02/2002', 10);
INSERT INTO valoracions VALUES (2161, 110, '15/06/2003', 7);
INSERT INTO valoracions VALUES (2161, 85, '22/07/2010', 6);
INSERT INTO valoracions VALUES (2162, 49, '25/06/2001', 4);
INSERT INTO valoracions VALUES (2162, 13, '23/03/2007', 6);
INSERT INTO valoracions VALUES (2162, 22, '05/05/2009', 6);
INSERT INTO valoracions VALUES (2162, 86, '01/04/2005', 7);
INSERT INTO valoracions VALUES (2163, 26, '07/03/2005', 6);
INSERT INTO valoracions VALUES (2163, 12, '13/06/2010', 9);
INSERT INTO valoracions VALUES (2163, 52, '25/07/2007', 6);
INSERT INTO valoracions VALUES (2163, 60, '17/11/2003', 8);
INSERT INTO valoracions VALUES (2163, 67, '23/06/2003', 10);
INSERT INTO valoracions VALUES (2163, 60, '19/11/2007', 5);
INSERT INTO valoracions VALUES (2163, 67, '24/06/2009', 3);
INSERT INTO valoracions VALUES (2164, 84, '30/05/2007', 7);
INSERT INTO valoracions VALUES (2164, 36, '30/09/2007', 9);
INSERT INTO valoracions VALUES (2164, 20, '23/09/2002', 7);
INSERT INTO valoracions VALUES (2164, 39, '24/03/2009', 9);
INSERT INTO valoracions VALUES (2164, 9, '19/12/2007', 7);
INSERT INTO valoracions VALUES (2165, 75, '19/06/2005', 5);
INSERT INTO valoracions VALUES (2165, 67, '26/10/2010', 8);
INSERT INTO valoracions VALUES (2165, 3, '20/11/2008', 5);
INSERT INTO valoracions VALUES (2165, 29, '25/04/2002', 8);
INSERT INTO valoracions VALUES (2165, 82, '15/01/2003', 9);
INSERT INTO valoracions VALUES (2165, 90, '04/10/2009', 8);
INSERT INTO valoracions VALUES (2166, 112, '23/06/2001', 4);
INSERT INTO valoracions VALUES (2166, 98, '03/08/2006', 5);
INSERT INTO valoracions VALUES (2166, 110, '27/10/2003', 7);
INSERT INTO valoracions VALUES (2167, 108, '31/08/2006', 10);
INSERT INTO valoracions VALUES (2167, 50, '11/01/2008', 7);
INSERT INTO valoracions VALUES (2167, 98, '01/12/2001', 7);
INSERT INTO valoracions VALUES (2167, 59, '27/12/2002', 3);
INSERT INTO valoracions VALUES (2167, 1, '02/05/2008', 9);
INSERT INTO valoracions VALUES (2167, 86, '24/06/2005', 4);
INSERT INTO valoracions VALUES (2168, 112, '12/02/2005', 2);
INSERT INTO valoracions VALUES (2168, 101, '26/07/2007', 6);
INSERT INTO valoracions VALUES (2168, 51, '01/05/2004', 6);
INSERT INTO valoracions VALUES (2168, 106, '05/01/2008', 1);
INSERT INTO valoracions VALUES (2169, 40, '23/10/2010', 7);
INSERT INTO valoracions VALUES (2169, 100, '13/08/2010', 7);
INSERT INTO valoracions VALUES (2169, 27, '30/04/2010', 8);
INSERT INTO valoracions VALUES (2169, 41, '12/07/2009', 5);
INSERT INTO valoracions VALUES (2170, 93, '19/04/2009', 10);
INSERT INTO valoracions VALUES (2170, 45, '29/04/2010', 9);
INSERT INTO valoracions VALUES (2170, 31, '29/05/2001', 9);
INSERT INTO valoracions VALUES (2170, 61, '24/03/2002', 8);
INSERT INTO valoracions VALUES (2170, 62, '09/08/2010', 8);
INSERT INTO valoracions VALUES (2171, 1, '31/01/2007', 8);
INSERT INTO valoracions VALUES (2171, 67, '23/07/2010', 2);
INSERT INTO valoracions VALUES (2171, 32, '11/01/2007', 8);
INSERT INTO valoracions VALUES (2171, 37, '18/04/2005', 9);
INSERT INTO valoracions VALUES (2172, 12, '18/05/2004', 6);
INSERT INTO valoracions VALUES (2172, 104, '01/10/2009', 2);
INSERT INTO valoracions VALUES (2172, 29, '25/09/2004', 10);
INSERT INTO valoracions VALUES (2172, 91, '27/04/2002', 2);
INSERT INTO valoracions VALUES (2173, 49, '11/01/2002', 5);
INSERT INTO valoracions VALUES (2173, 17, '02/05/2007', 5);
INSERT INTO valoracions VALUES (2173, 36, '30/08/2002', 6);
INSERT INTO valoracions VALUES (2173, 7, '06/07/2001', 5);
INSERT INTO valoracions VALUES (2173, 44, '15/03/2010', 7);
INSERT INTO valoracions VALUES (2173, 12, '28/06/2005', 6);
INSERT INTO valoracions VALUES (2174, 36, '26/05/2009', 5);
INSERT INTO valoracions VALUES (2175, 58, '22/09/2004', 7);
INSERT INTO valoracions VALUES (2175, 68, '16/10/2010', 5);
INSERT INTO valoracions VALUES (2175, 32, '25/09/2005', 6);
INSERT INTO valoracions VALUES (2176, 67, '30/06/2001', 2);
INSERT INTO valoracions VALUES (2176, 114, '19/04/2009', 0);
INSERT INTO valoracions VALUES (2176, 109, '18/11/2001', 2);
INSERT INTO valoracions VALUES (2176, 55, '12/09/2004', 3);
INSERT INTO valoracions VALUES (2176, 81, '30/07/2001', 2);
INSERT INTO valoracions VALUES (2176, 73, '21/11/2005', 8);
INSERT INTO valoracions VALUES (2177, 93, '01/07/2001', 2);
INSERT INTO valoracions VALUES (2177, 4, '07/02/2008', 9);
INSERT INTO valoracions VALUES (2177, 16, '15/03/2009', 9);
INSERT INTO valoracions VALUES (2177, 101, '30/01/2009', 6);
INSERT INTO valoracions VALUES (2178, 69, '08/04/2003', 10);
INSERT INTO valoracions VALUES (2178, 40, '24/05/2006', 9);
INSERT INTO valoracions VALUES (2178, 88, '01/09/2002', 6);
INSERT INTO valoracions VALUES (2178, 30, '11/05/2010', 4);
INSERT INTO valoracions VALUES (2178, 103, '14/09/2008', 4);
INSERT INTO valoracions VALUES (2178, 25, '09/09/2010', 8);
INSERT INTO valoracions VALUES (2178, 110, '19/07/2009', 4);
INSERT INTO valoracions VALUES (2179, 75, '01/10/2003', 9);
INSERT INTO valoracions VALUES (2179, 54, '12/04/2006', 9);
INSERT INTO valoracions VALUES (2179, 45, '10/10/2009', 7);
INSERT INTO valoracions VALUES (2179, 51, '10/12/2009', 3);
INSERT INTO valoracions VALUES (2179, 81, '31/08/2002', 2);
INSERT INTO valoracions VALUES (2179, 16, '05/06/2008', 9);
INSERT INTO valoracions VALUES (2179, 21, '27/04/2006', 7);
INSERT INTO valoracions VALUES (2179, 76, '21/04/2005', 7);
INSERT INTO valoracions VALUES (2179, 73, '18/04/2009', 8);
INSERT INTO valoracions VALUES (2180, 39, '30/01/2008', 9);
INSERT INTO valoracions VALUES (2180, 27, '27/06/2003', 6);
INSERT INTO valoracions VALUES (2180, 97, '02/10/2002', 9);
INSERT INTO valoracions VALUES (2181, 17, '01/09/2007', 8);
INSERT INTO valoracions VALUES (2181, 58, '13/03/2002', 6);
INSERT INTO valoracions VALUES (2181, 72, '20/11/2003', 8);
INSERT INTO valoracions VALUES (2181, 74, '04/05/2001', 10);
INSERT INTO valoracions VALUES (2181, 57, '02/07/2006', 7);
INSERT INTO valoracions VALUES (2182, 64, '30/05/2005', 5);
INSERT INTO valoracions VALUES (2182, 98, '10/09/2004', 7);
INSERT INTO valoracions VALUES (2183, 85, '18/07/2007', 1);
INSERT INTO valoracions VALUES (2183, 51, '17/09/2007', 5);
INSERT INTO valoracions VALUES (2183, 81, '25/08/2002', 5);
INSERT INTO valoracions VALUES (2183, 1, '10/11/2009', 5);
INSERT INTO valoracions VALUES (2184, 12, '21/11/2006', 10);
INSERT INTO valoracions VALUES (2184, 39, '27/11/2006', 7);
INSERT INTO valoracions VALUES (2184, 42, '07/10/2008', 6);
INSERT INTO valoracions VALUES (2185, 107, '13/03/2003', 7);
INSERT INTO valoracions VALUES (2185, 62, '17/10/2009', 6);
INSERT INTO valoracions VALUES (2185, 87, '19/08/2008', 9);
INSERT INTO valoracions VALUES (2185, 52, '20/06/2007', 9);
INSERT INTO valoracions VALUES (2185, 8, '25/12/2002', 9);
INSERT INTO valoracions VALUES (2185, 83, '31/05/2001', 9);
INSERT INTO valoracions VALUES (2185, 3, '23/08/2003', 5);
INSERT INTO valoracions VALUES (2186, 43, '11/08/2001', 7);
INSERT INTO valoracions VALUES (2186, 37, '06/06/2002', 7);
INSERT INTO valoracions VALUES (2186, 57, '04/09/2003', 6);
INSERT INTO valoracions VALUES (2186, 1, '03/08/2002', 6);
INSERT INTO valoracions VALUES (2186, 63, '08/02/2008', 6);
INSERT INTO valoracions VALUES (2186, 14, '29/05/2004', 9);
INSERT INTO valoracions VALUES (2186, 105, '23/04/2002', 9);
INSERT INTO valoracions VALUES (2186, 15, '24/12/2004', 8);
INSERT INTO valoracions VALUES (2186, 24, '16/08/2008', 8);
INSERT INTO valoracions VALUES (2187, 91, '24/02/2002', 3);
INSERT INTO valoracions VALUES (2187, 35, '30/07/2006', 5);
INSERT INTO valoracions VALUES (2187, 13, '07/07/2010', 7);
INSERT INTO valoracions VALUES (2187, 35, '14/01/2003', 4);
INSERT INTO valoracions VALUES (2188, 90, '27/02/2004', 9);
INSERT INTO valoracions VALUES (2188, 60, '22/05/2006', 9);
INSERT INTO valoracions VALUES (2188, 60, '26/07/2001', 6);
INSERT INTO valoracions VALUES (2188, 29, '13/11/2005', 9);
INSERT INTO valoracions VALUES (2188, 77, '27/04/2006', 8);
INSERT INTO valoracions VALUES (2189, 34, '09/01/2005', 7);
INSERT INTO valoracions VALUES (2189, 68, '27/12/2009', 8);
INSERT INTO valoracions VALUES (2189, 105, '28/12/2003', 9);
INSERT INTO valoracions VALUES (2189, 76, '06/12/2003', 9);
INSERT INTO valoracions VALUES (2189, 46, '02/05/2009', 5);
INSERT INTO valoracions VALUES (2190, 99, '02/06/2004', 8);
INSERT INTO valoracions VALUES (2191, 14, '07/04/2009', 8);
INSERT INTO valoracions VALUES (2191, 48, '05/05/2010', 7);
INSERT INTO valoracions VALUES (2193, 102, '19/10/2009', 3);
INSERT INTO valoracions VALUES (2193, 34, '03/03/2010', 4);
INSERT INTO valoracions VALUES (2194, 47, '31/07/2004', 7);
INSERT INTO valoracions VALUES (2194, 59, '18/10/2004', 8);
INSERT INTO valoracions VALUES (2194, 88, '19/05/2005', 9);
INSERT INTO valoracions VALUES (2195, 85, '15/12/2002', 2);
INSERT INTO valoracions VALUES (2195, 50, '16/12/2003', 5);
INSERT INTO valoracions VALUES (2195, 4, '12/11/2004', 5);
INSERT INTO valoracions VALUES (2195, 58, '03/09/2008', 3);
INSERT INTO valoracions VALUES (2195, 49, '24/06/2003', 4);
INSERT INTO valoracions VALUES (2196, 88, '24/09/2007', 4);
INSERT INTO valoracions VALUES (2196, 66, '19/07/2006', 4);
INSERT INTO valoracions VALUES (2196, 3, '18/01/2010', 9);
INSERT INTO valoracions VALUES (2196, 56, '20/10/2008', 6);
INSERT INTO valoracions VALUES (2197, 88, '16/06/2008', 2);
INSERT INTO valoracions VALUES (2197, 9, '14/05/2008', 9);
INSERT INTO valoracions VALUES (2197, 38, '15/01/2009', 5);
INSERT INTO valoracions VALUES (2197, 53, '23/10/2008', 9);
INSERT INTO valoracions VALUES (2198, 43, '08/11/2002', 3);
INSERT INTO valoracions VALUES (2198, 70, '17/12/2005', 7);
INSERT INTO valoracions VALUES (2198, 19, '08/12/2008', 9);
INSERT INTO valoracions VALUES (2199, 13, '23/12/2001', 7);
INSERT INTO valoracions VALUES (2199, 2, '16/04/2005', 9);
INSERT INTO valoracions VALUES (2199, 103, '09/11/2002', 4);
INSERT INTO valoracions VALUES (2200, 1, '27/05/2003', 10);
INSERT INTO valoracions VALUES (2200, 80, '16/08/2004', 3);
INSERT INTO valoracions VALUES (2200, 82, '27/12/2007', 3);
INSERT INTO valoracions VALUES (2200, 101, '26/12/2006', 7);
INSERT INTO valoracions VALUES (2200, 22, '01/12/2003', 7);
INSERT INTO valoracions VALUES (2200, 104, '02/09/2009', 1);
INSERT INTO valoracions VALUES (2202, 13, '29/03/2010', 9);
INSERT INTO valoracions VALUES (2202, 47, '15/03/2010', 4);
INSERT INTO valoracions VALUES (2202, 69, '24/09/2002', 3);
INSERT INTO valoracions VALUES (2202, 9, '25/07/2002', 7);
INSERT INTO valoracions VALUES (2202, 74, '17/06/2001', 9);
INSERT INTO valoracions VALUES (2202, 106, '07/11/2009', 8);
INSERT INTO valoracions VALUES (2202, 28, '03/06/2001', 8);
INSERT INTO valoracions VALUES (2202, 69, '06/07/2009', 7);
INSERT INTO valoracions VALUES (2202, 23, '22/12/2002', 8);
INSERT INTO valoracions VALUES (2203, 70, '03/10/2009', 9);
INSERT INTO valoracions VALUES (2203, 6, '29/08/2008', 5);
INSERT INTO valoracions VALUES (2203, 11, '19/06/2007', 5);
INSERT INTO valoracions VALUES (2203, 13, '28/12/2006', 9);
INSERT INTO valoracions VALUES (2203, 4, '18/12/2003', 7);
INSERT INTO valoracions VALUES (2203, 59, '26/11/2005', 3);
INSERT INTO valoracions VALUES (2204, 59, '11/12/2009', 6);
INSERT INTO valoracions VALUES (2205, 52, '31/08/2006', 5);
INSERT INTO valoracions VALUES (2205, 89, '23/12/2009', 5);
INSERT INTO valoracions VALUES (2205, 16, '26/01/2004', 4);
INSERT INTO valoracions VALUES (2205, 29, '23/06/2007', 6);
INSERT INTO valoracions VALUES (2205, 6, '01/07/2006', 10);
INSERT INTO valoracions VALUES (2206, 109, '18/10/2009', 1);
INSERT INTO valoracions VALUES (2206, 101, '07/09/2003', 8);
INSERT INTO valoracions VALUES (2206, 70, '29/11/2009', 5);
INSERT INTO valoracions VALUES (2206, 94, '25/05/2005', 6);
INSERT INTO valoracions VALUES (2206, 54, '18/01/2007', 9);
INSERT INTO valoracions VALUES (2207, 87, '12/09/2002', 8);
INSERT INTO valoracions VALUES (2207, 57, '19/04/2006', 3);
INSERT INTO valoracions VALUES (2207, 14, '15/03/2005', 8);
INSERT INTO valoracions VALUES (2208, 106, '12/06/2006', 2);
INSERT INTO valoracions VALUES (2208, 73, '29/05/2004', 4);
INSERT INTO valoracions VALUES (2208, 37, '10/06/2002', 9);
INSERT INTO valoracions VALUES (2208, 8, '29/11/2004', 9);
INSERT INTO valoracions VALUES (2209, 27, '27/07/2001', 9);
INSERT INTO valoracions VALUES (2209, 47, '21/05/2005', 3);
INSERT INTO valoracions VALUES (2209, 99, '29/01/2003', 3);
INSERT INTO valoracions VALUES (2209, 66, '08/03/2004', 9);
INSERT INTO valoracions VALUES (2209, 25, '07/01/2009', 8);
INSERT INTO valoracions VALUES (2210, 29, '26/04/2006', 4);
INSERT INTO valoracions VALUES (2210, 85, '23/08/2004', 9);
INSERT INTO valoracions VALUES (2210, 95, '01/12/2005', 5);
INSERT INTO valoracions VALUES (2210, 68, '22/11/2003', 4);
INSERT INTO valoracions VALUES (2211, 110, '26/04/2007', 9);
INSERT INTO valoracions VALUES (2211, 76, '17/11/2004', 10);
INSERT INTO valoracions VALUES (2211, 36, '23/08/2007', 9);
INSERT INTO valoracions VALUES (2211, 37, '24/11/2007', 5);
INSERT INTO valoracions VALUES (2211, 67, '27/12/2003', 6);
INSERT INTO valoracions VALUES (2212, 5, '18/07/2009', 5);
INSERT INTO valoracions VALUES (2212, 30, '19/06/2008', 9);
INSERT INTO valoracions VALUES (2212, 69, '17/06/2010', 5);
INSERT INTO valoracions VALUES (2212, 112, '14/01/2008', 3);
INSERT INTO valoracions VALUES (2212, 109, '01/03/2007', 4);
INSERT INTO valoracions VALUES (2212, 68, '18/09/2002', 8);
INSERT INTO valoracions VALUES (2212, 106, '07/04/2001', 7);
INSERT INTO valoracions VALUES (2213, 2, '17/01/2009', 9);
INSERT INTO valoracions VALUES (2213, 84, '16/08/2005', 5);
INSERT INTO valoracions VALUES (2213, 55, '16/04/2009', 8);
INSERT INTO valoracions VALUES (2214, 17, '03/04/2010', 9);
INSERT INTO valoracions VALUES (2214, 32, '17/12/2002', 4);
INSERT INTO valoracions VALUES (2214, 97, '06/09/2009', 5);
INSERT INTO valoracions VALUES (2215, 90, '02/07/2005', 8);
INSERT INTO valoracions VALUES (2215, 55, '10/06/2004', 6);
INSERT INTO valoracions VALUES (2215, 44, '06/07/2004', 9);
INSERT INTO valoracions VALUES (2215, 52, '09/03/2008', 4);
INSERT INTO valoracions VALUES (2216, 96, '20/03/2010', 6);
INSERT INTO valoracions VALUES (2216, 26, '05/11/2002', 9);
INSERT INTO valoracions VALUES (2216, 102, '20/10/2007', 3);
INSERT INTO valoracions VALUES (2216, 99, '08/06/2010', 8);
INSERT INTO valoracions VALUES (2216, 70, '08/05/2005', 4);
INSERT INTO valoracions VALUES (2217, 28, '22/07/2001', 8);
INSERT INTO valoracions VALUES (2218, 44, '25/05/2001', 7);
INSERT INTO valoracions VALUES (2218, 16, '12/01/2008', 4);
INSERT INTO valoracions VALUES (2218, 35, '20/01/2002', 9);
INSERT INTO valoracions VALUES (2218, 96, '11/12/2007', 6);
INSERT INTO valoracions VALUES (2219, 20, '11/12/2001', 5);
INSERT INTO valoracions VALUES (2219, 56, '19/04/2002', 7);
INSERT INTO valoracions VALUES (2219, 59, '14/08/2006', 5);
INSERT INTO valoracions VALUES (2219, 27, '31/07/2010', 8);
INSERT INTO valoracions VALUES (2219, 67, '05/04/2009', 7);
INSERT INTO valoracions VALUES (2220, 41, '15/07/2007', 7);
INSERT INTO valoracions VALUES (2221, 37, '08/10/2008', 5);
INSERT INTO valoracions VALUES (2221, 98, '31/08/2002', 6);
INSERT INTO valoracions VALUES (2221, 43, '29/03/2003', 5);
INSERT INTO valoracions VALUES (2221, 87, '11/05/2002', 9);
INSERT INTO valoracions VALUES (2222, 58, '13/11/2002', 7);
INSERT INTO valoracions VALUES (2222, 77, '09/02/2002', 10);
INSERT INTO valoracions VALUES (2223, 5, '10/04/2007', 7);
INSERT INTO valoracions VALUES (2223, 29, '08/06/2008', 7);
INSERT INTO valoracions VALUES (2223, 88, '17/04/2008', 7);
INSERT INTO valoracions VALUES (2223, 103, '22/02/2005', 6);
INSERT INTO valoracions VALUES (2223, 109, '13/11/2003', 2);
INSERT INTO valoracions VALUES (2224, 20, '14/05/2003', 5);
INSERT INTO valoracions VALUES (2224, 58, '27/07/2004', 4);
INSERT INTO valoracions VALUES (2224, 23, '23/11/2001', 8);
INSERT INTO valoracions VALUES (2225, 94, '09/11/2004', 4);
INSERT INTO valoracions VALUES (2225, 109, '13/06/2010', 10);
INSERT INTO valoracions VALUES (2225, 4, '07/07/2010', 7);
INSERT INTO valoracions VALUES (2226, 36, '06/09/2008', 5);
INSERT INTO valoracions VALUES (2226, 82, '04/11/2001', 4);
INSERT INTO valoracions VALUES (2226, 24, '20/10/2003', 8);
INSERT INTO valoracions VALUES (2226, 44, '30/07/2004', 4);
INSERT INTO valoracions VALUES (2227, 20, '20/08/2009', 5);
INSERT INTO valoracions VALUES (2227, 90, '07/01/2006', 6);
INSERT INTO valoracions VALUES (2227, 98, '14/10/2005', 10);
INSERT INTO valoracions VALUES (2228, 62, '07/01/2007', 5);
INSERT INTO valoracions VALUES (2228, 24, '03/12/2006', 8);
INSERT INTO valoracions VALUES (2228, 53, '31/10/2003', 6);
INSERT INTO valoracions VALUES (2228, 103, '28/08/2004', 2);
INSERT INTO valoracions VALUES (2228, 32, '06/07/2008', 8);
INSERT INTO valoracions VALUES (2228, 6, '16/12/2002', 8);
INSERT INTO valoracions VALUES (2229, 68, '08/11/2001', 2);
INSERT INTO valoracions VALUES (2229, 90, '27/05/2008', 2);
INSERT INTO valoracions VALUES (2229, 72, '10/08/2010', 5);
INSERT INTO valoracions VALUES (2230, 19, '07/10/2004', 8);
INSERT INTO valoracions VALUES (2231, 17, '28/08/2003', 8);
INSERT INTO valoracions VALUES (2231, 67, '16/09/2002', 6);
INSERT INTO valoracions VALUES (2232, 102, '14/10/2003', 10);
INSERT INTO valoracions VALUES (2232, 76, '13/12/2001', 5);
INSERT INTO valoracions VALUES (2232, 98, '10/12/2002', 1);
INSERT INTO valoracions VALUES (2232, 39, '13/03/2006', 6);
INSERT INTO valoracions VALUES (2232, 94, '19/12/2005', 1);
INSERT INTO valoracions VALUES (2232, 31, '11/05/2004', 6);
INSERT INTO valoracions VALUES (2233, 14, '15/07/2001', 7);
INSERT INTO valoracions VALUES (2233, 67, '14/06/2008', 8);
INSERT INTO valoracions VALUES (2233, 52, '14/02/2008', 10);
INSERT INTO valoracions VALUES (2233, 31, '07/08/2008', 7);
INSERT INTO valoracions VALUES (2234, 49, '23/01/2009', 5);
INSERT INTO valoracions VALUES (2234, 3, '30/10/2003', 5);
INSERT INTO valoracions VALUES (2235, 115, '23/06/2005', 2);
INSERT INTO valoracions VALUES (2235, 110, '21/10/2006', 8);
INSERT INTO valoracions VALUES (2235, 28, '27/12/2004', 9);
INSERT INTO valoracions VALUES (2235, 42, '28/06/2008', 10);
INSERT INTO valoracions VALUES (2236, 2, '04/01/2002', 7);
INSERT INTO valoracions VALUES (2236, 5, '28/06/2001', 6);
INSERT INTO valoracions VALUES (2236, 17, '14/10/2010', 5);
INSERT INTO valoracions VALUES (2237, 47, '08/06/2004', 7);
INSERT INTO valoracions VALUES (2237, 112, '01/09/2009', 5);
INSERT INTO valoracions VALUES (2238, 26, '21/05/2010', 8);
INSERT INTO valoracions VALUES (2238, 31, '11/01/2007', 4);
INSERT INTO valoracions VALUES (2238, 45, '25/10/2004', 4);
INSERT INTO valoracions VALUES (2238, 58, '20/10/2003', 6);
INSERT INTO valoracions VALUES (2238, 38, '22/01/2003', 10);
INSERT INTO valoracions VALUES (2238, 40, '01/05/2003', 9);
INSERT INTO valoracions VALUES (2239, 46, '29/10/2002', 9);
INSERT INTO valoracions VALUES (2239, 73, '15/07/2007', 8);
INSERT INTO valoracions VALUES (2239, 2, '26/03/2008', 10);
INSERT INTO valoracions VALUES (2240, 29, '18/12/2007', 6);
INSERT INTO valoracions VALUES (2240, 12, '22/04/2006', 5);
INSERT INTO valoracions VALUES (2241, 45, '19/11/2007', 5);
INSERT INTO valoracions VALUES (2241, 113, '13/09/2006', 2);
INSERT INTO valoracions VALUES (2242, 61, '17/07/2001', 5);
INSERT INTO valoracions VALUES (2242, 25, '16/08/2004', 7);
INSERT INTO valoracions VALUES (2242, 31, '12/09/2009', 6);
INSERT INTO valoracions VALUES (2242, 33, '30/11/2005', 7);
INSERT INTO valoracions VALUES (2242, 67, '04/01/2004', 4);
INSERT INTO valoracions VALUES (2243, 99, '14/03/2009', 7);
INSERT INTO valoracions VALUES (2243, 64, '06/04/2004', 8);
INSERT INTO valoracions VALUES (2244, 94, '19/03/2006', 4);
INSERT INTO valoracions VALUES (2244, 17, '03/06/2008', 10);
INSERT INTO valoracions VALUES (2244, 79, '04/09/2010', 9);
INSERT INTO valoracions VALUES (2244, 49, '17/04/2001', 9);
INSERT INTO valoracions VALUES (2245, 42, '25/02/2003', 9);
INSERT INTO valoracions VALUES (2246, 18, '12/04/2003', 8);
INSERT INTO valoracions VALUES (2246, 55, '06/12/2003', 10);
INSERT INTO valoracions VALUES (2246, 36, '02/07/2003', 7);
INSERT INTO valoracions VALUES (2246, 97, '28/05/2002', 5);
INSERT INTO valoracions VALUES (2246, 34, '21/12/2005', 8);
INSERT INTO valoracions VALUES (2247, 7, '23/03/2003', 6);
INSERT INTO valoracions VALUES (2248, 8, '20/07/2009', 6);
INSERT INTO valoracions VALUES (2248, 45, '17/09/2002', 9);
INSERT INTO valoracions VALUES (2248, 97, '24/10/2008', 1);
INSERT INTO valoracions VALUES (2248, 53, '07/08/2009', 6);
INSERT INTO valoracions VALUES (2249, 29, '19/11/2003', 8);
INSERT INTO valoracions VALUES (2249, 111, '04/09/2001', 2);
INSERT INTO valoracions VALUES (2250, 81, '19/10/2009', 4);
INSERT INTO valoracions VALUES (2250, 88, '15/10/2003', 7);
INSERT INTO valoracions VALUES (2250, 110, '19/11/2005', 1);
INSERT INTO valoracions VALUES (2250, 31, '06/08/2008', 9);
INSERT INTO valoracions VALUES (2250, 60, '06/04/2010', 5);
INSERT INTO valoracions VALUES (2251, 116, '09/03/2009', 1);
INSERT INTO valoracions VALUES (2251, 13, '15/01/2010', 9);
INSERT INTO valoracions VALUES (2252, 115, '18/12/2001', 2);
INSERT INTO valoracions VALUES (2252, 114, '05/12/2002', 2);
INSERT INTO valoracions VALUES (2252, 103, '08/05/2008', 2);
INSERT INTO valoracions VALUES (2252, 13, '22/09/2002', 5);
INSERT INTO valoracions VALUES (2252, 76, '02/11/2002', 10);
INSERT INTO valoracions VALUES (2252, 79, '12/03/2007', 5);
INSERT INTO valoracions VALUES (2253, 16, '26/04/2002', 9);
INSERT INTO valoracions VALUES (2253, 97, '05/12/2006', 9);
INSERT INTO valoracions VALUES (2254, 57, '05/02/2009', 10);
INSERT INTO valoracions VALUES (2254, 1, '11/06/2006', 6);
INSERT INTO valoracions VALUES (2254, 65, '08/04/2003', 4);
INSERT INTO valoracions VALUES (2254, 87, '01/06/2010', 3);
INSERT INTO valoracions VALUES (2254, 69, '25/01/2008', 8);
INSERT INTO valoracions VALUES (2254, 60, '16/01/2004', 8);
INSERT INTO valoracions VALUES (2254, 116, '09/11/2008', 7);
INSERT INTO valoracions VALUES (2254, 112, '11/08/2001', 6);
INSERT INTO valoracions VALUES (2254, 26, '22/10/2005', 9);
INSERT INTO valoracions VALUES (2255, 36, '08/07/2002', 5);
INSERT INTO valoracions VALUES (2255, 31, '03/10/2008', 7);
INSERT INTO valoracions VALUES (2255, 110, '29/08/2003', 4);
INSERT INTO valoracions VALUES (2255, 43, '01/04/2004', 7);
INSERT INTO valoracions VALUES (2255, 62, '08/11/2006', 3);
INSERT INTO valoracions VALUES (2255, 65, '29/05/2005', 4);
INSERT INTO valoracions VALUES (2255, 25, '31/01/2009', 5);
INSERT INTO valoracions VALUES (2255, 88, '27/06/2006', 10);
INSERT INTO valoracions VALUES (2256, 99, '28/05/2006', 9);
INSERT INTO valoracions VALUES (2256, 61, '29/07/2010', 5);
INSERT INTO valoracions VALUES (2256, 13, '10/03/2007', 9);
INSERT INTO valoracions VALUES (2257, 96, '18/03/2007', 7);
INSERT INTO valoracions VALUES (2258, 104, '01/01/2004', 4);
INSERT INTO valoracions VALUES (2258, 4, '12/05/2009', 8);
INSERT INTO valoracions VALUES (2258, 53, '03/02/2009', 8);
INSERT INTO valoracions VALUES (2258, 15, '30/07/2009', 10);
INSERT INTO valoracions VALUES (2258, 37, '17/05/2005', 7);
INSERT INTO valoracions VALUES (2259, 91, '07/12/2004', 1);
INSERT INTO valoracions VALUES (2259, 107, '18/07/2003', 2);
INSERT INTO valoracions VALUES (2259, 83, '01/12/2004', 6);
INSERT INTO valoracions VALUES (2259, 19, '07/04/2008', 5);
INSERT INTO valoracions VALUES (2260, 22, '05/09/2001', 6);
INSERT INTO valoracions VALUES (2260, 1, '19/11/2001', 9);
INSERT INTO valoracions VALUES (2261, 61, '10/02/2008', 8);
INSERT INTO valoracions VALUES (2261, 116, '20/04/2009', 0);
INSERT INTO valoracions VALUES (2262, 32, '28/03/2009', 6);
INSERT INTO valoracions VALUES (2262, 110, '26/04/2007', 8);
INSERT INTO valoracions VALUES (2263, 12, '07/06/2004', 9);
INSERT INTO valoracions VALUES (2263, 35, '04/04/2003', 7);
INSERT INTO valoracions VALUES (2263, 6, '17/07/2006', 7);
INSERT INTO valoracions VALUES (2263, 26, '12/06/2009', 5);
INSERT INTO valoracions VALUES (2264, 85, '31/08/2001', 2);
INSERT INTO valoracions VALUES (2264, 47, '25/11/2004', 7);
INSERT INTO valoracions VALUES (2264, 90, '13/04/2005', 10);
INSERT INTO valoracions VALUES (2264, 33, '30/10/2002', 7);
INSERT INTO valoracions VALUES (2264, 47, '26/03/2009', 4);
INSERT INTO valoracions VALUES (2265, 101, '09/06/2009', 2);
INSERT INTO valoracions VALUES (2266, 75, '15/06/2004', 6);
INSERT INTO valoracions VALUES (2266, 49, '26/11/2008', 9);
INSERT INTO valoracions VALUES (2266, 12, '14/05/2003', 7);
INSERT INTO valoracions VALUES (2267, 14, '26/04/2001', 9);
INSERT INTO valoracions VALUES (2268, 67, '08/08/2005', 5);
INSERT INTO valoracions VALUES (2268, 29, '20/05/2008', 7);
INSERT INTO valoracions VALUES (2268, 19, '03/05/2002', 9);
INSERT INTO valoracions VALUES (2269, 55, '04/06/2001', 8);
INSERT INTO valoracions VALUES (2269, 23, '07/02/2010', 8);
INSERT INTO valoracions VALUES (2269, 102, '13/04/2008', 1);
INSERT INTO valoracions VALUES (2269, 23, '15/10/2007', 8);
INSERT INTO valoracions VALUES (2269, 47, '28/07/2003', 5);
INSERT INTO valoracions VALUES (2270, 109, '24/09/2003', 6);
INSERT INTO valoracions VALUES (2270, 43, '12/10/2003', 7);
INSERT INTO valoracions VALUES (2270, 111, '13/09/2004', 4);
INSERT INTO valoracions VALUES (2270, 35, '07/01/2009', 10);
INSERT INTO valoracions VALUES (2271, 88, '11/02/2004', 7);
INSERT INTO valoracions VALUES (2271, 47, '29/11/2007', 4);
INSERT INTO valoracions VALUES (2272, 101, '13/08/2003', 7);
INSERT INTO valoracions VALUES (2272, 25, '25/08/2005', 8);
INSERT INTO valoracions VALUES (2273, 40, '04/06/2007', 9);
INSERT INTO valoracions VALUES (2273, 115, '27/08/2006', 2);
INSERT INTO valoracions VALUES (2274, 98, '24/05/2009', 8);
INSERT INTO valoracions VALUES (2274, 64, '15/11/2005', 9);
INSERT INTO valoracions VALUES (2275, 107, '11/06/2003', 8);
INSERT INTO valoracions VALUES (2275, 79, '15/10/2010', 3);
INSERT INTO valoracions VALUES (2275, 3, '03/06/2008', 6);
INSERT INTO valoracions VALUES (2275, 1, '13/05/2005', 9);
INSERT INTO valoracions VALUES (2275, 61, '23/08/2001', 9);
INSERT INTO valoracions VALUES (2275, 107, '14/07/2007', 1);
INSERT INTO valoracions VALUES (2275, 83, '09/08/2010', 7);
INSERT INTO valoracions VALUES (2276, 27, '20/12/2001', 6);
INSERT INTO valoracions VALUES (2276, 36, '20/02/2006', 6);
INSERT INTO valoracions VALUES (2276, 49, '12/06/2004', 7);
INSERT INTO valoracions VALUES (2276, 68, '10/12/2009', 8);
INSERT INTO valoracions VALUES (2276, 14, '04/10/2003', 4);
INSERT INTO valoracions VALUES (2276, 68, '05/11/2002', 4);
INSERT INTO valoracions VALUES (2277, 64, '02/12/2003', 4);
INSERT INTO valoracions VALUES (2277, 6, '09/07/2003', 8);
INSERT INTO valoracions VALUES (2277, 28, '27/07/2005', 5);
INSERT INTO valoracions VALUES (2277, 28, '27/05/2004', 9);
INSERT INTO valoracions VALUES (2277, 72, '19/05/2009', 4);
INSERT INTO valoracions VALUES (2277, 26, '06/04/2006', 6);
INSERT INTO valoracions VALUES (2277, 83, '07/09/2007', 8);
INSERT INTO valoracions VALUES (2278, 9, '13/09/2004', 6);
INSERT INTO valoracions VALUES (2278, 13, '19/08/2010', 9);
INSERT INTO valoracions VALUES (2278, 2, '12/11/2006', 9);
INSERT INTO valoracions VALUES (2278, 89, '23/03/2002', 2);
INSERT INTO valoracions VALUES (2278, 116, '18/01/2002', 9);
INSERT INTO valoracions VALUES (2278, 102, '10/02/2009', 1);
INSERT INTO valoracions VALUES (2278, 30, '22/08/2010', 10);
INSERT INTO valoracions VALUES (2279, 85, '06/04/2005', 10);
INSERT INTO valoracions VALUES (2279, 88, '06/01/2010', 7);
INSERT INTO valoracions VALUES (2279, 48, '19/06/2004', 4);
INSERT INTO valoracions VALUES (2280, 44, '12/03/2002', 5);
INSERT INTO valoracions VALUES (2280, 88, '09/07/2003', 1);
INSERT INTO valoracions VALUES (2280, 70, '19/10/2007', 4);
INSERT INTO valoracions VALUES (2280, 92, '18/11/2009', 5);
INSERT INTO valoracions VALUES (2281, 116, '16/10/2007', 7);
INSERT INTO valoracions VALUES (2281, 86, '19/07/2004', 4);
INSERT INTO valoracions VALUES (2281, 66, '04/09/2007', 6);
INSERT INTO valoracions VALUES (2282, 30, '25/03/2003', 8);
INSERT INTO valoracions VALUES (2282, 61, '05/04/2006', 9);
INSERT INTO valoracions VALUES (2282, 27, '04/08/2009', 10);
INSERT INTO valoracions VALUES (2282, 18, '06/04/2005', 9);
INSERT INTO valoracions VALUES (2282, 55, '27/01/2007', 6);
INSERT INTO valoracions VALUES (2283, 13, '21/06/2003', 6);
INSERT INTO valoracions VALUES (2283, 69, '17/04/2001', 6);
INSERT INTO valoracions VALUES (2283, 40, '17/01/2010', 8);
INSERT INTO valoracions VALUES (2283, 29, '04/09/2002', 8);
INSERT INTO valoracions VALUES (2284, 84, '28/12/2007', 9);
INSERT INTO valoracions VALUES (2284, 114, '29/11/2008', 2);
INSERT INTO valoracions VALUES (2284, 14, '29/03/2010', 9);
INSERT INTO valoracions VALUES (2285, 35, '30/07/2004', 7);
INSERT INTO valoracions VALUES (2285, 21, '17/09/2003', 7);
INSERT INTO valoracions VALUES (2285, 34, '12/12/2009', 5);
INSERT INTO valoracions VALUES (2285, 70, '05/01/2004', 8);
INSERT INTO valoracions VALUES (2285, 72, '06/08/2004', 8);
INSERT INTO valoracions VALUES (2286, 44, '17/08/2005', 6);
INSERT INTO valoracions VALUES (2286, 58, '14/06/2010', 6);
INSERT INTO valoracions VALUES (2287, 64, '11/07/2010', 8);
INSERT INTO valoracions VALUES (2287, 54, '16/07/2010', 8);
INSERT INTO valoracions VALUES (2288, 95, '24/12/2003', 4);
INSERT INTO valoracions VALUES (2288, 87, '07/10/2003', 6);
INSERT INTO valoracions VALUES (2289, 12, '27/08/2004', 7);
INSERT INTO valoracions VALUES (2289, 47, '25/09/2007', 8);
INSERT INTO valoracions VALUES (2289, 3, '24/08/2003', 7);
INSERT INTO valoracions VALUES (2289, 70, '24/04/2004', 2);
INSERT INTO valoracions VALUES (2289, 101, '30/04/2006', 3);
INSERT INTO valoracions VALUES (2290, 57, '28/03/2010', 6);
INSERT INTO valoracions VALUES (2290, 106, '16/03/2005', 3);
INSERT INTO valoracions VALUES (2291, 71, '23/03/2008', 7);
INSERT INTO valoracions VALUES (2291, 114, '26/11/2003', 3);
INSERT INTO valoracions VALUES (2291, 8, '25/03/2005', 9);
INSERT INTO valoracions VALUES (2291, 109, '17/09/2008', 3);
INSERT INTO valoracions VALUES (2291, 29, '10/07/2001', 6);
INSERT INTO valoracions VALUES (2292, 11, '03/03/2008', 8);
INSERT INTO valoracions VALUES (2292, 108, '02/01/2007', 1);
INSERT INTO valoracions VALUES (2292, 23, '31/07/2002', 5);
INSERT INTO valoracions VALUES (2292, 24, '02/06/2001', 8);
INSERT INTO valoracions VALUES (2292, 113, '19/10/2008', 7);
INSERT INTO valoracions VALUES (2293, 80, '18/07/2003', 9);
INSERT INTO valoracions VALUES (2293, 116, '15/10/2010', 0);
INSERT INTO valoracions VALUES (2293, 88, '23/02/2005', 2);
INSERT INTO valoracions VALUES (2293, 64, '28/02/2003', 3);
INSERT INTO valoracions VALUES (2294, 33, '29/01/2008', 9);
INSERT INTO valoracions VALUES (2294, 115, '07/10/2008', 8);
INSERT INTO valoracions VALUES (2295, 34, '25/08/2001', 9);
INSERT INTO valoracions VALUES (2295, 72, '28/09/2004', 4);
INSERT INTO valoracions VALUES (2295, 32, '15/07/2007', 4);
INSERT INTO valoracions VALUES (2296, 100, '30/06/2006', 1);
INSERT INTO valoracions VALUES (2296, 92, '09/08/2003', 8);
INSERT INTO valoracions VALUES (2296, 95, '30/04/2002', 2);
INSERT INTO valoracions VALUES (2296, 26, '23/06/2001', 6);
INSERT INTO valoracions VALUES (2297, 4, '01/03/2004', 6);
INSERT INTO valoracions VALUES (2297, 68, '28/01/2007', 9);
INSERT INTO valoracions VALUES (2298, 63, '10/12/2001', 9);
INSERT INTO valoracions VALUES (2298, 78, '14/07/2006', 4);
INSERT INTO valoracions VALUES (2299, 34, '13/02/2002', 4);
INSERT INTO valoracions VALUES (2299, 27, '31/10/2003', 8);
INSERT INTO valoracions VALUES (2299, 42, '01/08/2007', 5);
INSERT INTO valoracions VALUES (2300, 85, '05/05/2008', 7);
INSERT INTO valoracions VALUES (2300, 38, '22/07/2009', 7);
INSERT INTO valoracions VALUES (2300, 21, '22/06/2005', 10);
INSERT INTO valoracions VALUES (2300, 51, '14/09/2006', 4);
INSERT INTO valoracions VALUES (2301, 105, '05/05/2009', 9);
INSERT INTO valoracions VALUES (2301, 82, '16/02/2008', 4);
INSERT INTO valoracions VALUES (2301, 81, '03/01/2008', 3);
INSERT INTO valoracions VALUES (2301, 81, '25/02/2003', 7);
INSERT INTO valoracions VALUES (2301, 34, '15/11/2007', 4);
INSERT INTO valoracions VALUES (2302, 116, '07/06/2005', 4);
INSERT INTO valoracions VALUES (2302, 75, '19/11/2007', 6);
INSERT INTO valoracions VALUES (2303, 110, '22/11/2005', 3);
INSERT INTO valoracions VALUES (2303, 60, '19/11/2005', 4);
INSERT INTO valoracions VALUES (2303, 29, '25/06/2009', 8);
INSERT INTO valoracions VALUES (2304, 82, '27/04/2009', 6);
INSERT INTO valoracions VALUES (2304, 83, '02/05/2007', 4);
INSERT INTO valoracions VALUES (2304, 19, '18/10/2009', 8);
INSERT INTO valoracions VALUES (2304, 86, '05/05/2004', 4);
INSERT INTO valoracions VALUES (2304, 111, '05/02/2009', 1);
INSERT INTO valoracions VALUES (2304, 113, '25/01/2004', 8);
INSERT INTO valoracions VALUES (2304, 43, '13/09/2010', 4);
INSERT INTO valoracions VALUES (2304, 13, '19/01/2004', 9);
INSERT INTO valoracions VALUES (2304, 20, '10/02/2005', 7);
INSERT INTO valoracions VALUES (2304, 68, '06/04/2006', 8);
INSERT INTO valoracions VALUES (2305, 109, '24/08/2009', 4);
INSERT INTO valoracions VALUES (2305, 98, '18/09/2005', 10);
INSERT INTO valoracions VALUES (2305, 65, '01/12/2006', 6);
INSERT INTO valoracions VALUES (2306, 65, '27/02/2009', 8);
INSERT INTO valoracions VALUES (2306, 71, '08/10/2009', 9);
INSERT INTO valoracions VALUES (2306, 64, '02/02/2003', 8);
INSERT INTO valoracions VALUES (2306, 54, '05/02/2007', 9);
INSERT INTO valoracions VALUES (2307, 34, '01/05/2006', 7);
INSERT INTO valoracions VALUES (2307, 88, '25/10/2008', 7);
INSERT INTO valoracions VALUES (2307, 79, '19/03/2006', 8);
INSERT INTO valoracions VALUES (2307, 9, '09/10/2005', 6);
INSERT INTO valoracions VALUES (2307, 19, '12/01/2009', 9);
INSERT INTO valoracions VALUES (2307, 37, '05/08/2001', 9);
INSERT INTO valoracions VALUES (2308, 66, '19/02/2004', 7);
INSERT INTO valoracions VALUES (2308, 107, '16/03/2002', 5);
INSERT INTO valoracions VALUES (2308, 88, '06/11/2003', 4);
INSERT INTO valoracions VALUES (2308, 70, '17/01/2009', 6);
INSERT INTO valoracions VALUES (2308, 82, '16/10/2005', 8);
INSERT INTO valoracions VALUES (2310, 28, '05/09/2001', 7);
INSERT INTO valoracions VALUES (2310, 90, '29/07/2005', 3);
INSERT INTO valoracions VALUES (2310, 8, '20/08/2008', 7);
INSERT INTO valoracions VALUES (2311, 75, '24/05/2007', 3);
INSERT INTO valoracions VALUES (2311, 74, '03/03/2003', 7);
INSERT INTO valoracions VALUES (2311, 24, '01/01/2004', 9);
INSERT INTO valoracions VALUES (2311, 46, '04/07/2008', 3);
INSERT INTO valoracions VALUES (2311, 30, '03/12/2003', 9);
INSERT INTO valoracions VALUES (2311, 116, '25/09/2007', 3);
INSERT INTO valoracions VALUES (2311, 42, '10/04/2003', 5);
INSERT INTO valoracions VALUES (2312, 83, '10/01/2004', 5);
INSERT INTO valoracions VALUES (2312, 65, '04/12/2004', 8);
INSERT INTO valoracions VALUES (2312, 86, '11/08/2010', 7);
INSERT INTO valoracions VALUES (2313, 80, '03/05/2010', 6);
INSERT INTO valoracions VALUES (2313, 91, '03/07/2003', 10);
INSERT INTO valoracions VALUES (2313, 87, '03/09/2007', 7);
INSERT INTO valoracions VALUES (2313, 53, '09/06/2004', 9);
INSERT INTO valoracions VALUES (2313, 106, '29/10/2010', 4);
INSERT INTO valoracions VALUES (2314, 40, '16/10/2008', 8);
INSERT INTO valoracions VALUES (2314, 11, '04/03/2010', 6);
INSERT INTO valoracions VALUES (2314, 24, '27/02/2005', 5);
INSERT INTO valoracions VALUES (2314, 27, '05/04/2004', 6);
INSERT INTO valoracions VALUES (2314, 43, '21/09/2005', 7);
INSERT INTO valoracions VALUES (2314, 4, '21/06/2007', 8);
INSERT INTO valoracions VALUES (2315, 76, '17/07/2002', 7);
INSERT INTO valoracions VALUES (2315, 81, '04/07/2008', 4);
INSERT INTO valoracions VALUES (2315, 113, '11/07/2010', 7);
INSERT INTO valoracions VALUES (2315, 83, '01/03/2007', 8);
INSERT INTO valoracions VALUES (2316, 100, '15/10/2002', 7);
INSERT INTO valoracions VALUES (2316, 107, '12/01/2004', 5);
INSERT INTO valoracions VALUES (2316, 102, '10/11/2005', 4);
INSERT INTO valoracions VALUES (2316, 50, '27/07/2005', 3);
INSERT INTO valoracions VALUES (2317, 90, '13/11/2009', 6);
INSERT INTO valoracions VALUES (2317, 49, '01/02/2004', 5);
INSERT INTO valoracions VALUES (2317, 95, '16/08/2009', 5);
INSERT INTO valoracions VALUES (2317, 76, '28/02/2004', 2);
INSERT INTO valoracions VALUES (2317, 81, '26/10/2002', 8);
INSERT INTO valoracions VALUES (2317, 94, '15/05/2004', 2);
INSERT INTO valoracions VALUES (2318, 51, '19/01/2006', 4);
INSERT INTO valoracions VALUES (2318, 2, '25/07/2006', 8);
INSERT INTO valoracions VALUES (2318, 26, '05/03/2006', 9);
INSERT INTO valoracions VALUES (2318, 69, '22/12/2001', 9);
INSERT INTO valoracions VALUES (2318, 102, '05/03/2006', 6);
INSERT INTO valoracions VALUES (2318, 11, '11/09/2003', 6);
INSERT INTO valoracions VALUES (2318, 114, '30/11/2008', 2);
INSERT INTO valoracions VALUES (2319, 36, '29/07/2009', 5);
INSERT INTO valoracions VALUES (2319, 47, '11/07/2005', 8);
INSERT INTO valoracions VALUES (2320, 83, '16/08/2004', 6);
INSERT INTO valoracions VALUES (2320, 3, '11/12/2005', 6);
INSERT INTO valoracions VALUES (2320, 100, '08/06/2005', 4);
INSERT INTO valoracions VALUES (2320, 45, '07/09/2007', 10);
INSERT INTO valoracions VALUES (2321, 36, '05/06/2006', 7);
INSERT INTO valoracions VALUES (2321, 15, '16/01/2003', 9);
INSERT INTO valoracions VALUES (2321, 35, '17/03/2009', 5);
INSERT INTO valoracions VALUES (2321, 54, '10/10/2005', 4);
INSERT INTO valoracions VALUES (2321, 60, '19/11/2008', 5);
INSERT INTO valoracions VALUES (2321, 94, '04/01/2007', 5);
INSERT INTO valoracions VALUES (2322, 114, '12/03/2008', 10);
INSERT INTO valoracions VALUES (2322, 108, '27/10/2008', 6);
INSERT INTO valoracions VALUES (2322, 4, '23/02/2007', 6);
INSERT INTO valoracions VALUES (2322, 94, '22/02/2008', 1);
INSERT INTO valoracions VALUES (2322, 16, '21/11/2005', 7);
INSERT INTO valoracions VALUES (2323, 99, '16/02/2006', 6);
INSERT INTO valoracions VALUES (2323, 57, '19/04/2006', 6);
INSERT INTO valoracions VALUES (2323, 52, '28/03/2005', 5);
INSERT INTO valoracions VALUES (2323, 98, '08/05/2003', 7);
INSERT INTO valoracions VALUES (2323, 73, '06/08/2009', 6);
INSERT INTO valoracions VALUES (2324, 52, '28/04/2002', 5);
INSERT INTO valoracions VALUES (2324, 96, '02/08/2008', 5);
INSERT INTO valoracions VALUES (2324, 13, '19/10/2006', 6);
INSERT INTO valoracions VALUES (2324, 90, '17/05/2008', 7);
INSERT INTO valoracions VALUES (2324, 56, '03/08/2006', 7);
INSERT INTO valoracions VALUES (2325, 37, '29/11/2007', 7);
INSERT INTO valoracions VALUES (2326, 55, '08/12/2002', 9);
INSERT INTO valoracions VALUES (2326, 103, '10/03/2008', 4);
INSERT INTO valoracions VALUES (2326, 36, '05/07/2010', 9);
INSERT INTO valoracions VALUES (2326, 77, '03/03/2004', 4);
INSERT INTO valoracions VALUES (2326, 114, '10/09/2009', 8);
INSERT INTO valoracions VALUES (2326, 64, '01/10/2009', 3);
INSERT INTO valoracions VALUES (2326, 52, '02/04/2005', 9);
INSERT INTO valoracions VALUES (2327, 113, '07/01/2008', 2);
INSERT INTO valoracions VALUES (2327, 21, '16/01/2010', 6);
INSERT INTO valoracions VALUES (2327, 113, '27/12/2004', 6);
INSERT INTO valoracions VALUES (2327, 37, '22/10/2003', 7);
INSERT INTO valoracions VALUES (2327, 109, '09/06/2009', 1);
INSERT INTO valoracions VALUES (2328, 59, '25/10/2006', 8);
INSERT INTO valoracions VALUES (2328, 64, '17/10/2003', 8);
INSERT INTO valoracions VALUES (2328, 91, '05/05/2005', 6);
INSERT INTO valoracions VALUES (2329, 69, '14/05/2010', 2);
INSERT INTO valoracions VALUES (2329, 47, '15/06/2009', 5);
INSERT INTO valoracions VALUES (2329, 90, '03/12/2008', 6);
INSERT INTO valoracions VALUES (2330, 26, '27/03/2002', 6);
INSERT INTO valoracions VALUES (2330, 10, '24/03/2009', 6);
INSERT INTO valoracions VALUES (2330, 84, '13/03/2008', 3);
INSERT INTO valoracions VALUES (2330, 28, '21/04/2001', 6);
INSERT INTO valoracions VALUES (2330, 9, '25/10/2005', 6);
INSERT INTO valoracions VALUES (2330, 106, '21/12/2002', 10);
INSERT INTO valoracions VALUES (2331, 112, '13/03/2002', 1);
INSERT INTO valoracions VALUES (2331, 52, '11/10/2001', 9);
INSERT INTO valoracions VALUES (2331, 24, '31/08/2004', 7);
INSERT INTO valoracions VALUES (2332, 72, '26/04/2010', 5);
INSERT INTO valoracions VALUES (2332, 113, '17/05/2001', 9);
INSERT INTO valoracions VALUES (2332, 90, '11/06/2002', 6);
INSERT INTO valoracions VALUES (2332, 75, '21/05/2004', 3);
INSERT INTO valoracions VALUES (2332, 59, '17/09/2010', 7);
INSERT INTO valoracions VALUES (2332, 104, '26/05/2001', 2);
INSERT INTO valoracions VALUES (2333, 15, '08/10/2004', 10);
INSERT INTO valoracions VALUES (2333, 30, '26/05/2003', 7);
INSERT INTO valoracions VALUES (2333, 80, '17/12/2001', 6);
INSERT INTO valoracions VALUES (2333, 70, '01/02/2006', 3);
INSERT INTO valoracions VALUES (2333, 19, '16/12/2007', 5);
INSERT INTO valoracions VALUES (2334, 75, '24/07/2001', 3);
INSERT INTO valoracions VALUES (2334, 90, '05/07/2004', 10);
INSERT INTO valoracions VALUES (2334, 78, '30/11/2002', 4);
INSERT INTO valoracions VALUES (2334, 47, '09/03/2008', 6);
INSERT INTO valoracions VALUES (2334, 51, '06/06/2001', 6);
INSERT INTO valoracions VALUES (2334, 90, '11/03/2009', 9);
INSERT INTO valoracions VALUES (2335, 23, '16/10/2006', 7);
INSERT INTO valoracions VALUES (2335, 23, '30/03/2003', 10);
INSERT INTO valoracions VALUES (2335, 7, '27/01/2008', 6);
INSERT INTO valoracions VALUES (2336, 34, '19/03/2009', 6);
INSERT INTO valoracions VALUES (2336, 108, '29/08/2006', 4);
INSERT INTO valoracions VALUES (2336, 61, '15/06/2004', 9);
INSERT INTO valoracions VALUES (2336, 70, '26/06/2001', 7);
INSERT INTO valoracions VALUES (2336, 18, '12/05/2005', 8);
INSERT INTO valoracions VALUES (2336, 104, '13/02/2007', 5);
INSERT INTO valoracions VALUES (2336, 70, '28/03/2009', 8);
INSERT INTO valoracions VALUES (2336, 20, '09/10/2003', 10);
INSERT INTO valoracions VALUES (2336, 10, '27/12/2004', 8);
INSERT INTO valoracions VALUES (2337, 77, '28/05/2004', 4);
INSERT INTO valoracions VALUES (2337, 102, '16/06/2004', 6);
INSERT INTO valoracions VALUES (2337, 27, '31/08/2002', 8);
INSERT INTO valoracions VALUES (2337, 21, '18/02/2002', 5);
INSERT INTO valoracions VALUES (2337, 16, '12/03/2002', 8);
INSERT INTO valoracions VALUES (2337, 110, '23/05/2005', 10);
INSERT INTO valoracions VALUES (2338, 50, '20/02/2010', 9);
INSERT INTO valoracions VALUES (2339, 107, '01/02/2005', 5);
INSERT INTO valoracions VALUES (2339, 19, '29/03/2005', 9);
INSERT INTO valoracions VALUES (2339, 71, '16/10/2005', 6);
INSERT INTO valoracions VALUES (2339, 29, '24/04/2001', 7);
INSERT INTO valoracions VALUES (2339, 45, '23/06/2006', 9);
INSERT INTO valoracions VALUES (2339, 102, '12/12/2007', 6);
INSERT INTO valoracions VALUES (2339, 69, '19/07/2009', 9);
INSERT INTO valoracions VALUES (2340, 66, '07/08/2001', 7);
INSERT INTO valoracions VALUES (2340, 9, '22/05/2009', 5);
INSERT INTO valoracions VALUES (2340, 9, '26/02/2003', 10);
INSERT INTO valoracions VALUES (2341, 78, '29/12/2006', 3);
INSERT INTO valoracions VALUES (2341, 109, '30/10/2010', 5);
INSERT INTO valoracions VALUES (2341, 113, '11/01/2005', 0);
INSERT INTO valoracions VALUES (2341, 98, '01/10/2004', 4);
INSERT INTO valoracions VALUES (2341, 54, '22/03/2010', 5);
INSERT INTO valoracions VALUES (2342, 73, '19/01/2010', 6);
INSERT INTO valoracions VALUES (2342, 64, '25/09/2004', 8);
INSERT INTO valoracions VALUES (2342, 111, '15/04/2001', 8);
INSERT INTO valoracions VALUES (2342, 32, '17/08/2002', 7);
INSERT INTO valoracions VALUES (2342, 38, '29/12/2005', 5);
INSERT INTO valoracions VALUES (2342, 72, '16/01/2003', 6);
INSERT INTO valoracions VALUES (2342, 34, '10/12/2008', 8);
INSERT INTO valoracions VALUES (2342, 107, '19/12/2005', 1);
INSERT INTO valoracions VALUES (2342, 110, '12/08/2006', 7);
INSERT INTO valoracions VALUES (2342, 82, '25/06/2003', 7);
INSERT INTO valoracions VALUES (2343, 42, '17/09/2001', 10);
INSERT INTO valoracions VALUES (2343, 12, '11/11/2009', 9);
INSERT INTO valoracions VALUES (2343, 1, '29/04/2006', 10);
INSERT INTO valoracions VALUES (2344, 52, '02/09/2010', 8);
INSERT INTO valoracions VALUES (2344, 67, '15/04/2006', 7);
INSERT INTO valoracions VALUES (2344, 42, '25/11/2006', 5);
INSERT INTO valoracions VALUES (2344, 29, '19/02/2009', 6);
INSERT INTO valoracions VALUES (2344, 55, '05/07/2006', 8);
INSERT INTO valoracions VALUES (2344, 54, '25/10/2002', 7);
INSERT INTO valoracions VALUES (2345, 93, '30/06/2001', 4);
INSERT INTO valoracions VALUES (2345, 58, '09/02/2010', 4);
INSERT INTO valoracions VALUES (2345, 88, '30/07/2004', 7);
INSERT INTO valoracions VALUES (2346, 56, '09/10/2002', 9);
INSERT INTO valoracions VALUES (2346, 22, '05/06/2008', 5);
INSERT INTO valoracions VALUES (2347, 23, '11/10/2005', 9);
INSERT INTO valoracions VALUES (2347, 60, '20/10/2002', 8);
INSERT INTO valoracions VALUES (2347, 109, '12/01/2008', 2);
INSERT INTO valoracions VALUES (2347, 45, '19/09/2005', 5);
INSERT INTO valoracions VALUES (2348, 92, '28/06/2001', 5);
INSERT INTO valoracions VALUES (2348, 22, '02/08/2010', 6);
INSERT INTO valoracions VALUES (2348, 16, '19/09/2010', 5);
INSERT INTO valoracions VALUES (2348, 74, '01/08/2006', 7);
INSERT INTO valoracions VALUES (2349, 58, '26/09/2009', 6);
INSERT INTO valoracions VALUES (2349, 1, '19/11/2006', 10);
INSERT INTO valoracions VALUES (2349, 95, '20/12/2006', 9);
INSERT INTO valoracions VALUES (2350, 73, '01/09/2005', 3);
INSERT INTO valoracions VALUES (2350, 57, '28/01/2005', 5);
INSERT INTO valoracions VALUES (2350, 95, '17/07/2010', 8);
INSERT INTO valoracions VALUES (2351, 43, '22/04/2009', 9);
INSERT INTO valoracions VALUES (2351, 2, '09/01/2003', 9);
INSERT INTO valoracions VALUES (2351, 71, '13/05/2009', 8);
INSERT INTO valoracions VALUES (2351, 48, '29/09/2008', 10);
INSERT INTO valoracions VALUES (2352, 73, '06/07/2004', 4);
INSERT INTO valoracions VALUES (2352, 93, '06/08/2007', 6);
INSERT INTO valoracions VALUES (2352, 49, '02/10/2002', 6);
INSERT INTO valoracions VALUES (2352, 104, '28/04/2009', 2);
INSERT INTO valoracions VALUES (2353, 81, '22/06/2007', 9);
INSERT INTO valoracions VALUES (2353, 53, '01/12/2006', 9);
INSERT INTO valoracions VALUES (2353, 39, '27/08/2008', 5);
INSERT INTO valoracions VALUES (2354, 9, '10/04/2007', 8);
INSERT INTO valoracions VALUES (2354, 65, '24/09/2007', 2);
INSERT INTO valoracions VALUES (2354, 111, '10/06/2002', 10);
INSERT INTO valoracions VALUES (2354, 63, '30/07/2008', 5);
INSERT INTO valoracions VALUES (2354, 52, '24/06/2006', 8);
INSERT INTO valoracions VALUES (2355, 71, '09/01/2002', 5);
INSERT INTO valoracions VALUES (2355, 87, '10/05/2004', 9);
INSERT INTO valoracions VALUES (2355, 105, '31/01/2010', 6);
INSERT INTO valoracions VALUES (2355, 3, '08/10/2004', 8);
INSERT INTO valoracions VALUES (2355, 108, '09/09/2008', 5);
INSERT INTO valoracions VALUES (2356, 47, '25/08/2005', 9);
INSERT INTO valoracions VALUES (2356, 8, '05/11/2006', 6);
INSERT INTO valoracions VALUES (2356, 14, '20/09/2006', 9);
INSERT INTO valoracions VALUES (2356, 46, '29/03/2009', 7);
INSERT INTO valoracions VALUES (2356, 1, '23/07/2010', 7);
INSERT INTO valoracions VALUES (2356, 23, '14/01/2009', 8);
INSERT INTO valoracions VALUES (2356, 114, '10/12/2006', 4);
INSERT INTO valoracions VALUES (2356, 105, '13/11/2007', 5);
INSERT INTO valoracions VALUES (2356, 9, '25/01/2005', 8);
INSERT INTO valoracions VALUES (2356, 23, '26/10/2007', 9);
INSERT INTO valoracions VALUES (2357, 105, '26/04/2008', 2);
INSERT INTO valoracions VALUES (2357, 70, '12/08/2009', 4);
INSERT INTO valoracions VALUES (2357, 12, '24/10/2004', 5);
INSERT INTO valoracions VALUES (2357, 7, '18/05/2001', 5);
INSERT INTO valoracions VALUES (2357, 49, '08/12/2008', 6);
INSERT INTO valoracions VALUES (2358, 35, '12/11/2001', 7);
INSERT INTO valoracions VALUES (2358, 35, '21/11/2009', 4);
INSERT INTO valoracions VALUES (2358, 42, '18/06/2008', 9);
INSERT INTO valoracions VALUES (2358, 32, '03/06/2003', 7);
INSERT INTO valoracions VALUES (2359, 33, '23/11/2003', 10);
INSERT INTO valoracions VALUES (2359, 101, '10/08/2003', 3);
INSERT INTO valoracions VALUES (2359, 38, '24/05/2006', 6);
INSERT INTO valoracions VALUES (2359, 55, '24/06/2008', 6);
INSERT INTO valoracions VALUES (2360, 115, '20/01/2009', 9);
INSERT INTO valoracions VALUES (2360, 77, '27/07/2005', 4);
INSERT INTO valoracions VALUES (2360, 28, '02/09/2001', 9);
INSERT INTO valoracions VALUES (2360, 68, '23/12/2004', 8);
INSERT INTO valoracions VALUES (2360, 48, '03/02/2006', 5);
INSERT INTO valoracions VALUES (2360, 116, '18/12/2006', 4);
INSERT INTO valoracions VALUES (2361, 60, '24/12/2003', 3);
INSERT INTO valoracions VALUES (2361, 85, '20/09/2009', 4);
INSERT INTO valoracions VALUES (2361, 16, '13/09/2005', 7);
INSERT INTO valoracions VALUES (2361, 57, '19/06/2008', 9);
INSERT INTO valoracions VALUES (2362, 1, '13/05/2001', 7);
INSERT INTO valoracions VALUES (2363, 88, '02/09/2001', 8);
INSERT INTO valoracions VALUES (2363, 13, '26/02/2009', 9);
INSERT INTO valoracions VALUES (2364, 1, '23/04/2006', 6);
INSERT INTO valoracions VALUES (2364, 42, '30/07/2006', 6);
INSERT INTO valoracions VALUES (2364, 67, '20/08/2010', 5);
INSERT INTO valoracions VALUES (2364, 74, '24/07/2010', 4);
INSERT INTO valoracions VALUES (2364, 90, '26/09/2008', 4);
INSERT INTO valoracions VALUES (2365, 93, '28/06/2006', 8);
INSERT INTO valoracions VALUES (2365, 112, '15/03/2008', 10);
INSERT INTO valoracions VALUES (2366, 23, '23/06/2004', 8);
INSERT INTO valoracions VALUES (2366, 100, '11/01/2002', 4);
INSERT INTO valoracions VALUES (2366, 110, '26/12/2004', 9);
INSERT INTO valoracions VALUES (2366, 49, '27/11/2007', 10);
INSERT INTO valoracions VALUES (2367, 28, '17/01/2007', 10);
INSERT INTO valoracions VALUES (2367, 34, '13/10/2010', 7);
INSERT INTO valoracions VALUES (2367, 97, '08/02/2005', 6);
INSERT INTO valoracions VALUES (2367, 100, '15/04/2005', 2);
INSERT INTO valoracions VALUES (2367, 64, '01/11/2006', 8);
INSERT INTO valoracions VALUES (2367, 111, '02/11/2004', 2);
INSERT INTO valoracions VALUES (2367, 57, '02/12/2002', 5);
INSERT INTO valoracions VALUES (2368, 79, '07/02/2008', 7);
INSERT INTO valoracions VALUES (2368, 12, '30/03/2002', 9);
INSERT INTO valoracions VALUES (2368, 23, '23/11/2003', 7);
INSERT INTO valoracions VALUES (2368, 15, '18/03/2009', 8);
INSERT INTO valoracions VALUES (2369, 99, '20/07/2001', 4);
INSERT INTO valoracions VALUES (2369, 105, '16/11/2002', 3);
INSERT INTO valoracions VALUES (2369, 54, '09/03/2003', 9);
INSERT INTO valoracions VALUES (2369, 12, '24/08/2004', 6);
INSERT INTO valoracions VALUES (2370, 15, '28/08/2010', 8);
INSERT INTO valoracions VALUES (2370, 12, '30/01/2003', 8);
INSERT INTO valoracions VALUES (2370, 3, '13/07/2010', 7);
INSERT INTO valoracions VALUES (2371, 36, '09/06/2001', 8);
INSERT INTO valoracions VALUES (2371, 8, '09/01/2009', 10);
INSERT INTO valoracions VALUES (2371, 103, '08/05/2004', 9);
INSERT INTO valoracions VALUES (2371, 50, '01/12/2003', 3);
INSERT INTO valoracions VALUES (2371, 41, '02/05/2004', 7);
INSERT INTO valoracions VALUES (2371, 85, '02/04/2008', 1);
INSERT INTO valoracions VALUES (2372, 100, '27/09/2009', 4);
INSERT INTO valoracions VALUES (2372, 23, '08/06/2001', 7);
INSERT INTO valoracions VALUES (2372, 84, '02/06/2003', 7);
INSERT INTO valoracions VALUES (2372, 114, '27/02/2004', 5);
INSERT INTO valoracions VALUES (2373, 96, '13/01/2009', 5);
INSERT INTO valoracions VALUES (2373, 73, '16/10/2003', 7);
INSERT INTO valoracions VALUES (2373, 2, '23/10/2010', 8);
INSERT INTO valoracions VALUES (2373, 8, '12/02/2002', 6);
INSERT INTO valoracions VALUES (2374, 29, '05/03/2005', 9);
INSERT INTO valoracions VALUES (2374, 19, '21/11/2004', 6);
INSERT INTO valoracions VALUES (2374, 88, '28/05/2010', 4);
INSERT INTO valoracions VALUES (2374, 50, '23/01/2005', 5);
INSERT INTO valoracions VALUES (2374, 34, '01/11/2003', 7);
INSERT INTO valoracions VALUES (2376, 69, '30/08/2008', 3);
INSERT INTO valoracions VALUES (2376, 79, '06/02/2003', 8);
INSERT INTO valoracions VALUES (2376, 26, '27/02/2007', 6);
INSERT INTO valoracions VALUES (2376, 60, '24/03/2003', 5);
INSERT INTO valoracions VALUES (2376, 27, '06/07/2006', 6);
INSERT INTO valoracions VALUES (2377, 78, '28/12/2002', 9);
INSERT INTO valoracions VALUES (2377, 26, '09/02/2007', 8);
INSERT INTO valoracions VALUES (2378, 91, '13/02/2010', 10);
INSERT INTO valoracions VALUES (2378, 57, '15/06/2009', 3);
INSERT INTO valoracions VALUES (2378, 37, '06/01/2004', 3);
INSERT INTO valoracions VALUES (2378, 92, '29/12/2006', 9);
INSERT INTO valoracions VALUES (2378, 52, '19/07/2010', 4);
INSERT INTO valoracions VALUES (2378, 113, '23/04/2008', 1);
INSERT INTO valoracions VALUES (2379, 98, '05/08/2009', 5);
INSERT INTO valoracions VALUES (2379, 92, '27/02/2004', 3);
INSERT INTO valoracions VALUES (2379, 103, '09/05/2010', 9);
INSERT INTO valoracions VALUES (2379, 99, '22/10/2010', 2);
INSERT INTO valoracions VALUES (2380, 110, '01/08/2004', 9);
INSERT INTO valoracions VALUES (2380, 58, '02/05/2005', 9);
INSERT INTO valoracions VALUES (2380, 24, '16/01/2002', 6);
INSERT INTO valoracions VALUES (2380, 47, '26/10/2007', 7);
INSERT INTO valoracions VALUES (2381, 92, '23/05/2004', 1);
INSERT INTO valoracions VALUES (2381, 74, '16/07/2006', 4);
INSERT INTO valoracions VALUES (2381, 55, '18/03/2010', 3);
INSERT INTO valoracions VALUES (2382, 7, '18/02/2009', 10);
INSERT INTO valoracions VALUES (2382, 1, '07/08/2010', 6);
INSERT INTO valoracions VALUES (2382, 87, '25/06/2006', 3);
INSERT INTO valoracions VALUES (2382, 99, '07/02/2004', 7);
INSERT INTO valoracions VALUES (2382, 103, '28/09/2005', 9);
INSERT INTO valoracions VALUES (2383, 94, '03/05/2010', 6);
INSERT INTO valoracions VALUES (2383, 18, '26/08/2008', 6);
INSERT INTO valoracions VALUES (2383, 8, '17/03/2005', 10);
INSERT INTO valoracions VALUES (2383, 63, '11/02/2003', 9);
INSERT INTO valoracions VALUES (2383, 50, '14/12/2005', 4);
INSERT INTO valoracions VALUES (2383, 108, '30/11/2006', 6);
INSERT INTO valoracions VALUES (2384, 60, '29/03/2008', 5);
INSERT INTO valoracions VALUES (2384, 96, '15/11/2002', 5);
INSERT INTO valoracions VALUES (2384, 80, '29/08/2003', 9);
INSERT INTO valoracions VALUES (2384, 85, '27/07/2009', 6);
INSERT INTO valoracions VALUES (2385, 108, '19/03/2010', 1);
INSERT INTO valoracions VALUES (2385, 35, '27/04/2008', 7);
INSERT INTO valoracions VALUES (2385, 13, '18/02/2003', 8);
INSERT INTO valoracions VALUES (2385, 53, '08/06/2005', 7);
INSERT INTO valoracions VALUES (2386, 90, '18/05/2008', 3);
INSERT INTO valoracions VALUES (2386, 113, '17/09/2009', 6);
INSERT INTO valoracions VALUES (2386, 105, '24/04/2010', 6);
INSERT INTO valoracions VALUES (2387, 87, '29/12/2009', 9);
INSERT INTO valoracions VALUES (2387, 50, '25/07/2007', 6);
INSERT INTO valoracions VALUES (2387, 11, '19/06/2009', 8);
INSERT INTO valoracions VALUES (2387, 85, '07/12/2004', 5);
INSERT INTO valoracions VALUES (2387, 82, '20/02/2005', 6);
INSERT INTO valoracions VALUES (2388, 16, '30/05/2004', 9);
INSERT INTO valoracions VALUES (2388, 11, '12/03/2007', 8);
INSERT INTO valoracions VALUES (2388, 25, '11/10/2009', 5);
INSERT INTO valoracions VALUES (2388, 89, '25/05/2005', 4);
INSERT INTO valoracions VALUES (2388, 20, '08/07/2003', 8);
INSERT INTO valoracions VALUES (2388, 3, '21/06/2001', 5);
INSERT INTO valoracions VALUES (2389, 102, '23/03/2008', 7);
INSERT INTO valoracions VALUES (2389, 6, '02/03/2008', 7);
INSERT INTO valoracions VALUES (2389, 82, '19/04/2001', 2);
INSERT INTO valoracions VALUES (2389, 63, '27/01/2009', 7);
INSERT INTO valoracions VALUES (2389, 116, '05/01/2008', 7);
INSERT INTO valoracions VALUES (2390, 6, '10/11/2001', 7);
INSERT INTO valoracions VALUES (2390, 77, '25/03/2008', 9);
INSERT INTO valoracions VALUES (2390, 1, '04/06/2008', 10);
INSERT INTO valoracions VALUES (2390, 41, '07/06/2005', 7);
INSERT INTO valoracions VALUES (2390, 22, '15/07/2010', 6);
INSERT INTO valoracions VALUES (2390, 60, '27/12/2002', 8);
INSERT INTO valoracions VALUES (2390, 103, '03/01/2007', 2);
INSERT INTO valoracions VALUES (2390, 56, '05/08/2009', 3);
INSERT INTO valoracions VALUES (2391, 75, '28/01/2003', 7);
INSERT INTO valoracions VALUES (2391, 8, '03/09/2006', 5);
INSERT INTO valoracions VALUES (2391, 115, '15/07/2007', 4);
INSERT INTO valoracions VALUES (2392, 70, '14/04/2001', 3);
INSERT INTO valoracions VALUES (2392, 39, '09/08/2008', 5);
INSERT INTO valoracions VALUES (2392, 94, '19/05/2005', 3);
INSERT INTO valoracions VALUES (2392, 25, '01/01/2010', 9);
INSERT INTO valoracions VALUES (2393, 99, '28/07/2008', 5);
INSERT INTO valoracions VALUES (2393, 113, '03/05/2003', 9);
INSERT INTO valoracions VALUES (2393, 46, '19/05/2009', 5);
INSERT INTO valoracions VALUES (2393, 47, '20/10/2010', 7);
INSERT INTO valoracions VALUES (2393, 83, '24/04/2003', 7);
INSERT INTO valoracions VALUES (2394, 11, '12/01/2003', 6);
INSERT INTO valoracions VALUES (2394, 15, '10/03/2009', 4);
INSERT INTO valoracions VALUES (2394, 105, '22/09/2008', 3);
INSERT INTO valoracions VALUES (2394, 68, '17/06/2002', 4);
INSERT INTO valoracions VALUES (2394, 16, '08/12/2003', 10);
INSERT INTO valoracions VALUES (2394, 83, '17/01/2010', 9);
INSERT INTO valoracions VALUES (2395, 56, '30/07/2003', 4);
INSERT INTO valoracions VALUES (2395, 14, '07/07/2003', 4);
INSERT INTO valoracions VALUES (2395, 96, '14/11/2005', 6);
INSERT INTO valoracions VALUES (2395, 51, '20/02/2002', 6);
INSERT INTO valoracions VALUES (2395, 56, '19/07/2009', 7);
INSERT INTO valoracions VALUES (2395, 115, '13/02/2007', 6);
INSERT INTO valoracions VALUES (2396, 74, '09/09/2001', 8);
INSERT INTO valoracions VALUES (2396, 35, '21/09/2007', 5);
INSERT INTO valoracions VALUES (2396, 45, '10/03/2003', 5);
INSERT INTO valoracions VALUES (2396, 16, '23/11/2007', 7);
INSERT INTO valoracions VALUES (2397, 88, '07/01/2006', 6);
INSERT INTO valoracions VALUES (2397, 50, '26/09/2007', 7);
INSERT INTO valoracions VALUES (2397, 88, '07/02/2007', 7);
INSERT INTO valoracions VALUES (2397, 17, '14/06/2001', 8);
INSERT INTO valoracions VALUES (2397, 81, '26/06/2003', 2);
INSERT INTO valoracions VALUES (2398, 103, '03/05/2002', 8);
INSERT INTO valoracions VALUES (2398, 35, '26/10/2003', 7);
INSERT INTO valoracions VALUES (2398, 69, '12/03/2007', 6);
INSERT INTO valoracions VALUES (2398, 2, '05/05/2007', 9);
INSERT INTO valoracions VALUES (2399, 19, '23/06/2002', 6);
INSERT INTO valoracions VALUES (2399, 81, '11/01/2006', 3);
INSERT INTO valoracions VALUES (2399, 100, '14/09/2009', 9);
INSERT INTO valoracions VALUES (2399, 69, '26/07/2001', 6);
INSERT INTO valoracions VALUES (2399, 92, '28/11/2005', 3);
INSERT INTO valoracions VALUES (2400, 106, '15/02/2010', 6);
INSERT INTO valoracions VALUES (2400, 9, '22/08/2005', 6);
INSERT INTO valoracions VALUES (2400, 39, '17/06/2004', 8);
INSERT INTO valoracions VALUES (2400, 86, '12/10/2003', 3);
INSERT INTO valoracions VALUES (2401, 4, '14/09/2007', 8);
INSERT INTO valoracions VALUES (2401, 15, '14/03/2009', 6);
INSERT INTO valoracions VALUES (2401, 92, '21/05/2003', 7);
INSERT INTO valoracions VALUES (2402, 80, '03/08/2008', 6);
INSERT INTO valoracions VALUES (2402, 59, '10/08/2001', 6);
INSERT INTO valoracions VALUES (2402, 48, '11/07/2009', 9);
INSERT INTO valoracions VALUES (2402, 21, '12/07/2006', 8);
INSERT INTO valoracions VALUES (2403, 66, '08/07/2003', 4);
INSERT INTO valoracions VALUES (2403, 16, '29/11/2009', 7);
INSERT INTO valoracions VALUES (2403, 115, '16/01/2008', 3);
INSERT INTO valoracions VALUES (2403, 22, '27/05/2004', 5);
INSERT INTO valoracions VALUES (2404, 48, '01/12/2006', 7);
INSERT INTO valoracions VALUES (2404, 108, '20/07/2010', 7);
INSERT INTO valoracions VALUES (2404, 97, '20/12/2004', 9);
INSERT INTO valoracions VALUES (2405, 14, '14/09/2001', 5);
INSERT INTO valoracions VALUES (2405, 77, '10/08/2006', 7);
INSERT INTO valoracions VALUES (2405, 27, '09/02/2004', 5);
INSERT INTO valoracions VALUES (2406, 87, '18/06/2006', 1);
INSERT INTO valoracions VALUES (2408, 22, '10/09/2010', 8);
INSERT INTO valoracions VALUES (2408, 25, '23/04/2010', 8);
INSERT INTO valoracions VALUES (2409, 40, '26/01/2007', 7);
INSERT INTO valoracions VALUES (2409, 1, '27/06/2005', 8);
INSERT INTO valoracions VALUES (2409, 64, '08/07/2004', 7);
INSERT INTO valoracions VALUES (2409, 73, '25/06/2002', 6);
INSERT INTO valoracions VALUES (2409, 60, '13/12/2009', 3);
INSERT INTO valoracions VALUES (2410, 6, '11/01/2009', 10);
INSERT INTO valoracions VALUES (2410, 58, '21/11/2007', 10);
INSERT INTO valoracions VALUES (2410, 41, '29/09/2004', 7);
INSERT INTO valoracions VALUES (2411, 62, '03/04/2007', 5);
INSERT INTO valoracions VALUES (2411, 72, '23/10/2002', 7);
INSERT INTO valoracions VALUES (2411, 42, '07/11/2004', 4);
INSERT INTO valoracions VALUES (2412, 29, '21/11/2009', 8);
INSERT INTO valoracions VALUES (2412, 71, '28/01/2009', 4);
INSERT INTO valoracions VALUES (2412, 3, '15/06/2005', 7);
INSERT INTO valoracions VALUES (2413, 77, '30/07/2003', 8);
INSERT INTO valoracions VALUES (2413, 37, '10/08/2010', 9);
INSERT INTO valoracions VALUES (2413, 93, '10/10/2004', 3);
INSERT INTO valoracions VALUES (2414, 87, '11/02/2007', 7);
INSERT INTO valoracions VALUES (2414, 78, '11/08/2001', 3);
INSERT INTO valoracions VALUES (2414, 62, '13/06/2003', 5);
INSERT INTO valoracions VALUES (2414, 97, '10/03/2004', 4);
INSERT INTO valoracions VALUES (2414, 51, '31/07/2002', 5);
INSERT INTO valoracions VALUES (2414, 55, '14/10/2005', 7);
INSERT INTO valoracions VALUES (2415, 78, '05/12/2009', 5);
INSERT INTO valoracions VALUES (2415, 63, '11/10/2003', 3);
INSERT INTO valoracions VALUES (2415, 39, '26/05/2009', 4);
INSERT INTO valoracions VALUES (2415, 67, '30/10/2005', 8);
INSERT INTO valoracions VALUES (2416, 98, '19/06/2002', 8);
INSERT INTO valoracions VALUES (2416, 9, '13/11/2009', 8);
INSERT INTO valoracions VALUES (2416, 81, '29/01/2008', 7);
INSERT INTO valoracions VALUES (2416, 32, '22/10/2003', 4);
INSERT INTO valoracions VALUES (2416, 66, '05/01/2009', 3);
INSERT INTO valoracions VALUES (2416, 45, '13/02/2007', 5);
INSERT INTO valoracions VALUES (2416, 99, '16/07/2003', 7);
INSERT INTO valoracions VALUES (2417, 43, '24/08/2008', 3);
INSERT INTO valoracions VALUES (2417, 112, '27/07/2010', 3);
INSERT INTO valoracions VALUES (2417, 63, '09/08/2007', 8);
INSERT INTO valoracions VALUES (2417, 109, '01/01/2006', 8);
INSERT INTO valoracions VALUES (2418, 111, '27/10/2009', 0);
INSERT INTO valoracions VALUES (2418, 87, '01/02/2009', 6);
INSERT INTO valoracions VALUES (2419, 72, '31/12/2006', 3);
INSERT INTO valoracions VALUES (2419, 107, '19/04/2007', 10);
INSERT INTO valoracions VALUES (2419, 29, '21/03/2002', 7);
INSERT INTO valoracions VALUES (2420, 66, '12/01/2003', 8);
INSERT INTO valoracions VALUES (2420, 14, '03/09/2010', 7);
INSERT INTO valoracions VALUES (2420, 34, '16/04/2008', 4);
INSERT INTO valoracions VALUES (2420, 95, '14/06/2001', 5);
INSERT INTO valoracions VALUES (2421, 19, '18/08/2003', 8);
INSERT INTO valoracions VALUES (2421, 8, '23/11/2002', 5);
INSERT INTO valoracions VALUES (2422, 94, '02/06/2004', 8);
INSERT INTO valoracions VALUES (2422, 75, '24/10/2001', 3);
INSERT INTO valoracions VALUES (2423, 21, '30/03/2004', 9);
INSERT INTO valoracions VALUES (2423, 48, '30/10/2001', 10);
INSERT INTO valoracions VALUES (2423, 101, '09/07/2008', 3);
INSERT INTO valoracions VALUES (2423, 3, '13/01/2002', 10);
INSERT INTO valoracions VALUES (2423, 67, '20/06/2001', 4);
INSERT INTO valoracions VALUES (2423, 17, '09/03/2007', 8);
INSERT INTO valoracions VALUES (2423, 19, '11/01/2008', 4);
INSERT INTO valoracions VALUES (2424, 111, '28/05/2005', 9);
INSERT INTO valoracions VALUES (2424, 8, '19/12/2004', 7);
INSERT INTO valoracions VALUES (2424, 64, '20/10/2009', 5);
INSERT INTO valoracions VALUES (2424, 83, '16/01/2008', 5);
INSERT INTO valoracions VALUES (2424, 37, '18/12/2009', 8);
INSERT INTO valoracions VALUES (2425, 10, '12/12/2005', 5);
INSERT INTO valoracions VALUES (2425, 47, '28/10/2005', 5);
INSERT INTO valoracions VALUES (2425, 102, '30/09/2002', 1);
INSERT INTO valoracions VALUES (2425, 104, '17/07/2008', 9);
INSERT INTO valoracions VALUES (2425, 97, '24/02/2004', 4);
INSERT INTO valoracions VALUES (2426, 33, '11/10/2006', 9);
INSERT INTO valoracions VALUES (2427, 114, '11/12/2006', 3);
INSERT INTO valoracions VALUES (2427, 86, '23/11/2006', 9);
INSERT INTO valoracions VALUES (2427, 30, '17/02/2006', 5);
INSERT INTO valoracions VALUES (2427, 43, '11/07/2006', 7);
INSERT INTO valoracions VALUES (2428, 12, '28/09/2005', 8);
INSERT INTO valoracions VALUES (2428, 40, '21/12/2006', 10);
INSERT INTO valoracions VALUES (2428, 108, '17/07/2002', 1);
INSERT INTO valoracions VALUES (2428, 21, '02/05/2003', 5);
INSERT INTO valoracions VALUES (2428, 46, '05/12/2006', 4);
INSERT INTO valoracions VALUES (2428, 63, '05/03/2008', 7);
INSERT INTO valoracions VALUES (2429, 74, '15/10/2006', 8);
INSERT INTO valoracions VALUES (2429, 102, '09/03/2010', 7);
INSERT INTO valoracions VALUES (2429, 97, '11/07/2001', 2);
INSERT INTO valoracions VALUES (2429, 46, '20/08/2008', 9);
INSERT INTO valoracions VALUES (2429, 92, '20/11/2002', 1);
INSERT INTO valoracions VALUES (2431, 29, '07/06/2008', 9);
INSERT INTO valoracions VALUES (2431, 3, '11/11/2006', 9);
INSERT INTO valoracions VALUES (2431, 94, '18/04/2003', 5);
INSERT INTO valoracions VALUES (2432, 18, '13/05/2008', 9);
INSERT INTO valoracions VALUES (2432, 107, '28/07/2005', 3);
INSERT INTO valoracions VALUES (2432, 71, '27/04/2001', 4);
INSERT INTO valoracions VALUES (2432, 23, '20/12/2007', 4);
INSERT INTO valoracions VALUES (2433, 113, '13/03/2008', 0);
INSERT INTO valoracions VALUES (2433, 97, '19/10/2006', 5);
INSERT INTO valoracions VALUES (2433, 45, '14/05/2002', 8);
INSERT INTO valoracions VALUES (2433, 72, '08/06/2009', 4);
INSERT INTO valoracions VALUES (2434, 58, '21/05/2006', 4);
INSERT INTO valoracions VALUES (2434, 53, '17/10/2003', 5);
INSERT INTO valoracions VALUES (2434, 92, '14/01/2010', 10);
INSERT INTO valoracions VALUES (2435, 99, '24/06/2010', 5);
INSERT INTO valoracions VALUES (2435, 2, '09/10/2001', 10);
INSERT INTO valoracions VALUES (2435, 93, '07/12/2003', 2);
INSERT INTO valoracions VALUES (2435, 21, '04/09/2002', 8);
INSERT INTO valoracions VALUES (2436, 80, '12/04/2002', 7);
INSERT INTO valoracions VALUES (2437, 31, '13/06/2004', 4);
INSERT INTO valoracions VALUES (2437, 48, '17/12/2004', 4);
INSERT INTO valoracions VALUES (2437, 28, '08/10/2009', 9);
INSERT INTO valoracions VALUES (2438, 6, '27/07/2001', 6);
INSERT INTO valoracions VALUES (2438, 12, '12/05/2009', 9);
INSERT INTO valoracions VALUES (2438, 11, '03/05/2001', 5);
INSERT INTO valoracions VALUES (2438, 57, '15/10/2003', 3);
INSERT INTO valoracions VALUES (2439, 14, '08/10/2004', 9);
INSERT INTO valoracions VALUES (2439, 72, '18/07/2005', 4);
INSERT INTO valoracions VALUES (2439, 97, '16/05/2005', 2);
INSERT INTO valoracions VALUES (2440, 90, '06/05/2006', 2);
INSERT INTO valoracions VALUES (2440, 106, '03/11/2005', 4);
INSERT INTO valoracions VALUES (2440, 95, '08/05/2010', 5);
INSERT INTO valoracions VALUES (2440, 59, '04/07/2010', 5);
INSERT INTO valoracions VALUES (2440, 46, '13/07/2009', 5);
INSERT INTO valoracions VALUES (2441, 25, '22/05/2002', 9);
INSERT INTO valoracions VALUES (2441, 46, '12/11/2008', 6);
INSERT INTO valoracions VALUES (2442, 69, '08/01/2007', 4);
INSERT INTO valoracions VALUES (2442, 56, '25/09/2001', 8);
INSERT INTO valoracions VALUES (2442, 22, '21/11/2009', 5);
INSERT INTO valoracions VALUES (2442, 71, '26/07/2006', 8);
INSERT INTO valoracions VALUES (2443, 104, '18/12/2004', 7);
INSERT INTO valoracions VALUES (2443, 20, '19/08/2002', 5);
INSERT INTO valoracions VALUES (2443, 44, '08/09/2002', 9);
INSERT INTO valoracions VALUES (2443, 9, '26/06/2007', 6);
INSERT INTO valoracions VALUES (2444, 46, '14/04/2008', 7);
INSERT INTO valoracions VALUES (2444, 34, '05/07/2006', 6);
INSERT INTO valoracions VALUES (2444, 93, '09/11/2005', 7);
INSERT INTO valoracions VALUES (2444, 82, '19/01/2009', 4);
INSERT INTO valoracions VALUES (2444, 42, '21/02/2009', 6);
INSERT INTO valoracions VALUES (2445, 13, '14/07/2001', 7);
INSERT INTO valoracions VALUES (2445, 50, '02/08/2004', 5);
INSERT INTO valoracions VALUES (2445, 40, '28/05/2007', 5);
INSERT INTO valoracions VALUES (2445, 107, '20/05/2002', 5);
INSERT INTO valoracions VALUES (2446, 49, '26/12/2008', 4);
INSERT INTO valoracions VALUES (2446, 78, '21/03/2004', 9);
INSERT INTO valoracions VALUES (2447, 85, '29/04/2008', 4);
INSERT INTO valoracions VALUES (2447, 43, '06/06/2004', 8);
INSERT INTO valoracions VALUES (2447, 106, '18/07/2008', 4);
INSERT INTO valoracions VALUES (2447, 85, '14/10/2006', 3);
INSERT INTO valoracions VALUES (2447, 116, '14/07/2007', 8);
INSERT INTO valoracions VALUES (2447, 112, '21/01/2004', 6);
INSERT INTO valoracions VALUES (2448, 91, '16/12/2008', 2);
INSERT INTO valoracions VALUES (2448, 56, '04/07/2009', 6);
INSERT INTO valoracions VALUES (2448, 58, '16/05/2006', 4);
INSERT INTO valoracions VALUES (2448, 105, '03/11/2007', 6);
INSERT INTO valoracions VALUES (2448, 93, '11/08/2009', 7);
INSERT INTO valoracions VALUES (2449, 59, '18/03/2007', 5);
INSERT INTO valoracions VALUES (2449, 36, '16/02/2002', 9);
INSERT INTO valoracions VALUES (2449, 71, '09/10/2007', 4);
INSERT INTO valoracions VALUES (2450, 58, '29/06/2009', 6);
INSERT INTO valoracions VALUES (2450, 2, '18/04/2001', 7);
INSERT INTO valoracions VALUES (2450, 35, '19/10/2009', 6);
INSERT INTO valoracions VALUES (2450, 107, '20/09/2009', 1);
INSERT INTO valoracions VALUES (2450, 112, '07/09/2008', 2);
INSERT INTO valoracions VALUES (2451, 48, '08/10/2008', 9);
INSERT INTO valoracions VALUES (2451, 42, '08/04/2003', 7);
INSERT INTO valoracions VALUES (2452, 4, '18/11/2002', 7);
INSERT INTO valoracions VALUES (2452, 76, '11/04/2001', 8);
INSERT INTO valoracions VALUES (2453, 89, '07/05/2004', 6);
INSERT INTO valoracions VALUES (2453, 76, '13/09/2008', 8);
INSERT INTO valoracions VALUES (2453, 33, '07/07/2004', 5);
INSERT INTO valoracions VALUES (2454, 22, '08/08/2003', 6);
INSERT INTO valoracions VALUES (2454, 103, '11/02/2004', 10);
INSERT INTO valoracions VALUES (2454, 50, '05/01/2008', 8);
INSERT INTO valoracions VALUES (2455, 56, '27/08/2007', 3);
INSERT INTO valoracions VALUES (2455, 38, '18/09/2009', 4);
INSERT INTO valoracions VALUES (2455, 55, '16/10/2006', 3);
INSERT INTO valoracions VALUES (2455, 72, '21/02/2009', 10);
INSERT INTO valoracions VALUES (2455, 108, '30/09/2002', 0);
INSERT INTO valoracions VALUES (2455, 43, '10/04/2006', 8);
INSERT INTO valoracions VALUES (2456, 102, '14/02/2006', 2);
INSERT INTO valoracions VALUES (2457, 18, '22/01/2004', 8);
INSERT INTO valoracions VALUES (2457, 79, '07/02/2007', 9);
INSERT INTO valoracions VALUES (2457, 51, '06/05/2005', 7);
INSERT INTO valoracions VALUES (2457, 111, '22/01/2007', 0);
INSERT INTO valoracions VALUES (2457, 27, '13/07/2002', 5);
INSERT INTO valoracions VALUES (2457, 56, '08/11/2007', 4);
INSERT INTO valoracions VALUES (2457, 93, '12/05/2003', 6);
INSERT INTO valoracions VALUES (2457, 90, '29/03/2006', 3);
INSERT INTO valoracions VALUES (2458, 8, '01/09/2006', 7);
INSERT INTO valoracions VALUES (2458, 47, '06/07/2007', 5);
INSERT INTO valoracions VALUES (2458, 35, '30/11/2003', 5);
INSERT INTO valoracions VALUES (2458, 78, '27/05/2003', 3);
INSERT INTO valoracions VALUES (2459, 14, '24/08/2005', 6);
INSERT INTO valoracions VALUES (2459, 85, '30/07/2004', 5);
INSERT INTO valoracions VALUES (2459, 17, '29/11/2006', 5);
INSERT INTO valoracions VALUES (2459, 8, '12/06/2009', 9);
INSERT INTO valoracions VALUES (2460, 20, '09/12/2003', 5);
INSERT INTO valoracions VALUES (2460, 115, '11/03/2008', 2);
INSERT INTO valoracions VALUES (2460, 102, '14/12/2003', 6);
INSERT INTO valoracions VALUES (2460, 30, '12/07/2010', 4);
INSERT INTO valoracions VALUES (2460, 88, '21/01/2010', 4);
INSERT INTO valoracions VALUES (2461, 5, '01/06/2004', 5);
INSERT INTO valoracions VALUES (2461, 8, '07/04/2005', 8);
INSERT INTO valoracions VALUES (2461, 1, '11/05/2009', 8);
INSERT INTO valoracions VALUES (2461, 96, '20/04/2004', 9);
INSERT INTO valoracions VALUES (2461, 109, '08/01/2002', 2);
INSERT INTO valoracions VALUES (2461, 21, '27/11/2009', 10);
INSERT INTO valoracions VALUES (2462, 73, '15/05/2002', 8);
INSERT INTO valoracions VALUES (2463, 48, '25/03/2009', 8);
INSERT INTO valoracions VALUES (2463, 59, '09/11/2003', 7);
INSERT INTO valoracions VALUES (2463, 45, '20/12/2006', 7);
INSERT INTO valoracions VALUES (2463, 65, '25/11/2007', 3);
INSERT INTO valoracions VALUES (2463, 8, '15/11/2007', 8);
INSERT INTO valoracions VALUES (2464, 11, '08/03/2007', 5);
INSERT INTO valoracions VALUES (2464, 50, '02/05/2006', 10);
INSERT INTO valoracions VALUES (2465, 42, '03/01/2009', 9);
INSERT INTO valoracions VALUES (2465, 64, '10/01/2004', 5);
INSERT INTO valoracions VALUES (2465, 72, '16/11/2001', 10);
INSERT INTO valoracions VALUES (2465, 20, '09/10/2008', 8);
INSERT INTO valoracions VALUES (2465, 113, '26/02/2006', 0);
INSERT INTO valoracions VALUES (2465, 112, '29/03/2006', 6);
INSERT INTO valoracions VALUES (2465, 67, '18/08/2004', 5);
INSERT INTO valoracions VALUES (2466, 22, '22/04/2006', 7);
INSERT INTO valoracions VALUES (2466, 42, '04/09/2009', 6);
INSERT INTO valoracions VALUES (2466, 11, '28/03/2009', 6);
INSERT INTO valoracions VALUES (2466, 30, '15/12/2009', 4);
INSERT INTO valoracions VALUES (2466, 71, '17/02/2004', 3);
INSERT INTO valoracions VALUES (2467, 22, '28/01/2003', 5);
INSERT INTO valoracions VALUES (2467, 49, '21/02/2009', 4);
INSERT INTO valoracions VALUES (2467, 70, '25/11/2005', 2);
INSERT INTO valoracions VALUES (2467, 55, '23/04/2005', 4);
INSERT INTO valoracions VALUES (2468, 107, '22/04/2005', 10);
INSERT INTO valoracions VALUES (2468, 7, '05/11/2003', 8);
INSERT INTO valoracions VALUES (2468, 86, '01/02/2005', 2);
INSERT INTO valoracions VALUES (2468, 11, '23/09/2004', 9);
INSERT INTO valoracions VALUES (2468, 99, '20/09/2006', 2);
INSERT INTO valoracions VALUES (2469, 25, '26/12/2007', 8);
INSERT INTO valoracions VALUES (2469, 84, '21/11/2007', 2);
INSERT INTO valoracions VALUES (2469, 105, '04/06/2005', 4);
INSERT INTO valoracions VALUES (2469, 50, '04/11/2002', 9);
INSERT INTO valoracions VALUES (2469, 83, '18/10/2002', 5);
INSERT INTO valoracions VALUES (2470, 61, '09/02/2004', 6);
INSERT INTO valoracions VALUES (2470, 41, '13/06/2006', 5);
INSERT INTO valoracions VALUES (2470, 100, '19/06/2002', 3);
INSERT INTO valoracions VALUES (2470, 3, '22/08/2002', 7);
INSERT INTO valoracions VALUES (2470, 47, '22/09/2008', 9);
INSERT INTO valoracions VALUES (2470, 30, '10/12/2004', 6);
INSERT INTO valoracions VALUES (2470, 64, '06/12/2001', 6);
INSERT INTO valoracions VALUES (2471, 41, '07/08/2007', 6);
INSERT INTO valoracions VALUES (2471, 49, '20/04/2008', 6);
INSERT INTO valoracions VALUES (2471, 10, '15/09/2002', 9);
INSERT INTO valoracions VALUES (2471, 59, '28/03/2007', 9);
INSERT INTO valoracions VALUES (2471, 69, '11/03/2007', 8);
INSERT INTO valoracions VALUES (2471, 93, '22/10/2006', 3);
INSERT INTO valoracions VALUES (2471, 80, '14/05/2005', 6);
INSERT INTO valoracions VALUES (2471, 74, '20/09/2006', 10);
INSERT INTO valoracions VALUES (2471, 100, '08/05/2002', 7);
INSERT INTO valoracions VALUES (2471, 63, '30/08/2010', 5);
INSERT INTO valoracions VALUES (2472, 1, '16/03/2002', 7);
INSERT INTO valoracions VALUES (2472, 62, '27/05/2006', 4);
INSERT INTO valoracions VALUES (2472, 21, '07/11/2006', 8);
INSERT INTO valoracions VALUES (2472, 66, '19/08/2004', 4);
INSERT INTO valoracions VALUES (2472, 79, '31/07/2007', 3);
INSERT INTO valoracions VALUES (2473, 23, '03/09/2003', 6);
INSERT INTO valoracions VALUES (2474, 80, '13/10/2009', 4);
INSERT INTO valoracions VALUES (2474, 53, '22/03/2009', 4);
INSERT INTO valoracions VALUES (2474, 17, '10/04/2005', 8);
INSERT INTO valoracions VALUES (2474, 38, '06/03/2010', 6);
INSERT INTO valoracions VALUES (2474, 105, '10/04/2005', 5);
INSERT INTO valoracions VALUES (2474, 101, '18/12/2003', 5);
INSERT INTO valoracions VALUES (2474, 23, '10/10/2005', 6);
INSERT INTO valoracions VALUES (2474, 71, '02/05/2001', 3);
INSERT INTO valoracions VALUES (2475, 78, '15/09/2006', 8);
INSERT INTO valoracions VALUES (2475, 15, '14/06/2001', 9);
INSERT INTO valoracions VALUES (2476, 29, '25/11/2001', 6);
INSERT INTO valoracions VALUES (2476, 15, '29/12/2007', 10);
INSERT INTO valoracions VALUES (2477, 34, '09/05/2002', 9);
INSERT INTO valoracions VALUES (2477, 9, '22/07/2005', 9);
INSERT INTO valoracions VALUES (2477, 85, '13/10/2004', 2);
INSERT INTO valoracions VALUES (2477, 80, '21/06/2008', 5);
INSERT INTO valoracions VALUES (2477, 33, '15/10/2009', 9);
INSERT INTO valoracions VALUES (2477, 73, '24/02/2005', 8);
INSERT INTO valoracions VALUES (2477, 68, '28/08/2004', 4);
INSERT INTO valoracions VALUES (2478, 57, '28/03/2009', 5);
INSERT INTO valoracions VALUES (2478, 107, '03/11/2009', 0);
INSERT INTO valoracions VALUES (2478, 95, '17/01/2008', 9);
INSERT INTO valoracions VALUES (2478, 111, '28/01/2008', 6);
INSERT INTO valoracions VALUES (2478, 8, '13/03/2006', 9);
INSERT INTO valoracions VALUES (2479, 48, '30/08/2001', 4);
INSERT INTO valoracions VALUES (2479, 83, '17/01/2006', 7);
INSERT INTO valoracions VALUES (2480, 13, '01/04/2008', 8);
INSERT INTO valoracions VALUES (2480, 95, '03/05/2003', 9);
INSERT INTO valoracions VALUES (2480, 95, '24/08/2004', 10);
INSERT INTO valoracions VALUES (2481, 57, '19/03/2008', 6);
INSERT INTO valoracions VALUES (2481, 94, '15/10/2007', 6);
INSERT INTO valoracions VALUES (2482, 9, '15/04/2003', 9);
INSERT INTO valoracions VALUES (2482, 20, '25/06/2008', 5);
INSERT INTO valoracions VALUES (2482, 81, '12/11/2008', 2);
INSERT INTO valoracions VALUES (2482, 55, '10/12/2008', 9);
INSERT INTO valoracions VALUES (2483, 28, '05/03/2006', 6);
INSERT INTO valoracions VALUES (2483, 101, '04/04/2006', 3);
INSERT INTO valoracions VALUES (2483, 97, '27/05/2010', 5);
INSERT INTO valoracions VALUES (2484, 57, '13/09/2003', 8);
INSERT INTO valoracions VALUES (2484, 14, '24/12/2006', 6);
INSERT INTO valoracions VALUES (2484, 56, '10/09/2001', 8);
INSERT INTO valoracions VALUES (2484, 110, '01/08/2006', 4);
INSERT INTO valoracions VALUES (2484, 75, '01/07/2001', 6);
INSERT INTO valoracions VALUES (2484, 75, '25/11/2007', 10);
INSERT INTO valoracions VALUES (2484, 111, '03/02/2009', 4);
INSERT INTO valoracions VALUES (2484, 61, '03/05/2004', 4);
INSERT INTO valoracions VALUES (2485, 97, '17/09/2004', 5);
INSERT INTO valoracions VALUES (2485, 31, '29/11/2001', 5);
INSERT INTO valoracions VALUES (2485, 31, '26/05/2010', 10);
INSERT INTO valoracions VALUES (2485, 37, '19/10/2009', 4);
INSERT INTO valoracions VALUES (2485, 10, '26/05/2004', 8);
INSERT INTO valoracions VALUES (2485, 75, '12/01/2002', 6);
INSERT INTO valoracions VALUES (2485, 100, '26/03/2004', 6);
INSERT INTO valoracions VALUES (2485, 84, '08/02/2002', 9);
INSERT INTO valoracions VALUES (2485, 89, '16/09/2003', 5);
INSERT INTO valoracions VALUES (2486, 19, '26/10/2003', 8);
INSERT INTO valoracions VALUES (2486, 94, '14/06/2006', 2);
INSERT INTO valoracions VALUES (2486, 114, '31/08/2008', 7);
INSERT INTO valoracions VALUES (2486, 71, '06/09/2001', 4);
INSERT INTO valoracions VALUES (2486, 2, '09/05/2008', 5);
INSERT INTO valoracions VALUES (2487, 79, '14/10/2007', 4);
INSERT INTO valoracions VALUES (2487, 63, '29/09/2001', 8);
INSERT INTO valoracions VALUES (2487, 26, '14/08/2008', 9);
INSERT INTO valoracions VALUES (2488, 7, '06/10/2004', 7);
INSERT INTO valoracions VALUES (2488, 102, '22/05/2008', 8);
INSERT INTO valoracions VALUES (2489, 62, '03/04/2004', 7);
INSERT INTO valoracions VALUES (2489, 109, '20/09/2003', 6);
INSERT INTO valoracions VALUES (2490, 95, '23/01/2006', 2);
INSERT INTO valoracions VALUES (2490, 1, '09/09/2009', 7);
INSERT INTO valoracions VALUES (2491, 47, '09/08/2003', 7);
INSERT INTO valoracions VALUES (2491, 78, '06/07/2003', 3);
INSERT INTO valoracions VALUES (2492, 85, '30/12/2002', 8);
INSERT INTO valoracions VALUES (2492, 97, '17/06/2009', 9);
INSERT INTO valoracions VALUES (2492, 76, '10/04/2007', 9);
INSERT INTO valoracions VALUES (2493, 62, '09/07/2009', 9);
INSERT INTO valoracions VALUES (2493, 115, '20/06/2004', 5);
INSERT INTO valoracions VALUES (2493, 72, '30/05/2006', 2);
INSERT INTO valoracions VALUES (2493, 2, '19/02/2005', 6);
INSERT INTO valoracions VALUES (2493, 55, '20/04/2005', 3);
INSERT INTO valoracions VALUES (2493, 115, '27/10/2009', 7);
INSERT INTO valoracions VALUES (2494, 76, '25/06/2008', 2);
INSERT INTO valoracions VALUES (2494, 7, '04/08/2008', 7);
INSERT INTO valoracions VALUES (2494, 35, '30/06/2003', 9);
INSERT INTO valoracions VALUES (2494, 96, '21/09/2007', 5);
INSERT INTO valoracions VALUES (2494, 47, '20/06/2008', 4);
INSERT INTO valoracions VALUES (2495, 10, '20/12/2004', 7);
INSERT INTO valoracions VALUES (2496, 87, '13/09/2006', 3);
INSERT INTO valoracions VALUES (2496, 42, '07/03/2004', 7);
INSERT INTO valoracions VALUES (2496, 23, '02/09/2008', 8);
INSERT INTO valoracions VALUES (2496, 93, '08/05/2008', 5);
INSERT INTO valoracions VALUES (2497, 99, '18/04/2006', 9);
INSERT INTO valoracions VALUES (2497, 35, '24/02/2006', 9);
INSERT INTO valoracions VALUES (2497, 36, '31/05/2010', 5);
INSERT INTO valoracions VALUES (2498, 29, '20/02/2003', 8);
INSERT INTO valoracions VALUES (2498, 111, '01/12/2007', 8);
INSERT INTO valoracions VALUES (2498, 53, '15/05/2003', 8);
INSERT INTO valoracions VALUES (2498, 41, '13/04/2005', 7);
INSERT INTO valoracions VALUES (2498, 111, '28/10/2009', 7);
INSERT INTO valoracions VALUES (2499, 51, '03/12/2001', 9);
INSERT INTO valoracions VALUES (2499, 71, '21/06/2003', 10);
INSERT INTO valoracions VALUES (2500, 75, '01/09/2003', 3);
INSERT INTO valoracions VALUES (2500, 13, '06/09/2006', 5);
INSERT INTO valoracions VALUES (2500, 29, '12/10/2005', 6);
INSERT INTO valoracions VALUES (2500, 18, '11/12/2009', 6);
INSERT INTO valoracions VALUES (2500, 32, '13/12/2007', 9);
INSERT INTO valoracions VALUES (2501, 79, '04/09/2007', 9);
INSERT INTO valoracions VALUES (2501, 105, '30/11/2006', 1);
INSERT INTO valoracions VALUES (2501, 75, '20/04/2002', 8);
INSERT INTO valoracions VALUES (2501, 40, '13/04/2007', 9);
INSERT INTO valoracions VALUES (2502, 80, '01/10/2006', 6);
INSERT INTO valoracions VALUES (2502, 65, '22/06/2010', 10);
INSERT INTO valoracions VALUES (2502, 2, '18/02/2004', 6);
INSERT INTO valoracions VALUES (2503, 89, '10/07/2009', 10);
INSERT INTO valoracions VALUES (2503, 23, '18/11/2002', 5);
INSERT INTO valoracions VALUES (2504, 85, '07/02/2007', 9);
INSERT INTO valoracions VALUES (2505, 93, '07/06/2010', 6);
INSERT INTO valoracions VALUES (2505, 62, '08/06/2009', 4);
INSERT INTO valoracions VALUES (2505, 78, '06/08/2008', 3);
INSERT INTO valoracions VALUES (2506, 98, '08/03/2006', 7);
INSERT INTO valoracions VALUES (2507, 88, '15/10/2005', 2);
INSERT INTO valoracions VALUES (2507, 22, '05/08/2001', 6);
INSERT INTO valoracions VALUES (2507, 39, '04/01/2004', 3);
INSERT INTO valoracions VALUES (2507, 89, '06/05/2007', 6);
INSERT INTO valoracions VALUES (2507, 110, '04/12/2001', 6);
INSERT INTO valoracions VALUES (2507, 17, '26/10/2006', 8);
INSERT INTO valoracions VALUES (2507, 65, '14/08/2008', 7);
INSERT INTO valoracions VALUES (2507, 30, '20/06/2005', 5);
INSERT INTO valoracions VALUES (2507, 88, '22/04/2004', 5);
INSERT INTO valoracions VALUES (2507, 51, '15/05/2008', 9);
INSERT INTO valoracions VALUES (2508, 61, '09/05/2009', 3);
INSERT INTO valoracions VALUES (2508, 114, '21/07/2001', 8);
INSERT INTO valoracions VALUES (2508, 5, '12/09/2004', 5);
INSERT INTO valoracions VALUES (2508, 115, '28/02/2007', 2);
INSERT INTO valoracions VALUES (2508, 107, '22/02/2003', 9);
INSERT INTO valoracions VALUES (2508, 18, '21/12/2005', 4);
INSERT INTO valoracions VALUES (2508, 87, '22/07/2006', 7);
INSERT INTO valoracions VALUES (2509, 51, '07/07/2009', 9);
INSERT INTO valoracions VALUES (2509, 85, '09/01/2002', 6);
INSERT INTO valoracions VALUES (2510, 53, '20/05/2005', 8);
INSERT INTO valoracions VALUES (2510, 88, '21/05/2002', 5);
INSERT INTO valoracions VALUES (2511, 56, '29/11/2003', 6);
INSERT INTO valoracions VALUES (2511, 94, '07/06/2003', 2);
INSERT INTO valoracions VALUES (2512, 32, '18/04/2001', 8);
INSERT INTO valoracions VALUES (2512, 13, '01/03/2004', 9);
INSERT INTO valoracions VALUES (2512, 114, '18/05/2005', 1);
INSERT INTO valoracions VALUES (2512, 111, '12/11/2001', 5);
INSERT INTO valoracions VALUES (2512, 99, '27/10/2002', 2);
INSERT INTO valoracions VALUES (2512, 29, '28/02/2008', 5);
INSERT INTO valoracions VALUES (2512, 47, '07/09/2001', 4);
INSERT INTO valoracions VALUES (2513, 54, '20/09/2007', 3);
INSERT INTO valoracions VALUES (2513, 66, '24/02/2002', 7);
INSERT INTO valoracions VALUES (2513, 111, '06/08/2003', 9);
INSERT INTO valoracions VALUES (2514, 49, '13/07/2008', 4);
INSERT INTO valoracions VALUES (2514, 71, '19/03/2002', 9);
INSERT INTO valoracions VALUES (2514, 7, '19/07/2001', 9);
INSERT INTO valoracions VALUES (2515, 83, '12/01/2004', 7);
INSERT INTO valoracions VALUES (2515, 3, '22/02/2007', 10);
INSERT INTO valoracions VALUES (2515, 14, '20/08/2002', 8);
INSERT INTO valoracions VALUES (2515, 88, '01/09/2002', 3);
INSERT INTO valoracions VALUES (2515, 91, '21/08/2004', 2);
INSERT INTO valoracions VALUES (2515, 100, '24/01/2007', 4);
INSERT INTO valoracions VALUES (2515, 79, '31/03/2009', 6);
INSERT INTO valoracions VALUES (2515, 91, '27/04/2002', 8);
INSERT INTO valoracions VALUES (2516, 13, '31/03/2008', 6);
INSERT INTO valoracions VALUES (2516, 8, '26/08/2002', 8);
INSERT INTO valoracions VALUES (2516, 63, '08/07/2002', 3);
INSERT INTO valoracions VALUES (2516, 54, '04/07/2004', 6);
INSERT INTO valoracions VALUES (2516, 9, '26/07/2004', 8);
INSERT INTO valoracions VALUES (2517, 65, '13/09/2004', 3);
INSERT INTO valoracions VALUES (2517, 110, '24/07/2010', 3);
INSERT INTO valoracions VALUES (2517, 75, '15/06/2006', 9);
INSERT INTO valoracions VALUES (2517, 107, '09/10/2009', 10);
INSERT INTO valoracions VALUES (2517, 61, '28/12/2002', 4);
INSERT INTO valoracions VALUES (2518, 6, '13/08/2003', 5);
INSERT INTO valoracions VALUES (2518, 84, '03/09/2009', 10);
INSERT INTO valoracions VALUES (2518, 9, '04/04/2005', 5);
INSERT INTO valoracions VALUES (2518, 102, '16/10/2004', 8);
INSERT INTO valoracions VALUES (2519, 82, '17/07/2003', 7);
INSERT INTO valoracions VALUES (2519, 14, '31/03/2007', 8);
INSERT INTO valoracions VALUES (2519, 1, '04/02/2004', 6);
INSERT INTO valoracions VALUES (2520, 105, '13/06/2005', 3);
INSERT INTO valoracions VALUES (2520, 94, '25/06/2006', 3);
INSERT INTO valoracions VALUES (2521, 6, '09/08/2008', 6);
INSERT INTO valoracions VALUES (2521, 8, '17/12/2005', 7);
INSERT INTO valoracions VALUES (2521, 14, '19/07/2004', 9);
INSERT INTO valoracions VALUES (2521, 25, '22/12/2003', 6);
INSERT INTO valoracions VALUES (2521, 1, '20/09/2001', 10);
INSERT INTO valoracions VALUES (2522, 25, '10/02/2003', 5);
INSERT INTO valoracions VALUES (2522, 36, '06/05/2010', 4);
INSERT INTO valoracions VALUES (2523, 21, '29/04/2001', 6);
INSERT INTO valoracions VALUES (2523, 56, '26/08/2006', 9);
INSERT INTO valoracions VALUES (2524, 71, '21/05/2005', 2);
INSERT INTO valoracions VALUES (2524, 116, '13/12/2007', 6);
INSERT INTO valoracions VALUES (2524, 23, '03/02/2004', 6);
INSERT INTO valoracions VALUES (2524, 3, '09/11/2004', 5);
INSERT INTO valoracions VALUES (2524, 81, '10/10/2002', 9);
INSERT INTO valoracions VALUES (2524, 45, '26/06/2006', 9);
INSERT INTO valoracions VALUES (2524, 33, '31/01/2006', 7);
INSERT INTO valoracions VALUES (2524, 101, '18/07/2002', 3);
INSERT INTO valoracions VALUES (2525, 64, '07/10/2005', 7);
INSERT INTO valoracions VALUES (2525, 48, '17/05/2003', 8);
INSERT INTO valoracions VALUES (2525, 17, '24/04/2008', 6);
INSERT INTO valoracions VALUES (2525, 111, '23/08/2003', 2);
INSERT INTO valoracions VALUES (2526, 46, '13/07/2003', 4);
INSERT INTO valoracions VALUES (2526, 69, '11/10/2006', 6);
INSERT INTO valoracions VALUES (2526, 114, '11/10/2004', 9);
INSERT INTO valoracions VALUES (2526, 17, '13/02/2002', 8);
INSERT INTO valoracions VALUES (2526, 9, '12/11/2006', 5);
INSERT INTO valoracions VALUES (2527, 67, '10/08/2008', 3);
INSERT INTO valoracions VALUES (2527, 14, '24/09/2009', 8);
INSERT INTO valoracions VALUES (2527, 91, '04/04/2002', 4);
INSERT INTO valoracions VALUES (2527, 100, '20/02/2003', 6);
INSERT INTO valoracions VALUES (2528, 47, '21/09/2003', 8);
INSERT INTO valoracions VALUES (2528, 67, '03/04/2001', 2);
INSERT INTO valoracions VALUES (2528, 4, '17/02/2006', 7);
INSERT INTO valoracions VALUES (2529, 60, '05/08/2003', 8);
INSERT INTO valoracions VALUES (2529, 18, '19/04/2008', 9);
INSERT INTO valoracions VALUES (2529, 27, '12/05/2007', 4);
INSERT INTO valoracions VALUES (2529, 101, '15/01/2007', 9);
INSERT INTO valoracions VALUES (2529, 102, '18/08/2006', 4);
INSERT INTO valoracions VALUES (2529, 67, '10/08/2009', 2);
INSERT INTO valoracions VALUES (2530, 38, '29/10/2009', 10);
INSERT INTO valoracions VALUES (2530, 8, '19/10/2003', 5);
INSERT INTO valoracions VALUES (2530, 72, '08/04/2007', 4);
INSERT INTO valoracions VALUES (2530, 1, '28/09/2003', 8);
INSERT INTO valoracions VALUES (2530, 62, '02/03/2007', 8);
INSERT INTO valoracions VALUES (2531, 63, '02/05/2002', 7);
INSERT INTO valoracions VALUES (2531, 99, '09/11/2001', 6);
INSERT INTO valoracions VALUES (2532, 96, '27/04/2002', 5);
INSERT INTO valoracions VALUES (2534, 95, '29/06/2001', 6);
INSERT INTO valoracions VALUES (2534, 8, '21/10/2005', 9);
INSERT INTO valoracions VALUES (2534, 115, '01/03/2009', 4);
INSERT INTO valoracions VALUES (2535, 49, '22/08/2007', 10);
INSERT INTO valoracions VALUES (2535, 113, '23/05/2003', 9);
INSERT INTO valoracions VALUES (2535, 41, '10/07/2006', 9);
INSERT INTO valoracions VALUES (2535, 61, '16/05/2010', 8);
INSERT INTO valoracions VALUES (2535, 80, '21/09/2006', 7);
INSERT INTO valoracions VALUES (2536, 74, '09/09/2009', 2);
INSERT INTO valoracions VALUES (2536, 93, '04/04/2005', 5);
INSERT INTO valoracions VALUES (2537, 96, '02/07/2006', 4);
INSERT INTO valoracions VALUES (2537, 70, '13/10/2006', 10);
INSERT INTO valoracions VALUES (2538, 80, '05/12/2008', 6);
INSERT INTO valoracions VALUES (2538, 19, '08/09/2002', 7);
INSERT INTO valoracions VALUES (2538, 112, '25/04/2005', 8);
INSERT INTO valoracions VALUES (2538, 30, '21/09/2002', 4);
INSERT INTO valoracions VALUES (2539, 76, '09/01/2010', 4);
INSERT INTO valoracions VALUES (2540, 19, '22/11/2005', 9);
INSERT INTO valoracions VALUES (2540, 112, '31/05/2005', 9);
INSERT INTO valoracions VALUES (2540, 2, '18/12/2003', 6);
INSERT INTO valoracions VALUES (2540, 73, '11/05/2003', 5);
INSERT INTO valoracions VALUES (2541, 64, '02/08/2003', 6);
INSERT INTO valoracions VALUES (2541, 23, '24/06/2010', 8);
INSERT INTO valoracions VALUES (2541, 67, '25/06/2010', 7);
INSERT INTO valoracions VALUES (2544, 40, '10/04/2002', 5);
INSERT INTO valoracions VALUES (2544, 89, '19/05/2001', 10);
INSERT INTO valoracions VALUES (2544, 16, '29/07/2010', 6);
INSERT INTO valoracions VALUES (2544, 88, '15/06/2002', 3);
INSERT INTO valoracions VALUES (2544, 39, '27/10/2001', 8);
INSERT INTO valoracions VALUES (2544, 100, '20/11/2003', 7);
INSERT INTO valoracions VALUES (2544, 108, '13/12/2005', 8);
INSERT INTO valoracions VALUES (2544, 49, '09/02/2004', 4);
INSERT INTO valoracions VALUES (2545, 85, '24/07/2007', 5);
INSERT INTO valoracions VALUES (2545, 92, '18/11/2007', 10);
INSERT INTO valoracions VALUES (2546, 56, '07/12/2004', 7);
INSERT INTO valoracions VALUES (2546, 90, '31/03/2005', 4);
INSERT INTO valoracions VALUES (2546, 53, '18/09/2002', 7);
INSERT INTO valoracions VALUES (2546, 106, '26/12/2003', 3);
INSERT INTO valoracions VALUES (2547, 23, '28/04/2003', 5);
INSERT INTO valoracions VALUES (2547, 89, '09/07/2003', 4);
INSERT INTO valoracions VALUES (2548, 65, '05/11/2003', 5);
INSERT INTO valoracions VALUES (2548, 73, '16/08/2008', 4);
INSERT INTO valoracions VALUES (2548, 114, '29/11/2006', 7);
INSERT INTO valoracions VALUES (2549, 106, '10/08/2001', 9);
INSERT INTO valoracions VALUES (2549, 68, '19/11/2004', 8);
INSERT INTO valoracions VALUES (2549, 74, '24/01/2003', 7);
INSERT INTO valoracions VALUES (2549, 2, '10/08/2001', 6);
INSERT INTO valoracions VALUES (2549, 83, '20/06/2009', 7);
INSERT INTO valoracions VALUES (2550, 44, '08/04/2004', 5);
INSERT INTO valoracions VALUES (2550, 66, '11/11/2002', 5);
INSERT INTO valoracions VALUES (2550, 92, '01/02/2006', 6);
INSERT INTO valoracions VALUES (2551, 97, '27/12/2007', 3);
INSERT INTO valoracions VALUES (2551, 95, '11/12/2002', 3);
INSERT INTO valoracions VALUES (2551, 114, '26/05/2008', 3);
INSERT INTO valoracions VALUES (2551, 82, '07/07/2008', 4);
INSERT INTO valoracions VALUES (2552, 45, '25/02/2005', 6);
INSERT INTO valoracions VALUES (2552, 95, '11/12/2009', 1);
INSERT INTO valoracions VALUES (2552, 28, '20/10/2005', 9);
INSERT INTO valoracions VALUES (2552, 16, '30/03/2006', 5);
INSERT INTO valoracions VALUES (2552, 44, '20/08/2010', 9);
INSERT INTO valoracions VALUES (2552, 33, '04/05/2006', 5);
INSERT INTO valoracions VALUES (2552, 34, '09/10/2003', 9);
INSERT INTO valoracions VALUES (2552, 82, '31/07/2009', 4);
INSERT INTO valoracions VALUES (2553, 101, '14/09/2007', 9);
INSERT INTO valoracions VALUES (2553, 7, '30/10/2010', 9);
INSERT INTO valoracions VALUES (2553, 99, '12/05/2009', 4);
INSERT INTO valoracions VALUES (2553, 1, '03/11/2006', 5);
INSERT INTO valoracions VALUES (2554, 67, '29/08/2007', 8);
INSERT INTO valoracions VALUES (2554, 9, '21/09/2001', 5);
INSERT INTO valoracions VALUES (2554, 72, '17/04/2004', 8);
INSERT INTO valoracions VALUES (2554, 18, '25/09/2001', 7);
INSERT INTO valoracions VALUES (2554, 20, '18/09/2010', 5);
INSERT INTO valoracions VALUES (2554, 28, '11/01/2008', 8);
INSERT INTO valoracions VALUES (2554, 31, '29/05/2010', 5);
INSERT INTO valoracions VALUES (2554, 39, '09/05/2010', 5);
INSERT INTO valoracions VALUES (2554, 15, '10/03/2004', 4);
INSERT INTO valoracions VALUES (2555, 104, '23/05/2001', 5);
INSERT INTO valoracions VALUES (2555, 6, '06/03/2004', 9);
INSERT INTO valoracions VALUES (2555, 22, '13/05/2009', 5);
INSERT INTO valoracions VALUES (2555, 112, '07/06/2010', 3);
INSERT INTO valoracions VALUES (2556, 99, '10/09/2003', 4);
INSERT INTO valoracions VALUES (2557, 16, '26/05/2007', 7);
INSERT INTO valoracions VALUES (2557, 6, '08/05/2009', 8);
INSERT INTO valoracions VALUES (2557, 85, '24/11/2001', 7);
INSERT INTO valoracions VALUES (2557, 110, '21/03/2003', 2);
INSERT INTO valoracions VALUES (2558, 61, '21/01/2005', 6);
INSERT INTO valoracions VALUES (2558, 65, '17/05/2004', 4);
INSERT INTO valoracions VALUES (2559, 31, '30/09/2009', 9);
INSERT INTO valoracions VALUES (2559, 64, '20/01/2003', 5);
INSERT INTO valoracions VALUES (2559, 26, '26/09/2001', 8);
INSERT INTO valoracions VALUES (2560, 85, '17/10/2008', 4);
INSERT INTO valoracions VALUES (2560, 91, '21/10/2002', 8);
INSERT INTO valoracions VALUES (2560, 100, '06/05/2008', 6);
INSERT INTO valoracions VALUES (2560, 84, '13/11/2005', 9);
INSERT INTO valoracions VALUES (2560, 108, '13/02/2003', 4);
INSERT INTO valoracions VALUES (2560, 115, '12/12/2007', 7);
INSERT INTO valoracions VALUES (2561, 97, '06/07/2007', 5);
INSERT INTO valoracions VALUES (2561, 5, '05/05/2010', 5);
INSERT INTO valoracions VALUES (2561, 56, '27/09/2010', 3);
INSERT INTO valoracions VALUES (2561, 78, '09/11/2002', 3);
INSERT INTO valoracions VALUES (2562, 20, '06/05/2005', 8);
INSERT INTO valoracions VALUES (2562, 16, '28/09/2001', 6);
INSERT INTO valoracions VALUES (2562, 45, '09/11/2006', 5);
INSERT INTO valoracions VALUES (2562, 6, '18/04/2004', 6);
INSERT INTO valoracions VALUES (2562, 95, '22/07/2007', 4);
INSERT INTO valoracions VALUES (2562, 111, '12/07/2010', 3);
INSERT INTO valoracions VALUES (2562, 50, '10/12/2006', 6);
INSERT INTO valoracions VALUES (2562, 55, '09/12/2006', 6);
INSERT INTO valoracions VALUES (2562, 52, '10/12/2004', 4);
INSERT INTO valoracions VALUES (2563, 46, '15/08/2007', 9);
INSERT INTO valoracions VALUES (2563, 85, '05/02/2009', 9);
INSERT INTO valoracions VALUES (2563, 16, '12/05/2009', 8);
INSERT INTO valoracions VALUES (2564, 60, '15/04/2007', 8);
INSERT INTO valoracions VALUES (2564, 6, '27/10/2001', 7);
INSERT INTO valoracions VALUES (2564, 105, '03/05/2002', 7);
INSERT INTO valoracions VALUES (2565, 76, '22/08/2004', 5);
INSERT INTO valoracions VALUES (2565, 65, '03/03/2008', 9);
INSERT INTO valoracions VALUES (2565, 4, '05/04/2010', 5);
INSERT INTO valoracions VALUES (2566, 24, '09/05/2009', 7);
INSERT INTO valoracions VALUES (2566, 103, '07/02/2010', 7);
INSERT INTO valoracions VALUES (2566, 60, '14/12/2008', 4);
INSERT INTO valoracions VALUES (2566, 60, '05/04/2009', 8);
INSERT INTO valoracions VALUES (2566, 6, '14/11/2009', 10);
INSERT INTO valoracions VALUES (2566, 79, '02/08/2009', 2);
INSERT INTO valoracions VALUES (2566, 16, '11/01/2006', 7);
INSERT INTO valoracions VALUES (2567, 67, '17/11/2004', 9);
INSERT INTO valoracions VALUES (2567, 116, '13/06/2010', 7);
INSERT INTO valoracions VALUES (2567, 91, '22/07/2009', 9);
INSERT INTO valoracions VALUES (2568, 20, '28/09/2004', 5);
INSERT INTO valoracions VALUES (2569, 105, '28/11/2002', 8);
INSERT INTO valoracions VALUES (2569, 109, '25/07/2005', 8);
INSERT INTO valoracions VALUES (2570, 49, '23/04/2006', 10);
INSERT INTO valoracions VALUES (2570, 71, '08/09/2010', 3);
INSERT INTO valoracions VALUES (2570, 55, '28/10/2007', 3);
INSERT INTO valoracions VALUES (2570, 55, '08/09/2010', 7);
INSERT INTO valoracions VALUES (2571, 6, '28/08/2001', 8);
INSERT INTO valoracions VALUES (2571, 26, '02/11/2009', 6);
INSERT INTO valoracions VALUES (2571, 18, '03/04/2009', 6);
INSERT INTO valoracions VALUES (2571, 61, '11/02/2010', 7);
INSERT INTO valoracions VALUES (2571, 94, '11/08/2004', 5);
INSERT INTO valoracions VALUES (2572, 102, '23/05/2005', 9);
INSERT INTO valoracions VALUES (2572, 8, '05/03/2003', 8);
INSERT INTO valoracions VALUES (2572, 71, '29/03/2003', 4);
INSERT INTO valoracions VALUES (2573, 49, '24/07/2009', 5);
INSERT INTO valoracions VALUES (2573, 59, '18/06/2009', 8);
INSERT INTO valoracions VALUES (2573, 13, '24/10/2008', 9);
INSERT INTO valoracions VALUES (2573, 2, '06/06/2005', 9);
INSERT INTO valoracions VALUES (2573, 47, '30/10/2003', 7);
INSERT INTO valoracions VALUES (2573, 25, '05/06/2004', 6);
INSERT INTO valoracions VALUES (2573, 14, '11/08/2001', 8);
INSERT INTO valoracions VALUES (2573, 106, '21/10/2003', 8);
INSERT INTO valoracions VALUES (2574, 65, '10/10/2001', 8);
INSERT INTO valoracions VALUES (2574, 81, '15/04/2001', 9);
INSERT INTO valoracions VALUES (2574, 83, '25/11/2001', 7);
INSERT INTO valoracions VALUES (2574, 92, '12/09/2008', 6);
INSERT INTO valoracions VALUES (2574, 18, '02/07/2007', 7);
INSERT INTO valoracions VALUES (2574, 56, '29/12/2004', 9);
INSERT INTO valoracions VALUES (2574, 36, '05/10/2004', 7);
INSERT INTO valoracions VALUES (2574, 63, '19/12/2003', 9);
INSERT INTO valoracions VALUES (2574, 100, '13/07/2010', 4);
INSERT INTO valoracions VALUES (2574, 41, '03/09/2004', 8);
INSERT INTO valoracions VALUES (2575, 36, '21/01/2007', 5);
INSERT INTO valoracions VALUES (2576, 44, '20/03/2010', 3);
INSERT INTO valoracions VALUES (2576, 82, '06/05/2009', 9);
INSERT INTO valoracions VALUES (2576, 60, '05/04/2010', 5);
INSERT INTO valoracions VALUES (2576, 41, '26/02/2005', 7);
INSERT INTO valoracions VALUES (2576, 96, '16/06/2006', 8);
INSERT INTO valoracions VALUES (2576, 84, '12/01/2009', 5);
INSERT INTO valoracions VALUES (2576, 82, '22/12/2001', 9);
INSERT INTO valoracions VALUES (2577, 43, '04/05/2001', 9);
INSERT INTO valoracions VALUES (2577, 66, '21/07/2004', 9);
INSERT INTO valoracions VALUES (2577, 39, '20/11/2001', 9);
INSERT INTO valoracions VALUES (2577, 110, '31/05/2001', 8);
INSERT INTO valoracions VALUES (2577, 33, '24/12/2002', 7);
INSERT INTO valoracions VALUES (2577, 98, '23/04/2006', 4);
INSERT INTO valoracions VALUES (2577, 31, '23/06/2010', 6);
INSERT INTO valoracions VALUES (2578, 101, '13/02/2003', 4);
INSERT INTO valoracions VALUES (2578, 14, '21/09/2006', 6);
INSERT INTO valoracions VALUES (2578, 12, '09/05/2008', 8);
INSERT INTO valoracions VALUES (2578, 56, '28/04/2007', 5);
INSERT INTO valoracions VALUES (2578, 81, '25/03/2005', 6);
INSERT INTO valoracions VALUES (2579, 83, '17/07/2004', 7);
INSERT INTO valoracions VALUES (2579, 80, '14/08/2009', 8);
INSERT INTO valoracions VALUES (2579, 20, '24/08/2005', 7);
INSERT INTO valoracions VALUES (2579, 1, '22/05/2006', 10);
INSERT INTO valoracions VALUES (2579, 54, '14/12/2004', 9);
INSERT INTO valoracions VALUES (2579, 74, '25/06/2010', 3);
INSERT INTO valoracions VALUES (2579, 63, '01/12/2006', 5);
INSERT INTO valoracions VALUES (2580, 111, '04/12/2003', 10);
INSERT INTO valoracions VALUES (2581, 50, '02/10/2008', 6);
INSERT INTO valoracions VALUES (2581, 9, '23/11/2005', 8);
INSERT INTO valoracions VALUES (2581, 46, '06/10/2005', 8);
INSERT INTO valoracions VALUES (2581, 63, '17/07/2005', 3);
INSERT INTO valoracions VALUES (2581, 16, '09/05/2003', 8);
INSERT INTO valoracions VALUES (2581, 106, '23/01/2007', 2);
INSERT INTO valoracions VALUES (2581, 7, '14/09/2008', 6);
INSERT INTO valoracions VALUES (2582, 63, '08/05/2006', 4);
INSERT INTO valoracions VALUES (2582, 59, '21/01/2004', 6);
INSERT INTO valoracions VALUES (2582, 54, '27/11/2007', 3);
INSERT INTO valoracions VALUES (2582, 58, '09/10/2003', 6);
INSERT INTO valoracions VALUES (2582, 25, '22/11/2006', 9);
INSERT INTO valoracions VALUES (2582, 41, '09/11/2009', 10);
INSERT INTO valoracions VALUES (2582, 11, '28/12/2005', 6);
INSERT INTO valoracions VALUES (2583, 90, '12/12/2003', 5);
INSERT INTO valoracions VALUES (2583, 6, '29/10/2002', 8);
INSERT INTO valoracions VALUES (2583, 54, '11/04/2005', 5);
INSERT INTO valoracions VALUES (2583, 73, '16/05/2002', 2);
INSERT INTO valoracions VALUES (2583, 103, '07/06/2007', 8);
INSERT INTO valoracions VALUES (2583, 95, '11/06/2006', 9);
INSERT INTO valoracions VALUES (2584, 51, '16/09/2002', 7);
INSERT INTO valoracions VALUES (2584, 36, '20/03/2003', 5);
INSERT INTO valoracions VALUES (2584, 93, '06/07/2006', 2);
INSERT INTO valoracions VALUES (2584, 21, '26/08/2006', 9);
INSERT INTO valoracions VALUES (2585, 86, '04/08/2009', 10);
INSERT INTO valoracions VALUES (2585, 85, '29/07/2010', 4);
INSERT INTO valoracions VALUES (2585, 103, '09/07/2010', 6);
INSERT INTO valoracions VALUES (2585, 4, '24/07/2006', 5);
INSERT INTO valoracions VALUES (2586, 57, '14/10/2004', 3);
INSERT INTO valoracions VALUES (2586, 21, '02/04/2008', 4);
INSERT INTO valoracions VALUES (2586, 18, '29/04/2002', 8);
INSERT INTO valoracions VALUES (2587, 14, '28/09/2009', 8);
INSERT INTO valoracions VALUES (2587, 106, '09/09/2006', 7);
INSERT INTO valoracions VALUES (2587, 75, '23/01/2009', 9);
INSERT INTO valoracions VALUES (2588, 57, '13/06/2005', 5);
INSERT INTO valoracions VALUES (2588, 75, '22/08/2010', 8);
INSERT INTO valoracions VALUES (2589, 47, '24/11/2003', 7);
INSERT INTO valoracions VALUES (2589, 50, '16/06/2007', 5);
INSERT INTO valoracions VALUES (2589, 101, '23/08/2007', 6);
INSERT INTO valoracions VALUES (2590, 36, '13/12/2008', 9);
INSERT INTO valoracions VALUES (2590, 85, '11/01/2005', 6);
INSERT INTO valoracions VALUES (2590, 23, '16/03/2005', 8);
INSERT INTO valoracions VALUES (2590, 50, '09/09/2003', 6);
INSERT INTO valoracions VALUES (2591, 59, '08/06/2003', 6);
INSERT INTO valoracions VALUES (2591, 107, '24/01/2007', 8);
INSERT INTO valoracions VALUES (2591, 61, '07/09/2010', 5);
INSERT INTO valoracions VALUES (2591, 9, '02/09/2007', 8);
INSERT INTO valoracions VALUES (2592, 40, '03/06/2004', 7);
INSERT INTO valoracions VALUES (2592, 32, '11/12/2003', 7);
INSERT INTO valoracions VALUES (2592, 2, '22/09/2010', 10);
INSERT INTO valoracions VALUES (2592, 26, '14/02/2008', 9);
INSERT INTO valoracions VALUES (2592, 53, '24/09/2002', 3);
INSERT INTO valoracions VALUES (2593, 106, '13/10/2004', 9);
INSERT INTO valoracions VALUES (2593, 40, '12/05/2001', 5);
INSERT INTO valoracions VALUES (2593, 50, '02/07/2001', 9);
INSERT INTO valoracions VALUES (2593, 102, '06/05/2010', 2);
INSERT INTO valoracions VALUES (2594, 53, '14/06/2003', 5);
INSERT INTO valoracions VALUES (2594, 28, '14/12/2009', 5);
INSERT INTO valoracions VALUES (2595, 3, '13/09/2003', 5);
INSERT INTO valoracions VALUES (2595, 114, '18/07/2004', 4);
INSERT INTO valoracions VALUES (2595, 17, '24/06/2006', 7);
INSERT INTO valoracions VALUES (2595, 62, '11/02/2004', 5);
INSERT INTO valoracions VALUES (2595, 81, '04/05/2007', 5);
INSERT INTO valoracions VALUES (2595, 87, '08/07/2010', 3);
INSERT INTO valoracions VALUES (2595, 39, '12/03/2005', 10);
INSERT INTO valoracions VALUES (2595, 116, '02/08/2002', 5);
INSERT INTO valoracions VALUES (2596, 57, '05/09/2004', 6);
INSERT INTO valoracions VALUES (2596, 10, '10/04/2006', 9);
INSERT INTO valoracions VALUES (2596, 100, '13/02/2004', 5);
INSERT INTO valoracions VALUES (2596, 45, '25/10/2001', 7);
INSERT INTO valoracions VALUES (2596, 39, '08/09/2007', 6);
INSERT INTO valoracions VALUES (2596, 72, '06/01/2005', 10);
INSERT INTO valoracions VALUES (2597, 39, '28/08/2008', 9);
INSERT INTO valoracions VALUES (2597, 58, '28/12/2006', 9);
INSERT INTO valoracions VALUES (2597, 52, '16/09/2003', 9);
INSERT INTO valoracions VALUES (2597, 50, '26/03/2003', 5);
INSERT INTO valoracions VALUES (2598, 106, '26/12/2004', 1);
INSERT INTO valoracions VALUES (2598, 106, '15/07/2005', 2);
INSERT INTO valoracions VALUES (2598, 35, '02/03/2003', 8);
INSERT INTO valoracions VALUES (2598, 111, '12/04/2010', 3);
INSERT INTO valoracions VALUES (2599, 109, '26/07/2001', 3);
INSERT INTO valoracions VALUES (2599, 101, '10/04/2009', 2);
INSERT INTO valoracions VALUES (2599, 76, '25/10/2006', 8);
INSERT INTO valoracions VALUES (2600, 74, '19/08/2003', 5);
INSERT INTO valoracions VALUES (2600, 112, '02/09/2001', 8);
INSERT INTO valoracions VALUES (2600, 57, '30/08/2002', 6);
INSERT INTO valoracions VALUES (2601, 34, '03/05/2001', 6);
INSERT INTO valoracions VALUES (2601, 70, '15/09/2009', 7);
INSERT INTO valoracions VALUES (2602, 56, '16/10/2001', 10);
INSERT INTO valoracions VALUES (2602, 96, '27/11/2009', 6);
INSERT INTO valoracions VALUES (2602, 14, '10/04/2004', 8);
INSERT INTO valoracions VALUES (2603, 28, '25/09/2002', 9);
INSERT INTO valoracions VALUES (2603, 9, '27/03/2009', 9);
INSERT INTO valoracions VALUES (2603, 50, '16/11/2002', 7);
INSERT INTO valoracions VALUES (2603, 2, '24/03/2007', 8);
INSERT INTO valoracions VALUES (2604, 57, '26/06/2002', 9);
INSERT INTO valoracions VALUES (2604, 76, '25/10/2002', 2);
INSERT INTO valoracions VALUES (2605, 34, '24/03/2003', 7);
INSERT INTO valoracions VALUES (2606, 41, '19/11/2006', 7);
INSERT INTO valoracions VALUES (2606, 95, '02/09/2010', 4);
INSERT INTO valoracions VALUES (2606, 70, '22/05/2008', 4);
INSERT INTO valoracions VALUES (2606, 42, '11/10/2001', 9);
INSERT INTO valoracions VALUES (2607, 18, '12/08/2010', 7);
INSERT INTO valoracions VALUES (2607, 99, '08/01/2007', 4);
INSERT INTO valoracions VALUES (2607, 52, '05/05/2005', 9);
INSERT INTO valoracions VALUES (2607, 33, '15/10/2007', 6);
INSERT INTO valoracions VALUES (2607, 88, '11/02/2010', 5);
INSERT INTO valoracions VALUES (2608, 94, '23/12/2001', 3);
INSERT INTO valoracions VALUES (2608, 73, '24/01/2008', 6);
INSERT INTO valoracions VALUES (2608, 111, '11/08/2007', 1);
INSERT INTO valoracions VALUES (2608, 6, '01/03/2007', 8);
INSERT INTO valoracions VALUES (2609, 48, '23/06/2010', 9);
INSERT INTO valoracions VALUES (2609, 26, '30/11/2005', 9);
INSERT INTO valoracions VALUES (2609, 99, '19/12/2002', 7);
INSERT INTO valoracions VALUES (2609, 48, '08/03/2009', 7);
INSERT INTO valoracions VALUES (2609, 76, '16/01/2010', 7);
INSERT INTO valoracions VALUES (2610, 13, '30/11/2008', 5);
INSERT INTO valoracions VALUES (2610, 81, '06/08/2003', 8);
INSERT INTO valoracions VALUES (2610, 5, '26/11/2003', 7);
INSERT INTO valoracions VALUES (2610, 55, '17/01/2003', 6);
INSERT INTO valoracions VALUES (2610, 93, '18/02/2008', 8);
INSERT INTO valoracions VALUES (2610, 61, '10/09/2006', 10);
INSERT INTO valoracions VALUES (2610, 88, '31/12/2007', 8);
INSERT INTO valoracions VALUES (2611, 92, '27/08/2006', 6);
INSERT INTO valoracions VALUES (2611, 77, '19/05/2010', 4);
INSERT INTO valoracions VALUES (2611, 34, '29/07/2001', 6);
INSERT INTO valoracions VALUES (2611, 6, '20/10/2006', 7);
INSERT INTO valoracions VALUES (2611, 33, '26/02/2008', 6);
INSERT INTO valoracions VALUES (2611, 6, '11/05/2001', 9);
INSERT INTO valoracions VALUES (2612, 105, '19/01/2005', 3);
INSERT INTO valoracions VALUES (2612, 11, '23/11/2007', 8);
INSERT INTO valoracions VALUES (2612, 97, '29/08/2004', 5);
INSERT INTO valoracions VALUES (2612, 6, '25/05/2001', 6);
INSERT INTO valoracions VALUES (2613, 73, '03/06/2004', 7);
INSERT INTO valoracions VALUES (2614, 21, '30/09/2009', 6);
INSERT INTO valoracions VALUES (2615, 64, '21/08/2005', 4);
INSERT INTO valoracions VALUES (2615, 7, '12/02/2008', 9);
INSERT INTO valoracions VALUES (2616, 6, '30/05/2010', 8);
INSERT INTO valoracions VALUES (2616, 77, '10/06/2010', 4);
INSERT INTO valoracions VALUES (2616, 53, '16/08/2002', 9);
INSERT INTO valoracions VALUES (2617, 40, '12/11/2009', 7);
INSERT INTO valoracions VALUES (2617, 39, '12/06/2002', 7);
INSERT INTO valoracions VALUES (2618, 36, '01/09/2002', 6);
INSERT INTO valoracions VALUES (2618, 8, '18/01/2004', 9);
INSERT INTO valoracions VALUES (2618, 41, '20/12/2001', 10);
INSERT INTO valoracions VALUES (2619, 35, '01/09/2010', 9);
INSERT INTO valoracions VALUES (2619, 64, '30/12/2005', 9);
INSERT INTO valoracions VALUES (2619, 33, '04/08/2002', 7);
INSERT INTO valoracions VALUES (2620, 50, '17/01/2008', 9);
INSERT INTO valoracions VALUES (2620, 46, '05/06/2005', 9);
INSERT INTO valoracions VALUES (2620, 84, '12/04/2010', 6);
INSERT INTO valoracions VALUES (2621, 29, '20/10/2001', 9);
INSERT INTO valoracions VALUES (2621, 86, '05/03/2007', 1);
INSERT INTO valoracions VALUES (2622, 110, '25/03/2009', 0);
INSERT INTO valoracions VALUES (2622, 30, '02/10/2004', 5);
INSERT INTO valoracions VALUES (2622, 87, '16/05/2003', 3);
INSERT INTO valoracions VALUES (2622, 82, '15/04/2008', 10);
INSERT INTO valoracions VALUES (2622, 84, '22/12/2004', 10);
INSERT INTO valoracions VALUES (2623, 51, '26/03/2009', 6);
INSERT INTO valoracions VALUES (2623, 65, '04/09/2001', 5);
INSERT INTO valoracions VALUES (2624, 62, '01/07/2007', 5);
INSERT INTO valoracions VALUES (2624, 101, '09/07/2010', 4);
INSERT INTO valoracions VALUES (2624, 75, '19/08/2003', 8);
INSERT INTO valoracions VALUES (2624, 64, '15/12/2001', 6);
INSERT INTO valoracions VALUES (2624, 59, '14/07/2005', 8);
INSERT INTO valoracions VALUES (2624, 106, '28/07/2005', 4);
INSERT INTO valoracions VALUES (2624, 40, '29/11/2005', 9);
INSERT INTO valoracions VALUES (2625, 6, '06/07/2004', 7);
INSERT INTO valoracions VALUES (2626, 51, '07/10/2004', 6);
INSERT INTO valoracions VALUES (2626, 104, '23/06/2001', 8);
INSERT INTO valoracions VALUES (2626, 101, '22/12/2004', 7);
INSERT INTO valoracions VALUES (2626, 2, '24/04/2009', 6);
INSERT INTO valoracions VALUES (2627, 106, '13/02/2002', 3);
INSERT INTO valoracions VALUES (2627, 61, '22/08/2010', 9);
INSERT INTO valoracions VALUES (2627, 96, '23/06/2006', 2);
INSERT INTO valoracions VALUES (2627, 33, '23/06/2001', 10);
INSERT INTO valoracions VALUES (2628, 54, '30/01/2003', 8);
INSERT INTO valoracions VALUES (2628, 53, '24/02/2006', 4);
INSERT INTO valoracions VALUES (2628, 96, '03/12/2001', 5);
INSERT INTO valoracions VALUES (2628, 100, '20/09/2007', 4);
INSERT INTO valoracions VALUES (2629, 33, '04/08/2002', 4);
INSERT INTO valoracions VALUES (2629, 101, '16/06/2004', 6);
INSERT INTO valoracions VALUES (2629, 90, '24/11/2009', 6);
INSERT INTO valoracions VALUES (2629, 55, '06/03/2009', 5);
INSERT INTO valoracions VALUES (2629, 64, '13/07/2001', 2);
INSERT INTO valoracions VALUES (2629, 46, '22/06/2008', 6);
INSERT INTO valoracions VALUES (2630, 94, '27/04/2010', 10);
INSERT INTO valoracions VALUES (2630, 94, '18/05/2003', 5);
INSERT INTO valoracions VALUES (2630, 113, '21/01/2004', 0);
INSERT INTO valoracions VALUES (2630, 9, '10/12/2008', 9);
INSERT INTO valoracions VALUES (2630, 53, '11/01/2002', 8);
INSERT INTO valoracions VALUES (2630, 5, '03/07/2002', 5);
INSERT INTO valoracions VALUES (2631, 13, '29/08/2008', 7);
INSERT INTO valoracions VALUES (2631, 12, '13/05/2009', 7);
INSERT INTO valoracions VALUES (2631, 2, '13/05/2008', 6);
INSERT INTO valoracions VALUES (2631, 30, '23/10/2008', 6);
INSERT INTO valoracions VALUES (2631, 29, '04/02/2010', 7);
INSERT INTO valoracions VALUES (2632, 90, '09/12/2008', 6);
INSERT INTO valoracions VALUES (2632, 76, '16/12/2004', 2);
INSERT INTO valoracions VALUES (2633, 90, '14/06/2009', 2);
INSERT INTO valoracions VALUES (2633, 108, '07/10/2006', 0);
INSERT INTO valoracions VALUES (2634, 34, '17/12/2005', 4);
INSERT INTO valoracions VALUES (2634, 15, '23/08/2003', 8);
INSERT INTO valoracions VALUES (2634, 45, '04/11/2007', 7);
INSERT INTO valoracions VALUES (2634, 91, '18/05/2008', 6);
INSERT INTO valoracions VALUES (2634, 9, '14/04/2005', 7);
INSERT INTO valoracions VALUES (2635, 86, '15/05/2006', 4);
INSERT INTO valoracions VALUES (2635, 78, '28/10/2001', 6);
INSERT INTO valoracions VALUES (2635, 93, '02/01/2008', 8);
INSERT INTO valoracions VALUES (2635, 105, '12/12/2005', 5);
INSERT INTO valoracions VALUES (2635, 79, '08/08/2008', 5);
INSERT INTO valoracions VALUES (2636, 25, '09/10/2001', 9);
INSERT INTO valoracions VALUES (2636, 69, '18/02/2007', 3);
INSERT INTO valoracions VALUES (2636, 81, '26/03/2007', 2);
INSERT INTO valoracions VALUES (2636, 100, '04/04/2006', 5);
INSERT INTO valoracions VALUES (2636, 16, '11/02/2004', 6);
INSERT INTO valoracions VALUES (2636, 51, '21/07/2005', 6);
INSERT INTO valoracions VALUES (2636, 10, '13/10/2009', 8);
INSERT INTO valoracions VALUES (2636, 111, '18/01/2009', 9);
INSERT INTO valoracions VALUES (2637, 70, '12/01/2010', 4);
INSERT INTO valoracions VALUES (2637, 6, '01/02/2003', 5);
INSERT INTO valoracions VALUES (2637, 39, '14/10/2007', 6);
INSERT INTO valoracions VALUES (2637, 41, '15/07/2005', 9);
INSERT INTO valoracions VALUES (2637, 60, '05/01/2007', 8);
INSERT INTO valoracions VALUES (2638, 9, '23/12/2006', 9);
INSERT INTO valoracions VALUES (2638, 60, '20/02/2002', 6);
INSERT INTO valoracions VALUES (2638, 4, '08/06/2001', 6);
INSERT INTO valoracions VALUES (2639, 107, '27/01/2006', 2);
INSERT INTO valoracions VALUES (2639, 79, '16/04/2006', 5);
INSERT INTO valoracions VALUES (2639, 7, '18/03/2009', 5);
INSERT INTO valoracions VALUES (2639, 69, '01/02/2004', 3);
INSERT INTO valoracions VALUES (2640, 55, '11/04/2008', 10);
INSERT INTO valoracions VALUES (2640, 80, '26/05/2008', 10);
INSERT INTO valoracions VALUES (2641, 69, '16/06/2005', 6);
INSERT INTO valoracions VALUES (2641, 4, '11/08/2008', 6);
INSERT INTO valoracions VALUES (2641, 11, '02/09/2008', 6);
INSERT INTO valoracions VALUES (2642, 73, '30/05/2006', 7);
INSERT INTO valoracions VALUES (2642, 113, '31/07/2005', 10);
INSERT INTO valoracions VALUES (2642, 110, '08/11/2006', 9);
INSERT INTO valoracions VALUES (2642, 18, '23/01/2002', 9);
INSERT INTO valoracions VALUES (2643, 42, '18/05/2003', 9);
INSERT INTO valoracions VALUES (2643, 15, '17/10/2005', 7);
INSERT INTO valoracions VALUES (2643, 8, '19/06/2010', 6);
INSERT INTO valoracions VALUES (2643, 35, '12/02/2009', 6);
INSERT INTO valoracions VALUES (2643, 48, '30/07/2006', 4);
INSERT INTO valoracions VALUES (2643, 92, '11/05/2007', 3);
INSERT INTO valoracions VALUES (2643, 77, '25/07/2007', 8);
INSERT INTO valoracions VALUES (2643, 2, '04/04/2003', 8);
INSERT INTO valoracions VALUES (2643, 113, '23/03/2008', 9);
INSERT INTO valoracions VALUES (2643, 41, '13/03/2003', 8);
INSERT INTO valoracions VALUES (2644, 16, '16/05/2003', 7);
INSERT INTO valoracions VALUES (2644, 93, '11/04/2003', 7);
INSERT INTO valoracions VALUES (2644, 30, '20/10/2003', 7);
INSERT INTO valoracions VALUES (2644, 3, '03/03/2010', 9);
INSERT INTO valoracions VALUES (2645, 80, '14/03/2007', 4);
INSERT INTO valoracions VALUES (2645, 62, '26/04/2010', 9);
INSERT INTO valoracions VALUES (2645, 112, '30/08/2010', 3);
INSERT INTO valoracions VALUES (2645, 44, '04/10/2006', 7);
INSERT INTO valoracions VALUES (2645, 74, '25/04/2004', 8);
INSERT INTO valoracions VALUES (2645, 39, '24/05/2002', 6);
INSERT INTO valoracions VALUES (2646, 89, '30/03/2008', 4);
INSERT INTO valoracions VALUES (2647, 31, '08/07/2003', 7);
INSERT INTO valoracions VALUES (2647, 58, '13/01/2010', 9);
INSERT INTO valoracions VALUES (2647, 112, '26/06/2009', 3);
INSERT INTO valoracions VALUES (2647, 10, '04/06/2009', 8);
INSERT INTO valoracions VALUES (2648, 42, '15/07/2009', 9);
INSERT INTO valoracions VALUES (2648, 9, '04/01/2003', 5);
INSERT INTO valoracions VALUES (2648, 7, '27/10/2010', 6);
INSERT INTO valoracions VALUES (2648, 66, '30/09/2004', 8);
INSERT INTO valoracions VALUES (2649, 90, '08/02/2004', 6);
INSERT INTO valoracions VALUES (2649, 63, '13/01/2004', 8);
INSERT INTO valoracions VALUES (2650, 7, '19/03/2010', 9);
INSERT INTO valoracions VALUES (2651, 8, '19/11/2005', 9);
INSERT INTO valoracions VALUES (2651, 93, '27/12/2005', 10);
INSERT INTO valoracions VALUES (2651, 11, '22/11/2006', 6);
INSERT INTO valoracions VALUES (2652, 50, '28/09/2009', 8);
INSERT INTO valoracions VALUES (2652, 19, '16/08/2007', 8);
INSERT INTO valoracions VALUES (2652, 74, '10/01/2005', 6);
INSERT INTO valoracions VALUES (2653, 94, '02/02/2007', 8);
INSERT INTO valoracions VALUES (2653, 50, '08/08/2009', 6);
INSERT INTO valoracions VALUES (2653, 69, '25/05/2006', 8);
INSERT INTO valoracions VALUES (2653, 51, '09/04/2005', 6);
INSERT INTO valoracions VALUES (2654, 96, '21/02/2002', 4);
INSERT INTO valoracions VALUES (2654, 20, '02/06/2010', 5);
INSERT INTO valoracions VALUES (2654, 51, '23/10/2010', 10);
INSERT INTO valoracions VALUES (2654, 111, '02/10/2001', 9);
INSERT INTO valoracions VALUES (2654, 92, '08/01/2006', 2);
INSERT INTO valoracions VALUES (2654, 81, '12/12/2003', 7);
INSERT INTO valoracions VALUES (2655, 50, '05/11/2009', 4);
INSERT INTO valoracions VALUES (2655, 39, '11/12/2008', 10);
INSERT INTO valoracions VALUES (2655, 111, '30/01/2009', 2);
INSERT INTO valoracions VALUES (2656, 66, '09/02/2009', 10);
INSERT INTO valoracions VALUES (2656, 29, '27/12/2005', 4);
INSERT INTO valoracions VALUES (2656, 68, '26/05/2008', 4);
INSERT INTO valoracions VALUES (2656, 110, '01/06/2001', 10);
INSERT INTO valoracions VALUES (2656, 2, '08/10/2010', 10);
INSERT INTO valoracions VALUES (2656, 56, '19/03/2002', 4);
INSERT INTO valoracions VALUES (2657, 69, '17/07/2001', 9);
INSERT INTO valoracions VALUES (2657, 73, '25/12/2009', 9);
INSERT INTO valoracions VALUES (2657, 20, '29/10/2006', 5);
INSERT INTO valoracions VALUES (2658, 32, '21/05/2004', 6);
INSERT INTO valoracions VALUES (2658, 113, '01/06/2007', 8);
INSERT INTO valoracions VALUES (2658, 39, '07/10/2004', 7);
INSERT INTO valoracions VALUES (2658, 55, '05/08/2004', 9);
INSERT INTO valoracions VALUES (2658, 33, '17/07/2003', 6);
INSERT INTO valoracions VALUES (2659, 77, '18/04/2001', 3);
INSERT INTO valoracions VALUES (2660, 10, '11/11/2004', 6);
INSERT INTO valoracions VALUES (2660, 9, '30/08/2009', 5);
INSERT INTO valoracions VALUES (2660, 62, '26/06/2007', 4);
INSERT INTO valoracions VALUES (2660, 63, '28/04/2002', 9);
INSERT INTO valoracions VALUES (2660, 54, '29/07/2006', 3);
INSERT INTO valoracions VALUES (2660, 30, '25/02/2006', 5);
INSERT INTO valoracions VALUES (2661, 106, '12/05/2010', 10);
INSERT INTO valoracions VALUES (2661, 17, '04/11/2002', 5);
INSERT INTO valoracions VALUES (2661, 25, '18/02/2010', 7);
INSERT INTO valoracions VALUES (2661, 104, '10/12/2001', 4);
INSERT INTO valoracions VALUES (2661, 99, '08/04/2003', 2);
INSERT INTO valoracions VALUES (2662, 53, '24/11/2001', 3);
INSERT INTO valoracions VALUES (2662, 83, '25/10/2006', 3);
INSERT INTO valoracions VALUES (2662, 84, '28/05/2010', 3);
INSERT INTO valoracions VALUES (2662, 26, '01/11/2002', 9);
INSERT INTO valoracions VALUES (2663, 31, '26/10/2003', 6);
INSERT INTO valoracions VALUES (2663, 80, '25/05/2001', 5);
INSERT INTO valoracions VALUES (2663, 78, '02/11/2005', 3);
INSERT INTO valoracions VALUES (2664, 87, '19/10/2010', 8);
INSERT INTO valoracions VALUES (2664, 38, '26/05/2004', 9);
INSERT INTO valoracions VALUES (2664, 76, '12/12/2002', 8);
INSERT INTO valoracions VALUES (2664, 6, '16/04/2007', 9);
INSERT INTO valoracions VALUES (2665, 73, '05/10/2004', 8);
INSERT INTO valoracions VALUES (2665, 7, '09/05/2004', 8);
INSERT INTO valoracions VALUES (2665, 16, '03/02/2007', 4);
INSERT INTO valoracions VALUES (2665, 71, '08/12/2005', 2);
INSERT INTO valoracions VALUES (2666, 2, '13/03/2007', 9);
INSERT INTO valoracions VALUES (2666, 12, '15/06/2005', 7);
INSERT INTO valoracions VALUES (2666, 83, '22/01/2005', 3);
INSERT INTO valoracions VALUES (2667, 63, '29/09/2001', 3);
INSERT INTO valoracions VALUES (2667, 102, '25/02/2002', 1);
INSERT INTO valoracions VALUES (2667, 6, '18/12/2005', 6);
INSERT INTO valoracions VALUES (2667, 22, '18/07/2002', 8);
INSERT INTO valoracions VALUES (2667, 107, '06/01/2010', 7);
INSERT INTO valoracions VALUES (2668, 83, '10/07/2007', 3);
INSERT INTO valoracions VALUES (2668, 91, '02/04/2005', 9);
INSERT INTO valoracions VALUES (2668, 97, '07/04/2002', 6);
INSERT INTO valoracions VALUES (2668, 24, '10/08/2008', 5);
INSERT INTO valoracions VALUES (2668, 90, '17/05/2009', 10);
INSERT INTO valoracions VALUES (2669, 14, '14/06/2004', 8);
INSERT INTO valoracions VALUES (2669, 106, '30/11/2006', 0);
INSERT INTO valoracions VALUES (2669, 88, '07/10/2004', 5);
INSERT INTO valoracions VALUES (2670, 88, '20/05/2002', 9);
INSERT INTO valoracions VALUES (2670, 8, '04/07/2001', 7);
INSERT INTO valoracions VALUES (2670, 93, '12/03/2006', 3);
INSERT INTO valoracions VALUES (2670, 58, '11/09/2009', 6);
INSERT INTO valoracions VALUES (2671, 41, '01/05/2003', 9);
INSERT INTO valoracions VALUES (2671, 62, '25/02/2003', 9);
INSERT INTO valoracions VALUES (2671, 85, '14/11/2008', 9);
INSERT INTO valoracions VALUES (2671, 39, '08/08/2009', 4);
INSERT INTO valoracions VALUES (2671, 116, '20/11/2001', 9);
INSERT INTO valoracions VALUES (2672, 47, '23/08/2003', 5);
INSERT INTO valoracions VALUES (2672, 6, '26/10/2007', 7);
INSERT INTO valoracions VALUES (2672, 46, '04/10/2009', 5);
INSERT INTO valoracions VALUES (2673, 109, '09/11/2003', 0);
INSERT INTO valoracions VALUES (2673, 37, '21/04/2002', 9);
INSERT INTO valoracions VALUES (2673, 65, '19/07/2007', 2);
INSERT INTO valoracions VALUES (2673, 104, '13/12/2009', 2);
INSERT INTO valoracions VALUES (2673, 83, '11/01/2004', 5);
INSERT INTO valoracions VALUES (2674, 25, '26/03/2002', 4);
INSERT INTO valoracions VALUES (2674, 98, '15/06/2002', 2);
INSERT INTO valoracions VALUES (2674, 76, '22/10/2010', 7);
INSERT INTO valoracions VALUES (2675, 76, '14/10/2009', 9);
INSERT INTO valoracions VALUES (2675, 44, '28/03/2003', 9);
INSERT INTO valoracions VALUES (2676, 12, '02/04/2001', 8);
INSERT INTO valoracions VALUES (2676, 38, '20/11/2001', 5);
INSERT INTO valoracions VALUES (2676, 78, '28/06/2008', 3);
INSERT INTO valoracions VALUES (2676, 2, '17/08/2010', 8);
INSERT INTO valoracions VALUES (2676, 86, '17/03/2003', 9);
INSERT INTO valoracions VALUES (2677, 7, '13/08/2003', 8);
INSERT INTO valoracions VALUES (2677, 39, '10/07/2004', 5);
INSERT INTO valoracions VALUES (2677, 85, '30/08/2006', 4);
INSERT INTO valoracions VALUES (2677, 97, '24/12/2002', 7);
INSERT INTO valoracions VALUES (2678, 52, '28/06/2010', 4);
INSERT INTO valoracions VALUES (2678, 75, '09/03/2010', 5);
INSERT INTO valoracions VALUES (2678, 75, '16/08/2009', 8);
INSERT INTO valoracions VALUES (2678, 106, '24/10/2010', 6);
INSERT INTO valoracions VALUES (2678, 111, '15/02/2005', 10);
INSERT INTO valoracions VALUES (2678, 16, '10/06/2003', 8);
INSERT INTO valoracions VALUES (2678, 18, '07/09/2007', 8);
INSERT INTO valoracions VALUES (2679, 73, '17/10/2004', 2);
INSERT INTO valoracions VALUES (2680, 35, '20/08/2001', 9);
INSERT INTO valoracions VALUES (2680, 61, '14/09/2009', 8);
INSERT INTO valoracions VALUES (2680, 70, '02/11/2004', 9);
INSERT INTO valoracions VALUES (2680, 32, '17/02/2007', 8);
INSERT INTO valoracions VALUES (2680, 116, '19/10/2001', 3);
INSERT INTO valoracions VALUES (2680, 33, '03/05/2001', 10);
INSERT INTO valoracions VALUES (2681, 79, '22/12/2009', 9);
INSERT INTO valoracions VALUES (2682, 98, '12/01/2002', 10);
INSERT INTO valoracions VALUES (2682, 71, '11/05/2008', 8);
INSERT INTO valoracions VALUES (2682, 35, '03/04/2010', 9);
INSERT INTO valoracions VALUES (2682, 51, '05/04/2010', 6);
INSERT INTO valoracions VALUES (2682, 115, '15/12/2007', 4);
INSERT INTO valoracions VALUES (2683, 38, '02/05/2007', 9);
INSERT INTO valoracions VALUES (2683, 20, '09/03/2003', 6);
INSERT INTO valoracions VALUES (2683, 5, '19/06/2010', 7);
INSERT INTO valoracions VALUES (2683, 22, '11/06/2007', 9);
INSERT INTO valoracions VALUES (2684, 93, '25/03/2009', 8);
INSERT INTO valoracions VALUES (2684, 77, '22/03/2010', 8);
INSERT INTO valoracions VALUES (2684, 83, '15/08/2004', 4);
INSERT INTO valoracions VALUES (2685, 39, '01/06/2005', 6);
INSERT INTO valoracions VALUES (2685, 59, '09/02/2004', 9);
INSERT INTO valoracions VALUES (2686, 79, '22/11/2006', 3);
INSERT INTO valoracions VALUES (2686, 91, '04/05/2001', 3);
INSERT INTO valoracions VALUES (2686, 99, '08/12/2005', 5);
INSERT INTO valoracions VALUES (2686, 107, '13/09/2002', 5);
INSERT INTO valoracions VALUES (2686, 62, '21/12/2002', 2);
INSERT INTO valoracions VALUES (2686, 30, '26/06/2003', 6);
INSERT INTO valoracions VALUES (2686, 21, '30/12/2002', 5);
INSERT INTO valoracions VALUES (2686, 71, '07/04/2009', 8);
INSERT INTO valoracions VALUES (2687, 47, '09/01/2008', 9);
INSERT INTO valoracions VALUES (2687, 113, '04/10/2010', 10);
INSERT INTO valoracions VALUES (2687, 73, '04/09/2010', 9);
INSERT INTO valoracions VALUES (2687, 73, '11/08/2010', 4);
INSERT INTO valoracions VALUES (2687, 112, '26/09/2010', 9);
INSERT INTO valoracions VALUES (2688, 46, '29/05/2008', 7);
INSERT INTO valoracions VALUES (2688, 58, '24/04/2005', 9);
INSERT INTO valoracions VALUES (2688, 41, '03/03/2010', 3);
INSERT INTO valoracions VALUES (2688, 65, '29/06/2007', 2);
INSERT INTO valoracions VALUES (2688, 26, '24/04/2001', 5);
INSERT INTO valoracions VALUES (2689, 42, '12/05/2004', 9);
INSERT INTO valoracions VALUES (2689, 8, '13/05/2004', 7);
INSERT INTO valoracions VALUES (2689, 35, '16/05/2005', 8);
INSERT INTO valoracions VALUES (2689, 95, '24/06/2010', 5);
INSERT INTO valoracions VALUES (2689, 3, '20/02/2005', 8);
INSERT INTO valoracions VALUES (2689, 34, '17/06/2010', 4);
INSERT INTO valoracions VALUES (2690, 42, '17/02/2009', 7);
INSERT INTO valoracions VALUES (2690, 58, '31/07/2010', 10);
INSERT INTO valoracions VALUES (2690, 83, '25/05/2009', 4);
INSERT INTO valoracions VALUES (2690, 71, '16/01/2004', 4);
INSERT INTO valoracions VALUES (2691, 76, '27/12/2008', 8);
INSERT INTO valoracions VALUES (2691, 31, '19/06/2003', 6);
INSERT INTO valoracions VALUES (2691, 39, '29/01/2002', 6);
INSERT INTO valoracions VALUES (2691, 48, '24/08/2003', 4);
INSERT INTO valoracions VALUES (2691, 42, '23/10/2010', 6);
INSERT INTO valoracions VALUES (2691, 23, '21/02/2007', 5);
INSERT INTO valoracions VALUES (2692, 98, '08/11/2006', 2);
INSERT INTO valoracions VALUES (2692, 25, '04/08/2008', 6);
INSERT INTO valoracions VALUES (2692, 57, '06/05/2001', 5);
INSERT INTO valoracions VALUES (2692, 113, '27/03/2008', 8);
INSERT INTO valoracions VALUES (2693, 31, '08/12/2009', 6);
INSERT INTO valoracions VALUES (2693, 106, '13/07/2007', 6);
INSERT INTO valoracions VALUES (2693, 105, '14/06/2009', 8);
INSERT INTO valoracions VALUES (2693, 92, '19/12/2002', 6);
INSERT INTO valoracions VALUES (2693, 66, '16/05/2004', 9);
INSERT INTO valoracions VALUES (2693, 65, '22/01/2008', 3);
INSERT INTO valoracions VALUES (2694, 100, '04/06/2008', 5);
INSERT INTO valoracions VALUES (2694, 50, '27/07/2001', 10);
INSERT INTO valoracions VALUES (2694, 97, '04/05/2003', 3);
INSERT INTO valoracions VALUES (2694, 111, '12/05/2004', 5);
INSERT INTO valoracions VALUES (2695, 112, '15/08/2008', 0);
INSERT INTO valoracions VALUES (2695, 51, '23/05/2002', 3);
INSERT INTO valoracions VALUES (2695, 77, '15/05/2006', 8);
INSERT INTO valoracions VALUES (2695, 84, '29/10/2009', 8);
INSERT INTO valoracions VALUES (2695, 76, '13/07/2002', 7);
INSERT INTO valoracions VALUES (2695, 96, '03/07/2009', 9);
INSERT INTO valoracions VALUES (2695, 11, '06/08/2005', 7);
INSERT INTO valoracions VALUES (2695, 84, '18/04/2001', 6);
INSERT INTO valoracions VALUES (2696, 71, '26/02/2005', 8);
INSERT INTO valoracions VALUES (2696, 58, '17/09/2006', 9);
INSERT INTO valoracions VALUES (2696, 106, '08/12/2001', 0);
INSERT INTO valoracions VALUES (2696, 88, '29/03/2005', 6);
INSERT INTO valoracions VALUES (2697, 47, '21/09/2004', 4);
INSERT INTO valoracions VALUES (2698, 9, '20/11/2004', 8);
INSERT INTO valoracions VALUES (2698, 1, '17/01/2003', 8);
INSERT INTO valoracions VALUES (2699, 21, '31/12/2001', 6);
INSERT INTO valoracions VALUES (2699, 22, '26/04/2001', 5);
INSERT INTO valoracions VALUES (2699, 67, '19/04/2009', 8);
INSERT INTO valoracions VALUES (2699, 103, '08/03/2005', 3);
INSERT INTO valoracions VALUES (2699, 58, '29/06/2010', 8);
INSERT INTO valoracions VALUES (2700, 20, '17/10/2003', 9);
INSERT INTO valoracions VALUES (2700, 68, '26/03/2009', 6);
INSERT INTO valoracions VALUES (2700, 26, '23/04/2009', 5);
INSERT INTO valoracions VALUES (2700, 5, '08/09/2010', 6);
INSERT INTO valoracions VALUES (2700, 43, '12/08/2007', 5);
INSERT INTO valoracions VALUES (2701, 67, '22/04/2007', 9);
INSERT INTO valoracions VALUES (2701, 33, '05/01/2007', 4);
INSERT INTO valoracions VALUES (2701, 92, '07/03/2010', 7);
INSERT INTO valoracions VALUES (2701, 1, '06/04/2001', 9);
INSERT INTO valoracions VALUES (2701, 24, '01/02/2004', 5);
INSERT INTO valoracions VALUES (2702, 72, '24/04/2009', 7);
INSERT INTO valoracions VALUES (2702, 100, '20/09/2003', 5);
INSERT INTO valoracions VALUES (2702, 98, '20/11/2008', 4);
INSERT INTO valoracions VALUES (2702, 98, '07/07/2008', 8);
INSERT INTO valoracions VALUES (2702, 11, '13/08/2005', 10);
INSERT INTO valoracions VALUES (2702, 28, '01/09/2009', 5);
INSERT INTO valoracions VALUES (2702, 110, '27/09/2004', 1);
INSERT INTO valoracions VALUES (2703, 7, '18/06/2001', 7);
INSERT INTO valoracions VALUES (2703, 68, '10/12/2005', 6);
INSERT INTO valoracions VALUES (2704, 8, '02/01/2006', 7);
INSERT INTO valoracions VALUES (2704, 29, '06/11/2008', 9);
INSERT INTO valoracions VALUES (2704, 107, '18/11/2003', 7);
INSERT INTO valoracions VALUES (2705, 21, '16/03/2008', 9);
INSERT INTO valoracions VALUES (2705, 96, '23/03/2003', 7);
INSERT INTO valoracions VALUES (2705, 4, '27/10/2002', 6);
INSERT INTO valoracions VALUES (2705, 2, '17/12/2006', 7);
INSERT INTO valoracions VALUES (2705, 24, '19/08/2009', 5);
INSERT INTO valoracions VALUES (2706, 58, '01/08/2005', 9);
INSERT INTO valoracions VALUES (2706, 16, '27/12/2009', 7);
INSERT INTO valoracions VALUES (2706, 33, '09/12/2004', 5);
INSERT INTO valoracions VALUES (2706, 34, '08/10/2006', 9);
INSERT INTO valoracions VALUES (2707, 30, '15/05/2008', 8);
INSERT INTO valoracions VALUES (2707, 75, '08/05/2001', 9);
INSERT INTO valoracions VALUES (2707, 36, '14/12/2001', 9);
INSERT INTO valoracions VALUES (2708, 97, '12/04/2005', 5);
INSERT INTO valoracions VALUES (2708, 49, '17/03/2009', 6);
INSERT INTO valoracions VALUES (2708, 18, '09/02/2009', 4);
INSERT INTO valoracions VALUES (2708, 94, '17/01/2003', 9);
INSERT INTO valoracions VALUES (2709, 36, '28/11/2001', 7);
INSERT INTO valoracions VALUES (2709, 73, '05/08/2008', 10);
INSERT INTO valoracions VALUES (2710, 2, '17/10/2006', 6);
INSERT INTO valoracions VALUES (2711, 1, '07/05/2003', 7);
INSERT INTO valoracions VALUES (2711, 12, '30/10/2004', 6);
INSERT INTO valoracions VALUES (2711, 18, '24/06/2002', 7);
INSERT INTO valoracions VALUES (2711, 21, '20/06/2009', 6);
INSERT INTO valoracions VALUES (2711, 25, '21/12/2004', 4);
INSERT INTO valoracions VALUES (2712, 10, '15/02/2004', 7);
INSERT INTO valoracions VALUES (2712, 114, '28/06/2005', 8);
INSERT INTO valoracions VALUES (2713, 77, '17/03/2006', 3);
INSERT INTO valoracions VALUES (2713, 110, '04/11/2005', 9);
INSERT INTO valoracions VALUES (2713, 39, '31/03/2008', 9);
INSERT INTO valoracions VALUES (2713, 53, '30/01/2008', 6);
INSERT INTO valoracions VALUES (2713, 47, '19/05/2007', 4);
INSERT INTO valoracions VALUES (2713, 107, '15/02/2005', 1);
INSERT INTO valoracions VALUES (2713, 76, '02/09/2010', 3);
INSERT INTO valoracions VALUES (2714, 68, '10/11/2004', 9);
INSERT INTO valoracions VALUES (2714, 95, '03/09/2006', 5);
INSERT INTO valoracions VALUES (2714, 76, '28/06/2006', 7);
INSERT INTO valoracions VALUES (2714, 56, '20/10/2001', 6);
INSERT INTO valoracions VALUES (2714, 85, '19/10/2002', 1);
INSERT INTO valoracions VALUES (2714, 116, '26/11/2008', 2);
INSERT INTO valoracions VALUES (2714, 26, '27/03/2009', 4);
INSERT INTO valoracions VALUES (2715, 15, '03/05/2004', 6);
INSERT INTO valoracions VALUES (2715, 81, '09/03/2003', 4);
INSERT INTO valoracions VALUES (2715, 54, '12/03/2006', 5);
INSERT INTO valoracions VALUES (2715, 86, '02/08/2002', 7);
INSERT INTO valoracions VALUES (2715, 112, '30/08/2010', 3);
INSERT INTO valoracions VALUES (2715, 75, '21/09/2008', 9);
INSERT INTO valoracions VALUES (2716, 27, '29/03/2002', 5);
INSERT INTO valoracions VALUES (2716, 107, '01/02/2009', 7);
INSERT INTO valoracions VALUES (2716, 26, '14/11/2003', 9);
INSERT INTO valoracions VALUES (2717, 102, '01/02/2002', 2);
INSERT INTO valoracions VALUES (2717, 18, '24/12/2004', 7);
INSERT INTO valoracions VALUES (2717, 44, '11/07/2002', 6);
INSERT INTO valoracions VALUES (2717, 35, '19/01/2003', 9);
INSERT INTO valoracions VALUES (2718, 74, '22/09/2005', 7);
INSERT INTO valoracions VALUES (2718, 70, '29/06/2001', 4);
INSERT INTO valoracions VALUES (2718, 105, '17/01/2003', 6);
INSERT INTO valoracions VALUES (2718, 9, '07/06/2006', 10);
INSERT INTO valoracions VALUES (2718, 28, '10/09/2008', 9);
INSERT INTO valoracions VALUES (2719, 43, '15/04/2006', 5);
INSERT INTO valoracions VALUES (2719, 25, '09/04/2007', 9);
INSERT INTO valoracions VALUES (2719, 17, '25/01/2009', 6);
INSERT INTO valoracions VALUES (2720, 65, '05/11/2004', 8);
INSERT INTO valoracions VALUES (2720, 20, '24/05/2008', 7);
INSERT INTO valoracions VALUES (2720, 56, '04/02/2004', 8);
INSERT INTO valoracions VALUES (2721, 97, '20/01/2003', 6);
INSERT INTO valoracions VALUES (2721, 70, '20/06/2001', 3);
INSERT INTO valoracions VALUES (2721, 52, '05/12/2006', 6);
INSERT INTO valoracions VALUES (2722, 110, '19/11/2002', 7);
INSERT INTO valoracions VALUES (2722, 40, '25/01/2002', 5);
INSERT INTO valoracions VALUES (2722, 44, '25/08/2006', 7);
INSERT INTO valoracions VALUES (2722, 108, '22/12/2001', 9);
INSERT INTO valoracions VALUES (2722, 74, '20/04/2004', 10);
INSERT INTO valoracions VALUES (2722, 109, '17/12/2005', 5);
INSERT INTO valoracions VALUES (2723, 83, '25/04/2003', 5);
INSERT INTO valoracions VALUES (2723, 22, '10/05/2006', 10);
INSERT INTO valoracions VALUES (2723, 98, '20/07/2005', 6);
INSERT INTO valoracions VALUES (2723, 80, '24/02/2008', 6);
INSERT INTO valoracions VALUES (2724, 101, '07/11/2008', 4);
INSERT INTO valoracions VALUES (2724, 16, '19/10/2004', 6);
INSERT INTO valoracions VALUES (2724, 85, '27/07/2002', 8);
INSERT INTO valoracions VALUES (2724, 31, '24/05/2010', 10);
INSERT INTO valoracions VALUES (2725, 115, '16/11/2004', 8);
INSERT INTO valoracions VALUES (2725, 49, '23/08/2005', 10);
INSERT INTO valoracions VALUES (2725, 22, '29/05/2010', 5);
INSERT INTO valoracions VALUES (2725, 24, '21/07/2010', 5);
INSERT INTO valoracions VALUES (2725, 57, '26/11/2003', 3);
INSERT INTO valoracions VALUES (2726, 63, '09/11/2007', 8);
INSERT INTO valoracions VALUES (2726, 3, '06/05/2002', 7);
INSERT INTO valoracions VALUES (2727, 51, '31/10/2004', 5);
INSERT INTO valoracions VALUES (2727, 36, '17/07/2003', 8);
INSERT INTO valoracions VALUES (2727, 4, '24/03/2002', 6);
INSERT INTO valoracions VALUES (2728, 109, '05/10/2001', 9);
INSERT INTO valoracions VALUES (2728, 35, '16/09/2002', 5);
INSERT INTO valoracions VALUES (2728, 58, '20/06/2010', 5);
INSERT INTO valoracions VALUES (2728, 103, '13/09/2009', 2);
INSERT INTO valoracions VALUES (2728, 89, '27/03/2009', 8);
INSERT INTO valoracions VALUES (2728, 71, '28/08/2009', 4);
INSERT INTO valoracions VALUES (2728, 97, '19/10/2007', 7);
INSERT INTO valoracions VALUES (2729, 71, '27/05/2007', 4);
INSERT INTO valoracions VALUES (2730, 10, '06/04/2005', 8);
INSERT INTO valoracions VALUES (2730, 63, '30/12/2009', 6);
INSERT INTO valoracions VALUES (2731, 115, '20/10/2007', 0);
INSERT INTO valoracions VALUES (2731, 91, '25/04/2006', 9);
INSERT INTO valoracions VALUES (2731, 85, '24/03/2006', 5);
INSERT INTO valoracions VALUES (2731, 66, '03/08/2010', 5);
INSERT INTO valoracions VALUES (2731, 33, '16/03/2007', 6);
INSERT INTO valoracions VALUES (2732, 37, '10/09/2009', 8);
INSERT INTO valoracions VALUES (2732, 87, '17/04/2008', 7);
INSERT INTO valoracions VALUES (2732, 96, '29/03/2009', 2);
INSERT INTO valoracions VALUES (2732, 83, '27/05/2008', 1);
INSERT INTO valoracions VALUES (2732, 35, '02/08/2009', 8);
INSERT INTO valoracions VALUES (2732, 81, '23/03/2002', 7);
INSERT INTO valoracions VALUES (2732, 32, '03/08/2005', 6);
INSERT INTO valoracions VALUES (2733, 55, '24/10/2009', 3);
INSERT INTO valoracions VALUES (2733, 86, '29/05/2003', 7);
INSERT INTO valoracions VALUES (2733, 33, '26/06/2002', 7);
INSERT INTO valoracions VALUES (2733, 87, '18/02/2002', 9);
INSERT INTO valoracions VALUES (2733, 106, '22/04/2009', 4);
INSERT INTO valoracions VALUES (2733, 110, '11/09/2008', 2);
INSERT INTO valoracions VALUES (2733, 24, '12/01/2010', 6);
INSERT INTO valoracions VALUES (2733, 22, '18/05/2003', 7);
INSERT INTO valoracions VALUES (2734, 110, '05/04/2003', 4);
INSERT INTO valoracions VALUES (2734, 66, '19/08/2007', 4);
INSERT INTO valoracions VALUES (2734, 111, '30/04/2009', 4);
INSERT INTO valoracions VALUES (2734, 40, '19/09/2001', 8);
INSERT INTO valoracions VALUES (2735, 68, '01/08/2010', 4);
INSERT INTO valoracions VALUES (2735, 66, '06/07/2007', 5);
INSERT INTO valoracions VALUES (2735, 48, '10/03/2007', 3);
INSERT INTO valoracions VALUES (2735, 92, '04/09/2006', 9);
INSERT INTO valoracions VALUES (2735, 97, '16/12/2007', 3);
INSERT INTO valoracions VALUES (2735, 112, '09/02/2002', 6);
INSERT INTO valoracions VALUES (2735, 110, '28/03/2006', 9);
INSERT INTO valoracions VALUES (2735, 110, '04/04/2008', 6);
INSERT INTO valoracions VALUES (2736, 45, '17/10/2007', 8);
INSERT INTO valoracions VALUES (2736, 104, '10/10/2006', 5);
INSERT INTO valoracions VALUES (2736, 4, '03/01/2002', 6);
INSERT INTO valoracions VALUES (2736, 63, '20/06/2004', 5);
INSERT INTO valoracions VALUES (2736, 105, '29/07/2008', 2);
INSERT INTO valoracions VALUES (2736, 79, '11/05/2006', 9);
INSERT INTO valoracions VALUES (2736, 45, '11/10/2003', 9);
INSERT INTO valoracions VALUES (2737, 56, '24/07/2006', 10);
INSERT INTO valoracions VALUES (2737, 99, '06/04/2003', 4);
INSERT INTO valoracions VALUES (2737, 64, '24/07/2009', 7);
INSERT INTO valoracions VALUES (2737, 4, '04/08/2008', 6);
INSERT INTO valoracions VALUES (2737, 56, '19/07/2009', 6);
INSERT INTO valoracions VALUES (2738, 62, '02/01/2010', 7);
INSERT INTO valoracions VALUES (2738, 19, '26/06/2001', 5);
INSERT INTO valoracions VALUES (2738, 72, '11/09/2004', 4);
INSERT INTO valoracions VALUES (2739, 101, '28/06/2007', 3);
INSERT INTO valoracions VALUES (2739, 114, '20/09/2001', 0);
INSERT INTO valoracions VALUES (2739, 29, '16/04/2009', 9);
INSERT INTO valoracions VALUES (2739, 68, '21/12/2008', 8);
INSERT INTO valoracions VALUES (2740, 52, '24/08/2002', 5);
INSERT INTO valoracions VALUES (2740, 104, '14/06/2010', 2);
INSERT INTO valoracions VALUES (2740, 66, '23/10/2004', 7);
INSERT INTO valoracions VALUES (2740, 22, '29/09/2005', 6);
INSERT INTO valoracions VALUES (2740, 35, '06/09/2008', 8);
INSERT INTO valoracions VALUES (2740, 28, '18/10/2009', 6);
INSERT INTO valoracions VALUES (2741, 115, '04/06/2004', 2);
INSERT INTO valoracions VALUES (2741, 5, '24/09/2010', 5);
INSERT INTO valoracions VALUES (2741, 108, '16/07/2008', 10);
INSERT INTO valoracions VALUES (2741, 99, '29/11/2002', 7);
INSERT INTO valoracions VALUES (2741, 41, '17/06/2005', 9);
INSERT INTO valoracions VALUES (2741, 55, '19/02/2010', 9);
INSERT INTO valoracions VALUES (2742, 63, '14/10/2008', 6);
INSERT INTO valoracions VALUES (2742, 52, '05/10/2001', 9);
INSERT INTO valoracions VALUES (2742, 90, '13/12/2007', 7);
INSERT INTO valoracions VALUES (2742, 12, '08/04/2002', 6);
INSERT INTO valoracions VALUES (2742, 81, '10/04/2001', 7);
INSERT INTO valoracions VALUES (2743, 101, '14/09/2002', 2);
INSERT INTO valoracions VALUES (2743, 68, '10/02/2004', 7);
INSERT INTO valoracions VALUES (2743, 63, '21/02/2009', 3);
INSERT INTO valoracions VALUES (2743, 89, '01/03/2004', 7);
INSERT INTO valoracions VALUES (2744, 108, '03/08/2008', 2);
INSERT INTO valoracions VALUES (2744, 59, '26/12/2008', 5);
INSERT INTO valoracions VALUES (2744, 107, '13/08/2008', 2);
INSERT INTO valoracions VALUES (2744, 46, '17/12/2007', 9);
INSERT INTO valoracions VALUES (2745, 110, '28/02/2004', 3);
INSERT INTO valoracions VALUES (2745, 45, '23/07/2010', 9);
INSERT INTO valoracions VALUES (2745, 60, '01/07/2004', 9);
INSERT INTO valoracions VALUES (2745, 69, '22/06/2002', 4);
INSERT INTO valoracions VALUES (2746, 106, '12/10/2002', 1);
INSERT INTO valoracions VALUES (2746, 45, '19/10/2009', 3);
INSERT INTO valoracions VALUES (2746, 96, '18/11/2007', 7);
INSERT INTO valoracions VALUES (2746, 38, '30/06/2008', 3);
INSERT INTO valoracions VALUES (2747, 18, '31/01/2008', 8);
INSERT INTO valoracions VALUES (2747, 18, '14/10/2002', 5);
INSERT INTO valoracions VALUES (2747, 8, '25/03/2006', 7);
INSERT INTO valoracions VALUES (2748, 44, '21/03/2010', 6);
INSERT INTO valoracions VALUES (2748, 113, '11/08/2004', 4);
INSERT INTO valoracions VALUES (2748, 40, '04/03/2008', 7);
INSERT INTO valoracions VALUES (2749, 16, '27/06/2008', 6);
INSERT INTO valoracions VALUES (2749, 91, '21/12/2002', 4);
INSERT INTO valoracions VALUES (2749, 36, '23/03/2010', 5);
INSERT INTO valoracions VALUES (2749, 8, '28/08/2002', 8);
INSERT INTO valoracions VALUES (2749, 21, '05/02/2005', 5);
INSERT INTO valoracions VALUES (2750, 18, '17/09/2003', 5);
INSERT INTO valoracions VALUES (2750, 102, '27/06/2004', 4);
INSERT INTO valoracions VALUES (2751, 95, '03/07/2003', 10);
INSERT INTO valoracions VALUES (2752, 93, '08/06/2006', 6);
INSERT INTO valoracions VALUES (2752, 70, '16/03/2003', 2);
INSERT INTO valoracions VALUES (2752, 70, '28/01/2008', 4);
INSERT INTO valoracions VALUES (2753, 43, '01/02/2005', 9);
INSERT INTO valoracions VALUES (2754, 74, '11/01/2006', 8);
INSERT INTO valoracions VALUES (2754, 15, '04/10/2009', 9);
INSERT INTO valoracions VALUES (2754, 58, '20/12/2003', 3);
INSERT INTO valoracions VALUES (2755, 22, '14/10/2007', 4);
INSERT INTO valoracions VALUES (2755, 55, '19/07/2002', 4);
INSERT INTO valoracions VALUES (2756, 106, '03/03/2006', 5);
INSERT INTO valoracions VALUES (2756, 91, '12/08/2005', 2);
INSERT INTO valoracions VALUES (2756, 35, '25/09/2009', 9);
INSERT INTO valoracions VALUES (2756, 48, '15/07/2002', 7);
INSERT INTO valoracions VALUES (2757, 4, '23/05/2009', 6);
INSERT INTO valoracions VALUES (2757, 19, '04/08/2010', 5);
INSERT INTO valoracions VALUES (2757, 58, '27/05/2001', 9);
INSERT INTO valoracions VALUES (2758, 86, '09/07/2010', 5);
INSERT INTO valoracions VALUES (2758, 53, '02/11/2003', 4);
INSERT INTO valoracions VALUES (2758, 12, '06/07/2005', 7);
INSERT INTO valoracions VALUES (2758, 73, '18/12/2008', 3);
INSERT INTO valoracions VALUES (2758, 3, '14/09/2004', 9);
INSERT INTO valoracions VALUES (2758, 57, '21/09/2002', 9);
INSERT INTO valoracions VALUES (2758, 44, '08/04/2007', 5);
INSERT INTO valoracions VALUES (2758, 15, '18/08/2001', 8);
INSERT INTO valoracions VALUES (2759, 58, '04/11/2002', 9);
INSERT INTO valoracions VALUES (2759, 37, '19/09/2005', 9);
INSERT INTO valoracions VALUES (2759, 98, '18/07/2007', 7);
INSERT INTO valoracions VALUES (2760, 30, '20/04/2001', 4);
INSERT INTO valoracions VALUES (2760, 36, '28/05/2001', 6);
INSERT INTO valoracions VALUES (2760, 91, '25/06/2008', 6);
INSERT INTO valoracions VALUES (2760, 41, '14/03/2010', 7);
INSERT INTO valoracions VALUES (2760, 26, '21/11/2009', 6);
INSERT INTO valoracions VALUES (2760, 29, '26/07/2002', 7);
INSERT INTO valoracions VALUES (2760, 71, '25/02/2004', 5);
INSERT INTO valoracions VALUES (2760, 110, '12/10/2008', 9);
INSERT INTO valoracions VALUES (2761, 13, '11/11/2001', 5);
INSERT INTO valoracions VALUES (2761, 22, '21/06/2003', 6);
INSERT INTO valoracions VALUES (2761, 83, '07/05/2008', 4);
INSERT INTO valoracions VALUES (2762, 42, '28/11/2005', 9);
INSERT INTO valoracions VALUES (2762, 87, '21/12/2005', 2);
INSERT INTO valoracions VALUES (2762, 49, '23/11/2005', 6);
INSERT INTO valoracions VALUES (2762, 14, '23/08/2001', 5);
INSERT INTO valoracions VALUES (2762, 28, '08/04/2005', 4);
INSERT INTO valoracions VALUES (2762, 91, '29/04/2003', 9);
INSERT INTO valoracions VALUES (2763, 108, '07/05/2004', 2);
INSERT INTO valoracions VALUES (2763, 77, '11/04/2008', 7);
INSERT INTO valoracions VALUES (2763, 28, '20/10/2001', 5);
INSERT INTO valoracions VALUES (2763, 53, '15/05/2002', 8);
INSERT INTO valoracions VALUES (2763, 35, '12/05/2007', 5);
INSERT INTO valoracions VALUES (2763, 37, '14/12/2008', 8);
INSERT INTO valoracions VALUES (2763, 84, '11/01/2007', 2);
INSERT INTO valoracions VALUES (2763, 47, '03/03/2007', 4);
INSERT INTO valoracions VALUES (2763, 115, '26/02/2003', 7);
INSERT INTO valoracions VALUES (2764, 87, '09/09/2010', 5);
INSERT INTO valoracions VALUES (2764, 98, '06/05/2002', 5);
INSERT INTO valoracions VALUES (2765, 106, '29/07/2010', 8);
INSERT INTO valoracions VALUES (2765, 46, '30/06/2006', 10);
INSERT INTO valoracions VALUES (2765, 21, '08/11/2003', 8);
INSERT INTO valoracions VALUES (2765, 62, '03/07/2008', 3);
INSERT INTO valoracions VALUES (2766, 65, '22/03/2010', 8);
INSERT INTO valoracions VALUES (2766, 115, '12/01/2005', 7);
INSERT INTO valoracions VALUES (2766, 82, '28/10/2010', 5);
INSERT INTO valoracions VALUES (2766, 67, '06/01/2004', 8);
INSERT INTO valoracions VALUES (2766, 103, '21/12/2005', 2);
INSERT INTO valoracions VALUES (2767, 77, '20/08/2002', 2);
INSERT INTO valoracions VALUES (2767, 61, '14/08/2009', 3);
INSERT INTO valoracions VALUES (2767, 12, '02/09/2007', 7);
INSERT INTO valoracions VALUES (2768, 114, '07/02/2008', 4);
INSERT INTO valoracions VALUES (2768, 116, '27/01/2004', 4);
INSERT INTO valoracions VALUES (2768, 77, '08/02/2005', 8);
INSERT INTO valoracions VALUES (2768, 4, '23/01/2003', 9);
INSERT INTO valoracions VALUES (2768, 9, '01/09/2008', 6);
INSERT INTO valoracions VALUES (2770, 19, '13/02/2009', 5);
INSERT INTO valoracions VALUES (2771, 22, '25/11/2004', 5);
INSERT INTO valoracions VALUES (2771, 116, '28/06/2008', 4);
INSERT INTO valoracions VALUES (2771, 92, '11/06/2001', 2);
INSERT INTO valoracions VALUES (2772, 8, '02/02/2004', 5);
INSERT INTO valoracions VALUES (2772, 82, '03/08/2003', 7);
INSERT INTO valoracions VALUES (2772, 58, '01/03/2009', 5);
INSERT INTO valoracions VALUES (2772, 90, '30/12/2003', 6);
INSERT INTO valoracions VALUES (2772, 28, '19/07/2006', 6);
INSERT INTO valoracions VALUES (2773, 103, '06/02/2007', 3);
INSERT INTO valoracions VALUES (2773, 83, '26/11/2007', 6);
INSERT INTO valoracions VALUES (2773, 77, '15/07/2002', 5);
INSERT INTO valoracions VALUES (2773, 78, '25/06/2003', 5);
INSERT INTO valoracions VALUES (2774, 12, '17/02/2005', 7);
INSERT INTO valoracions VALUES (2774, 42, '11/05/2002', 6);
INSERT INTO valoracions VALUES (2775, 36, '25/12/2002', 4);
INSERT INTO valoracions VALUES (2775, 41, '02/07/2006', 8);
INSERT INTO valoracions VALUES (2775, 85, '26/06/2001', 3);
INSERT INTO valoracions VALUES (2775, 71, '27/02/2010', 9);
INSERT INTO valoracions VALUES (2776, 2, '08/10/2005', 6);
INSERT INTO valoracions VALUES (2776, 70, '18/12/2009', 2);
INSERT INTO valoracions VALUES (2776, 73, '25/10/2006', 5);
INSERT INTO valoracions VALUES (2776, 110, '07/07/2006', 3);
INSERT INTO valoracions VALUES (2776, 86, '21/11/2008', 5);
INSERT INTO valoracions VALUES (2776, 68, '13/04/2004', 2);
INSERT INTO valoracions VALUES (2777, 45, '17/04/2004', 7);
INSERT INTO valoracions VALUES (2777, 108, '26/07/2001', 7);
INSERT INTO valoracions VALUES (2777, 104, '01/05/2002', 5);
INSERT INTO valoracions VALUES (2777, 68, '15/12/2007', 2);
INSERT INTO valoracions VALUES (2777, 27, '04/05/2002', 6);
INSERT INTO valoracions VALUES (2778, 47, '07/06/2002', 7);
INSERT INTO valoracions VALUES (2778, 82, '24/11/2003', 2);
INSERT INTO valoracions VALUES (2778, 99, '23/12/2001', 2);
INSERT INTO valoracions VALUES (2778, 62, '31/01/2002', 5);
INSERT INTO valoracions VALUES (2779, 109, '30/09/2007', 4);
INSERT INTO valoracions VALUES (2779, 112, '19/10/2009', 6);
INSERT INTO valoracions VALUES (2779, 50, '20/02/2002', 4);
INSERT INTO valoracions VALUES (2779, 108, '06/05/2001', 0);
INSERT INTO valoracions VALUES (2780, 22, '01/09/2001', 9);
INSERT INTO valoracions VALUES (2781, 21, '15/10/2010', 8);
INSERT INTO valoracions VALUES (2781, 4, '28/04/2009', 5);
INSERT INTO valoracions VALUES (2781, 114, '18/01/2003', 6);
INSERT INTO valoracions VALUES (2781, 12, '08/11/2005', 5);
INSERT INTO valoracions VALUES (2781, 1, '29/07/2006', 8);
INSERT INTO valoracions VALUES (2782, 42, '24/05/2006', 5);
INSERT INTO valoracions VALUES (2782, 42, '05/11/2005', 3);
INSERT INTO valoracions VALUES (2782, 5, '24/12/2006', 6);
INSERT INTO valoracions VALUES (2782, 102, '29/12/2005', 10);
INSERT INTO valoracions VALUES (2783, 103, '21/12/2003', 2);
INSERT INTO valoracions VALUES (2783, 79, '28/11/2006', 8);
INSERT INTO valoracions VALUES (2783, 29, '21/06/2001', 10);
INSERT INTO valoracions VALUES (2784, 53, '13/09/2010', 6);
INSERT INTO valoracions VALUES (2784, 36, '07/05/2002', 7);
INSERT INTO valoracions VALUES (2784, 110, '24/09/2002', 5);
INSERT INTO valoracions VALUES (2784, 108, '03/03/2005', 5);
INSERT INTO valoracions VALUES (2784, 111, '17/01/2003', 10);
INSERT INTO valoracions VALUES (2784, 108, '27/10/2004', 1);
INSERT INTO valoracions VALUES (2785, 15, '06/07/2002', 4);
INSERT INTO valoracions VALUES (2785, 23, '02/02/2004', 5);
INSERT INTO valoracions VALUES (2785, 26, '18/01/2006', 8);
INSERT INTO valoracions VALUES (2785, 3, '01/07/2002', 7);
INSERT INTO valoracions VALUES (2786, 67, '22/10/2002', 7);
INSERT INTO valoracions VALUES (2786, 104, '28/11/2005', 2);
INSERT INTO valoracions VALUES (2786, 35, '18/08/2003', 7);
INSERT INTO valoracions VALUES (2786, 39, '04/07/2009', 6);
INSERT INTO valoracions VALUES (2786, 56, '03/06/2010', 5);
INSERT INTO valoracions VALUES (2786, 67, '25/09/2009', 6);
INSERT INTO valoracions VALUES (2787, 76, '25/03/2005', 9);
INSERT INTO valoracions VALUES (2787, 13, '17/03/2005', 7);
INSERT INTO valoracions VALUES (2787, 66, '20/02/2005', 8);
INSERT INTO valoracions VALUES (2787, 16, '01/03/2003', 6);
INSERT INTO valoracions VALUES (2787, 69, '26/07/2003', 7);
INSERT INTO valoracions VALUES (2788, 106, '03/10/2003', 10);
INSERT INTO valoracions VALUES (2788, 66, '18/12/2004', 4);
INSERT INTO valoracions VALUES (2788, 55, '13/11/2006', 5);
INSERT INTO valoracions VALUES (2789, 20, '26/11/2003', 7);
INSERT INTO valoracions VALUES (2790, 38, '28/12/2008', 7);
INSERT INTO valoracions VALUES (2790, 20, '29/07/2004', 9);
INSERT INTO valoracions VALUES (2790, 103, '21/09/2002', 3);
INSERT INTO valoracions VALUES (2791, 27, '01/07/2002', 5);
INSERT INTO valoracions VALUES (2792, 82, '10/05/2005', 9);
INSERT INTO valoracions VALUES (2792, 113, '17/10/2006', 6);
INSERT INTO valoracions VALUES (2793, 98, '20/04/2009', 8);
INSERT INTO valoracions VALUES (2793, 59, '03/12/2009', 8);
INSERT INTO valoracions VALUES (2793, 39, '27/06/2008', 9);
INSERT INTO valoracions VALUES (2793, 31, '13/09/2009', 7);
INSERT INTO valoracions VALUES (2795, 105, '23/11/2007', 4);
INSERT INTO valoracions VALUES (2795, 41, '19/03/2007', 3);
INSERT INTO valoracions VALUES (2795, 68, '28/03/2004', 7);
INSERT INTO valoracions VALUES (2795, 71, '09/08/2004', 5);
INSERT INTO valoracions VALUES (2795, 33, '11/11/2001', 6);
INSERT INTO valoracions VALUES (2796, 31, '06/05/2005', 6);
INSERT INTO valoracions VALUES (2796, 85, '09/09/2002', 3);
INSERT INTO valoracions VALUES (2796, 62, '10/09/2008', 5);
INSERT INTO valoracions VALUES (2796, 23, '08/03/2002', 5);
INSERT INTO valoracions VALUES (2797, 96, '12/09/2007', 3);
INSERT INTO valoracions VALUES (2797, 59, '30/09/2006', 9);
INSERT INTO valoracions VALUES (2797, 41, '19/07/2010', 6);
INSERT INTO valoracions VALUES (2797, 12, '30/08/2005', 10);
INSERT INTO valoracions VALUES (2798, 109, '29/04/2005', 8);
INSERT INTO valoracions VALUES (2798, 67, '07/01/2010', 6);
INSERT INTO valoracions VALUES (2798, 51, '13/09/2006', 5);
INSERT INTO valoracions VALUES (2799, 25, '08/07/2009', 10);
INSERT INTO valoracions VALUES (2799, 46, '27/08/2004', 8);
INSERT INTO valoracions VALUES (2799, 82, '28/04/2002', 8);
INSERT INTO valoracions VALUES (2799, 33, '17/05/2006', 4);
INSERT INTO valoracions VALUES (2799, 112, '05/01/2008', 4);
INSERT INTO valoracions VALUES (2799, 65, '22/04/2006', 7);
INSERT INTO valoracions VALUES (2800, 79, '07/03/2003', 2);
INSERT INTO valoracions VALUES (2800, 18, '05/08/2003', 9);
INSERT INTO valoracions VALUES (2800, 103, '04/06/2005', 3);
INSERT INTO valoracions VALUES (2800, 100, '11/11/2002', 5);
INSERT INTO valoracions VALUES (2801, 114, '21/04/2001', 3);
INSERT INTO valoracions VALUES (2801, 75, '09/09/2010', 3);
INSERT INTO valoracions VALUES (2801, 87, '05/04/2002', 2);
INSERT INTO valoracions VALUES (2801, 22, '30/07/2009', 4);
INSERT INTO valoracions VALUES (2801, 77, '12/03/2004', 6);
INSERT INTO valoracions VALUES (2801, 59, '20/01/2003', 9);
INSERT INTO valoracions VALUES (2801, 81, '07/04/2008', 7);
INSERT INTO valoracions VALUES (2802, 32, '16/08/2005', 4);
INSERT INTO valoracions VALUES (2802, 47, '29/09/2004', 4);
INSERT INTO valoracions VALUES (2802, 9, '27/11/2008', 9);
INSERT INTO valoracions VALUES (2802, 92, '10/09/2010', 3);
INSERT INTO valoracions VALUES (2803, 39, '12/12/2003', 4);
INSERT INTO valoracions VALUES (2803, 75, '31/01/2002', 4);
INSERT INTO valoracions VALUES (2804, 56, '25/08/2008', 9);
INSERT INTO valoracions VALUES (2804, 96, '09/04/2001', 7);
INSERT INTO valoracions VALUES (2804, 7, '26/08/2009', 9);
INSERT INTO valoracions VALUES (2804, 76, '28/08/2006', 8);
INSERT INTO valoracions VALUES (2804, 95, '23/08/2010', 10);
INSERT INTO valoracions VALUES (2804, 35, '22/07/2002', 7);
INSERT INTO valoracions VALUES (2805, 92, '18/01/2007', 7);
INSERT INTO valoracions VALUES (2805, 32, '16/05/2006', 9);
INSERT INTO valoracions VALUES (2805, 33, '25/06/2009', 6);
INSERT INTO valoracions VALUES (2805, 36, '03/04/2006', 4);
INSERT INTO valoracions VALUES (2805, 74, '11/02/2006', 3);
INSERT INTO valoracions VALUES (2805, 29, '02/06/2007', 5);
INSERT INTO valoracions VALUES (2806, 1, '08/04/2008', 8);
INSERT INTO valoracions VALUES (2806, 67, '04/11/2003', 10);
INSERT INTO valoracions VALUES (2806, 100, '12/08/2008', 9);
INSERT INTO valoracions VALUES (2807, 8, '10/05/2005', 7);
INSERT INTO valoracions VALUES (2807, 57, '12/10/2010', 3);
INSERT INTO valoracions VALUES (2807, 27, '24/05/2004', 7);
INSERT INTO valoracions VALUES (2807, 56, '01/07/2004', 8);
INSERT INTO valoracions VALUES (2807, 14, '03/02/2007', 5);
INSERT INTO valoracions VALUES (2808, 64, '23/09/2004', 6);
INSERT INTO valoracions VALUES (2808, 80, '06/11/2002', 7);
INSERT INTO valoracions VALUES (2808, 80, '17/07/2004', 3);
INSERT INTO valoracions VALUES (2809, 40, '20/11/2006', 8);
INSERT INTO valoracions VALUES (2809, 28, '10/09/2009', 6);
INSERT INTO valoracions VALUES (2809, 31, '11/05/2010', 9);
INSERT INTO valoracions VALUES (2810, 28, '06/12/2001', 10);
INSERT INTO valoracions VALUES (2810, 73, '03/06/2006', 9);
INSERT INTO valoracions VALUES (2810, 74, '18/02/2003', 6);
INSERT INTO valoracions VALUES (2810, 72, '25/11/2007', 7);
INSERT INTO valoracions VALUES (2810, 2, '08/04/2001', 7);
INSERT INTO valoracions VALUES (2811, 47, '29/06/2002', 5);
INSERT INTO valoracions VALUES (2811, 92, '10/06/2006', 9);
INSERT INTO valoracions VALUES (2811, 57, '07/04/2005', 7);
INSERT INTO valoracions VALUES (2811, 26, '12/12/2007', 5);
INSERT INTO valoracions VALUES (2812, 28, '27/10/2004', 10);
INSERT INTO valoracions VALUES (2812, 57, '02/03/2004', 6);
INSERT INTO valoracions VALUES (2812, 5, '10/10/2003', 5);
INSERT INTO valoracions VALUES (2812, 32, '12/11/2005', 4);
INSERT INTO valoracions VALUES (2813, 102, '25/04/2006', 7);
INSERT INTO valoracions VALUES (2813, 90, '29/03/2008', 2);
INSERT INTO valoracions VALUES (2813, 83, '08/12/2003', 1);
INSERT INTO valoracions VALUES (2814, 43, '13/04/2006', 7);
INSERT INTO valoracions VALUES (2814, 77, '25/04/2003', 3);
INSERT INTO valoracions VALUES (2814, 116, '22/01/2005', 1);
INSERT INTO valoracions VALUES (2814, 48, '29/07/2001', 4);
INSERT INTO valoracions VALUES (2814, 83, '06/02/2009', 5);
INSERT INTO valoracions VALUES (2815, 59, '26/10/2010', 6);
INSERT INTO valoracions VALUES (2815, 59, '01/10/2010', 7);
INSERT INTO valoracions VALUES (2815, 34, '25/10/2003', 5);
INSERT INTO valoracions VALUES (2815, 114, '24/07/2008', 9);
INSERT INTO valoracions VALUES (2815, 47, '10/09/2001', 4);
INSERT INTO valoracions VALUES (2815, 87, '27/03/2007', 5);
INSERT INTO valoracions VALUES (2816, 74, '18/12/2004', 9);
INSERT INTO valoracions VALUES (2816, 50, '25/03/2009', 9);
INSERT INTO valoracions VALUES (2816, 110, '04/08/2007', 0);
INSERT INTO valoracions VALUES (2816, 52, '10/01/2006', 8);
INSERT INTO valoracions VALUES (2816, 103, '18/10/2002', 5);
INSERT INTO valoracions VALUES (2816, 79, '02/03/2005', 4);
INSERT INTO valoracions VALUES (2817, 40, '08/05/2006', 9);
INSERT INTO valoracions VALUES (2817, 101, '31/03/2006', 6);
INSERT INTO valoracions VALUES (2817, 75, '31/10/2002', 2);
INSERT INTO valoracions VALUES (2817, 50, '26/05/2002', 7);
INSERT INTO valoracions VALUES (2817, 38, '23/04/2007', 3);
INSERT INTO valoracions VALUES (2817, 39, '01/02/2009', 7);
INSERT INTO valoracions VALUES (2817, 53, '02/11/2003', 4);
INSERT INTO valoracions VALUES (2818, 106, '07/06/2009', 2);
INSERT INTO valoracions VALUES (2818, 81, '23/07/2003', 8);
INSERT INTO valoracions VALUES (2818, 48, '24/04/2006', 9);
INSERT INTO valoracions VALUES (2818, 49, '29/05/2006', 6);
INSERT INTO valoracions VALUES (2818, 96, '01/01/2002', 6);
INSERT INTO valoracions VALUES (2818, 19, '30/11/2003', 8);
INSERT INTO valoracions VALUES (2820, 61, '10/12/2001', 9);
INSERT INTO valoracions VALUES (2820, 74, '21/10/2001', 7);
INSERT INTO valoracions VALUES (2820, 97, '03/02/2009', 5);
INSERT INTO valoracions VALUES (2820, 29, '20/01/2002', 7);
INSERT INTO valoracions VALUES (2820, 4, '31/05/2007', 7);
INSERT INTO valoracions VALUES (2821, 79, '06/07/2010', 5);
INSERT INTO valoracions VALUES (2821, 49, '01/03/2008', 4);
INSERT INTO valoracions VALUES (2821, 76, '07/08/2003', 4);
INSERT INTO valoracions VALUES (2821, 20, '22/02/2010', 7);
INSERT INTO valoracions VALUES (2822, 97, '05/12/2001', 1);
INSERT INTO valoracions VALUES (2822, 85, '19/02/2008', 2);
INSERT INTO valoracions VALUES (2822, 97, '17/05/2009', 5);
INSERT INTO valoracions VALUES (2822, 20, '18/04/2006', 7);
INSERT INTO valoracions VALUES (2822, 115, '18/01/2006', 5);
INSERT INTO valoracions VALUES (2823, 62, '18/11/2004', 4);
INSERT INTO valoracions VALUES (2823, 11, '15/08/2005', 7);
INSERT INTO valoracions VALUES (2823, 102, '09/05/2010', 7);
INSERT INTO valoracions VALUES (2823, 13, '25/08/2009', 9);
INSERT INTO valoracions VALUES (2824, 12, '28/07/2001', 7);
INSERT INTO valoracions VALUES (2824, 20, '04/11/2009', 5);
INSERT INTO valoracions VALUES (2824, 9, '17/05/2008', 9);
INSERT INTO valoracions VALUES (2825, 101, '25/10/2007', 9);
INSERT INTO valoracions VALUES (2825, 36, '08/09/2007', 6);
INSERT INTO valoracions VALUES (2825, 78, '03/03/2003', 3);
INSERT INTO valoracions VALUES (2825, 105, '15/04/2006', 9);
INSERT INTO valoracions VALUES (2825, 43, '07/07/2009', 3);
INSERT INTO valoracions VALUES (2825, 58, '09/12/2001', 6);
INSERT INTO valoracions VALUES (2825, 41, '24/02/2008', 7);
INSERT INTO valoracions VALUES (2826, 73, '03/08/2008', 7);
INSERT INTO valoracions VALUES (2826, 55, '02/07/2002', 9);
INSERT INTO valoracions VALUES (2826, 6, '09/07/2006', 9);
INSERT INTO valoracions VALUES (2827, 5, '23/09/2006', 7);
INSERT INTO valoracions VALUES (2827, 106, '26/07/2009', 3);
INSERT INTO valoracions VALUES (2827, 17, '28/02/2008', 9);
INSERT INTO valoracions VALUES (2828, 41, '18/03/2009', 3);
INSERT INTO valoracions VALUES (2828, 106, '02/05/2004', 8);
INSERT INTO valoracions VALUES (2828, 19, '27/11/2003', 8);
INSERT INTO valoracions VALUES (2828, 54, '20/04/2004', 6);
INSERT INTO valoracions VALUES (2828, 60, '08/09/2002', 5);
INSERT INTO valoracions VALUES (2829, 16, '16/09/2002', 9);
INSERT INTO valoracions VALUES (2829, 66, '04/04/2005', 8);
INSERT INTO valoracions VALUES (2829, 27, '01/08/2010', 6);
INSERT INTO valoracions VALUES (2830, 101, '16/08/2005', 5);
INSERT INTO valoracions VALUES (2831, 98, '16/06/2010', 8);
INSERT INTO valoracions VALUES (2831, 13, '14/03/2007', 8);
INSERT INTO valoracions VALUES (2831, 52, '01/09/2010', 9);
INSERT INTO valoracions VALUES (2832, 100, '17/06/2009', 8);
INSERT INTO valoracions VALUES (2832, 85, '31/08/2004', 7);
INSERT INTO valoracions VALUES (2832, 113, '19/12/2005', 2);
INSERT INTO valoracions VALUES (2832, 107, '24/04/2009', 8);
INSERT INTO valoracions VALUES (2832, 76, '12/03/2006', 7);
INSERT INTO valoracions VALUES (2833, 97, '14/10/2001', 5);
INSERT INTO valoracions VALUES (2833, 94, '14/05/2005', 8);
INSERT INTO valoracions VALUES (2833, 32, '23/01/2003', 5);
INSERT INTO valoracions VALUES (2834, 86, '23/07/2007', 7);
INSERT INTO valoracions VALUES (2834, 3, '24/05/2002', 8);
INSERT INTO valoracions VALUES (2834, 76, '10/03/2010', 8);
INSERT INTO valoracions VALUES (2835, 115, '24/06/2002', 8);
INSERT INTO valoracions VALUES (2835, 29, '06/01/2002', 4);
INSERT INTO valoracions VALUES (2835, 27, '14/06/2008', 6);
INSERT INTO valoracions VALUES (2835, 66, '24/10/2004', 6);
INSERT INTO valoracions VALUES (2835, 90, '18/04/2006', 8);
INSERT INTO valoracions VALUES (2835, 9, '27/10/2009', 9);
INSERT INTO valoracions VALUES (2835, 11, '16/04/2009', 8);
INSERT INTO valoracions VALUES (2836, 39, '21/06/2002', 9);
INSERT INTO valoracions VALUES (2836, 86, '18/06/2009', 9);
INSERT INTO valoracions VALUES (2836, 90, '04/01/2002', 9);
INSERT INTO valoracions VALUES (2836, 63, '30/03/2002', 2);
INSERT INTO valoracions VALUES (2836, 96, '26/08/2009', 3);
INSERT INTO valoracions VALUES (2837, 2, '08/04/2007', 9);
INSERT INTO valoracions VALUES (2837, 109, '12/02/2005', 2);
INSERT INTO valoracions VALUES (2837, 105, '08/04/2008', 3);
INSERT INTO valoracions VALUES (2837, 95, '14/06/2004', 7);
INSERT INTO valoracions VALUES (2837, 29, '01/09/2002', 6);
INSERT INTO valoracions VALUES (2837, 52, '07/09/2002', 5);
INSERT INTO valoracions VALUES (2837, 64, '15/01/2002', 8);
INSERT INTO valoracions VALUES (2837, 75, '16/05/2001', 3);
INSERT INTO valoracions VALUES (2838, 104, '30/07/2002', 4);
INSERT INTO valoracions VALUES (2838, 91, '08/04/2006', 3);
INSERT INTO valoracions VALUES (2838, 60, '03/02/2007', 8);
INSERT INTO valoracions VALUES (2839, 109, '01/09/2003', 5);
INSERT INTO valoracions VALUES (2839, 27, '21/10/2005', 9);
INSERT INTO valoracions VALUES (2839, 102, '12/10/2010', 10);
INSERT INTO valoracions VALUES (2839, 50, '10/02/2008', 9);
INSERT INTO valoracions VALUES (2840, 97, '31/08/2009', 8);
INSERT INTO valoracions VALUES (2840, 53, '12/09/2001', 9);
INSERT INTO valoracions VALUES (2840, 55, '02/09/2001', 8);
INSERT INTO valoracions VALUES (2840, 17, '20/09/2006', 7);
INSERT INTO valoracions VALUES (2840, 98, '13/07/2005', 9);
INSERT INTO valoracions VALUES (2840, 37, '21/08/2001', 5);
INSERT INTO valoracions VALUES (2841, 52, '06/01/2003', 9);
INSERT INTO valoracions VALUES (2841, 116, '28/11/2003', 1);
INSERT INTO valoracions VALUES (2841, 2, '04/06/2001', 7);
INSERT INTO valoracions VALUES (2842, 99, '24/05/2003', 5);
INSERT INTO valoracions VALUES (2842, 12, '15/08/2001', 6);
INSERT INTO valoracions VALUES (2842, 106, '24/06/2005', 2);
INSERT INTO valoracions VALUES (2842, 61, '30/08/2002', 4);
INSERT INTO valoracions VALUES (2842, 43, '17/08/2006', 7);
INSERT INTO valoracions VALUES (2843, 15, '09/05/2006', 4);
INSERT INTO valoracions VALUES (2843, 105, '31/01/2007', 8);
INSERT INTO valoracions VALUES (2843, 86, '22/06/2009', 7);
INSERT INTO valoracions VALUES (2843, 73, '12/12/2008', 3);
INSERT INTO valoracions VALUES (2843, 41, '14/06/2004', 5);
INSERT INTO valoracions VALUES (2844, 114, '25/09/2006', 5);
INSERT INTO valoracions VALUES (2844, 48, '23/02/2002', 4);
INSERT INTO valoracions VALUES (2844, 84, '10/04/2004', 3);
INSERT INTO valoracions VALUES (2844, 37, '29/07/2005', 3);
INSERT INTO valoracions VALUES (2844, 79, '09/02/2006', 6);
INSERT INTO valoracions VALUES (2844, 30, '20/05/2008', 10);
INSERT INTO valoracions VALUES (2844, 112, '23/07/2007', 2);
INSERT INTO valoracions VALUES (2845, 95, '14/02/2002', 2);
INSERT INTO valoracions VALUES (2845, 34, '13/10/2006', 7);
INSERT INTO valoracions VALUES (2845, 6, '27/12/2007', 8);
INSERT INTO valoracions VALUES (2845, 115, '30/01/2002', 1);
INSERT INTO valoracions VALUES (2845, 50, '06/03/2008', 5);
INSERT INTO valoracions VALUES (2845, 11, '10/11/2009', 5);
INSERT INTO valoracions VALUES (2845, 47, '24/03/2005', 4);
INSERT INTO valoracions VALUES (2846, 109, '28/09/2002', 3);
INSERT INTO valoracions VALUES (2846, 83, '21/01/2009', 7);
INSERT INTO valoracions VALUES (2847, 16, '16/04/2003', 6);
INSERT INTO valoracions VALUES (2847, 102, '10/06/2007', 3);
INSERT INTO valoracions VALUES (2847, 26, '24/08/2010', 8);
INSERT INTO valoracions VALUES (2847, 76, '23/12/2007', 8);
INSERT INTO valoracions VALUES (2848, 100, '13/01/2003', 4);
INSERT INTO valoracions VALUES (2848, 21, '29/01/2003', 8);
INSERT INTO valoracions VALUES (2849, 32, '16/08/2003', 8);
INSERT INTO valoracions VALUES (2850, 22, '28/09/2003', 6);
INSERT INTO valoracions VALUES (2850, 31, '08/08/2006', 7);
INSERT INTO valoracions VALUES (2850, 92, '10/08/2007', 5);
INSERT INTO valoracions VALUES (2850, 100, '03/10/2002', 7);
INSERT INTO valoracions VALUES (2850, 12, '16/10/2005', 9);
INSERT INTO valoracions VALUES (2851, 6, '27/06/2010', 7);
INSERT INTO valoracions VALUES (2851, 53, '12/07/2009', 4);
INSERT INTO valoracions VALUES (2851, 95, '31/07/2007', 4);
INSERT INTO valoracions VALUES (2851, 45, '20/07/2005', 7);
INSERT INTO valoracions VALUES (2852, 82, '17/03/2007', 6);
INSERT INTO valoracions VALUES (2852, 13, '11/07/2007', 9);
INSERT INTO valoracions VALUES (2852, 101, '26/04/2001', 7);
INSERT INTO valoracions VALUES (2853, 97, '21/11/2006', 8);
INSERT INTO valoracions VALUES (2853, 51, '12/09/2001', 6);
INSERT INTO valoracions VALUES (2853, 22, '28/06/2007', 5);
INSERT INTO valoracions VALUES (2854, 65, '10/05/2008', 10);
INSERT INTO valoracions VALUES (2854, 38, '18/07/2010', 9);
INSERT INTO valoracions VALUES (2854, 19, '30/11/2008', 8);
INSERT INTO valoracions VALUES (2854, 3, '14/08/2005', 7);
INSERT INTO valoracions VALUES (2855, 69, '30/09/2005', 10);
INSERT INTO valoracions VALUES (2855, 45, '30/09/2008', 8);
INSERT INTO valoracions VALUES (2855, 114, '26/12/2004', 8);
INSERT INTO valoracions VALUES (2855, 23, '19/04/2009', 6);
INSERT INTO valoracions VALUES (2855, 11, '08/08/2008', 5);
INSERT INTO valoracions VALUES (2856, 95, '31/12/2006', 4);
INSERT INTO valoracions VALUES (2856, 65, '31/03/2002', 4);
INSERT INTO valoracions VALUES (2856, 70, '17/11/2003', 8);
INSERT INTO valoracions VALUES (2856, 19, '04/06/2006', 7);
INSERT INTO valoracions VALUES (2856, 48, '20/02/2002', 7);
INSERT INTO valoracions VALUES (2857, 103, '24/07/2009', 4);
INSERT INTO valoracions VALUES (2857, 95, '22/03/2006', 6);
INSERT INTO valoracions VALUES (2857, 17, '23/05/2004', 7);
INSERT INTO valoracions VALUES (2857, 55, '01/03/2003', 4);
INSERT INTO valoracions VALUES (2858, 83, '13/03/2002', 10);
INSERT INTO valoracions VALUES (2859, 84, '15/03/2005', 7);
INSERT INTO valoracions VALUES (2859, 89, '05/08/2001', 2);
INSERT INTO valoracions VALUES (2859, 84, '15/09/2010', 6);
INSERT INTO valoracions VALUES (2860, 102, '19/05/2006', 10);
INSERT INTO valoracions VALUES (2860, 91, '04/10/2005', 9);
INSERT INTO valoracions VALUES (2860, 9, '05/10/2010', 6);
INSERT INTO valoracions VALUES (2860, 96, '10/04/2004', 8);
INSERT INTO valoracions VALUES (2860, 14, '31/07/2008', 10);
INSERT INTO valoracions VALUES (2860, 93, '20/05/2010', 6);
INSERT INTO valoracions VALUES (2861, 9, '27/10/2003', 5);
INSERT INTO valoracions VALUES (2862, 14, '10/09/2008', 5);
INSERT INTO valoracions VALUES (2862, 24, '18/08/2007', 4);
INSERT INTO valoracions VALUES (2862, 47, '19/10/2003', 4);
INSERT INTO valoracions VALUES (2863, 61, '15/03/2006', 6);
INSERT INTO valoracions VALUES (2863, 109, '03/02/2009', 6);
INSERT INTO valoracions VALUES (2863, 109, '31/08/2008', 8);
INSERT INTO valoracions VALUES (2864, 68, '21/03/2002', 4);
INSERT INTO valoracions VALUES (2864, 1, '27/02/2002', 9);
INSERT INTO valoracions VALUES (2864, 84, '07/05/2007', 8);
INSERT INTO valoracions VALUES (2864, 1, '17/05/2009', 9);
INSERT INTO valoracions VALUES (2865, 13, '09/08/2003', 9);
INSERT INTO valoracions VALUES (2865, 81, '07/10/2009', 8);
INSERT INTO valoracions VALUES (2866, 101, '16/01/2006', 4);
INSERT INTO valoracions VALUES (2866, 99, '22/02/2008', 7);
INSERT INTO valoracions VALUES (2866, 22, '28/12/2006', 9);
INSERT INTO valoracions VALUES (2866, 54, '27/01/2003', 3);
INSERT INTO valoracions VALUES (2866, 102, '13/06/2008', 9);
INSERT INTO valoracions VALUES (2866, 55, '29/12/2008', 3);
INSERT INTO valoracions VALUES (2866, 64, '30/03/2010', 3);
INSERT INTO valoracions VALUES (2867, 23, '28/07/2008', 10);
INSERT INTO valoracions VALUES (2867, 108, '06/11/2003', 1);
INSERT INTO valoracions VALUES (2867, 8, '13/11/2003', 9);
INSERT INTO valoracions VALUES (2868, 112, '01/03/2003', 1);
INSERT INTO valoracions VALUES (2868, 86, '13/09/2001', 7);
INSERT INTO valoracions VALUES (2869, 62, '22/01/2008', 8);
INSERT INTO valoracions VALUES (2869, 41, '31/08/2001', 5);
INSERT INTO valoracions VALUES (2869, 6, '27/06/2005', 8);
INSERT INTO valoracions VALUES (2869, 10, '14/02/2007', 7);
INSERT INTO valoracions VALUES (2869, 44, '11/12/2003', 8);
INSERT INTO valoracions VALUES (2869, 22, '31/07/2001', 5);
INSERT INTO valoracions VALUES (2870, 59, '15/09/2001', 7);
INSERT INTO valoracions VALUES (2871, 13, '05/11/2005', 6);
INSERT INTO valoracions VALUES (2871, 54, '09/02/2002', 8);
INSERT INTO valoracions VALUES (2872, 94, '25/02/2003', 10);
INSERT INTO valoracions VALUES (2872, 111, '11/02/2005', 9);
INSERT INTO valoracions VALUES (2872, 41, '18/01/2005', 4);
INSERT INTO valoracions VALUES (2872, 101, '03/08/2003', 7);
INSERT INTO valoracions VALUES (2872, 20, '31/07/2010', 5);
INSERT INTO valoracions VALUES (2873, 80, '30/05/2004', 7);
INSERT INTO valoracions VALUES (2873, 51, '07/12/2009', 9);
INSERT INTO valoracions VALUES (2873, 7, '05/02/2007', 7);
INSERT INTO valoracions VALUES (2873, 18, '18/05/2001', 6);
INSERT INTO valoracions VALUES (2873, 74, '15/05/2008', 4);
INSERT INTO valoracions VALUES (2874, 106, '26/08/2002', 8);
INSERT INTO valoracions VALUES (2874, 112, '06/07/2009', 5);
INSERT INTO valoracions VALUES (2874, 45, '02/02/2010', 9);
INSERT INTO valoracions VALUES (2874, 101, '11/04/2007', 8);
INSERT INTO valoracions VALUES (2874, 78, '27/02/2002', 9);
INSERT INTO valoracions VALUES (2874, 87, '18/09/2005', 7);
INSERT INTO valoracions VALUES (2875, 93, '02/06/2003', 7);
INSERT INTO valoracions VALUES (2875, 10, '24/06/2007', 8);
INSERT INTO valoracions VALUES (2875, 3, '30/05/2007', 6);
INSERT INTO valoracions VALUES (2875, 35, '30/08/2005', 8);
INSERT INTO valoracions VALUES (2875, 44, '28/02/2009', 5);
INSERT INTO valoracions VALUES (2875, 19, '01/09/2003', 7);
INSERT INTO valoracions VALUES (2875, 2, '17/04/2005', 9);
INSERT INTO valoracions VALUES (2876, 12, '25/10/2006', 6);
INSERT INTO valoracions VALUES (2876, 107, '03/10/2010', 1);
INSERT INTO valoracions VALUES (2876, 66, '12/03/2006', 10);
INSERT INTO valoracions VALUES (2876, 87, '14/09/2006', 5);
INSERT INTO valoracions VALUES (2876, 100, '28/01/2005', 4);
INSERT INTO valoracions VALUES (2876, 55, '29/04/2002', 7);
INSERT INTO valoracions VALUES (2876, 41, '11/09/2008', 9);
INSERT INTO valoracions VALUES (2877, 31, '10/12/2005', 5);
INSERT INTO valoracions VALUES (2877, 29, '25/10/2003', 5);
INSERT INTO valoracions VALUES (2878, 7, '03/06/2007', 7);
INSERT INTO valoracions VALUES (2878, 37, '02/04/2003', 7);
INSERT INTO valoracions VALUES (2878, 37, '12/07/2010', 5);
INSERT INTO valoracions VALUES (2878, 3, '26/01/2008', 9);
INSERT INTO valoracions VALUES (2879, 54, '26/05/2001', 3);
INSERT INTO valoracions VALUES (2879, 22, '23/01/2003', 7);
INSERT INTO valoracions VALUES (2879, 46, '08/08/2007', 9);
INSERT INTO valoracions VALUES (2879, 74, '30/08/2001', 3);
INSERT INTO valoracions VALUES (2880, 108, '26/11/2008', 9);
INSERT INTO valoracions VALUES (2880, 38, '13/04/2005', 7);
INSERT INTO valoracions VALUES (2880, 66, '11/10/2002', 3);
INSERT INTO valoracions VALUES (2880, 79, '06/01/2007', 4);
INSERT INTO valoracions VALUES (2881, 12, '10/11/2008', 8);
INSERT INTO valoracions VALUES (2881, 1, '10/05/2001', 10);
INSERT INTO valoracions VALUES (2881, 69, '10/05/2005', 4);
INSERT INTO valoracions VALUES (2881, 7, '30/03/2010', 9);
INSERT INTO valoracions VALUES (2882, 96, '11/09/2002', 6);
INSERT INTO valoracions VALUES (2882, 89, '15/01/2009', 1);
INSERT INTO valoracions VALUES (2882, 78, '04/09/2007', 7);
INSERT INTO valoracions VALUES (2882, 89, '11/12/2004', 8);
INSERT INTO valoracions VALUES (2883, 54, '22/08/2004', 7);
INSERT INTO valoracions VALUES (2883, 102, '02/03/2008', 5);
INSERT INTO valoracions VALUES (2883, 90, '29/01/2009', 7);
INSERT INTO valoracions VALUES (2883, 17, '09/02/2009', 7);
INSERT INTO valoracions VALUES (2884, 37, '15/05/2005', 4);
INSERT INTO valoracions VALUES (2885, 30, '02/02/2004', 7);
INSERT INTO valoracions VALUES (2885, 35, '15/06/2010', 4);
INSERT INTO valoracions VALUES (2885, 69, '06/08/2005', 6);
INSERT INTO valoracions VALUES (2885, 93, '20/04/2003', 4);
INSERT INTO valoracions VALUES (2885, 35, '28/07/2004', 8);
INSERT INTO valoracions VALUES (2885, 47, '30/10/2002', 4);
INSERT INTO valoracions VALUES (2885, 46, '01/05/2006', 5);
INSERT INTO valoracions VALUES (2885, 92, '14/03/2006', 1);
INSERT INTO valoracions VALUES (2886, 28, '18/04/2006', 5);
INSERT INTO valoracions VALUES (2886, 91, '26/10/2008', 8);
INSERT INTO valoracions VALUES (2886, 103, '04/08/2007', 8);
INSERT INTO valoracions VALUES (2886, 74, '16/03/2008', 3);
INSERT INTO valoracions VALUES (2886, 75, '08/10/2008', 5);
INSERT INTO valoracions VALUES (2886, 80, '19/01/2010', 8);
INSERT INTO valoracions VALUES (2886, 86, '17/02/2009', 7);
INSERT INTO valoracions VALUES (2887, 81, '18/09/2009', 7);
INSERT INTO valoracions VALUES (2887, 84, '28/10/2001', 9);
INSERT INTO valoracions VALUES (2887, 108, '23/01/2009', 1);
INSERT INTO valoracions VALUES (2887, 48, '18/04/2007', 3);
INSERT INTO valoracions VALUES (2887, 42, '01/10/2003', 5);
INSERT INTO valoracions VALUES (2887, 58, '01/06/2008', 4);
INSERT INTO valoracions VALUES (2887, 1, '03/12/2005', 6);
INSERT INTO valoracions VALUES (2888, 74, '13/06/2006', 7);
INSERT INTO valoracions VALUES (2888, 29, '24/07/2003', 5);
INSERT INTO valoracions VALUES (2888, 96, '13/08/2002', 10);
INSERT INTO valoracions VALUES (2889, 60, '09/08/2009', 10);
INSERT INTO valoracions VALUES (2891, 30, '07/06/2007', 9);
INSERT INTO valoracions VALUES (2891, 106, '25/03/2002', 3);
INSERT INTO valoracions VALUES (2891, 24, '02/11/2005', 6);
INSERT INTO valoracions VALUES (2891, 59, '10/01/2007', 8);
INSERT INTO valoracions VALUES (2891, 12, '01/11/2001', 7);
INSERT INTO valoracions VALUES (2891, 57, '01/06/2010', 4);
INSERT INTO valoracions VALUES (2892, 79, '19/02/2002', 9);
INSERT INTO valoracions VALUES (2892, 18, '02/05/2005', 5);
INSERT INTO valoracions VALUES (2893, 80, '22/01/2010', 9);
INSERT INTO valoracions VALUES (2893, 37, '25/05/2010', 5);
INSERT INTO valoracions VALUES (2893, 76, '16/01/2006', 4);
INSERT INTO valoracions VALUES (2893, 98, '25/06/2004', 4);
INSERT INTO valoracions VALUES (2894, 46, '23/09/2004', 6);
INSERT INTO valoracions VALUES (2894, 18, '16/10/2001', 6);
INSERT INTO valoracions VALUES (2894, 30, '08/11/2001', 5);
INSERT INTO valoracions VALUES (2895, 52, '11/05/2009', 4);
INSERT INTO valoracions VALUES (2895, 47, '30/12/2006', 7);
INSERT INTO valoracions VALUES (2895, 31, '24/09/2003', 4);
INSERT INTO valoracions VALUES (2895, 14, '02/02/2004', 9);
INSERT INTO valoracions VALUES (2896, 16, '05/05/2001', 5);
INSERT INTO valoracions VALUES (2896, 86, '02/10/2004', 9);
INSERT INTO valoracions VALUES (2897, 36, '14/06/2003', 6);
INSERT INTO valoracions VALUES (2898, 109, '01/07/2010', 3);
INSERT INTO valoracions VALUES (2898, 25, '08/03/2009', 10);
INSERT INTO valoracions VALUES (2898, 48, '10/07/2008', 5);
INSERT INTO valoracions VALUES (2898, 21, '29/12/2009', 10);
INSERT INTO valoracions VALUES (2898, 2, '21/09/2007', 7);
INSERT INTO valoracions VALUES (2898, 55, '13/09/2003', 7);
INSERT INTO valoracions VALUES (2899, 60, '28/04/2006', 4);
INSERT INTO valoracions VALUES (2899, 97, '10/09/2010', 5);
INSERT INTO valoracions VALUES (2899, 1, '16/10/2006', 10);
INSERT INTO valoracions VALUES (2899, 49, '03/12/2005', 6);
INSERT INTO valoracions VALUES (2899, 61, '27/01/2009', 3);
INSERT INTO valoracions VALUES (2899, 91, '17/07/2004', 8);
INSERT INTO valoracions VALUES (2900, 54, '25/09/2006', 5);
INSERT INTO valoracions VALUES (2901, 7, '12/05/2002', 6);
INSERT INTO valoracions VALUES (2901, 9, '09/01/2005', 10);
INSERT INTO valoracions VALUES (2901, 3, '15/09/2010', 9);
INSERT INTO valoracions VALUES (2901, 26, '27/12/2005', 7);
INSERT INTO valoracions VALUES (2901, 108, '22/09/2009', 1);
INSERT INTO valoracions VALUES (2901, 34, '07/02/2003', 6);
INSERT INTO valoracions VALUES (2901, 10, '17/03/2010', 8);
INSERT INTO valoracions VALUES (2902, 14, '22/12/2004', 7);
INSERT INTO valoracions VALUES (2902, 63, '31/07/2004', 9);
INSERT INTO valoracions VALUES (2902, 27, '04/01/2006', 10);
INSERT INTO valoracions VALUES (2902, 112, '14/06/2009', 3);
INSERT INTO valoracions VALUES (2902, 116, '04/05/2006', 8);
INSERT INTO valoracions VALUES (2902, 28, '03/06/2009', 5);
INSERT INTO valoracions VALUES (2903, 2, '05/01/2010', 10);
INSERT INTO valoracions VALUES (2903, 25, '21/04/2002', 5);
INSERT INTO valoracions VALUES (2903, 23, '06/01/2006', 7);
INSERT INTO valoracions VALUES (2903, 41, '17/06/2002', 5);
INSERT INTO valoracions VALUES (2903, 24, '07/05/2005', 6);
INSERT INTO valoracions VALUES (2903, 57, '28/02/2004', 9);
INSERT INTO valoracions VALUES (2904, 101, '30/10/2006', 8);
INSERT INTO valoracions VALUES (2904, 105, '14/01/2004', 8);
INSERT INTO valoracions VALUES (2904, 10, '03/04/2006', 7);
INSERT INTO valoracions VALUES (2904, 78, '12/12/2005', 8);
INSERT INTO valoracions VALUES (2904, 82, '25/03/2005', 2);
INSERT INTO valoracions VALUES (2905, 44, '06/11/2009', 5);
INSERT INTO valoracions VALUES (2905, 89, '15/09/2001', 9);
INSERT INTO valoracions VALUES (2905, 91, '17/07/2008', 5);
INSERT INTO valoracions VALUES (2905, 99, '01/08/2001', 3);
INSERT INTO valoracions VALUES (2905, 9, '08/11/2008', 6);
INSERT INTO valoracions VALUES (2905, 46, '28/01/2005', 5);
INSERT INTO valoracions VALUES (2906, 10, '27/03/2004', 8);
INSERT INTO valoracions VALUES (2906, 53, '12/09/2003', 3);
INSERT INTO valoracions VALUES (2907, 10, '14/10/2008', 9);
INSERT INTO valoracions VALUES (2907, 23, '27/09/2007', 10);
INSERT INTO valoracions VALUES (2907, 71, '25/11/2001', 4);
INSERT INTO valoracions VALUES (2907, 106, '23/03/2002', 10);
INSERT INTO valoracions VALUES (2907, 2, '10/10/2008', 8);
INSERT INTO valoracions VALUES (2908, 76, '03/05/2007', 5);
INSERT INTO valoracions VALUES (2908, 21, '10/11/2005', 5);
INSERT INTO valoracions VALUES (2908, 11, '11/09/2007', 7);
INSERT INTO valoracions VALUES (2908, 116, '28/03/2006', 4);
INSERT INTO valoracions VALUES (2908, 92, '01/09/2009', 6);
INSERT INTO valoracions VALUES (2908, 102, '25/03/2009', 8);
INSERT INTO valoracions VALUES (2909, 92, '24/10/2007', 8);
INSERT INTO valoracions VALUES (2909, 53, '03/02/2003', 4);
INSERT INTO valoracions VALUES (2909, 31, '18/08/2008', 4);
INSERT INTO valoracions VALUES (2909, 115, '01/02/2005', 1);
INSERT INTO valoracions VALUES (2910, 85, '06/07/2006', 4);
INSERT INTO valoracions VALUES (2910, 107, '01/03/2002', 2);
INSERT INTO valoracions VALUES (2910, 98, '11/10/2003', 9);
INSERT INTO valoracions VALUES (2910, 16, '02/11/2009', 6);
INSERT INTO valoracions VALUES (2910, 53, '31/08/2001', 6);
INSERT INTO valoracions VALUES (2911, 59, '20/06/2005', 6);
INSERT INTO valoracions VALUES (2911, 111, '02/08/2006', 6);
INSERT INTO valoracions VALUES (2911, 44, '03/02/2006', 9);
INSERT INTO valoracions VALUES (2911, 49, '26/03/2009', 5);
INSERT INTO valoracions VALUES (2911, 103, '10/10/2010', 6);
INSERT INTO valoracions VALUES (2912, 18, '04/04/2009', 5);
INSERT INTO valoracions VALUES (2912, 103, '23/07/2003', 7);
INSERT INTO valoracions VALUES (2912, 101, '03/05/2010', 3);
INSERT INTO valoracions VALUES (2913, 35, '30/09/2009', 6);
INSERT INTO valoracions VALUES (2913, 63, '21/12/2006', 8);
INSERT INTO valoracions VALUES (2913, 36, '08/06/2001', 4);
INSERT INTO valoracions VALUES (2913, 35, '08/10/2005', 9);
INSERT INTO valoracions VALUES (2914, 92, '23/12/2008', 2);
INSERT INTO valoracions VALUES (2914, 115, '05/07/2006', 8);
INSERT INTO valoracions VALUES (2914, 59, '30/09/2010', 9);
INSERT INTO valoracions VALUES (2914, 84, '01/06/2010', 4);
INSERT INTO valoracions VALUES (2915, 88, '05/07/2002', 2);
INSERT INTO valoracions VALUES (2915, 88, '29/04/2006', 9);
INSERT INTO valoracions VALUES (2915, 87, '25/11/2001', 5);
INSERT INTO valoracions VALUES (2915, 64, '23/10/2001', 6);
INSERT INTO valoracions VALUES (2915, 54, '12/08/2009', 3);
INSERT INTO valoracions VALUES (2915, 98, '02/03/2007', 7);
INSERT INTO valoracions VALUES (2916, 34, '21/01/2007', 6);
INSERT INTO valoracions VALUES (2916, 20, '25/01/2006', 5);
INSERT INTO valoracions VALUES (2916, 21, '19/02/2006', 8);
INSERT INTO valoracions VALUES (2916, 92, '23/01/2003', 8);
INSERT INTO valoracions VALUES (2917, 71, '21/08/2002', 6);
INSERT INTO valoracions VALUES (2917, 54, '11/09/2009', 7);
INSERT INTO valoracions VALUES (2917, 64, '03/02/2004', 7);
INSERT INTO valoracions VALUES (2917, 94, '31/03/2004', 3);
INSERT INTO valoracions VALUES (2918, 114, '05/06/2008', 5);
INSERT INTO valoracions VALUES (2919, 31, '28/11/2009', 4);
INSERT INTO valoracions VALUES (2919, 99, '23/09/2004', 7);
INSERT INTO valoracions VALUES (2919, 28, '24/08/2001', 9);
INSERT INTO valoracions VALUES (2919, 12, '09/03/2009', 9);
INSERT INTO valoracions VALUES (2920, 70, '05/02/2003', 7);
INSERT INTO valoracions VALUES (2921, 60, '15/05/2010', 6);
INSERT INTO valoracions VALUES (2921, 112, '27/03/2002', 5);
INSERT INTO valoracions VALUES (2921, 45, '27/01/2006', 7);
INSERT INTO valoracions VALUES (2921, 3, '02/10/2004', 5);
INSERT INTO valoracions VALUES (2921, 81, '17/01/2006', 8);
INSERT INTO valoracions VALUES (2922, 79, '24/10/2006', 7);
INSERT INTO valoracions VALUES (2922, 56, '09/11/2007', 9);
INSERT INTO valoracions VALUES (2922, 2, '19/08/2009', 8);
INSERT INTO valoracions VALUES (2922, 23, '17/08/2010', 9);
INSERT INTO valoracions VALUES (2923, 113, '07/01/2006', 1);
INSERT INTO valoracions VALUES (2923, 32, '24/03/2006', 6);
INSERT INTO valoracions VALUES (2923, 92, '04/08/2008', 6);
INSERT INTO valoracions VALUES (2924, 14, '23/07/2007', 6);
INSERT INTO valoracions VALUES (2924, 112, '09/06/2005', 0);
INSERT INTO valoracions VALUES (2924, 61, '05/08/2005', 5);
INSERT INTO valoracions VALUES (2924, 46, '22/11/2002', 4);
INSERT INTO valoracions VALUES (2924, 24, '13/12/2002', 5);
INSERT INTO valoracions VALUES (2925, 89, '09/04/2003', 8);
INSERT INTO valoracions VALUES (2925, 95, '13/07/2003', 10);
INSERT INTO valoracions VALUES (2925, 92, '23/10/2007', 4);
INSERT INTO valoracions VALUES (2925, 116, '23/07/2002', 3);
INSERT INTO valoracions VALUES (2927, 54, '23/01/2009', 3);
INSERT INTO valoracions VALUES (2927, 107, '02/11/2007', 10);
INSERT INTO valoracions VALUES (2927, 80, '27/06/2002', 7);
INSERT INTO valoracions VALUES (2927, 107, '01/12/2002', 7);
INSERT INTO valoracions VALUES (2928, 56, '26/09/2010', 9);
INSERT INTO valoracions VALUES (2928, 67, '20/09/2010', 9);
INSERT INTO valoracions VALUES (2928, 36, '12/12/2004', 7);
INSERT INTO valoracions VALUES (2929, 32, '28/10/2001', 7);
INSERT INTO valoracions VALUES (2929, 110, '18/08/2007', 2);
INSERT INTO valoracions VALUES (2929, 71, '29/10/2008', 4);
INSERT INTO valoracions VALUES (2929, 84, '13/08/2008', 7);
INSERT INTO valoracions VALUES (2930, 30, '19/02/2007', 4);
INSERT INTO valoracions VALUES (2930, 7, '11/12/2006', 9);
INSERT INTO valoracions VALUES (2930, 39, '07/07/2004', 7);
INSERT INTO valoracions VALUES (2931, 107, '22/05/2001', 1);
INSERT INTO valoracions VALUES (2931, 51, '17/07/2003', 4);
INSERT INTO valoracions VALUES (2931, 114, '10/03/2003', 5);
INSERT INTO valoracions VALUES (2931, 98, '09/05/2008', 8);
INSERT INTO valoracions VALUES (2932, 72, '02/09/2003', 8);
INSERT INTO valoracions VALUES (2932, 97, '10/09/2003', 8);
INSERT INTO valoracions VALUES (2932, 101, '08/03/2002', 8);
INSERT INTO valoracions VALUES (2932, 47, '04/04/2003', 9);
INSERT INTO valoracions VALUES (2933, 89, '08/09/2007', 3);
INSERT INTO valoracions VALUES (2933, 91, '01/03/2008', 5);
INSERT INTO valoracions VALUES (2933, 62, '09/04/2008', 3);
INSERT INTO valoracions VALUES (2934, 34, '18/02/2007', 10);
INSERT INTO valoracions VALUES (2935, 107, '08/09/2004', 6);
INSERT INTO valoracions VALUES (2935, 7, '28/11/2008', 9);
INSERT INTO valoracions VALUES (2936, 98, '08/02/2004', 4);
INSERT INTO valoracions VALUES (2936, 107, '29/01/2005', 8);
INSERT INTO valoracions VALUES (2936, 87, '23/09/2002', 3);
INSERT INTO valoracions VALUES (2937, 102, '17/03/2010', 2);
INSERT INTO valoracions VALUES (2937, 105, '28/09/2010', 8);
INSERT INTO valoracions VALUES (2937, 90, '17/08/2010', 2);
INSERT INTO valoracions VALUES (2938, 29, '01/08/2001', 4);
INSERT INTO valoracions VALUES (2938, 62, '10/11/2001', 8);
INSERT INTO valoracions VALUES (2938, 79, '21/02/2004', 5);
INSERT INTO valoracions VALUES (2938, 68, '21/11/2007', 3);
INSERT INTO valoracions VALUES (2939, 25, '29/11/2002', 5);
INSERT INTO valoracions VALUES (2939, 52, '03/10/2002', 6);
INSERT INTO valoracions VALUES (2939, 47, '01/01/2010', 6);
INSERT INTO valoracions VALUES (2940, 103, '19/06/2009', 8);
INSERT INTO valoracions VALUES (2940, 41, '31/07/2010', 5);
INSERT INTO valoracions VALUES (2940, 79, '15/09/2005', 8);
INSERT INTO valoracions VALUES (2940, 1, '18/03/2004', 9);
INSERT INTO valoracions VALUES (2940, 106, '13/04/2009', 8);
INSERT INTO valoracions VALUES (2940, 98, '15/11/2009', 5);
INSERT INTO valoracions VALUES (2940, 80, '11/04/2008', 5);
INSERT INTO valoracions VALUES (2941, 10, '17/04/2007', 5);
INSERT INTO valoracions VALUES (2941, 22, '24/11/2008', 6);
INSERT INTO valoracions VALUES (2941, 20, '04/06/2005', 9);
INSERT INTO valoracions VALUES (2942, 32, '02/02/2003', 9);
INSERT INTO valoracions VALUES (2942, 95, '14/04/2001', 6);
INSERT INTO valoracions VALUES (2942, 83, '13/01/2008', 7);
INSERT INTO valoracions VALUES (2942, 73, '16/01/2010', 9);
INSERT INTO valoracions VALUES (2942, 70, '02/11/2003', 6);
INSERT INTO valoracions VALUES (2943, 67, '31/03/2008', 3);
INSERT INTO valoracions VALUES (2943, 51, '02/08/2003', 7);
INSERT INTO valoracions VALUES (2943, 35, '04/12/2008', 7);
INSERT INTO valoracions VALUES (2943, 24, '13/01/2006', 5);
INSERT INTO valoracions VALUES (2943, 37, '11/07/2009', 6);
INSERT INTO valoracions VALUES (2944, 13, '30/08/2004', 9);
INSERT INTO valoracions VALUES (2944, 35, '10/01/2004', 5);
INSERT INTO valoracions VALUES (2944, 106, '07/03/2002', 1);
INSERT INTO valoracions VALUES (2944, 25, '26/10/2007', 6);
INSERT INTO valoracions VALUES (2944, 38, '14/11/2001', 10);
INSERT INTO valoracions VALUES (2945, 56, '20/01/2007', 7);
INSERT INTO valoracions VALUES (2945, 52, '26/02/2010', 5);
INSERT INTO valoracions VALUES (2945, 49, '20/01/2008', 6);
INSERT INTO valoracions VALUES (2946, 80, '09/05/2003', 10);
INSERT INTO valoracions VALUES (2946, 14, '15/03/2007', 7);
INSERT INTO valoracions VALUES (2946, 67, '20/04/2004', 5);
INSERT INTO valoracions VALUES (2946, 50, '17/03/2002', 3);
INSERT INTO valoracions VALUES (2946, 91, '20/10/2007', 4);
INSERT INTO valoracions VALUES (2946, 40, '17/01/2005', 9);
INSERT INTO valoracions VALUES (2946, 3, '29/11/2006', 8);
INSERT INTO valoracions VALUES (2947, 113, '01/11/2008', 1);
INSERT INTO valoracions VALUES (2947, 87, '05/12/2007', 9);
INSERT INTO valoracions VALUES (2947, 2, '24/10/2009', 8);
INSERT INTO valoracions VALUES (2947, 42, '26/08/2010', 5);
INSERT INTO valoracions VALUES (2947, 75, '26/05/2009', 7);
INSERT INTO valoracions VALUES (2948, 19, '19/06/2005', 4);
INSERT INTO valoracions VALUES (2949, 89, '07/02/2002', 9);
INSERT INTO valoracions VALUES (2949, 32, '31/07/2006', 4);
INSERT INTO valoracions VALUES (2950, 93, '21/05/2010', 5);
INSERT INTO valoracions VALUES (2950, 105, '06/05/2010', 5);
INSERT INTO valoracions VALUES (2950, 85, '05/04/2007', 3);
INSERT INTO valoracions VALUES (2951, 19, '26/02/2004', 5);
INSERT INTO valoracions VALUES (2951, 114, '15/04/2003', 9);
INSERT INTO valoracions VALUES (2951, 27, '21/04/2002', 5);
INSERT INTO valoracions VALUES (2951, 49, '07/03/2010', 3);
INSERT INTO valoracions VALUES (2951, 16, '25/01/2006', 6);
INSERT INTO valoracions VALUES (2952, 18, '09/03/2002', 5);
INSERT INTO valoracions VALUES (2952, 64, '09/07/2005', 5);
INSERT INTO valoracions VALUES (2953, 25, '13/12/2006', 6);
INSERT INTO valoracions VALUES (2953, 58, '26/01/2010', 8);
INSERT INTO valoracions VALUES (2953, 10, '07/07/2009', 8);
INSERT INTO valoracions VALUES (2953, 53, '10/10/2005', 9);
INSERT INTO valoracions VALUES (2953, 83, '16/01/2006', 10);
INSERT INTO valoracions VALUES (2953, 88, '19/06/2005', 6);
INSERT INTO valoracions VALUES (2953, 85, '01/08/2003', 4);
INSERT INTO valoracions VALUES (2953, 45, '02/09/2007', 5);
INSERT INTO valoracions VALUES (2954, 90, '23/06/2009', 7);
INSERT INTO valoracions VALUES (2954, 94, '09/05/2002', 1);
INSERT INTO valoracions VALUES (2954, 85, '04/07/2007', 3);
INSERT INTO valoracions VALUES (2954, 92, '10/01/2003', 3);
INSERT INTO valoracions VALUES (2955, 79, '11/03/2009', 2);
INSERT INTO valoracions VALUES (2955, 55, '12/01/2008', 3);
INSERT INTO valoracions VALUES (2955, 74, '13/08/2006', 4);
INSERT INTO valoracions VALUES (2955, 97, '23/10/2001', 1);
INSERT INTO valoracions VALUES (2956, 99, '04/07/2005', 6);
INSERT INTO valoracions VALUES (2956, 98, '24/11/2004', 9);
INSERT INTO valoracions VALUES (2956, 54, '18/01/2009', 6);
INSERT INTO valoracions VALUES (2957, 43, '25/09/2010', 9);
INSERT INTO valoracions VALUES (2957, 27, '17/01/2002', 8);
INSERT INTO valoracions VALUES (2957, 78, '03/09/2008', 6);
INSERT INTO valoracions VALUES (2957, 46, '17/10/2002', 9);
INSERT INTO valoracions VALUES (2958, 13, '15/04/2007', 6);
INSERT INTO valoracions VALUES (2958, 82, '02/02/2007', 6);
INSERT INTO valoracions VALUES (2958, 65, '23/12/2009', 9);
INSERT INTO valoracions VALUES (2959, 53, '03/06/2003', 9);
INSERT INTO valoracions VALUES (2959, 27, '07/05/2010', 9);
INSERT INTO valoracions VALUES (2959, 75, '15/12/2007', 3);
INSERT INTO valoracions VALUES (2959, 71, '18/08/2008', 8);
INSERT INTO valoracions VALUES (2959, 82, '31/05/2004', 5);
INSERT INTO valoracions VALUES (2959, 14, '01/02/2010', 5);
INSERT INTO valoracions VALUES (2960, 77, '31/10/2003', 3);
INSERT INTO valoracions VALUES (2961, 19, '06/08/2001', 10);
INSERT INTO valoracions VALUES (2961, 87, '30/05/2009', 1);
INSERT INTO valoracions VALUES (2961, 101, '11/04/2004', 6);
INSERT INTO valoracions VALUES (2962, 65, '30/03/2005', 8);
INSERT INTO valoracions VALUES (2962, 29, '08/09/2004', 8);
INSERT INTO valoracions VALUES (2962, 13, '27/03/2010', 10);
INSERT INTO valoracions VALUES (2962, 111, '28/02/2005', 2);
INSERT INTO valoracions VALUES (2962, 62, '08/04/2007', 8);
INSERT INTO valoracions VALUES (2963, 109, '17/12/2001', 6);
INSERT INTO valoracions VALUES (2963, 62, '07/12/2008', 7);
INSERT INTO valoracions VALUES (2963, 20, '05/02/2009', 7);
INSERT INTO valoracions VALUES (2963, 113, '18/06/2010', 6);
INSERT INTO valoracions VALUES (2963, 5, '17/10/2002', 9);
INSERT INTO valoracions VALUES (2964, 4, '04/05/2001', 9);
INSERT INTO valoracions VALUES (2965, 85, '30/06/2008', 7);
INSERT INTO valoracions VALUES (2965, 3, '10/02/2003', 6);
INSERT INTO valoracions VALUES (2965, 116, '25/11/2005', 10);
INSERT INTO valoracions VALUES (2965, 37, '14/05/2010', 6);
INSERT INTO valoracions VALUES (2966, 71, '04/01/2010', 6);
INSERT INTO valoracions VALUES (2966, 74, '31/10/2005', 5);
INSERT INTO valoracions VALUES (2966, 15, '22/07/2005', 6);
INSERT INTO valoracions VALUES (2966, 83, '06/05/2001', 4);
INSERT INTO valoracions VALUES (2966, 83, '03/01/2002', 9);
INSERT INTO valoracions VALUES (2966, 76, '16/06/2005', 9);
INSERT INTO valoracions VALUES (2967, 106, '05/01/2003', 5);
INSERT INTO valoracions VALUES (2967, 49, '30/01/2004', 6);
INSERT INTO valoracions VALUES (2968, 40, '15/07/2009', 6);
INSERT INTO valoracions VALUES (2968, 18, '12/04/2002', 7);
INSERT INTO valoracions VALUES (2968, 111, '29/01/2006', 0);
INSERT INTO valoracions VALUES (2968, 87, '18/07/2007', 3);
INSERT INTO valoracions VALUES (2969, 7, '29/01/2002', 6);
INSERT INTO valoracions VALUES (2969, 27, '14/04/2010', 5);
INSERT INTO valoracions VALUES (2969, 34, '01/08/2008', 7);
INSERT INTO valoracions VALUES (2969, 108, '22/01/2005', 5);
INSERT INTO valoracions VALUES (2970, 112, '28/09/2009', 4);
INSERT INTO valoracions VALUES (2970, 69, '24/03/2005', 3);
INSERT INTO valoracions VALUES (2970, 94, '06/09/2002', 5);
INSERT INTO valoracions VALUES (2971, 116, '10/12/2005', 2);
INSERT INTO valoracions VALUES (2972, 7, '21/11/2007', 9);
INSERT INTO valoracions VALUES (2972, 98, '31/05/2010', 8);
INSERT INTO valoracions VALUES (2973, 65, '04/12/2005', 5);
INSERT INTO valoracions VALUES (2973, 55, '24/05/2004', 9);
INSERT INTO valoracions VALUES (2973, 72, '16/06/2008', 8);
INSERT INTO valoracions VALUES (2973, 98, '23/09/2008', 1);
INSERT INTO valoracions VALUES (2973, 1, '30/12/2004', 7);
INSERT INTO valoracions VALUES (2974, 68, '13/09/2008', 4);
INSERT INTO valoracions VALUES (2974, 86, '13/08/2002', 6);
INSERT INTO valoracions VALUES (2975, 88, '01/11/2008', 1);
INSERT INTO valoracions VALUES (2976, 104, '11/06/2007', 1);
INSERT INTO valoracions VALUES (2976, 108, '23/04/2009', 3);
INSERT INTO valoracions VALUES (2977, 90, '14/05/2008', 8);
INSERT INTO valoracions VALUES (2977, 85, '17/10/2002', 5);
INSERT INTO valoracions VALUES (2978, 1, '06/05/2009', 10);
INSERT INTO valoracions VALUES (2978, 96, '01/09/2004', 6);
INSERT INTO valoracions VALUES (2979, 76, '12/08/2009', 3);
INSERT INTO valoracions VALUES (2979, 94, '22/05/2008', 7);
INSERT INTO valoracions VALUES (2979, 78, '02/10/2007', 3);
INSERT INTO valoracions VALUES (2979, 87, '17/06/2005', 7);
INSERT INTO valoracions VALUES (2979, 2, '27/08/2001', 9);
INSERT INTO valoracions VALUES (2980, 105, '23/03/2006', 1);
INSERT INTO valoracions VALUES (2980, 44, '04/04/2009', 9);
INSERT INTO valoracions VALUES (2981, 57, '17/11/2001', 4);
INSERT INTO valoracions VALUES (2981, 93, '11/08/2005', 5);
INSERT INTO valoracions VALUES (2981, 18, '15/11/2004', 5);
INSERT INTO valoracions VALUES (2981, 19, '27/07/2002', 9);
INSERT INTO valoracions VALUES (2981, 88, '10/09/2002', 7);
INSERT INTO valoracions VALUES (2982, 62, '24/10/2008', 10);
INSERT INTO valoracions VALUES (2982, 84, '08/12/2003', 2);
INSERT INTO valoracions VALUES (2982, 107, '12/04/2009', 10);
INSERT INTO valoracions VALUES (2983, 101, '31/03/2008', 3);
INSERT INTO valoracions VALUES (2983, 59, '21/07/2005', 3);
INSERT INTO valoracions VALUES (2984, 98, '01/08/2005', 6);
INSERT INTO valoracions VALUES (2984, 18, '19/02/2006', 10);
INSERT INTO valoracions VALUES (2985, 92, '04/08/2008', 8);
INSERT INTO valoracions VALUES (2985, 51, '12/08/2007', 9);
INSERT INTO valoracions VALUES (2985, 38, '21/02/2005', 8);
INSERT INTO valoracions VALUES (2985, 85, '14/05/2002', 2);
INSERT INTO valoracions VALUES (2985, 61, '11/01/2008', 9);
INSERT INTO valoracions VALUES (2985, 92, '31/08/2004', 7);
INSERT INTO valoracions VALUES (2985, 22, '30/05/2003', 7);
INSERT INTO valoracions VALUES (2986, 37, '18/04/2006', 4);
INSERT INTO valoracions VALUES (2987, 16, '10/05/2001', 10);
INSERT INTO valoracions VALUES (2987, 108, '25/05/2004', 3);
INSERT INTO valoracions VALUES (2987, 81, '20/12/2003', 8);
INSERT INTO valoracions VALUES (2987, 40, '27/03/2004', 9);
INSERT INTO valoracions VALUES (2987, 13, '15/03/2005', 7);
INSERT INTO valoracions VALUES (2988, 113, '19/03/2005', 3);
INSERT INTO valoracions VALUES (2988, 75, '29/03/2002', 7);
INSERT INTO valoracions VALUES (2988, 30, '08/04/2004', 10);
INSERT INTO valoracions VALUES (2988, 112, '16/05/2007', 1);
INSERT INTO valoracions VALUES (2988, 113, '02/06/2004', 8);
INSERT INTO valoracions VALUES (2989, 116, '20/03/2002', 4);
INSERT INTO valoracions VALUES (2989, 112, '11/08/2008', 9);
INSERT INTO valoracions VALUES (2989, 92, '26/11/2001', 6);
INSERT INTO valoracions VALUES (2989, 59, '15/08/2007', 9);
INSERT INTO valoracions VALUES (2990, 71, '06/10/2002', 4);
INSERT INTO valoracions VALUES (2990, 63, '22/11/2002', 8);
INSERT INTO valoracions VALUES (2990, 16, '08/09/2001', 7);
INSERT INTO valoracions VALUES (2990, 85, '11/11/2004', 7);
INSERT INTO valoracions VALUES (2990, 73, '22/12/2006', 10);
INSERT INTO valoracions VALUES (2990, 17, '27/08/2006', 8);
INSERT INTO valoracions VALUES (2990, 105, '23/04/2002', 1);
INSERT INTO valoracions VALUES (2990, 113, '28/01/2007', 8);
INSERT INTO valoracions VALUES (2991, 32, '16/03/2009', 6);
INSERT INTO valoracions VALUES (2991, 58, '25/09/2009', 3);
INSERT INTO valoracions VALUES (2991, 108, '18/03/2002', 8);
INSERT INTO valoracions VALUES (2991, 55, '21/07/2008', 4);
INSERT INTO valoracions VALUES (2991, 81, '13/02/2006', 2);
INSERT INTO valoracions VALUES (2991, 51, '12/03/2010', 6);
INSERT INTO valoracions VALUES (2991, 62, '19/07/2003', 3);
INSERT INTO valoracions VALUES (2991, 60, '06/10/2008', 5);
INSERT INTO valoracions VALUES (2992, 114, '18/09/2007', 5);
INSERT INTO valoracions VALUES (2992, 44, '22/08/2004', 4);
INSERT INTO valoracions VALUES (2993, 14, '10/09/2006', 5);
INSERT INTO valoracions VALUES (2993, 95, '04/06/2008', 3);
INSERT INTO valoracions VALUES (2993, 66, '20/05/2007', 6);
INSERT INTO valoracions VALUES (2994, 92, '19/01/2004', 6);
INSERT INTO valoracions VALUES (2994, 17, '01/08/2007', 7);
INSERT INTO valoracions VALUES (2994, 109, '27/04/2008', 7);
INSERT INTO valoracions VALUES (2995, 17, '15/12/2001', 9);
INSERT INTO valoracions VALUES (2995, 109, '14/09/2003', 9);
INSERT INTO valoracions VALUES (2995, 69, '13/01/2003', 7);
INSERT INTO valoracions VALUES (2996, 3, '21/10/2009', 5);
INSERT INTO valoracions VALUES (2996, 79, '29/01/2004', 6);
INSERT INTO valoracions VALUES (2996, 43, '17/01/2004', 5);
INSERT INTO valoracions VALUES (2996, 113, '19/08/2005', 9);
INSERT INTO valoracions VALUES (2996, 11, '31/07/2001', 9);
INSERT INTO valoracions VALUES (2997, 111, '21/07/2007', 6);
INSERT INTO valoracions VALUES (2997, 40, '05/06/2010', 6);
INSERT INTO valoracions VALUES (2997, 100, '19/10/2010', 3);
INSERT INTO valoracions VALUES (2997, 98, '19/08/2003', 8);
INSERT INTO valoracions VALUES (2998, 58, '02/12/2001', 5);
INSERT INTO valoracions VALUES (2998, 16, '23/02/2003', 7);
INSERT INTO valoracions VALUES (2998, 58, '18/05/2008', 6);
INSERT INTO valoracions VALUES (2998, 35, '23/07/2004', 9);
INSERT INTO valoracions VALUES (2999, 52, '05/01/2009', 10);
INSERT INTO valoracions VALUES (2999, 77, '11/06/2005', 8);
INSERT INTO valoracions VALUES (2999, 52, '15/04/2005', 7);
INSERT INTO valoracions VALUES (2999, 44, '29/06/2007', 9);
INSERT INTO valoracions VALUES (3000, 51, '30/08/2002', 9);
INSERT INTO valoracions VALUES (3000, 76, '15/10/2009', 3);
INSERT INTO valoracions VALUES (3000, 101, '17/02/2006', 5);
INSERT INTO valoracions VALUES (3000, 4, '11/04/2005', 7);
INSERT INTO valoracions VALUES (3000, 43, '29/06/2001', 5);
INSERT INTO valoracions VALUES (3001, 55, '05/05/2008', 4);
INSERT INTO valoracions VALUES (3001, 8, '08/02/2004', 8);
INSERT INTO valoracions VALUES (3002, 3, '16/08/2006', 5);
INSERT INTO valoracions VALUES (3002, 60, '03/07/2002', 8);
INSERT INTO valoracions VALUES (3002, 102, '16/04/2009', 9);
INSERT INTO valoracions VALUES (3002, 24, '04/09/2002', 5);
INSERT INTO valoracions VALUES (3003, 53, '21/03/2004', 6);
INSERT INTO valoracions VALUES (3003, 17, '11/07/2008', 7);
INSERT INTO valoracions VALUES (3003, 19, '22/11/2007', 5);
INSERT INTO valoracions VALUES (3003, 106, '17/08/2009', 10);
INSERT INTO valoracions VALUES (3003, 55, '28/08/2006', 10);
INSERT INTO valoracions VALUES (3003, 113, '17/12/2005', 5);
INSERT INTO valoracions VALUES (3003, 6, '18/03/2003', 5);
INSERT INTO valoracions VALUES (3003, 52, '15/09/2005', 3);
INSERT INTO valoracions VALUES (3004, 73, '23/09/2002', 10);
INSERT INTO valoracions VALUES (3004, 22, '25/09/2007', 4);
INSERT INTO valoracions VALUES (3004, 30, '30/05/2003', 4);
INSERT INTO valoracions VALUES (3005, 74, '15/01/2006', 8);
INSERT INTO valoracions VALUES (3005, 103, '13/06/2007', 6);
INSERT INTO valoracions VALUES (3005, 38, '15/07/2007', 6);
INSERT INTO valoracions VALUES (3005, 25, '03/11/2008', 5);
INSERT INTO valoracions VALUES (3005, 28, '05/09/2001', 4);
INSERT INTO valoracions VALUES (3005, 2, '06/02/2007', 9);
INSERT INTO valoracions VALUES (3006, 11, '08/02/2005', 9);
INSERT INTO valoracions VALUES (3006, 24, '01/07/2009', 8);
INSERT INTO valoracions VALUES (3006, 12, '15/05/2001', 7);
INSERT INTO valoracions VALUES (3006, 91, '30/01/2004', 2);
INSERT INTO valoracions VALUES (3007, 115, '07/11/2001', 8);
INSERT INTO valoracions VALUES (3007, 9, '07/12/2005', 5);
INSERT INTO valoracions VALUES (3007, 75, '04/10/2008', 4);
INSERT INTO valoracions VALUES (3007, 18, '30/06/2003', 8);
INSERT INTO valoracions VALUES (3007, 11, '01/10/2006', 6);
INSERT INTO valoracions VALUES (3007, 111, '08/04/2005', 8);
INSERT INTO valoracions VALUES (3008, 97, '29/10/2006', 5);
INSERT INTO valoracions VALUES (3008, 53, '26/09/2003', 3);
INSERT INTO valoracions VALUES (3008, 97, '17/03/2003', 8);
INSERT INTO valoracions VALUES (3008, 97, '22/10/2009', 5);
INSERT INTO valoracions VALUES (3008, 14, '04/11/2002', 7);
INSERT INTO valoracions VALUES (3008, 13, '08/09/2005', 6);
INSERT INTO valoracions VALUES (3008, 72, '22/10/2007', 4);
INSERT INTO valoracions VALUES (3009, 20, '18/03/2004', 7);
INSERT INTO valoracions VALUES (3009, 85, '15/04/2004', 10);
INSERT INTO valoracions VALUES (3010, 49, '29/03/2005', 5);
INSERT INTO valoracions VALUES (3010, 62, '09/10/2006', 6);
INSERT INTO valoracions VALUES (3010, 34, '04/02/2006', 4);
INSERT INTO valoracions VALUES (3011, 4, '14/06/2001', 8);
INSERT INTO valoracions VALUES (3011, 75, '18/05/2004', 8);
INSERT INTO valoracions VALUES (3011, 73, '09/05/2010', 7);
INSERT INTO valoracions VALUES (3011, 45, '06/11/2009', 4);
INSERT INTO valoracions VALUES (3012, 22, '19/10/2004', 5);
INSERT INTO valoracions VALUES (3012, 115, '11/10/2008', 10);
INSERT INTO valoracions VALUES (3012, 63, '17/01/2007', 3);
INSERT INTO valoracions VALUES (3012, 94, '07/07/2005', 1);
INSERT INTO valoracions VALUES (3013, 60, '03/07/2006', 3);
INSERT INTO valoracions VALUES (3014, 10, '03/09/2001', 10);
INSERT INTO valoracions VALUES (3014, 9, '20/12/2003', 6);
INSERT INTO valoracions VALUES (3014, 16, '12/04/2010', 6);
INSERT INTO valoracions VALUES (3014, 23, '23/10/2010', 5);
INSERT INTO valoracions VALUES (3015, 6, '17/11/2003', 8);
INSERT INTO valoracions VALUES (3015, 98, '21/09/2010', 7);
INSERT INTO valoracions VALUES (3015, 44, '29/05/2007', 5);
INSERT INTO valoracions VALUES (3016, 63, '18/02/2003', 8);
INSERT INTO valoracions VALUES (3016, 52, '15/01/2002', 9);
INSERT INTO valoracions VALUES (3016, 91, '07/06/2006', 2);
INSERT INTO valoracions VALUES (3016, 6, '05/11/2002', 8);
INSERT INTO valoracions VALUES (3016, 12, '05/06/2004', 9);
INSERT INTO valoracions VALUES (3016, 14, '30/10/2007', 6);
INSERT INTO valoracions VALUES (3017, 50, '04/06/2006', 4);
INSERT INTO valoracions VALUES (3017, 103, '28/12/2007', 2);
INSERT INTO valoracions VALUES (3017, 67, '01/12/2004', 8);
INSERT INTO valoracions VALUES (3017, 89, '28/11/2004', 5);
INSERT INTO valoracions VALUES (3018, 35, '16/06/2003', 5);
INSERT INTO valoracions VALUES (3018, 70, '18/02/2007', 10);
INSERT INTO valoracions VALUES (3018, 8, '22/06/2008', 8);
INSERT INTO valoracions VALUES (3018, 107, '13/04/2002', 3);
INSERT INTO valoracions VALUES (3018, 59, '14/11/2006', 6);
INSERT INTO valoracions VALUES (3019, 40, '21/09/2004', 6);
INSERT INTO valoracions VALUES (3019, 80, '31/08/2010', 2);
INSERT INTO valoracions VALUES (3019, 107, '31/01/2007', 6);
INSERT INTO valoracions VALUES (3019, 53, '08/08/2001', 5);
INSERT INTO valoracions VALUES (3019, 107, '04/01/2009', 9);
INSERT INTO valoracions VALUES (3019, 47, '09/09/2006', 3);
INSERT INTO valoracions VALUES (3021, 54, '14/09/2003', 5);
INSERT INTO valoracions VALUES (3021, 3, '12/03/2008', 5);
INSERT INTO valoracions VALUES (3022, 89, '17/07/2004', 8);
INSERT INTO valoracions VALUES (3022, 59, '20/10/2010', 10);
INSERT INTO valoracions VALUES (3022, 36, '19/05/2004', 9);
INSERT INTO valoracions VALUES (3022, 2, '18/07/2007', 7);
INSERT INTO valoracions VALUES (3022, 78, '31/07/2008', 7);
INSERT INTO valoracions VALUES (3022, 5, '01/04/2003', 7);
INSERT INTO valoracions VALUES (3023, 3, '29/04/2004', 6);
INSERT INTO valoracions VALUES (3023, 51, '03/07/2010', 7);
INSERT INTO valoracions VALUES (3023, 53, '28/07/2007', 9);
INSERT INTO valoracions VALUES (3023, 17, '10/09/2003', 7);
INSERT INTO valoracions VALUES (3023, 113, '07/05/2003', 9);
INSERT INTO valoracions VALUES (3023, 72, '20/04/2007', 5);
INSERT INTO valoracions VALUES (3024, 60, '04/07/2005', 5);
INSERT INTO valoracions VALUES (3024, 16, '14/11/2002', 8);
INSERT INTO valoracions VALUES (3024, 46, '08/10/2005', 4);
INSERT INTO valoracions VALUES (3024, 103, '16/07/2005', 6);
INSERT INTO valoracions VALUES (3024, 11, '23/04/2001', 6);
INSERT INTO valoracions VALUES (3025, 29, '27/05/2010', 10);
INSERT INTO valoracions VALUES (3025, 47, '27/09/2002', 8);
INSERT INTO valoracions VALUES (3026, 27, '25/09/2005', 5);
INSERT INTO valoracions VALUES (3026, 49, '17/12/2003', 9);
INSERT INTO valoracions VALUES (3026, 35, '26/02/2003', 7);
INSERT INTO valoracions VALUES (3027, 23, '22/03/2004', 8);
INSERT INTO valoracions VALUES (3027, 82, '17/08/2002', 6);
INSERT INTO valoracions VALUES (3027, 104, '30/03/2003', 7);
INSERT INTO valoracions VALUES (3027, 103, '30/05/2009', 2);
INSERT INTO valoracions VALUES (3027, 75, '22/10/2003', 6);
INSERT INTO valoracions VALUES (3027, 97, '25/01/2004', 4);
INSERT INTO valoracions VALUES (3027, 37, '29/09/2006', 5);
INSERT INTO valoracions VALUES (3028, 36, '05/08/2007', 4);
INSERT INTO valoracions VALUES (3028, 103, '14/08/2008', 2);
INSERT INTO valoracions VALUES (3028, 67, '15/01/2004', 2);
INSERT INTO valoracions VALUES (3029, 66, '18/09/2010', 6);
INSERT INTO valoracions VALUES (3029, 70, '03/11/2002', 3);
INSERT INTO valoracions VALUES (3029, 2, '19/09/2001', 10);
INSERT INTO valoracions VALUES (3030, 73, '26/02/2004', 10);
INSERT INTO valoracions VALUES (3030, 114, '06/07/2001', 3);
INSERT INTO valoracions VALUES (3030, 97, '06/04/2006', 9);
INSERT INTO valoracions VALUES (3030, 75, '01/12/2008', 5);
INSERT INTO valoracions VALUES (3030, 18, '30/08/2006', 7);
INSERT INTO valoracions VALUES (3031, 37, '12/05/2008', 5);
INSERT INTO valoracions VALUES (3031, 79, '11/04/2008', 2);
INSERT INTO valoracions VALUES (3031, 76, '01/09/2010', 3);
INSERT INTO valoracions VALUES (3031, 44, '13/04/2006', 8);
INSERT INTO valoracions VALUES (3032, 39, '27/07/2008', 10);
INSERT INTO valoracions VALUES (3032, 61, '10/06/2009', 8);
INSERT INTO valoracions VALUES (3032, 104, '25/12/2002', 7);
INSERT INTO valoracions VALUES (3032, 48, '29/07/2010', 3);
INSERT INTO valoracions VALUES (3032, 36, '01/09/2002', 5);
INSERT INTO valoracions VALUES (3032, 10, '17/04/2001', 8);
INSERT INTO valoracions VALUES (3033, 26, '18/12/2004', 4);
INSERT INTO valoracions VALUES (3034, 82, '12/08/2001', 6);
INSERT INTO valoracions VALUES (3034, 24, '05/12/2003', 5);
INSERT INTO valoracions VALUES (3034, 3, '07/04/2010', 8);
INSERT INTO valoracions VALUES (3034, 48, '16/11/2004', 8);
INSERT INTO valoracions VALUES (3034, 24, '26/07/2002', 8);
INSERT INTO valoracions VALUES (3034, 73, '09/09/2009', 7);
INSERT INTO valoracions VALUES (3035, 57, '21/06/2002', 6);
INSERT INTO valoracions VALUES (3035, 50, '30/04/2009', 9);
INSERT INTO valoracions VALUES (3035, 116, '28/12/2003', 5);
INSERT INTO valoracions VALUES (3035, 33, '16/02/2008', 9);
INSERT INTO valoracions VALUES (3036, 70, '05/08/2005', 4);
INSERT INTO valoracions VALUES (3036, 100, '06/06/2006', 2);
INSERT INTO valoracions VALUES (3038, 84, '27/08/2004', 8);
INSERT INTO valoracions VALUES (3038, 2, '23/04/2004', 9);
INSERT INTO valoracions VALUES (3038, 93, '06/05/2009', 6);
INSERT INTO valoracions VALUES (3038, 39, '13/12/2001', 7);
INSERT INTO valoracions VALUES (3039, 106, '07/05/2010', 7);
INSERT INTO valoracions VALUES (3040, 7, '13/11/2005', 8);
INSERT INTO valoracions VALUES (3040, 18, '22/03/2002', 5);
INSERT INTO valoracions VALUES (3040, 30, '16/04/2010', 8);
INSERT INTO valoracions VALUES (3040, 16, '23/05/2001', 9);
INSERT INTO valoracions VALUES (3041, 40, '09/05/2005', 9);
INSERT INTO valoracions VALUES (3041, 79, '03/07/2009', 2);
INSERT INTO valoracions VALUES (3042, 16, '18/04/2002', 8);
INSERT INTO valoracions VALUES (3042, 98, '03/09/2008', 7);
INSERT INTO valoracions VALUES (3042, 43, '09/02/2002', 9);
INSERT INTO valoracions VALUES (3042, 62, '05/07/2010', 4);
INSERT INTO valoracions VALUES (3042, 96, '29/09/2002', 8);
INSERT INTO valoracions VALUES (3043, 55, '09/08/2002', 8);
INSERT INTO valoracions VALUES (3043, 45, '07/03/2008', 4);
INSERT INTO valoracions VALUES (3043, 104, '26/08/2007', 5);
INSERT INTO valoracions VALUES (3043, 86, '28/10/2008', 9);
INSERT INTO valoracions VALUES (3043, 12, '07/05/2009', 7);
INSERT INTO valoracions VALUES (3043, 88, '11/01/2005', 9);
INSERT INTO valoracions VALUES (3043, 59, '04/06/2003', 9);
INSERT INTO valoracions VALUES (3044, 40, '15/10/2003', 3);
INSERT INTO valoracions VALUES (3045, 106, '14/09/2006', 1);
INSERT INTO valoracions VALUES (3045, 81, '11/03/2010', 2);
INSERT INTO valoracions VALUES (3045, 76, '14/08/2006', 8);
INSERT INTO valoracions VALUES (3045, 63, '09/04/2010', 7);
INSERT INTO valoracions VALUES (3045, 50, '04/10/2002', 8);
INSERT INTO valoracions VALUES (3045, 18, '04/12/2005', 6);
INSERT INTO valoracions VALUES (3045, 17, '02/01/2008', 8);
INSERT INTO valoracions VALUES (3045, 80, '07/03/2002', 5);
INSERT INTO valoracions VALUES (3045, 19, '14/08/2007', 7);
INSERT INTO valoracions VALUES (3046, 27, '26/09/2006', 5);
INSERT INTO valoracions VALUES (3046, 38, '23/03/2003', 8);
INSERT INTO valoracions VALUES (3046, 16, '30/05/2007', 4);
INSERT INTO valoracions VALUES (3046, 71, '12/01/2004', 4);
INSERT INTO valoracions VALUES (3046, 24, '22/08/2004', 4);
INSERT INTO valoracions VALUES (3046, 82, '13/06/2009', 7);
INSERT INTO valoracions VALUES (3047, 76, '28/09/2009', 7);
INSERT INTO valoracions VALUES (3047, 13, '28/04/2003', 6);
INSERT INTO valoracions VALUES (3048, 45, '14/09/2004', 9);
INSERT INTO valoracions VALUES (3048, 101, '27/04/2004', 9);
INSERT INTO valoracions VALUES (3048, 10, '30/07/2003', 5);
INSERT INTO valoracions VALUES (3048, 23, '09/07/2005', 8);
INSERT INTO valoracions VALUES (3049, 54, '30/11/2002', 3);
INSERT INTO valoracions VALUES (3049, 4, '15/05/2008', 5);
INSERT INTO valoracions VALUES (3050, 53, '04/12/2008', 9);
INSERT INTO valoracions VALUES (3050, 95, '21/07/2002', 2);
INSERT INTO valoracions VALUES (3050, 11, '14/11/2009', 9);
INSERT INTO valoracions VALUES (3051, 35, '05/03/2008', 5);
INSERT INTO valoracions VALUES (3052, 36, '14/06/2008', 7);
INSERT INTO valoracions VALUES (3052, 96, '27/04/2005', 8);
INSERT INTO valoracions VALUES (3052, 58, '13/12/2004', 9);
INSERT INTO valoracions VALUES (3053, 74, '17/10/2001', 8);
INSERT INTO valoracions VALUES (3053, 104, '30/05/2004', 2);
INSERT INTO valoracions VALUES (3053, 22, '23/03/2003', 7);
INSERT INTO valoracions VALUES (3053, 62, '29/04/2010', 9);
INSERT INTO valoracions VALUES (3053, 83, '10/08/2002', 8);
INSERT INTO valoracions VALUES (3053, 29, '05/05/2007', 4);
INSERT INTO valoracions VALUES (3053, 85, '29/06/2002', 8);
INSERT INTO valoracions VALUES (3054, 93, '14/09/2004', 8);
INSERT INTO valoracions VALUES (3054, 33, '05/06/2001', 6);
INSERT INTO valoracions VALUES (3054, 8, '12/10/2003', 9);
INSERT INTO valoracions VALUES (3054, 100, '22/07/2008', 1);
INSERT INTO valoracions VALUES (3055, 99, '05/04/2002', 4);
INSERT INTO valoracions VALUES (3055, 49, '26/11/2001', 4);
INSERT INTO valoracions VALUES (3055, 97, '25/11/2007', 5);
INSERT INTO valoracions VALUES (3055, 74, '06/09/2001', 8);
INSERT INTO valoracions VALUES (3056, 29, '22/09/2002', 6);
INSERT INTO valoracions VALUES (3056, 15, '30/04/2009', 6);
INSERT INTO valoracions VALUES (3056, 62, '13/11/2002', 5);
INSERT INTO valoracions VALUES (3057, 73, '24/01/2010', 8);
INSERT INTO valoracions VALUES (3057, 39, '23/09/2004', 7);
INSERT INTO valoracions VALUES (3058, 103, '25/08/2010', 5);
INSERT INTO valoracions VALUES (3058, 94, '04/01/2005', 1);
INSERT INTO valoracions VALUES (3058, 62, '07/11/2008', 8);
INSERT INTO valoracions VALUES (3059, 74, '19/10/2006', 8);
INSERT INTO valoracions VALUES (3059, 11, '07/01/2010', 9);
INSERT INTO valoracions VALUES (3059, 35, '13/06/2001', 6);
INSERT INTO valoracions VALUES (3059, 55, '26/02/2010', 3);
INSERT INTO valoracions VALUES (3060, 86, '16/08/2009', 7);
INSERT INTO valoracions VALUES (3060, 35, '18/11/2007', 6);
INSERT INTO valoracions VALUES (3060, 17, '17/10/2004', 8);
INSERT INTO valoracions VALUES (3060, 21, '04/05/2004', 9);
INSERT INTO valoracions VALUES (3060, 44, '09/01/2008', 4);
INSERT INTO valoracions VALUES (3060, 106, '28/04/2004', 7);
INSERT INTO valoracions VALUES (3060, 93, '29/08/2009', 8);
INSERT INTO valoracions VALUES (3060, 55, '21/09/2004', 3);
INSERT INTO valoracions VALUES (3061, 91, '04/05/2001', 7);
INSERT INTO valoracions VALUES (3061, 54, '25/11/2009', 8);
INSERT INTO valoracions VALUES (3061, 47, '23/04/2005', 4);
INSERT INTO valoracions VALUES (3061, 79, '06/07/2009', 2);
INSERT INTO valoracions VALUES (3061, 60, '29/05/2005', 7);
INSERT INTO valoracions VALUES (3061, 80, '13/04/2005', 7);
INSERT INTO valoracions VALUES (3062, 71, '07/11/2001', 9);
INSERT INTO valoracions VALUES (3062, 14, '09/09/2003', 7);
INSERT INTO valoracions VALUES (3062, 75, '22/09/2001', 6);
INSERT INTO valoracions VALUES (3062, 59, '11/11/2006', 9);
INSERT INTO valoracions VALUES (3063, 84, '08/01/2002', 5);
INSERT INTO valoracions VALUES (3063, 49, '21/07/2009', 10);
INSERT INTO valoracions VALUES (3065, 35, '18/09/2002', 7);
INSERT INTO valoracions VALUES (3065, 76, '03/06/2002', 3);
INSERT INTO valoracions VALUES (3065, 67, '12/06/2003', 8);
INSERT INTO valoracions VALUES (3065, 24, '06/02/2007', 8);
INSERT INTO valoracions VALUES (3065, 63, '12/02/2007', 8);
INSERT INTO valoracions VALUES (3066, 88, '06/10/2003', 8);
INSERT INTO valoracions VALUES (3066, 62, '06/08/2002', 3);
INSERT INTO valoracions VALUES (3066, 5, '10/03/2003', 8);
INSERT INTO valoracions VALUES (3066, 85, '05/07/2006', 7);
INSERT INTO valoracions VALUES (3066, 23, '28/11/2001', 9);
INSERT INTO valoracions VALUES (3067, 83, '23/12/2002', 3);
INSERT INTO valoracions VALUES (3067, 49, '22/12/2008', 8);
INSERT INTO valoracions VALUES (3068, 55, '05/12/2004', 3);
INSERT INTO valoracions VALUES (3068, 11, '12/04/2006', 8);
INSERT INTO valoracions VALUES (3068, 87, '08/03/2005', 1);
INSERT INTO valoracions VALUES (3068, 57, '08/01/2010', 9);
INSERT INTO valoracions VALUES (3069, 18, '01/05/2008', 5);
INSERT INTO valoracions VALUES (3069, 72, '04/10/2003', 7);
INSERT INTO valoracions VALUES (3069, 107, '02/02/2004', 2);
INSERT INTO valoracions VALUES (3069, 59, '23/05/2009', 9);
INSERT INTO valoracions VALUES (3070, 50, '06/06/2004', 5);
INSERT INTO valoracions VALUES (3070, 31, '24/04/2004', 5);
INSERT INTO valoracions VALUES (3070, 66, '25/11/2002', 8);
INSERT INTO valoracions VALUES (3071, 32, '22/03/2008', 7);
INSERT INTO valoracions VALUES (3071, 94, '02/03/2009', 9);
INSERT INTO valoracions VALUES (3071, 61, '01/06/2010', 8);
INSERT INTO valoracions VALUES (3072, 105, '02/08/2009', 8);
INSERT INTO valoracions VALUES (3072, 99, '08/02/2009', 9);
INSERT INTO valoracions VALUES (3072, 18, '11/05/2004', 5);
INSERT INTO valoracions VALUES (3072, 1, '09/12/2001', 6);
INSERT INTO valoracions VALUES (3073, 30, '05/10/2007', 6);
INSERT INTO valoracions VALUES (3073, 25, '22/03/2008', 8);
INSERT INTO valoracions VALUES (3073, 89, '05/08/2005', 5);
INSERT INTO valoracions VALUES (3073, 77, '21/09/2004', 6);
INSERT INTO valoracions VALUES (3073, 71, '25/04/2002', 9);
INSERT INTO valoracions VALUES (3074, 103, '06/03/2008', 3);
INSERT INTO valoracions VALUES (3074, 19, '16/01/2003', 7);
INSERT INTO valoracions VALUES (3074, 66, '11/04/2007', 7);
INSERT INTO valoracions VALUES (3074, 54, '23/10/2010', 10);
INSERT INTO valoracions VALUES (3074, 47, '07/08/2009', 5);
INSERT INTO valoracions VALUES (3074, 44, '02/09/2009', 5);
INSERT INTO valoracions VALUES (3074, 34, '21/01/2008', 4);
INSERT INTO valoracions VALUES (3075, 100, '26/08/2007', 8);
INSERT INTO valoracions VALUES (3075, 3, '25/10/2006', 5);
INSERT INTO valoracions VALUES (3075, 103, '21/01/2005', 10);
INSERT INTO valoracions VALUES (3075, 72, '18/08/2004', 4);
INSERT INTO valoracions VALUES (3076, 21, '24/03/2004', 5);
INSERT INTO valoracions VALUES (3076, 101, '28/02/2005', 6);
INSERT INTO valoracions VALUES (3077, 36, '03/09/2005', 9);
INSERT INTO valoracions VALUES (3077, 77, '19/07/2007', 8);
INSERT INTO valoracions VALUES (3077, 19, '23/06/2002', 9);
INSERT INTO valoracions VALUES (3077, 11, '21/08/2008', 10);
INSERT INTO valoracions VALUES (3077, 37, '13/04/2009', 9);
INSERT INTO valoracions VALUES (3077, 54, '16/06/2005', 7);
INSERT INTO valoracions VALUES (3077, 2, '22/09/2001', 10);
INSERT INTO valoracions VALUES (3077, 34, '30/12/2006', 4);
INSERT INTO valoracions VALUES (3078, 113, '02/03/2010', 3);
INSERT INTO valoracions VALUES (3078, 38, '05/06/2003', 4);
INSERT INTO valoracions VALUES (3078, 12, '16/05/2007', 9);
INSERT INTO valoracions VALUES (3079, 24, '18/12/2004', 8);
INSERT INTO valoracions VALUES (3079, 101, '28/08/2003', 1);
INSERT INTO valoracions VALUES (3079, 93, '18/08/2008', 6);
INSERT INTO valoracions VALUES (3079, 45, '11/10/2007', 7);
INSERT INTO valoracions VALUES (3079, 63, '16/02/2006', 8);
INSERT INTO valoracions VALUES (3080, 2, '17/08/2008', 10);
INSERT INTO valoracions VALUES (3080, 16, '13/08/2005', 8);
INSERT INTO valoracions VALUES (3080, 28, '15/03/2006', 4);
INSERT INTO valoracions VALUES (3080, 39, '21/07/2002', 10);
INSERT INTO valoracions VALUES (3080, 37, '05/12/2005', 6);
INSERT INTO valoracions VALUES (3080, 90, '31/08/2009', 2);
INSERT INTO valoracions VALUES (3080, 104, '16/08/2008', 8);
INSERT INTO valoracions VALUES (3080, 96, '25/12/2004', 6);
INSERT INTO valoracions VALUES (3080, 58, '27/06/2008', 6);
INSERT INTO valoracions VALUES (3080, 11, '06/11/2009', 8);
INSERT INTO valoracions VALUES (3081, 51, '26/06/2005', 5);
INSERT INTO valoracions VALUES (3082, 27, '06/07/2009', 10);
INSERT INTO valoracions VALUES (3082, 27, '25/07/2007', 9);
INSERT INTO valoracions VALUES (3082, 64, '28/08/2004', 5);
INSERT INTO valoracions VALUES (3082, 84, '07/02/2010', 7);
INSERT INTO valoracions VALUES (3082, 78, '08/11/2007', 2);
INSERT INTO valoracions VALUES (3082, 22, '28/06/2007', 8);
INSERT INTO valoracions VALUES (3083, 66, '09/09/2007', 7);
INSERT INTO valoracions VALUES (3083, 42, '15/04/2002', 9);
INSERT INTO valoracions VALUES (3083, 42, '09/02/2005', 5);
INSERT INTO valoracions VALUES (3084, 90, '09/01/2009', 5);
INSERT INTO valoracions VALUES (3084, 40, '25/08/2002', 6);
INSERT INTO valoracions VALUES (3084, 57, '16/03/2008', 6);
INSERT INTO valoracions VALUES (3085, 94, '08/09/2007', 9);
INSERT INTO valoracions VALUES (3086, 26, '24/02/2009', 7);
INSERT INTO valoracions VALUES (3086, 66, '08/02/2007', 3);
INSERT INTO valoracions VALUES (3086, 103, '02/03/2002', 9);
INSERT INTO valoracions VALUES (3087, 107, '08/02/2010', 7);
INSERT INTO valoracions VALUES (3087, 2, '21/01/2003', 7);
INSERT INTO valoracions VALUES (3087, 16, '30/08/2008', 8);
INSERT INTO valoracions VALUES (3087, 44, '19/08/2004', 8);
INSERT INTO valoracions VALUES (3088, 83, '13/10/2001', 8);
INSERT INTO valoracions VALUES (3088, 18, '01/04/2002', 7);
INSERT INTO valoracions VALUES (3088, 5, '28/10/2003', 5);
INSERT INTO valoracions VALUES (3089, 65, '15/11/2003', 5);
INSERT INTO valoracions VALUES (3089, 104, '23/05/2001', 7);
INSERT INTO valoracions VALUES (3089, 28, '11/11/2008', 9);
INSERT INTO valoracions VALUES (3089, 90, '29/07/2001', 9);
INSERT INTO valoracions VALUES (3090, 14, '12/07/2008', 9);
INSERT INTO valoracions VALUES (3090, 107, '30/05/2008', 6);
INSERT INTO valoracions VALUES (3090, 4, '24/07/2005', 8);
INSERT INTO valoracions VALUES (3090, 76, '14/06/2003', 9);
INSERT INTO valoracions VALUES (3091, 65, '29/06/2008', 5);
INSERT INTO valoracions VALUES (3091, 35, '25/09/2001', 4);
INSERT INTO valoracions VALUES (3091, 48, '16/01/2009', 4);
INSERT INTO valoracions VALUES (3091, 63, '04/03/2003', 9);
INSERT INTO valoracions VALUES (3092, 86, '12/10/2005', 8);
INSERT INTO valoracions VALUES (3092, 112, '26/11/2004', 1);
INSERT INTO valoracions VALUES (3092, 110, '17/04/2004', 6);
INSERT INTO valoracions VALUES (3093, 115, '25/03/2006', 4);
INSERT INTO valoracions VALUES (3093, 116, '22/04/2001', 9);
INSERT INTO valoracions VALUES (3094, 38, '14/08/2001', 7);
INSERT INTO valoracions VALUES (3094, 111, '27/02/2003', 2);
INSERT INTO valoracions VALUES (3094, 10, '01/05/2002', 9);
INSERT INTO valoracions VALUES (3094, 21, '01/08/2008', 6);
INSERT INTO valoracions VALUES (3094, 115, '12/01/2005', 9);
INSERT INTO valoracions VALUES (3094, 61, '30/11/2006', 6);
INSERT INTO valoracions VALUES (3094, 105, '22/05/2009', 5);
INSERT INTO valoracions VALUES (3094, 115, '26/08/2001', 3);
INSERT INTO valoracions VALUES (3095, 45, '10/11/2005', 4);
INSERT INTO valoracions VALUES (3096, 54, '06/03/2009', 5);
INSERT INTO valoracions VALUES (3096, 69, '12/10/2005', 6);
INSERT INTO valoracions VALUES (3096, 93, '10/09/2010', 6);
INSERT INTO valoracions VALUES (3096, 8, '03/04/2005', 5);
INSERT INTO valoracions VALUES (3096, 109, '20/08/2009', 0);
INSERT INTO valoracions VALUES (3096, 13, '26/11/2002', 9);
INSERT INTO valoracions VALUES (3097, 26, '17/07/2002', 4);
INSERT INTO valoracions VALUES (3098, 99, '19/05/2008', 4);
INSERT INTO valoracions VALUES (3098, 107, '15/02/2004', 4);
INSERT INTO valoracions VALUES (3098, 111, '28/03/2008', 7);
INSERT INTO valoracions VALUES (3098, 52, '18/08/2009', 6);
INSERT INTO valoracions VALUES (3099, 18, '13/12/2004', 7);
INSERT INTO valoracions VALUES (3099, 90, '02/07/2001', 7);
INSERT INTO valoracions VALUES (3099, 10, '06/08/2003', 8);
INSERT INTO valoracions VALUES (3099, 85, '08/10/2009', 9);
INSERT INTO valoracions VALUES (3099, 113, '11/12/2006', 10);
INSERT INTO valoracions VALUES (3100, 33, '07/12/2006', 6);
INSERT INTO valoracions VALUES (3100, 77, '05/04/2009', 5);
INSERT INTO valoracions VALUES (3100, 40, '21/12/2002', 3);
INSERT INTO valoracions VALUES (3100, 43, '22/07/2007', 10);
INSERT INTO valoracions VALUES (3100, 48, '27/12/2001', 4);
INSERT INTO valoracions VALUES (3101, 32, '06/04/2008', 6);
INSERT INTO valoracions VALUES (3101, 10, '15/10/2008', 6);
INSERT INTO valoracions VALUES (3102, 62, '25/10/2006', 7);
INSERT INTO valoracions VALUES (3102, 34, '20/04/2003', 6);
INSERT INTO valoracions VALUES (3102, 49, '07/07/2005', 6);
INSERT INTO valoracions VALUES (3103, 116, '09/03/2009', 10);
INSERT INTO valoracions VALUES (3103, 47, '06/09/2002', 6);
INSERT INTO valoracions VALUES (3103, 43, '21/05/2008', 8);
INSERT INTO valoracions VALUES (3103, 84, '25/04/2008', 7);
INSERT INTO valoracions VALUES (3103, 94, '07/12/2003', 5);
INSERT INTO valoracions VALUES (3103, 47, '06/09/2006', 4);
INSERT INTO valoracions VALUES (3103, 114, '30/09/2006', 7);
INSERT INTO valoracions VALUES (3103, 105, '24/07/2006', 7);
INSERT INTO valoracions VALUES (3103, 36, '08/06/2003', 4);
INSERT INTO valoracions VALUES (3104, 82, '10/10/2001', 10);
INSERT INTO valoracions VALUES (3104, 103, '14/04/2001', 7);
INSERT INTO valoracions VALUES (3104, 24, '23/06/2006', 5);
INSERT INTO valoracions VALUES (3104, 92, '19/05/2006', 9);
INSERT INTO valoracions VALUES (3104, 7, '15/04/2009', 8);
INSERT INTO valoracions VALUES (3105, 3, '21/09/2003', 7);
INSERT INTO valoracions VALUES (3105, 24, '02/03/2009', 6);
INSERT INTO valoracions VALUES (3105, 36, '29/04/2005', 5);
INSERT INTO valoracions VALUES (3106, 54, '11/01/2005', 6);
INSERT INTO valoracions VALUES (3107, 18, '20/12/2003', 4);
INSERT INTO valoracions VALUES (3107, 36, '18/03/2003', 10);
INSERT INTO valoracions VALUES (3108, 20, '12/11/2009', 5);
INSERT INTO valoracions VALUES (3108, 85, '02/02/2006', 7);
INSERT INTO valoracions VALUES (3108, 97, '20/08/2009', 4);
INSERT INTO valoracions VALUES (3108, 91, '27/03/2004', 5);
INSERT INTO valoracions VALUES (3108, 27, '03/05/2010', 8);
INSERT INTO valoracions VALUES (3108, 86, '14/07/2009', 7);
INSERT INTO valoracions VALUES (3108, 54, '23/02/2005', 7);
INSERT INTO valoracions VALUES (3109, 4, '27/08/2006', 9);
INSERT INTO valoracions VALUES (3109, 97, '16/07/2003', 7);
INSERT INTO valoracions VALUES (3110, 12, '11/12/2004', 10);
INSERT INTO valoracions VALUES (3111, 64, '06/03/2003', 5);
INSERT INTO valoracions VALUES (3111, 63, '15/05/2010', 5);
INSERT INTO valoracions VALUES (3111, 41, '09/03/2010', 6);
INSERT INTO valoracions VALUES (3111, 92, '03/09/2003', 5);
INSERT INTO valoracions VALUES (3112, 105, '14/11/2001', 2);
INSERT INTO valoracions VALUES (3112, 58, '25/07/2003', 9);
INSERT INTO valoracions VALUES (3112, 100, '11/09/2001', 9);
INSERT INTO valoracions VALUES (3113, 60, '29/07/2005', 5);
INSERT INTO valoracions VALUES (3113, 64, '11/07/2010', 6);
INSERT INTO valoracions VALUES (3113, 34, '13/09/2006', 5);
INSERT INTO valoracions VALUES (3113, 83, '06/07/2009', 3);
INSERT INTO valoracions VALUES (3113, 109, '06/08/2005', 6);
INSERT INTO valoracions VALUES (3114, 3, '21/12/2003', 6);
INSERT INTO valoracions VALUES (3114, 112, '16/04/2002', 8);
INSERT INTO valoracions VALUES (3114, 69, '27/07/2010', 7);
INSERT INTO valoracions VALUES (3114, 101, '11/07/2002', 3);
INSERT INTO valoracions VALUES (3114, 46, '08/12/2006', 7);
INSERT INTO valoracions VALUES (3114, 54, '10/04/2002', 7);
INSERT INTO valoracions VALUES (3114, 31, '30/12/2001', 5);
INSERT INTO valoracions VALUES (3114, 115, '17/03/2006', 9);
INSERT INTO valoracions VALUES (3115, 74, '27/09/2010', 8);
INSERT INTO valoracions VALUES (3115, 31, '11/02/2008', 5);
INSERT INTO valoracions VALUES (3115, 94, '15/12/2006', 6);
INSERT INTO valoracions VALUES (3116, 108, '03/02/2005', 2);
INSERT INTO valoracions VALUES (3116, 27, '17/02/2003', 8);
INSERT INTO valoracions VALUES (3117, 49, '24/08/2007', 6);
INSERT INTO valoracions VALUES (3117, 75, '08/07/2001', 4);
INSERT INTO valoracions VALUES (3117, 82, '19/05/2007', 2);
INSERT INTO valoracions VALUES (3117, 71, '02/12/2001', 3);
INSERT INTO valoracions VALUES (3117, 46, '22/04/2002', 7);
INSERT INTO valoracions VALUES (3117, 2, '31/01/2008', 7);
INSERT INTO valoracions VALUES (3118, 30, '25/01/2010', 6);
INSERT INTO valoracions VALUES (3118, 71, '27/12/2009', 8);
INSERT INTO valoracions VALUES (3118, 18, '18/10/2003', 9);
INSERT INTO valoracions VALUES (3118, 71, '07/07/2002', 8);
INSERT INTO valoracions VALUES (3118, 91, '09/09/2009', 3);
INSERT INTO valoracions VALUES (3118, 86, '16/08/2010', 4);
INSERT INTO valoracions VALUES (3119, 96, '25/09/2007', 5);
INSERT INTO valoracions VALUES (3119, 95, '12/08/2003', 10);
INSERT INTO valoracions VALUES (3119, 91, '14/06/2006', 3);
INSERT INTO valoracions VALUES (3119, 112, '08/06/2007', 3);
INSERT INTO valoracions VALUES (3119, 94, '09/01/2005', 4);
INSERT INTO valoracions VALUES (3119, 58, '20/07/2002', 9);
INSERT INTO valoracions VALUES (3119, 3, '30/12/2007', 6);
INSERT INTO valoracions VALUES (3120, 32, '10/10/2004', 6);
INSERT INTO valoracions VALUES (3120, 19, '01/02/2010', 8);
INSERT INTO valoracions VALUES (3120, 110, '28/05/2002', 1);
INSERT INTO valoracions VALUES (3120, 30, '20/10/2001', 9);
INSERT INTO valoracions VALUES (3120, 81, '28/06/2009', 7);
INSERT INTO valoracions VALUES (3120, 114, '17/07/2008', 8);
INSERT INTO valoracions VALUES (3120, 19, '29/09/2006', 9);
INSERT INTO valoracions VALUES (3121, 106, '28/04/2007', 8);
INSERT INTO valoracions VALUES (3121, 63, '17/07/2010', 7);
INSERT INTO valoracions VALUES (3121, 76, '20/03/2003', 8);
INSERT INTO valoracions VALUES (3122, 108, '30/08/2008', 8);
INSERT INTO valoracions VALUES (3122, 14, '26/07/2010', 6);
INSERT INTO valoracions VALUES (3122, 37, '08/02/2002', 7);
INSERT INTO valoracions VALUES (3122, 65, '22/06/2004', 8);
INSERT INTO valoracions VALUES (3123, 11, '12/10/2006', 10);
INSERT INTO valoracions VALUES (3123, 93, '15/12/2004', 2);
INSERT INTO valoracions VALUES (3123, 108, '09/06/2009', 7);
INSERT INTO valoracions VALUES (3123, 2, '19/09/2001', 6);
INSERT INTO valoracions VALUES (3123, 95, '26/07/2006', 10);
INSERT INTO valoracions VALUES (3123, 24, '24/11/2001', 9);
INSERT INTO valoracions VALUES (3123, 97, '17/05/2007', 7);
INSERT INTO valoracions VALUES (3123, 80, '14/01/2008', 10);
INSERT INTO valoracions VALUES (3123, 55, '24/04/2001', 5);
INSERT INTO valoracions VALUES (3124, 14, '29/08/2003', 6);
INSERT INTO valoracions VALUES (3124, 24, '22/09/2005', 8);
INSERT INTO valoracions VALUES (3124, 29, '14/05/2002', 9);
INSERT INTO valoracions VALUES (3124, 43, '11/10/2002', 7);
INSERT INTO valoracions VALUES (3124, 55, '31/07/2009', 5);
INSERT INTO valoracions VALUES (3124, 84, '28/11/2005', 4);
INSERT INTO valoracions VALUES (3125, 70, '11/07/2001', 4);
INSERT INTO valoracions VALUES (3125, 111, '27/01/2007', 7);
INSERT INTO valoracions VALUES (3125, 37, '07/01/2008', 5);
INSERT INTO valoracions VALUES (3125, 16, '13/05/2010', 8);
INSERT INTO valoracions VALUES (3126, 22, '07/06/2009', 9);
INSERT INTO valoracions VALUES (3126, 13, '21/08/2009', 6);
INSERT INTO valoracions VALUES (3126, 71, '26/10/2009', 4);
INSERT INTO valoracions VALUES (3127, 46, '03/06/2005', 7);
INSERT INTO valoracions VALUES (3127, 48, '20/11/2009', 4);
INSERT INTO valoracions VALUES (3127, 104, '16/06/2004', 2);
INSERT INTO valoracions VALUES (3128, 60, '22/02/2010', 9);
INSERT INTO valoracions VALUES (3128, 113, '22/11/2005', 1);
INSERT INTO valoracions VALUES (3128, 90, '23/05/2009', 4);
INSERT INTO valoracions VALUES (3128, 83, '12/12/2001', 8);
INSERT INTO valoracions VALUES (3128, 29, '10/10/2007', 4);
INSERT INTO valoracions VALUES (3128, 22, '04/05/2004', 10);
INSERT INTO valoracions VALUES (3128, 48, '03/08/2004', 9);
INSERT INTO valoracions VALUES (3129, 89, '27/06/2004', 9);
INSERT INTO valoracions VALUES (3129, 17, '21/07/2005', 7);
INSERT INTO valoracions VALUES (3129, 33, '04/03/2006', 6);
INSERT INTO valoracions VALUES (3129, 14, '22/08/2006', 6);
INSERT INTO valoracions VALUES (3129, 3, '03/02/2005', 7);
INSERT INTO valoracions VALUES (3130, 68, '13/10/2008', 9);
INSERT INTO valoracions VALUES (3130, 20, '20/07/2010', 7);
INSERT INTO valoracions VALUES (3130, 75, '29/08/2008', 9);
INSERT INTO valoracions VALUES (3130, 47, '10/06/2010', 8);
INSERT INTO valoracions VALUES (3130, 86, '11/11/2003', 9);
INSERT INTO valoracions VALUES (3130, 113, '01/01/2006', 4);
INSERT INTO valoracions VALUES (3131, 40, '18/02/2004', 9);
INSERT INTO valoracions VALUES (3131, 52, '06/04/2009', 4);
INSERT INTO valoracions VALUES (3131, 70, '13/10/2004', 2);
INSERT INTO valoracions VALUES (3131, 95, '15/09/2002', 4);
INSERT INTO valoracions VALUES (3132, 104, '21/05/2009', 3);
INSERT INTO valoracions VALUES (3132, 65, '09/10/2001', 5);
INSERT INTO valoracions VALUES (3132, 44, '07/12/2006', 9);
INSERT INTO valoracions VALUES (3132, 12, '07/03/2004', 6);
INSERT INTO valoracions VALUES (3132, 18, '10/06/2010', 5);
INSERT INTO valoracions VALUES (3132, 59, '03/04/2006', 6);
INSERT INTO valoracions VALUES (3133, 5, '07/08/2006', 9);
INSERT INTO valoracions VALUES (3133, 74, '12/10/2007', 5);
INSERT INTO valoracions VALUES (3134, 95, '20/11/2003', 7);
INSERT INTO valoracions VALUES (3134, 53, '27/05/2005', 7);
INSERT INTO valoracions VALUES (3134, 68, '22/05/2008', 4);
INSERT INTO valoracions VALUES (3134, 65, '06/10/2010', 7);
INSERT INTO valoracions VALUES (3135, 89, '11/02/2010', 9);
INSERT INTO valoracions VALUES (3135, 31, '30/09/2002', 9);
INSERT INTO valoracions VALUES (3135, 106, '05/08/2007', 8);
INSERT INTO valoracions VALUES (3135, 109, '31/03/2002', 4);
INSERT INTO valoracions VALUES (3135, 91, '15/04/2004', 5);
INSERT INTO valoracions VALUES (3135, 84, '18/01/2008', 8);
INSERT INTO valoracions VALUES (3136, 63, '16/06/2008', 4);
INSERT INTO valoracions VALUES (3136, 68, '10/03/2008', 10);
INSERT INTO valoracions VALUES (3137, 98, '15/04/2009', 4);
INSERT INTO valoracions VALUES (3137, 71, '04/04/2007', 5);
INSERT INTO valoracions VALUES (3137, 41, '29/02/2008', 5);
INSERT INTO valoracions VALUES (3137, 20, '27/02/2004', 9);
INSERT INTO valoracions VALUES (3138, 47, '24/09/2008', 6);
INSERT INTO valoracions VALUES (3138, 60, '24/04/2001', 5);
INSERT INTO valoracions VALUES (3138, 16, '27/06/2007', 10);
INSERT INTO valoracions VALUES (3138, 86, '16/04/2008', 2);
INSERT INTO valoracions VALUES (3139, 31, '22/12/2002', 7);
INSERT INTO valoracions VALUES (3140, 74, '14/06/2005', 3);
INSERT INTO valoracions VALUES (3140, 17, '02/12/2008', 9);
INSERT INTO valoracions VALUES (3140, 35, '25/07/2005', 6);
INSERT INTO valoracions VALUES (3141, 71, '06/10/2004', 3);
INSERT INTO valoracions VALUES (3141, 67, '13/10/2008', 7);
INSERT INTO valoracions VALUES (3141, 54, '20/12/2009', 6);
INSERT INTO valoracions VALUES (3141, 103, '11/02/2005', 8);
INSERT INTO valoracions VALUES (3141, 88, '02/02/2005', 8);
INSERT INTO valoracions VALUES (3142, 14, '24/08/2006', 7);
INSERT INTO valoracions VALUES (3142, 57, '27/03/2007', 5);
INSERT INTO valoracions VALUES (3142, 31, '30/05/2003', 10);
INSERT INTO valoracions VALUES (3142, 63, '01/08/2002', 8);
INSERT INTO valoracions VALUES (3142, 13, '18/10/2002', 5);
INSERT INTO valoracions VALUES (3142, 104, '28/07/2010', 6);
INSERT INTO valoracions VALUES (3143, 69, '14/10/2002', 9);
INSERT INTO valoracions VALUES (3143, 76, '27/03/2010', 3);
INSERT INTO valoracions VALUES (3143, 52, '08/01/2002', 9);
INSERT INTO valoracions VALUES (3144, 98, '12/08/2003', 1);
INSERT INTO valoracions VALUES (3144, 102, '13/09/2009', 6);
INSERT INTO valoracions VALUES (3145, 4, '02/12/2003', 5);
INSERT INTO valoracions VALUES (3145, 87, '14/10/2005', 10);
INSERT INTO valoracions VALUES (3145, 100, '23/05/2004', 10);
INSERT INTO valoracions VALUES (3145, 10, '31/12/2009', 5);
INSERT INTO valoracions VALUES (3145, 20, '26/07/2003', 9);
INSERT INTO valoracions VALUES (3145, 82, '27/05/2008', 2);
INSERT INTO valoracions VALUES (3146, 100, '07/11/2001', 9);
INSERT INTO valoracions VALUES (3146, 56, '03/03/2008', 4);
INSERT INTO valoracions VALUES (3146, 34, '24/11/2009', 9);
INSERT INTO valoracions VALUES (3146, 94, '12/12/2004', 10);
INSERT INTO valoracions VALUES (3147, 80, '03/12/2005', 9);
INSERT INTO valoracions VALUES (3147, 56, '02/05/2003', 9);
INSERT INTO valoracions VALUES (3147, 14, '06/05/2010', 5);
INSERT INTO valoracions VALUES (3147, 99, '10/09/2008', 4);
INSERT INTO valoracions VALUES (3147, 87, '04/12/2006', 3);
INSERT INTO valoracions VALUES (3148, 53, '27/09/2009', 4);
INSERT INTO valoracions VALUES (3148, 52, '10/03/2006', 6);
INSERT INTO valoracions VALUES (3148, 10, '07/07/2003', 5);
INSERT INTO valoracions VALUES (3148, 13, '19/03/2008', 8);
INSERT INTO valoracions VALUES (3149, 66, '18/05/2008', 8);
INSERT INTO valoracions VALUES (3149, 24, '01/01/2008', 9);
INSERT INTO valoracions VALUES (3150, 96, '16/12/2003', 5);
INSERT INTO valoracions VALUES (3150, 6, '28/08/2002', 5);
INSERT INTO valoracions VALUES (3150, 37, '13/06/2007', 6);
INSERT INTO valoracions VALUES (3150, 59, '18/01/2010', 3);
INSERT INTO valoracions VALUES (3150, 103, '04/09/2003', 7);
INSERT INTO valoracions VALUES (3151, 98, '04/05/2006', 8);
INSERT INTO valoracions VALUES (3151, 84, '17/05/2001', 7);
INSERT INTO valoracions VALUES (3151, 20, '16/04/2009', 7);
INSERT INTO valoracions VALUES (3151, 25, '01/09/2010', 5);
INSERT INTO valoracions VALUES (3152, 111, '31/01/2004', 8);
INSERT INTO valoracions VALUES (3152, 115, '29/10/2002', 1);
INSERT INTO valoracions VALUES (3153, 57, '19/08/2008', 7);
INSERT INTO valoracions VALUES (3153, 35, '11/06/2007', 10);
INSERT INTO valoracions VALUES (3153, 23, '02/11/2006', 9);
INSERT INTO valoracions VALUES (3153, 114, '24/04/2006', 8);
INSERT INTO valoracions VALUES (3154, 74, '23/07/2001', 7);
INSERT INTO valoracions VALUES (3154, 6, '25/07/2009', 8);
INSERT INTO valoracions VALUES (3154, 17, '11/07/2007', 9);
INSERT INTO valoracions VALUES (3154, 105, '11/03/2003', 5);
INSERT INTO valoracions VALUES (3155, 88, '10/04/2002', 1);
INSERT INTO valoracions VALUES (3155, 33, '14/10/2002', 6);
INSERT INTO valoracions VALUES (3155, 40, '05/11/2006', 9);
INSERT INTO valoracions VALUES (3155, 12, '20/12/2009', 7);
INSERT INTO valoracions VALUES (3155, 78, '29/11/2002', 9);
INSERT INTO valoracions VALUES (3155, 19, '19/04/2008', 6);
INSERT INTO valoracions VALUES (3155, 68, '17/07/2006', 2);
INSERT INTO valoracions VALUES (3155, 83, '31/12/2009', 7);
INSERT INTO valoracions VALUES (3156, 5, '01/11/2009', 7);
INSERT INTO valoracions VALUES (3156, 114, '15/10/2010', 7);
INSERT INTO valoracions VALUES (3156, 80, '16/11/2009', 8);
INSERT INTO valoracions VALUES (3156, 22, '19/10/2010', 8);
INSERT INTO valoracions VALUES (3156, 68, '02/01/2004', 8);
INSERT INTO valoracions VALUES (3156, 110, '21/10/2004', 6);
INSERT INTO valoracions VALUES (3156, 86, '29/02/2008', 3);
INSERT INTO valoracions VALUES (3157, 83, '23/06/2005', 4);
INSERT INTO valoracions VALUES (3157, 43, '25/02/2002', 9);
INSERT INTO valoracions VALUES (3157, 76, '23/06/2002', 9);
INSERT INTO valoracions VALUES (3157, 36, '10/11/2005', 7);
INSERT INTO valoracions VALUES (3157, 87, '19/09/2007', 8);
INSERT INTO valoracions VALUES (3158, 56, '17/07/2007', 7);
INSERT INTO valoracions VALUES (3158, 23, '25/03/2003', 5);
INSERT INTO valoracions VALUES (3158, 24, '16/08/2009', 4);
INSERT INTO valoracions VALUES (3158, 29, '26/11/2001', 7);
INSERT INTO valoracions VALUES (3158, 87, '14/12/2003', 9);
INSERT INTO valoracions VALUES (3159, 57, '30/06/2002', 6);
INSERT INTO valoracions VALUES (3159, 11, '15/03/2009', 5);
INSERT INTO valoracions VALUES (3159, 63, '18/09/2006', 4);
INSERT INTO valoracions VALUES (3159, 47, '20/12/2001', 9);
INSERT INTO valoracions VALUES (3160, 52, '26/02/2008', 4);
INSERT INTO valoracions VALUES (3160, 31, '08/10/2003', 9);
INSERT INTO valoracions VALUES (3160, 24, '06/09/2006', 4);
INSERT INTO valoracions VALUES (3161, 46, '02/02/2007', 5);
INSERT INTO valoracions VALUES (3161, 27, '14/08/2001', 7);
INSERT INTO valoracions VALUES (3161, 76, '25/02/2008', 4);
INSERT INTO valoracions VALUES (3162, 71, '28/04/2006', 7);
INSERT INTO valoracions VALUES (3162, 63, '01/12/2003', 4);
INSERT INTO valoracions VALUES (3162, 99, '15/02/2009', 3);
INSERT INTO valoracions VALUES (3162, 88, '02/12/2001', 2);
INSERT INTO valoracions VALUES (3162, 78, '10/08/2002', 4);
INSERT INTO valoracions VALUES (3162, 12, '30/04/2005', 6);
INSERT INTO valoracions VALUES (3163, 42, '17/01/2008', 4);
INSERT INTO valoracions VALUES (3163, 18, '25/10/2004', 8);
INSERT INTO valoracions VALUES (3163, 74, '27/09/2002', 5);
INSERT INTO valoracions VALUES (3163, 61, '29/12/2006', 8);
INSERT INTO valoracions VALUES (3163, 4, '11/09/2001', 7);
INSERT INTO valoracions VALUES (3163, 21, '28/02/2005', 8);
INSERT INTO valoracions VALUES (3163, 102, '28/08/2010', 4);
INSERT INTO valoracions VALUES (3163, 69, '19/07/2006', 3);
INSERT INTO valoracions VALUES (3163, 94, '29/12/2003', 8);
INSERT INTO valoracions VALUES (3164, 73, '26/12/2005', 3);
INSERT INTO valoracions VALUES (3164, 37, '19/09/2002', 5);
INSERT INTO valoracions VALUES (3164, 102, '25/04/2007', 3);
INSERT INTO valoracions VALUES (3164, 49, '16/09/2007', 8);
INSERT INTO valoracions VALUES (3165, 89, '02/10/2005', 2);
INSERT INTO valoracions VALUES (3165, 86, '06/06/2009', 6);
INSERT INTO valoracions VALUES (3166, 18, '27/11/2003', 6);
INSERT INTO valoracions VALUES (3166, 7, '18/05/2001', 6);
INSERT INTO valoracions VALUES (3166, 56, '02/12/2008', 9);
INSERT INTO valoracions VALUES (3166, 12, '15/01/2007', 8);
INSERT INTO valoracions VALUES (3166, 91, '03/01/2006', 4);
INSERT INTO valoracions VALUES (3166, 74, '30/12/2004', 8);
INSERT INTO valoracions VALUES (3167, 49, '06/01/2010', 9);
INSERT INTO valoracions VALUES (3167, 22, '20/07/2009', 5);
INSERT INTO valoracions VALUES (3167, 43, '10/05/2001', 8);
INSERT INTO valoracions VALUES (3167, 6, '19/07/2002', 8);
INSERT INTO valoracions VALUES (3168, 70, '31/08/2001', 9);
INSERT INTO valoracions VALUES (3168, 54, '17/02/2005', 10);
INSERT INTO valoracions VALUES (3169, 48, '23/12/2004', 4);
INSERT INTO valoracions VALUES (3169, 28, '26/08/2010', 4);
INSERT INTO valoracions VALUES (3170, 1, '29/05/2002', 7);
INSERT INTO valoracions VALUES (3170, 27, '23/02/2007', 6);
INSERT INTO valoracions VALUES (3170, 77, '23/06/2008', 9);
INSERT INTO valoracions VALUES (3170, 97, '08/09/2009', 7);
INSERT INTO valoracions VALUES (3170, 28, '22/11/2001', 8);
INSERT INTO valoracions VALUES (3170, 97, '28/08/2010', 5);
INSERT INTO valoracions VALUES (3170, 99, '19/07/2004', 3);
INSERT INTO valoracions VALUES (3171, 14, '19/02/2003', 5);
INSERT INTO valoracions VALUES (3171, 113, '15/02/2004', 0);
INSERT INTO valoracions VALUES (3171, 24, '15/12/2001', 6);
INSERT INTO valoracions VALUES (3172, 21, '19/01/2005', 6);
INSERT INTO valoracions VALUES (3172, 67, '19/12/2008', 6);
INSERT INTO valoracions VALUES (3172, 58, '08/02/2006', 3);
INSERT INTO valoracions VALUES (3172, 47, '25/05/2009', 4);
INSERT INTO valoracions VALUES (3173, 77, '27/05/2006', 7);
INSERT INTO valoracions VALUES (3173, 78, '08/05/2003', 7);
INSERT INTO valoracions VALUES (3173, 4, '28/11/2006', 7);
INSERT INTO valoracions VALUES (3173, 36, '10/06/2006', 5);
INSERT INTO valoracions VALUES (3175, 10, '03/08/2003', 8);
INSERT INTO valoracions VALUES (3175, 9, '11/11/2002', 7);
INSERT INTO valoracions VALUES (3175, 28, '18/10/2003', 6);
INSERT INTO valoracions VALUES (3175, 45, '04/08/2007', 7);
INSERT INTO valoracions VALUES (3175, 23, '24/09/2004', 5);
INSERT INTO valoracions VALUES (3175, 35, '07/08/2007', 7);
INSERT INTO valoracions VALUES (3175, 73, '17/02/2006', 7);
INSERT INTO valoracions VALUES (3176, 47, '07/09/2004', 4);
INSERT INTO valoracions VALUES (3176, 31, '28/02/2005', 6);
INSERT INTO valoracions VALUES (3176, 113, '06/09/2008', 4);
INSERT INTO valoracions VALUES (3176, 84, '24/03/2009', 7);
INSERT INTO valoracions VALUES (3176, 1, '12/10/2007', 10);
INSERT INTO valoracions VALUES (3176, 53, '19/01/2008', 5);
INSERT INTO valoracions VALUES (3176, 39, '27/02/2008', 5);
INSERT INTO valoracions VALUES (3177, 28, '28/04/2009', 4);
INSERT INTO valoracions VALUES (3177, 61, '02/02/2004', 8);
INSERT INTO valoracions VALUES (3177, 43, '11/02/2008', 7);
INSERT INTO valoracions VALUES (3178, 63, '12/06/2005', 3);
INSERT INTO valoracions VALUES (3178, 53, '31/05/2007', 6);
INSERT INTO valoracions VALUES (3178, 116, '01/02/2010', 8);
INSERT INTO valoracions VALUES (3178, 21, '26/07/2007', 7);
INSERT INTO valoracions VALUES (3179, 103, '21/04/2001', 3);
INSERT INTO valoracions VALUES (3179, 65, '29/04/2001', 2);
INSERT INTO valoracions VALUES (3180, 14, '05/10/2006', 8);
INSERT INTO valoracions VALUES (3180, 81, '20/02/2002', 5);
INSERT INTO valoracions VALUES (3180, 88, '29/10/2006', 2);
INSERT INTO valoracions VALUES (3180, 35, '21/04/2010', 8);
INSERT INTO valoracions VALUES (3181, 79, '05/01/2007', 9);
INSERT INTO valoracions VALUES (3182, 116, '28/12/2004', 1);
INSERT INTO valoracions VALUES (3182, 26, '26/07/2005', 9);
INSERT INTO valoracions VALUES (3182, 103, '26/12/2003', 9);
INSERT INTO valoracions VALUES (3182, 37, '20/03/2003', 7);
INSERT INTO valoracions VALUES (3183, 112, '14/12/2001', 5);
INSERT INTO valoracions VALUES (3183, 113, '09/08/2003', 4);
INSERT INTO valoracions VALUES (3183, 49, '18/01/2010', 5);
INSERT INTO valoracions VALUES (3183, 108, '06/11/2004', 0);
INSERT INTO valoracions VALUES (3183, 79, '18/10/2007', 8);
INSERT INTO valoracions VALUES (3183, 49, '11/06/2006', 6);
INSERT INTO valoracions VALUES (3184, 45, '29/04/2004', 8);
INSERT INTO valoracions VALUES (3184, 29, '06/01/2002', 9);
INSERT INTO valoracions VALUES (3184, 108, '12/09/2001', 3);
INSERT INTO valoracions VALUES (3185, 33, '05/10/2003', 9);
INSERT INTO valoracions VALUES (3185, 29, '03/06/2002', 9);
INSERT INTO valoracions VALUES (3185, 48, '29/10/2006', 8);
INSERT INTO valoracions VALUES (3185, 13, '03/08/2004', 8);
INSERT INTO valoracions VALUES (3186, 76, '13/03/2006', 8);
INSERT INTO valoracions VALUES (3186, 7, '08/04/2006', 9);
INSERT INTO valoracions VALUES (3186, 15, '18/09/2001', 9);
INSERT INTO valoracions VALUES (3186, 25, '21/09/2007', 10);
INSERT INTO valoracions VALUES (3187, 81, '19/01/2009', 3);
INSERT INTO valoracions VALUES (3188, 99, '07/02/2003', 5);
INSERT INTO valoracions VALUES (3188, 36, '18/12/2007', 4);
INSERT INTO valoracions VALUES (3188, 108, '31/03/2002', 8);
INSERT INTO valoracions VALUES (3189, 73, '15/08/2010', 6);
INSERT INTO valoracions VALUES (3189, 25, '16/04/2005', 8);
INSERT INTO valoracions VALUES (3189, 79, '11/02/2006', 3);
INSERT INTO valoracions VALUES (3189, 68, '04/10/2009', 6);
INSERT INTO valoracions VALUES (3190, 102, '26/03/2010', 9);
INSERT INTO valoracions VALUES (3190, 79, '05/02/2009', 10);
INSERT INTO valoracions VALUES (3190, 63, '18/07/2001', 5);
INSERT INTO valoracions VALUES (3191, 33, '16/12/2005', 6);
INSERT INTO valoracions VALUES (3191, 56, '08/06/2002', 8);
INSERT INTO valoracions VALUES (3191, 104, '20/02/2007', 1);
INSERT INTO valoracions VALUES (3192, 36, '30/12/2007', 5);
INSERT INTO valoracions VALUES (3192, 29, '24/08/2009', 6);
INSERT INTO valoracions VALUES (3192, 4, '30/07/2010', 9);
INSERT INTO valoracions VALUES (3192, 111, '08/06/2004', 6);
INSERT INTO valoracions VALUES (3192, 53, '03/01/2008', 7);
INSERT INTO valoracions VALUES (3192, 97, '25/09/2010', 7);
INSERT INTO valoracions VALUES (3192, 30, '24/08/2009', 5);
INSERT INTO valoracions VALUES (3192, 60, '18/11/2003', 9);
INSERT INTO valoracions VALUES (3193, 5, '04/10/2008', 7);
INSERT INTO valoracions VALUES (3193, 43, '02/01/2008', 9);
INSERT INTO valoracions VALUES (3193, 42, '09/01/2004', 5);
INSERT INTO valoracions VALUES (3193, 14, '18/08/2007', 9);
INSERT INTO valoracions VALUES (3194, 33, '22/11/2005', 7);
INSERT INTO valoracions VALUES (3194, 103, '25/06/2008', 1);
INSERT INTO valoracions VALUES (3194, 52, '02/11/2005', 4);
INSERT INTO valoracions VALUES (3194, 38, '22/01/2010', 10);
INSERT INTO valoracions VALUES (3194, 73, '20/12/2005', 3);
INSERT INTO valoracions VALUES (3195, 1, '20/11/2008', 6);
INSERT INTO valoracions VALUES (3195, 58, '28/12/2001', 6);
INSERT INTO valoracions VALUES (3195, 60, '01/12/2009', 6);
INSERT INTO valoracions VALUES (3195, 44, '25/09/2003', 8);
INSERT INTO valoracions VALUES (3195, 14, '16/05/2004', 9);
INSERT INTO valoracions VALUES (3195, 43, '19/07/2001', 7);
INSERT INTO valoracions VALUES (3196, 85, '06/05/2009', 6);
INSERT INTO valoracions VALUES (3196, 31, '09/07/2001', 5);
INSERT INTO valoracions VALUES (3196, 70, '27/04/2006', 3);
INSERT INTO valoracions VALUES (3197, 5, '19/07/2009', 7);
INSERT INTO valoracions VALUES (3197, 12, '19/04/2001', 8);
INSERT INTO valoracions VALUES (3197, 31, '12/06/2003', 7);
INSERT INTO valoracions VALUES (3197, 90, '14/01/2004', 7);
INSERT INTO valoracions VALUES (3197, 107, '13/07/2004', 0);
INSERT INTO valoracions VALUES (3197, 73, '15/05/2009', 8);
INSERT INTO valoracions VALUES (3198, 61, '06/02/2006', 5);
INSERT INTO valoracions VALUES (3198, 18, '23/04/2004', 5);
INSERT INTO valoracions VALUES (3198, 99, '16/02/2010', 10);
INSERT INTO valoracions VALUES (3198, 110, '29/05/2002', 2);
INSERT INTO valoracions VALUES (3198, 80, '29/06/2010', 3);
INSERT INTO valoracions VALUES (3198, 66, '03/12/2008', 2);
INSERT INTO valoracions VALUES (3198, 12, '16/07/2003', 5);
INSERT INTO valoracions VALUES (3198, 85, '09/02/2002', 5);
INSERT INTO valoracions VALUES (3198, 66, '23/06/2010', 9);
INSERT INTO valoracions VALUES (3198, 73, '12/04/2002', 7);
INSERT INTO valoracions VALUES (3199, 61, '25/06/2008', 10);
INSERT INTO valoracions VALUES (3199, 8, '13/05/2008', 6);
INSERT INTO valoracions VALUES (3199, 75, '22/05/2010', 10);
INSERT INTO valoracions VALUES (3200, 67, '16/04/2009', 5);
INSERT INTO valoracions VALUES (3200, 82, '14/04/2005', 4);
INSERT INTO valoracions VALUES (3200, 8, '06/09/2005', 6);
INSERT INTO valoracions VALUES (3200, 64, '26/07/2007', 5);
INSERT INTO valoracions VALUES (3200, 63, '30/05/2001', 9);
INSERT INTO valoracions VALUES (3200, 33, '02/07/2001', 5);
INSERT INTO valoracions VALUES (3200, 75, '30/08/2008', 2);
INSERT INTO valoracions VALUES (3201, 35, '01/09/2001', 4);
INSERT INTO valoracions VALUES (3201, 32, '26/08/2010', 6);
INSERT INTO valoracions VALUES (3201, 13, '14/01/2007', 6);
INSERT INTO valoracions VALUES (3201, 103, '12/06/2001', 3);
INSERT INTO valoracions VALUES (3202, 92, '23/08/2001', 2);
INSERT INTO valoracions VALUES (3202, 12, '11/12/2005', 8);
INSERT INTO valoracions VALUES (3202, 56, '09/02/2009', 9);
INSERT INTO valoracions VALUES (3202, 1, '12/10/2006', 9);
INSERT INTO valoracions VALUES (3203, 18, '17/01/2006', 6);
INSERT INTO valoracions VALUES (3203, 22, '28/10/2004', 9);
INSERT INTO valoracions VALUES (3203, 11, '15/02/2008', 7);
INSERT INTO valoracions VALUES (3204, 4, '25/03/2008', 8);
INSERT INTO valoracions VALUES (3204, 99, '09/01/2009', 4);
INSERT INTO valoracions VALUES (3204, 33, '16/10/2009', 9);
INSERT INTO valoracions VALUES (3204, 80, '29/01/2005', 5);
INSERT INTO valoracions VALUES (3204, 16, '03/04/2010', 9);
INSERT INTO valoracions VALUES (3204, 115, '23/04/2008', 5);
INSERT INTO valoracions VALUES (3204, 1, '21/10/2004', 9);
INSERT INTO valoracions VALUES (3204, 18, '07/04/2004', 9);
INSERT INTO valoracions VALUES (3205, 64, '07/11/2002', 9);
INSERT INTO valoracions VALUES (3205, 101, '10/09/2010', 5);
INSERT INTO valoracions VALUES (3205, 31, '29/03/2007', 7);
INSERT INTO valoracions VALUES (3205, 70, '20/04/2008', 7);
INSERT INTO valoracions VALUES (3205, 41, '31/05/2008', 9);
INSERT INTO valoracions VALUES (3205, 38, '10/01/2008', 4);
INSERT INTO valoracions VALUES (3205, 51, '31/07/2003', 6);
INSERT INTO valoracions VALUES (3206, 54, '19/06/2001', 6);
INSERT INTO valoracions VALUES (3207, 72, '22/06/2004', 8);
INSERT INTO valoracions VALUES (3207, 110, '16/07/2005', 9);
INSERT INTO valoracions VALUES (3208, 74, '08/12/2008', 8);
INSERT INTO valoracions VALUES (3208, 87, '06/02/2009', 8);
INSERT INTO valoracions VALUES (3208, 48, '08/04/2006', 7);
INSERT INTO valoracions VALUES (3208, 51, '21/05/2010', 10);
INSERT INTO valoracions VALUES (3208, 68, '31/07/2002', 4);
INSERT INTO valoracions VALUES (3208, 14, '21/05/2009', 6);
INSERT INTO valoracions VALUES (3209, 7, '03/07/2002', 5);
INSERT INTO valoracions VALUES (3209, 69, '11/11/2005', 5);
INSERT INTO valoracions VALUES (3209, 111, '04/06/2009', 1);
INSERT INTO valoracions VALUES (3209, 28, '02/10/2007', 5);
INSERT INTO valoracions VALUES (3210, 62, '03/10/2010', 8);
INSERT INTO valoracions VALUES (3210, 105, '29/10/2005', 3);
INSERT INTO valoracions VALUES (3211, 111, '06/12/2001', 3);
INSERT INTO valoracions VALUES (3211, 54, '29/07/2004', 9);
INSERT INTO valoracions VALUES (3211, 62, '04/12/2003', 3);
INSERT INTO valoracions VALUES (3211, 73, '22/02/2007', 8);
INSERT INTO valoracions VALUES (3211, 27, '03/04/2002', 9);
INSERT INTO valoracions VALUES (3211, 21, '28/06/2009', 8);
INSERT INTO valoracions VALUES (3212, 50, '04/03/2002', 9);
INSERT INTO valoracions VALUES (3212, 30, '17/07/2007', 9);
INSERT INTO valoracions VALUES (3213, 86, '29/12/2007', 5);
INSERT INTO valoracions VALUES (3213, 84, '19/08/2008', 7);
INSERT INTO valoracions VALUES (3214, 2, '02/04/2002', 9);
INSERT INTO valoracions VALUES (3214, 50, '03/06/2010', 9);
INSERT INTO valoracions VALUES (3214, 46, '26/10/2001', 9);
INSERT INTO valoracions VALUES (3214, 106, '22/04/2004', 5);
INSERT INTO valoracions VALUES (3214, 110, '25/03/2005', 7);
INSERT INTO valoracions VALUES (3215, 77, '19/04/2003', 8);
INSERT INTO valoracions VALUES (3215, 95, '26/09/2007', 7);
INSERT INTO valoracions VALUES (3215, 101, '30/05/2006', 2);
INSERT INTO valoracions VALUES (3215, 84, '15/03/2003', 8);
INSERT INTO valoracions VALUES (3215, 41, '06/08/2002', 9);
INSERT INTO valoracions VALUES (3215, 103, '06/03/2002', 7);
INSERT INTO valoracions VALUES (3216, 4, '27/07/2003', 9);
INSERT INTO valoracions VALUES (3216, 106, '04/04/2007', 5);
INSERT INTO valoracions VALUES (3216, 8, '08/08/2001', 5);
INSERT INTO valoracions VALUES (3216, 102, '04/05/2009', 3);
INSERT INTO valoracions VALUES (3216, 89, '23/04/2003', 6);
INSERT INTO valoracions VALUES (3217, 35, '14/02/2008', 10);
INSERT INTO valoracions VALUES (3217, 112, '03/01/2009', 5);
INSERT INTO valoracions VALUES (3219, 24, '27/04/2001', 7);
INSERT INTO valoracions VALUES (3219, 87, '21/09/2002', 7);
INSERT INTO valoracions VALUES (3219, 64, '29/06/2010', 6);
INSERT INTO valoracions VALUES (3219, 21, '19/01/2002', 7);
INSERT INTO valoracions VALUES (3219, 110, '03/11/2009', 7);
INSERT INTO valoracions VALUES (3220, 108, '29/10/2002', 2);
INSERT INTO valoracions VALUES (3220, 32, '01/05/2009', 6);
INSERT INTO valoracions VALUES (3220, 108, '12/05/2001', 5);
INSERT INTO valoracions VALUES (3220, 37, '15/06/2006', 9);
INSERT INTO valoracions VALUES (3220, 23, '31/10/2007', 5);
INSERT INTO valoracions VALUES (3221, 36, '04/09/2008', 4);
INSERT INTO valoracions VALUES (3221, 70, '06/01/2010', 8);
INSERT INTO valoracions VALUES (3221, 31, '28/07/2007', 7);
INSERT INTO valoracions VALUES (3222, 42, '20/05/2009', 6);
INSERT INTO valoracions VALUES (3222, 70, '05/11/2008', 7);
INSERT INTO valoracions VALUES (3222, 111, '28/09/2002', 1);
INSERT INTO valoracions VALUES (3222, 48, '09/11/2009', 7);
INSERT INTO valoracions VALUES (3223, 48, '26/03/2008', 4);
INSERT INTO valoracions VALUES (3223, 110, '10/10/2005', 8);
INSERT INTO valoracions VALUES (3223, 47, '07/08/2010', 5);
INSERT INTO valoracions VALUES (3224, 116, '29/05/2009', 10);
INSERT INTO valoracions VALUES (3224, 98, '11/07/2003', 10);
INSERT INTO valoracions VALUES (3224, 107, '02/07/2003', 2);
INSERT INTO valoracions VALUES (3224, 44, '22/04/2009', 9);
INSERT INTO valoracions VALUES (3224, 41, '17/10/2005', 3);
INSERT INTO valoracions VALUES (3224, 114, '20/03/2002', 5);
INSERT INTO valoracions VALUES (3224, 86, '08/03/2007', 5);
INSERT INTO valoracions VALUES (3224, 8, '09/03/2002', 6);
INSERT INTO valoracions VALUES (3225, 72, '07/08/2008', 4);
INSERT INTO valoracions VALUES (3225, 24, '14/06/2008', 9);
INSERT INTO valoracions VALUES (3225, 17, '24/09/2004', 5);
INSERT INTO valoracions VALUES (3225, 114, '18/11/2009', 5);
INSERT INTO valoracions VALUES (3225, 112, '30/11/2007', 9);
INSERT INTO valoracions VALUES (3226, 45, '10/02/2008', 9);
INSERT INTO valoracions VALUES (3226, 59, '17/10/2007', 3);
INSERT INTO valoracions VALUES (3226, 102, '20/04/2007', 5);
INSERT INTO valoracions VALUES (3226, 33, '12/01/2007', 6);
INSERT INTO valoracions VALUES (3226, 45, '10/10/2005', 8);
INSERT INTO valoracions VALUES (3227, 7, '20/01/2004', 8);
INSERT INTO valoracions VALUES (3228, 73, '02/02/2006', 3);
INSERT INTO valoracions VALUES (3229, 45, '15/07/2004', 9);
INSERT INTO valoracions VALUES (3229, 40, '26/01/2003', 9);
INSERT INTO valoracions VALUES (3229, 111, '09/10/2003', 2);
INSERT INTO valoracions VALUES (3229, 63, '11/09/2005', 10);
INSERT INTO valoracions VALUES (3229, 20, '19/05/2001', 8);
INSERT INTO valoracions VALUES (3229, 43, '19/05/2006', 7);
INSERT INTO valoracions VALUES (3229, 4, '26/08/2010', 7);
INSERT INTO valoracions VALUES (3230, 89, '20/05/2005', 6);
INSERT INTO valoracions VALUES (3230, 35, '21/05/2010', 7);
INSERT INTO valoracions VALUES (3230, 57, '11/12/2004', 5);
INSERT INTO valoracions VALUES (3230, 75, '11/04/2005', 3);
INSERT INTO valoracions VALUES (3230, 70, '15/02/2002', 3);
INSERT INTO valoracions VALUES (3231, 113, '12/11/2009', 10);
INSERT INTO valoracions VALUES (3231, 56, '22/11/2001', 4);
INSERT INTO valoracions VALUES (3231, 74, '11/02/2008', 3);
INSERT INTO valoracions VALUES (3231, 35, '09/07/2008', 5);
INSERT INTO valoracions VALUES (3231, 96, '11/11/2003', 4);
INSERT INTO valoracions VALUES (3231, 17, '06/11/2001', 9);
INSERT INTO valoracions VALUES (3232, 9, '28/12/2009', 6);
INSERT INTO valoracions VALUES (3232, 30, '23/02/2006', 9);
INSERT INTO valoracions VALUES (3233, 21, '17/01/2007', 5);
INSERT INTO valoracions VALUES (3233, 105, '09/03/2010', 5);
INSERT INTO valoracions VALUES (3234, 4, '30/06/2007', 9);
INSERT INTO valoracions VALUES (3234, 24, '05/10/2001', 9);
INSERT INTO valoracions VALUES (3234, 21, '17/11/2004', 8);
INSERT INTO valoracions VALUES (3234, 10, '17/06/2001', 8);
INSERT INTO valoracions VALUES (3234, 108, '14/05/2010', 7);
INSERT INTO valoracions VALUES (3235, 6, '07/05/2006', 9);
INSERT INTO valoracions VALUES (3235, 62, '08/07/2004', 5);
INSERT INTO valoracions VALUES (3235, 21, '26/03/2006', 7);
INSERT INTO valoracions VALUES (3236, 21, '22/03/2010', 8);
INSERT INTO valoracions VALUES (3236, 99, '30/04/2001', 8);
INSERT INTO valoracions VALUES (3236, 106, '18/10/2003', 7);
INSERT INTO valoracions VALUES (3236, 49, '01/10/2003', 4);
INSERT INTO valoracions VALUES (3236, 50, '16/09/2007', 7);
INSERT INTO valoracions VALUES (3236, 14, '28/06/2002', 9);
INSERT INTO valoracions VALUES (3236, 71, '18/12/2006', 8);
INSERT INTO valoracions VALUES (3237, 52, '27/02/2008', 5);
INSERT INTO valoracions VALUES (3237, 107, '05/10/2010', 7);
INSERT INTO valoracions VALUES (3238, 111, '28/11/2001', 5);
INSERT INTO valoracions VALUES (3238, 107, '11/08/2003', 1);
INSERT INTO valoracions VALUES (3238, 21, '20/07/2003', 8);
INSERT INTO valoracions VALUES (3238, 42, '14/08/2009', 4);
INSERT INTO valoracions VALUES (3239, 11, '19/11/2006', 9);
INSERT INTO valoracions VALUES (3239, 110, '27/06/2010', 5);
INSERT INTO valoracions VALUES (3239, 82, '20/08/2010', 7);
INSERT INTO valoracions VALUES (3239, 57, '03/12/2006', 3);
INSERT INTO valoracions VALUES (3240, 63, '22/06/2005', 8);
INSERT INTO valoracions VALUES (3241, 98, '08/05/2002', 10);
INSERT INTO valoracions VALUES (3242, 101, '31/07/2007', 8);
INSERT INTO valoracions VALUES (3242, 51, '27/07/2005', 4);
INSERT INTO valoracions VALUES (3242, 65, '27/12/2001', 5);
INSERT INTO valoracions VALUES (3242, 51, '23/04/2003', 6);
INSERT INTO valoracions VALUES (3242, 52, '26/10/2002', 6);
INSERT INTO valoracions VALUES (3243, 105, '16/12/2003', 3);
INSERT INTO valoracions VALUES (3243, 64, '27/10/2009', 5);
INSERT INTO valoracions VALUES (3243, 59, '25/12/2009', 10);
INSERT INTO valoracions VALUES (3243, 111, '04/06/2010', 10);
INSERT INTO valoracions VALUES (3244, 52, '05/04/2004', 4);
INSERT INTO valoracions VALUES (3244, 9, '03/06/2002', 7);
INSERT INTO valoracions VALUES (3245, 46, '06/09/2010', 9);
INSERT INTO valoracions VALUES (3245, 108, '24/05/2008', 4);
INSERT INTO valoracions VALUES (3245, 40, '15/03/2006', 9);
INSERT INTO valoracions VALUES (3245, 51, '24/07/2005', 4);
INSERT INTO valoracions VALUES (3245, 66, '12/10/2006', 2);
INSERT INTO valoracions VALUES (3246, 63, '30/09/2010', 5);
INSERT INTO valoracions VALUES (3246, 100, '09/07/2009', 1);
INSERT INTO valoracions VALUES (3246, 52, '31/07/2008', 8);
INSERT INTO valoracions VALUES (3246, 16, '30/08/2002', 6);
INSERT INTO valoracions VALUES (3246, 55, '14/11/2003', 8);
INSERT INTO valoracions VALUES (3246, 80, '03/12/2009', 2);
INSERT INTO valoracions VALUES (3246, 103, '21/02/2009', 8);
INSERT INTO valoracions VALUES (3247, 36, '25/07/2004', 7);
INSERT INTO valoracions VALUES (3248, 84, '07/02/2007', 8);
INSERT INTO valoracions VALUES (3248, 113, '27/09/2007', 9);
INSERT INTO valoracions VALUES (3248, 84, '15/07/2006', 5);
INSERT INTO valoracions VALUES (3248, 105, '26/07/2002', 2);
INSERT INTO valoracions VALUES (3248, 16, '05/01/2010', 8);
INSERT INTO valoracions VALUES (3249, 77, '31/03/2008', 3);
INSERT INTO valoracions VALUES (3249, 71, '05/05/2002', 8);
INSERT INTO valoracions VALUES (3249, 76, '20/08/2007', 8);
INSERT INTO valoracions VALUES (3249, 88, '01/12/2003', 10);
INSERT INTO valoracions VALUES (3250, 26, '07/07/2007', 8);
INSERT INTO valoracions VALUES (3250, 105, '01/05/2005', 1);
INSERT INTO valoracions VALUES (3250, 90, '17/12/2009', 8);
INSERT INTO valoracions VALUES (3250, 114, '09/10/2008', 8);
INSERT INTO valoracions VALUES (3250, 40, '28/07/2003', 9);
INSERT INTO valoracions VALUES (3251, 93, '10/01/2007', 8);
INSERT INTO valoracions VALUES (3251, 78, '21/12/2002', 3);
INSERT INTO valoracions VALUES (3252, 94, '16/12/2008', 1);
INSERT INTO valoracions VALUES (3252, 33, '28/07/2006', 6);
INSERT INTO valoracions VALUES (3252, 107, '03/09/2010', 5);
INSERT INTO valoracions VALUES (3252, 81, '16/08/2004', 2);
INSERT INTO valoracions VALUES (3252, 8, '05/07/2003', 5);
INSERT INTO valoracions VALUES (3252, 70, '02/12/2009', 8);
INSERT INTO valoracions VALUES (3253, 16, '01/05/2007', 9);
INSERT INTO valoracions VALUES (3253, 8, '29/05/2006', 8);
INSERT INTO valoracions VALUES (3253, 46, '17/03/2006', 8);
INSERT INTO valoracions VALUES (3253, 34, '03/07/2007', 6);
INSERT INTO valoracions VALUES (3253, 73, '19/05/2004', 8);
INSERT INTO valoracions VALUES (3254, 66, '27/01/2005', 8);
INSERT INTO valoracions VALUES (3254, 44, '08/09/2005', 5);
INSERT INTO valoracions VALUES (3254, 75, '05/02/2010', 3);
INSERT INTO valoracions VALUES (3255, 33, '31/03/2010', 8);
INSERT INTO valoracions VALUES (3255, 6, '04/06/2004', 10);
INSERT INTO valoracions VALUES (3255, 2, '09/01/2004', 10);
INSERT INTO valoracions VALUES (3255, 69, '03/08/2002', 5);
INSERT INTO valoracions VALUES (3256, 111, '03/07/2001', 6);
INSERT INTO valoracions VALUES (3256, 69, '24/07/2009', 5);
INSERT INTO valoracions VALUES (3257, 75, '28/01/2008', 5);
INSERT INTO valoracions VALUES (3257, 115, '21/11/2007', 4);
INSERT INTO valoracions VALUES (3257, 18, '29/07/2003', 6);
INSERT INTO valoracions VALUES (3259, 10, '03/11/2001', 9);
INSERT INTO valoracions VALUES (3259, 105, '21/04/2003', 8);
INSERT INTO valoracions VALUES (3259, 18, '06/09/2001', 9);
INSERT INTO valoracions VALUES (3259, 85, '02/06/2006', 3);
INSERT INTO valoracions VALUES (3259, 79, '15/04/2010', 4);
INSERT INTO valoracions VALUES (3260, 81, '06/04/2005', 7);
INSERT INTO valoracions VALUES (3260, 84, '14/07/2001', 8);
INSERT INTO valoracions VALUES (3260, 11, '19/10/2010', 8);
INSERT INTO valoracions VALUES (3260, 10, '06/09/2005', 6);
INSERT INTO valoracions VALUES (3261, 67, '06/09/2001', 7);
INSERT INTO valoracions VALUES (3261, 24, '03/12/2007', 8);
INSERT INTO valoracions VALUES (3261, 81, '11/01/2009', 7);
INSERT INTO valoracions VALUES (3261, 113, '11/09/2007', 2);
INSERT INTO valoracions VALUES (3261, 64, '09/09/2001', 8);
INSERT INTO valoracions VALUES (3262, 67, '05/01/2003', 8);
INSERT INTO valoracions VALUES (3262, 45, '01/06/2006', 7);
INSERT INTO valoracions VALUES (3262, 18, '11/10/2008', 5);
INSERT INTO valoracions VALUES (3262, 16, '20/01/2010', 8);
INSERT INTO valoracions VALUES (3262, 80, '22/02/2002', 3);
INSERT INTO valoracions VALUES (3263, 44, '16/10/2004', 10);
INSERT INTO valoracions VALUES (3263, 73, '09/06/2006', 10);
INSERT INTO valoracions VALUES (3263, 88, '23/10/2006', 7);
INSERT INTO valoracions VALUES (3263, 8, '18/01/2002', 6);
INSERT INTO valoracions VALUES (3264, 19, '06/09/2003', 6);
INSERT INTO valoracions VALUES (3264, 65, '25/10/2001', 10);
INSERT INTO valoracions VALUES (3264, 39, '03/04/2001', 5);
INSERT INTO valoracions VALUES (3264, 107, '11/04/2008', 1);
INSERT INTO valoracions VALUES (3265, 81, '16/10/2001', 6);
INSERT INTO valoracions VALUES (3265, 14, '16/07/2003', 7);
INSERT INTO valoracions VALUES (3265, 79, '30/05/2010', 6);
INSERT INTO valoracions VALUES (3266, 22, '25/10/2003', 6);
INSERT INTO valoracions VALUES (3266, 60, '15/05/2004', 8);
INSERT INTO valoracions VALUES (3266, 101, '29/12/2005', 7);
INSERT INTO valoracions VALUES (3266, 71, '20/05/2007', 3);
INSERT INTO valoracions VALUES (3267, 11, '20/06/2010', 5);
INSERT INTO valoracions VALUES (3267, 44, '01/01/2010', 3);
INSERT INTO valoracions VALUES (3267, 95, '21/07/2005', 7);
INSERT INTO valoracions VALUES (3268, 58, '10/10/2003', 5);
INSERT INTO valoracions VALUES (3268, 71, '07/01/2010', 4);
INSERT INTO valoracions VALUES (3269, 98, '09/09/2010', 10);
INSERT INTO valoracions VALUES (3269, 43, '04/10/2003', 5);
INSERT INTO valoracions VALUES (3269, 64, '22/12/2007', 8);
INSERT INTO valoracions VALUES (3270, 36, '09/04/2007', 7);
INSERT INTO valoracions VALUES (3270, 20, '12/04/2006', 5);
INSERT INTO valoracions VALUES (3270, 94, '05/03/2002', 9);
INSERT INTO valoracions VALUES (3270, 88, '02/06/2007', 3);
INSERT INTO valoracions VALUES (3271, 101, '15/07/2005', 9);
INSERT INTO valoracions VALUES (3271, 21, '21/02/2003', 8);
INSERT INTO valoracions VALUES (3271, 70, '17/09/2004', 4);
INSERT INTO valoracions VALUES (3271, 51, '03/10/2006', 4);
INSERT INTO valoracions VALUES (3271, 9, '27/08/2001', 6);
INSERT INTO valoracions VALUES (3271, 69, '31/07/2009', 4);
INSERT INTO valoracions VALUES (3271, 112, '19/04/2007', 8);
INSERT INTO valoracions VALUES (3271, 92, '20/09/2008', 7);
INSERT INTO valoracions VALUES (3271, 21, '24/05/2003', 5);
INSERT INTO valoracions VALUES (3272, 65, '29/05/2010', 7);
INSERT INTO valoracions VALUES (3272, 90, '04/03/2002', 7);
INSERT INTO valoracions VALUES (3273, 42, '29/07/2007', 9);
INSERT INTO valoracions VALUES (3273, 13, '17/09/2008', 9);
INSERT INTO valoracions VALUES (3273, 10, '25/09/2001', 7);
INSERT INTO valoracions VALUES (3273, 49, '30/08/2006', 6);
INSERT INTO valoracions VALUES (3274, 101, '16/04/2007', 3);
INSERT INTO valoracions VALUES (3274, 110, '14/03/2002', 7);
INSERT INTO valoracions VALUES (3274, 57, '07/07/2005', 10);
INSERT INTO valoracions VALUES (3274, 15, '14/11/2004', 7);
INSERT INTO valoracions VALUES (3274, 1, '06/08/2007', 6);
INSERT INTO valoracions VALUES (3275, 110, '13/05/2009', 2);
INSERT INTO valoracions VALUES (3275, 45, '02/09/2001', 7);
INSERT INTO valoracions VALUES (3275, 96, '10/05/2005', 5);
INSERT INTO valoracions VALUES (3276, 10, '25/10/2002', 6);
INSERT INTO valoracions VALUES (3276, 104, '12/03/2007', 1);
INSERT INTO valoracions VALUES (3276, 73, '22/08/2002', 4);
INSERT INTO valoracions VALUES (3277, 68, '13/04/2004', 6);
INSERT INTO valoracions VALUES (3277, 100, '23/11/2008', 9);
INSERT INTO valoracions VALUES (3277, 23, '03/05/2004', 9);
INSERT INTO valoracions VALUES (3277, 40, '20/08/2003', 6);
INSERT INTO valoracions VALUES (3277, 49, '29/09/2009', 6);
INSERT INTO valoracions VALUES (3277, 110, '18/04/2004', 8);
INSERT INTO valoracions VALUES (3277, 20, '22/11/2002', 4);
INSERT INTO valoracions VALUES (3277, 115, '07/04/2007', 0);
INSERT INTO valoracions VALUES (3278, 15, '29/12/2001', 6);
INSERT INTO valoracions VALUES (3278, 84, '12/05/2004', 7);
INSERT INTO valoracions VALUES (3278, 77, '29/04/2010', 3);
INSERT INTO valoracions VALUES (3279, 84, '28/03/2004', 7);
INSERT INTO valoracions VALUES (3279, 15, '01/09/2005', 9);
INSERT INTO valoracions VALUES (3279, 82, '24/04/2003', 4);
INSERT INTO valoracions VALUES (3279, 47, '11/07/2008', 8);
INSERT INTO valoracions VALUES (3280, 11, '24/07/2009', 6);
INSERT INTO valoracions VALUES (3280, 76, '17/06/2008', 7);
INSERT INTO valoracions VALUES (3280, 67, '12/06/2003', 6);
INSERT INTO valoracions VALUES (3280, 4, '20/02/2002', 7);
INSERT INTO valoracions VALUES (3280, 115, '25/08/2005', 2);
INSERT INTO valoracions VALUES (3280, 48, '12/01/2002', 6);
INSERT INTO valoracions VALUES (3280, 78, '19/11/2004', 7);
INSERT INTO valoracions VALUES (3280, 12, '26/05/2003', 9);
INSERT INTO valoracions VALUES (3280, 96, '02/10/2004', 2);
INSERT INTO valoracions VALUES (3280, 79, '13/12/2007', 5);
INSERT INTO valoracions VALUES (3281, 52, '22/06/2006', 9);
INSERT INTO valoracions VALUES (3281, 47, '14/12/2003', 4);
INSERT INTO valoracions VALUES (3281, 62, '14/02/2005', 8);
INSERT INTO valoracions VALUES (3281, 50, '23/06/2005', 7);
INSERT INTO valoracions VALUES (3281, 39, '22/04/2003', 5);
INSERT INTO valoracions VALUES (3282, 107, '13/08/2010', 9);
INSERT INTO valoracions VALUES (3282, 85, '24/01/2007', 5);
INSERT INTO valoracions VALUES (3282, 28, '18/09/2008', 7);
INSERT INTO valoracions VALUES (3282, 90, '13/08/2005', 8);
INSERT INTO valoracions VALUES (3282, 75, '05/07/2003', 5);
INSERT INTO valoracions VALUES (3282, 10, '24/09/2008', 5);
INSERT INTO valoracions VALUES (3282, 40, '17/07/2001', 6);
INSERT INTO valoracions VALUES (3282, 64, '27/08/2009', 5);
INSERT INTO valoracions VALUES (3283, 91, '07/02/2009', 6);
INSERT INTO valoracions VALUES (3283, 52, '14/09/2009', 4);
INSERT INTO valoracions VALUES (3284, 15, '14/08/2004', 9);
INSERT INTO valoracions VALUES (3284, 70, '15/05/2004', 8);
INSERT INTO valoracions VALUES (3284, 51, '08/08/2004', 4);
INSERT INTO valoracions VALUES (3285, 38, '27/05/2008', 3);
INSERT INTO valoracions VALUES (3286, 76, '18/01/2009', 8);
INSERT INTO valoracions VALUES (3286, 46, '16/07/2008', 7);
INSERT INTO valoracions VALUES (3286, 36, '19/01/2004', 4);
INSERT INTO valoracions VALUES (3286, 116, '28/04/2008', 0);
INSERT INTO valoracions VALUES (3286, 67, '03/12/2002', 9);
INSERT INTO valoracions VALUES (3287, 58, '27/09/2008', 6);
INSERT INTO valoracions VALUES (3287, 45, '27/06/2007', 5);
INSERT INTO valoracions VALUES (3287, 114, '11/04/2004', 8);
INSERT INTO valoracions VALUES (3287, 25, '29/01/2005', 9);
INSERT INTO valoracions VALUES (3287, 46, '12/03/2006', 6);
INSERT INTO valoracions VALUES (3288, 95, '13/01/2003', 5);
INSERT INTO valoracions VALUES (3288, 111, '18/09/2010', 3);
INSERT INTO valoracions VALUES (3288, 38, '23/01/2008', 4);
INSERT INTO valoracions VALUES (3288, 72, '07/02/2008', 2);
INSERT INTO valoracions VALUES (3288, 112, '26/11/2001', 8);
INSERT INTO valoracions VALUES (3288, 48, '22/08/2004', 8);
INSERT INTO valoracions VALUES (3289, 81, '09/01/2006', 9);
INSERT INTO valoracions VALUES (3289, 12, '01/07/2007', 9);
INSERT INTO valoracions VALUES (3289, 76, '06/08/2006', 8);
INSERT INTO valoracions VALUES (3289, 48, '08/09/2008', 6);
INSERT INTO valoracions VALUES (3290, 51, '20/08/2006', 9);
INSERT INTO valoracions VALUES (3290, 53, '13/03/2004', 9);
INSERT INTO valoracions VALUES (3290, 52, '03/02/2004', 6);
INSERT INTO valoracions VALUES (3290, 91, '03/03/2008', 7);
INSERT INTO valoracions VALUES (3290, 60, '18/07/2003', 7);
INSERT INTO valoracions VALUES (3291, 44, '17/01/2007', 4);
INSERT INTO valoracions VALUES (3291, 8, '20/12/2001', 6);
INSERT INTO valoracions VALUES (3291, 15, '03/04/2007', 7);
INSERT INTO valoracions VALUES (3291, 7, '10/02/2010', 6);
INSERT INTO valoracions VALUES (3291, 78, '14/08/2005', 8);
INSERT INTO valoracions VALUES (3291, 108, '23/08/2003', 2);
INSERT INTO valoracions VALUES (3291, 77, '30/04/2003', 5);
INSERT INTO valoracions VALUES (3292, 3, '26/10/2003', 6);
INSERT INTO valoracions VALUES (3292, 98, '03/04/2006', 8);
INSERT INTO valoracions VALUES (3293, 63, '25/10/2005', 3);
INSERT INTO valoracions VALUES (3293, 114, '06/03/2004', 1);
INSERT INTO valoracions VALUES (3294, 33, '06/08/2005', 9);
INSERT INTO valoracions VALUES (3294, 67, '13/12/2004', 8);
INSERT INTO valoracions VALUES (3295, 15, '28/02/2006', 8);
INSERT INTO valoracions VALUES (3295, 79, '02/11/2006', 2);
INSERT INTO valoracions VALUES (3296, 25, '03/01/2006', 10);
INSERT INTO valoracions VALUES (3296, 85, '15/05/2010', 4);
INSERT INTO valoracions VALUES (3296, 2, '12/01/2009', 6);
INSERT INTO valoracions VALUES (3296, 108, '22/05/2006', 3);
INSERT INTO valoracions VALUES (3297, 58, '01/10/2008', 7);
INSERT INTO valoracions VALUES (3297, 38, '16/07/2004', 9);
INSERT INTO valoracions VALUES (3297, 44, '07/11/2005', 7);
INSERT INTO valoracions VALUES (3297, 39, '11/03/2006', 9);
INSERT INTO valoracions VALUES (3297, 31, '31/08/2006', 9);
INSERT INTO valoracions VALUES (3297, 30, '14/06/2003', 7);
INSERT INTO valoracions VALUES (3298, 64, '23/12/2004', 7);
INSERT INTO valoracions VALUES (3298, 80, '14/10/2005', 2);
INSERT INTO valoracions VALUES (3298, 115, '05/11/2002', 1);
INSERT INTO valoracions VALUES (3298, 6, '06/03/2006', 8);
INSERT INTO valoracions VALUES (3299, 69, '09/04/2002', 8);
INSERT INTO valoracions VALUES (3299, 67, '12/11/2007', 5);
INSERT INTO valoracions VALUES (3299, 98, '04/02/2006', 5);
INSERT INTO valoracions VALUES (3300, 74, '05/03/2008', 6);
INSERT INTO valoracions VALUES (3300, 76, '12/03/2005', 10);
INSERT INTO valoracions VALUES (3300, 79, '26/02/2003', 6);
INSERT INTO valoracions VALUES (3300, 77, '03/06/2006', 5);
INSERT INTO valoracions VALUES (3301, 37, '28/06/2007', 5);
INSERT INTO valoracions VALUES (3301, 46, '29/01/2010', 5);
INSERT INTO valoracions VALUES (3302, 99, '11/10/2001', 6);
INSERT INTO valoracions VALUES (3302, 94, '12/10/2007', 2);
INSERT INTO valoracions VALUES (3302, 78, '27/10/2006', 9);
INSERT INTO valoracions VALUES (3302, 114, '08/09/2010', 9);
INSERT INTO valoracions VALUES (3303, 42, '23/12/2007', 8);
INSERT INTO valoracions VALUES (3303, 54, '28/06/2009', 4);
INSERT INTO valoracions VALUES (3303, 46, '28/03/2010', 9);
INSERT INTO valoracions VALUES (3303, 33, '02/06/2001', 6);
INSERT INTO valoracions VALUES (3303, 104, '20/12/2009', 7);
INSERT INTO valoracions VALUES (3303, 96, '22/09/2007', 4);
INSERT INTO valoracions VALUES (3303, 106, '20/08/2010', 4);
INSERT INTO valoracions VALUES (3304, 82, '14/03/2005', 5);
INSERT INTO valoracions VALUES (3305, 7, '05/01/2010', 6);
INSERT INTO valoracions VALUES (3305, 23, '17/09/2001', 6);
INSERT INTO valoracions VALUES (3306, 29, '13/07/2006', 4);
INSERT INTO valoracions VALUES (3306, 13, '19/06/2006', 9);
INSERT INTO valoracions VALUES (3306, 111, '26/06/2007', 9);
INSERT INTO valoracions VALUES (3306, 112, '15/07/2007', 8);
INSERT INTO valoracions VALUES (3306, 45, '04/02/2004', 9);
INSERT INTO valoracions VALUES (3306, 38, '04/03/2003', 9);
INSERT INTO valoracions VALUES (3307, 45, '12/07/2005', 4);
INSERT INTO valoracions VALUES (3307, 70, '04/02/2004', 8);
INSERT INTO valoracions VALUES (3308, 78, '19/07/2001', 9);
INSERT INTO valoracions VALUES (3308, 33, '17/11/2008', 4);
INSERT INTO valoracions VALUES (3308, 46, '12/10/2010', 4);
INSERT INTO valoracions VALUES (3308, 8, '10/05/2008', 5);
INSERT INTO valoracions VALUES (3308, 116, '21/10/2010', 2);
INSERT INTO valoracions VALUES (3308, 16, '31/08/2006', 8);
INSERT INTO valoracions VALUES (3309, 74, '07/05/2001', 2);
INSERT INTO valoracions VALUES (3309, 74, '22/04/2002', 4);
INSERT INTO valoracions VALUES (3309, 47, '03/07/2006', 9);
INSERT INTO valoracions VALUES (3309, 54, '16/06/2006', 5);
INSERT INTO valoracions VALUES (3310, 71, '18/06/2010', 10);
INSERT INTO valoracions VALUES (3310, 22, '16/01/2004', 6);
INSERT INTO valoracions VALUES (3310, 82, '25/12/2007', 4);
INSERT INTO valoracions VALUES (3310, 97, '04/11/2001', 9);
INSERT INTO valoracions VALUES (3310, 9, '22/04/2004', 5);
INSERT INTO valoracions VALUES (3311, 49, '28/09/2010', 6);
INSERT INTO valoracions VALUES (3311, 109, '19/01/2004', 2);
INSERT INTO valoracions VALUES (3312, 75, '23/02/2005', 4);
INSERT INTO valoracions VALUES (3312, 83, '05/07/2008', 1);
INSERT INTO valoracions VALUES (3312, 21, '09/05/2003', 7);
INSERT INTO valoracions VALUES (3312, 42, '05/11/2006', 9);
INSERT INTO valoracions VALUES (3312, 99, '24/01/2002', 4);
INSERT INTO valoracions VALUES (3312, 40, '13/10/2003', 9);
INSERT INTO valoracions VALUES (3312, 101, '11/06/2001', 4);
INSERT INTO valoracions VALUES (3313, 9, '06/03/2006', 6);
INSERT INTO valoracions VALUES (3313, 13, '06/07/2007', 9);
INSERT INTO valoracions VALUES (3313, 62, '03/03/2006', 5);
INSERT INTO valoracions VALUES (3313, 42, '21/08/2003', 5);
INSERT INTO valoracions VALUES (3314, 114, '17/01/2003', 3);
INSERT INTO valoracions VALUES (3314, 56, '07/11/2002', 6);
INSERT INTO valoracions VALUES (3314, 33, '09/02/2004', 4);
INSERT INTO valoracions VALUES (3314, 109, '21/11/2006', 2);
INSERT INTO valoracions VALUES (3316, 26, '12/07/2005', 5);
INSERT INTO valoracions VALUES (3316, 70, '26/10/2001', 5);
INSERT INTO valoracions VALUES (3316, 20, '09/05/2001', 7);
INSERT INTO valoracions VALUES (3316, 65, '28/11/2007', 5);
INSERT INTO valoracions VALUES (3316, 40, '27/12/2009', 5);
INSERT INTO valoracions VALUES (3317, 63, '23/10/2009', 8);
INSERT INTO valoracions VALUES (3317, 80, '27/02/2010', 7);
INSERT INTO valoracions VALUES (3317, 84, '26/03/2005', 8);
INSERT INTO valoracions VALUES (3317, 13, '15/08/2010', 5);
INSERT INTO valoracions VALUES (3317, 14, '26/04/2009', 5);
INSERT INTO valoracions VALUES (3318, 75, '30/03/2005', 4);
INSERT INTO valoracions VALUES (3319, 72, '03/04/2008', 6);
INSERT INTO valoracions VALUES (3319, 41, '06/01/2010', 9);
INSERT INTO valoracions VALUES (3320, 98, '17/02/2009', 2);
INSERT INTO valoracions VALUES (3321, 87, '11/08/2001', 6);
INSERT INTO valoracions VALUES (3321, 106, '09/09/2010', 4);
INSERT INTO valoracions VALUES (3321, 112, '11/09/2009', 5);
INSERT INTO valoracions VALUES (3321, 47, '14/08/2003', 7);
INSERT INTO valoracions VALUES (3322, 25, '08/02/2007', 5);
INSERT INTO valoracions VALUES (3322, 110, '04/01/2002', 7);
INSERT INTO valoracions VALUES (3322, 34, '19/09/2002', 4);
INSERT INTO valoracions VALUES (3322, 33, '27/02/2007', 4);
INSERT INTO valoracions VALUES (3323, 26, '02/11/2007', 10);
INSERT INTO valoracions VALUES (3323, 73, '14/01/2010', 4);
INSERT INTO valoracions VALUES (3323, 14, '28/05/2001', 9);
INSERT INTO valoracions VALUES (3323, 44, '20/09/2009', 9);
INSERT INTO valoracions VALUES (3323, 17, '08/07/2007', 7);
INSERT INTO valoracions VALUES (3323, 90, '27/01/2009', 9);
INSERT INTO valoracions VALUES (3323, 112, '02/04/2002', 4);
INSERT INTO valoracions VALUES (3324, 56, '30/10/2009', 9);
INSERT INTO valoracions VALUES (3324, 109, '20/03/2005', 10);
INSERT INTO valoracions VALUES (3324, 94, '23/07/2008', 1);
INSERT INTO valoracions VALUES (3324, 49, '18/03/2009', 7);
INSERT INTO valoracions VALUES (3325, 104, '22/03/2010', 8);
INSERT INTO valoracions VALUES (3325, 97, '14/12/2009', 5);
INSERT INTO valoracions VALUES (3325, 47, '09/10/2005', 9);
INSERT INTO valoracions VALUES (3326, 65, '21/02/2005', 9);
INSERT INTO valoracions VALUES (3326, 25, '21/12/2003', 8);
INSERT INTO valoracions VALUES (3326, 28, '28/08/2006', 4);
INSERT INTO valoracions VALUES (3326, 90, '15/08/2007', 7);
INSERT INTO valoracions VALUES (3327, 74, '26/10/2001', 7);
INSERT INTO valoracions VALUES (3327, 89, '17/06/2001', 6);
INSERT INTO valoracions VALUES (3327, 60, '23/10/2001', 3);
INSERT INTO valoracions VALUES (3327, 102, '09/04/2007', 9);
INSERT INTO valoracions VALUES (3327, 38, '23/09/2002', 7);
INSERT INTO valoracions VALUES (3327, 81, '13/03/2007', 7);
INSERT INTO valoracions VALUES (3328, 58, '12/12/2006', 9);
INSERT INTO valoracions VALUES (3328, 22, '07/03/2009', 8);
INSERT INTO valoracions VALUES (3329, 41, '23/11/2008', 4);
INSERT INTO valoracions VALUES (3329, 101, '03/01/2008', 6);
INSERT INTO valoracions VALUES (3329, 27, '29/07/2007', 9);
INSERT INTO valoracions VALUES (3329, 44, '10/08/2006', 6);
INSERT INTO valoracions VALUES (3329, 11, '15/07/2005', 6);
INSERT INTO valoracions VALUES (3329, 11, '21/11/2001', 9);
INSERT INTO valoracions VALUES (3330, 68, '13/03/2006', 8);
INSERT INTO valoracions VALUES (3330, 100, '05/11/2003', 3);
INSERT INTO valoracions VALUES (3330, 50, '24/01/2010', 9);
INSERT INTO valoracions VALUES (3330, 61, '18/04/2006', 5);
INSERT INTO valoracions VALUES (3331, 49, '07/10/2009', 6);
INSERT INTO valoracions VALUES (3331, 98, '08/05/2001', 4);
INSERT INTO valoracions VALUES (3331, 45, '18/08/2009', 5);
INSERT INTO valoracions VALUES (3331, 26, '27/11/2008', 5);
INSERT INTO valoracions VALUES (3331, 76, '25/12/2005', 3);
INSERT INTO valoracions VALUES (3331, 44, '30/07/2009', 9);
INSERT INTO valoracions VALUES (3332, 3, '01/05/2008', 7);
INSERT INTO valoracions VALUES (3332, 42, '26/07/2004', 5);
INSERT INTO valoracions VALUES (3332, 88, '29/10/2004', 9);
INSERT INTO valoracions VALUES (3333, 6, '02/07/2002', 7);
INSERT INTO valoracions VALUES (3333, 111, '11/09/2005', 4);
INSERT INTO valoracions VALUES (3333, 27, '24/01/2004', 9);
INSERT INTO valoracions VALUES (3334, 68, '19/10/2010', 4);
INSERT INTO valoracions VALUES (3334, 43, '17/10/2007', 4);
INSERT INTO valoracions VALUES (3334, 83, '17/09/2009', 7);
INSERT INTO valoracions VALUES (3334, 14, '20/10/2004', 9);
INSERT INTO valoracions VALUES (3335, 80, '20/06/2008', 3);
INSERT INTO valoracions VALUES (3335, 113, '19/08/2009', 9);
INSERT INTO valoracions VALUES (3336, 72, '22/03/2004', 4);
INSERT INTO valoracions VALUES (3336, 113, '01/05/2004', 8);
INSERT INTO valoracions VALUES (3336, 5, '06/06/2005', 5);
INSERT INTO valoracions VALUES (3336, 109, '20/07/2007', 6);
INSERT INTO valoracions VALUES (3336, 72, '16/02/2010', 8);
INSERT INTO valoracions VALUES (3337, 24, '20/09/2009', 9);
INSERT INTO valoracions VALUES (3337, 73, '06/06/2001', 7);
INSERT INTO valoracions VALUES (3338, 59, '08/01/2005', 6);
INSERT INTO valoracions VALUES (3338, 97, '14/10/2006', 4);
INSERT INTO valoracions VALUES (3339, 44, '17/06/2004', 7);
INSERT INTO valoracions VALUES (3339, 107, '01/10/2010', 6);
INSERT INTO valoracions VALUES (3339, 45, '07/08/2008', 5);
INSERT INTO valoracions VALUES (3339, 72, '19/12/2005', 9);
INSERT INTO valoracions VALUES (3339, 38, '15/09/2008', 4);
INSERT INTO valoracions VALUES (3339, 102, '02/03/2003', 7);
INSERT INTO valoracions VALUES (3339, 66, '28/05/2010', 5);
INSERT INTO valoracions VALUES (3339, 21, '19/11/2001', 8);
INSERT INTO valoracions VALUES (3340, 51, '23/11/2001', 3);
INSERT INTO valoracions VALUES (3340, 63, '24/06/2001', 9);
INSERT INTO valoracions VALUES (3340, 54, '04/02/2008', 3);
INSERT INTO valoracions VALUES (3340, 37, '10/11/2007', 9);
INSERT INTO valoracions VALUES (3341, 11, '14/08/2009', 6);
INSERT INTO valoracions VALUES (3341, 44, '24/04/2001', 6);
INSERT INTO valoracions VALUES (3341, 110, '23/11/2009', 9);
INSERT INTO valoracions VALUES (3341, 68, '08/06/2005', 4);
INSERT INTO valoracions VALUES (3341, 59, '01/11/2003', 3);
INSERT INTO valoracions VALUES (3342, 87, '06/03/2006', 4);
INSERT INTO valoracions VALUES (3342, 7, '23/04/2004', 9);
INSERT INTO valoracions VALUES (3342, 66, '03/09/2010', 8);
INSERT INTO valoracions VALUES (3343, 59, '12/08/2004', 3);
INSERT INTO valoracions VALUES (3343, 54, '28/09/2003', 10);
INSERT INTO valoracions VALUES (3343, 92, '08/12/2002', 9);
INSERT INTO valoracions VALUES (3343, 30, '28/07/2004', 5);
INSERT INTO valoracions VALUES (3344, 65, '21/09/2003', 5);
INSERT INTO valoracions VALUES (3344, 72, '21/04/2003', 8);
INSERT INTO valoracions VALUES (3344, 42, '19/06/2003', 8);
INSERT INTO valoracions VALUES (3344, 72, '08/07/2005', 5);
INSERT INTO valoracions VALUES (3344, 74, '10/11/2008', 4);
INSERT INTO valoracions VALUES (3344, 90, '07/09/2004', 6);
INSERT INTO valoracions VALUES (3344, 79, '13/05/2002', 4);
INSERT INTO valoracions VALUES (3345, 99, '24/07/2002', 8);
INSERT INTO valoracions VALUES (3345, 97, '08/08/2001', 9);
INSERT INTO valoracions VALUES (3345, 91, '10/08/2004', 5);
INSERT INTO valoracions VALUES (3346, 73, '25/10/2005', 7);
INSERT INTO valoracions VALUES (3346, 40, '13/01/2005', 9);
INSERT INTO valoracions VALUES (3346, 97, '29/12/2008', 4);
INSERT INTO valoracions VALUES (3346, 70, '26/07/2002', 5);
INSERT INTO valoracions VALUES (3346, 25, '04/03/2002', 8);
INSERT INTO valoracions VALUES (3346, 115, '22/06/2009', 10);
INSERT INTO valoracions VALUES (3347, 71, '20/07/2003', 7);
INSERT INTO valoracions VALUES (3348, 90, '02/01/2009', 8);
INSERT INTO valoracions VALUES (3348, 15, '03/05/2005', 8);
INSERT INTO valoracions VALUES (3348, 16, '15/08/2003', 4);
INSERT INTO valoracions VALUES (3348, 27, '12/06/2005', 9);
INSERT INTO valoracions VALUES (3349, 16, '19/11/2009', 9);
INSERT INTO valoracions VALUES (3350, 6, '27/04/2009', 7);
INSERT INTO valoracions VALUES (3350, 52, '30/11/2004', 6);
INSERT INTO valoracions VALUES (3350, 53, '30/03/2008', 10);
INSERT INTO valoracions VALUES (3351, 21, '03/12/2005', 5);
INSERT INTO valoracions VALUES (3351, 95, '23/07/2009', 5);
INSERT INTO valoracions VALUES (3351, 99, '04/09/2003', 7);
INSERT INTO valoracions VALUES (3351, 55, '10/04/2004', 9);
INSERT INTO valoracions VALUES (3352, 24, '26/08/2009', 6);
INSERT INTO valoracions VALUES (3352, 44, '08/01/2009', 6);
INSERT INTO valoracions VALUES (3352, 35, '20/02/2008', 9);
INSERT INTO valoracions VALUES (3352, 107, '14/07/2002', 2);
INSERT INTO valoracions VALUES (3352, 8, '20/05/2001', 6);
INSERT INTO valoracions VALUES (3352, 111, '10/08/2010', 6);
INSERT INTO valoracions VALUES (3352, 22, '05/10/2005', 8);
INSERT INTO valoracions VALUES (3353, 54, '28/11/2007', 9);
INSERT INTO valoracions VALUES (3353, 98, '28/03/2007', 7);
INSERT INTO valoracions VALUES (3353, 78, '26/07/2006', 3);
INSERT INTO valoracions VALUES (3353, 28, '25/05/2009', 9);
INSERT INTO valoracions VALUES (3353, 26, '27/11/2002', 8);
INSERT INTO valoracions VALUES (3354, 10, '04/09/2003', 6);
INSERT INTO valoracions VALUES (3354, 45, '12/10/2001', 7);
INSERT INTO valoracions VALUES (3354, 72, '21/01/2008', 5);
INSERT INTO valoracions VALUES (3354, 92, '17/02/2003', 1);
INSERT INTO valoracions VALUES (3355, 18, '07/03/2010', 5);
INSERT INTO valoracions VALUES (3355, 81, '10/07/2003', 7);
INSERT INTO valoracions VALUES (3356, 37, '29/08/2010', 7);
INSERT INTO valoracions VALUES (3356, 16, '21/11/2006', 7);
INSERT INTO valoracions VALUES (3356, 112, '14/11/2003', 6);
INSERT INTO valoracions VALUES (3357, 96, '18/06/2009', 3);
INSERT INTO valoracions VALUES (3357, 64, '13/11/2004', 8);
INSERT INTO valoracions VALUES (3357, 103, '29/04/2003', 10);
INSERT INTO valoracions VALUES (3360, 54, '03/03/2009', 6);
INSERT INTO valoracions VALUES (3360, 70, '17/04/2006', 8);
INSERT INTO valoracions VALUES (3360, 2, '23/09/2001', 7);
INSERT INTO valoracions VALUES (3360, 36, '05/11/2008', 8);
INSERT INTO valoracions VALUES (3361, 23, '02/07/2003', 9);
INSERT INTO valoracions VALUES (3361, 38, '19/12/2006', 7);
INSERT INTO valoracions VALUES (3362, 112, '13/03/2009', 7);
INSERT INTO valoracions VALUES (3362, 60, '04/09/2006', 5);
INSERT INTO valoracions VALUES (3362, 15, '02/10/2007', 8);
INSERT INTO valoracions VALUES (3362, 97, '16/12/2001', 8);
INSERT INTO valoracions VALUES (3362, 17, '10/06/2002', 9);
INSERT INTO valoracions VALUES (3362, 79, '07/01/2002', 3);
INSERT INTO valoracions VALUES (3362, 50, '27/12/2007', 6);
INSERT INTO valoracions VALUES (3362, 44, '20/08/2010', 5);
INSERT INTO valoracions VALUES (3362, 42, '02/11/2009', 8);
INSERT INTO valoracions VALUES (3362, 35, '30/01/2008', 8);
INSERT INTO valoracions VALUES (3362, 90, '27/05/2003', 4);
INSERT INTO valoracions VALUES (3363, 1, '26/03/2005', 9);
INSERT INTO valoracions VALUES (3363, 79, '30/12/2008', 9);
INSERT INTO valoracions VALUES (3363, 101, '09/04/2002', 3);
INSERT INTO valoracions VALUES (3364, 2, '14/04/2002', 9);
INSERT INTO valoracions VALUES (3364, 1, '24/12/2006', 9);
INSERT INTO valoracions VALUES (3364, 39, '11/10/2009', 5);
INSERT INTO valoracions VALUES (3364, 66, '23/12/2007', 4);
INSERT INTO valoracions VALUES (3364, 71, '22/08/2006', 7);
INSERT INTO valoracions VALUES (3365, 25, '04/11/2008', 5);
INSERT INTO valoracions VALUES (3365, 3, '30/10/2002', 5);
INSERT INTO valoracions VALUES (3365, 71, '09/10/2008', 6);
INSERT INTO valoracions VALUES (3365, 4, '15/09/2006', 8);
INSERT INTO valoracions VALUES (3366, 80, '30/05/2003', 10);
INSERT INTO valoracions VALUES (3366, 101, '06/05/2004', 2);
INSERT INTO valoracions VALUES (3366, 76, '28/05/2009', 3);
INSERT INTO valoracions VALUES (3366, 62, '28/09/2005', 6);
INSERT INTO valoracions VALUES (3366, 66, '17/03/2009', 8);
INSERT INTO valoracions VALUES (3366, 101, '28/05/2010', 7);
INSERT INTO valoracions VALUES (3366, 70, '29/12/2008', 9);
INSERT INTO valoracions VALUES (3366, 80, '15/04/2010', 10);
INSERT INTO valoracions VALUES (3366, 35, '14/10/2001', 5);
INSERT INTO valoracions VALUES (3366, 24, '25/12/2006', 4);
INSERT INTO valoracions VALUES (3367, 56, '14/04/2005', 9);
INSERT INTO valoracions VALUES (3367, 9, '13/12/2006', 9);
INSERT INTO valoracions VALUES (3367, 32, '01/09/2007', 4);
INSERT INTO valoracions VALUES (3368, 2, '28/09/2010', 5);
INSERT INTO valoracions VALUES (3368, 18, '22/01/2007', 7);
INSERT INTO valoracions VALUES (3368, 2, '20/12/2003', 10);
INSERT INTO valoracions VALUES (3369, 77, '03/01/2005', 5);
INSERT INTO valoracions VALUES (3369, 25, '14/11/2005', 10);
INSERT INTO valoracions VALUES (3369, 7, '31/05/2007', 7);
INSERT INTO valoracions VALUES (3369, 83, '29/12/2006', 4);
INSERT INTO valoracions VALUES (3370, 57, '19/01/2006', 5);
INSERT INTO valoracions VALUES (3370, 34, '03/07/2004', 9);
INSERT INTO valoracions VALUES (3371, 26, '04/06/2008', 9);
INSERT INTO valoracions VALUES (3371, 20, '28/08/2007', 5);
INSERT INTO valoracions VALUES (3371, 36, '12/12/2002', 4);
INSERT INTO valoracions VALUES (3371, 47, '20/01/2006', 9);
INSERT INTO valoracions VALUES (3371, 13, '26/09/2006', 5);
INSERT INTO valoracions VALUES (3372, 55, '10/12/2004', 5);
INSERT INTO valoracions VALUES (3372, 71, '26/12/2006', 5);
INSERT INTO valoracions VALUES (3372, 60, '19/12/2009', 10);
INSERT INTO valoracions VALUES (3373, 82, '01/08/2006', 3);
INSERT INTO valoracions VALUES (3373, 84, '29/06/2002', 8);
INSERT INTO valoracions VALUES (3374, 3, '03/08/2004', 8);
INSERT INTO valoracions VALUES (3374, 28, '19/10/2001', 8);
INSERT INTO valoracions VALUES (3374, 76, '04/07/2001', 3);
INSERT INTO valoracions VALUES (3374, 18, '29/06/2001', 8);
INSERT INTO valoracions VALUES (3374, 23, '18/06/2004', 6);
INSERT INTO valoracions VALUES (3374, 64, '20/04/2005', 3);
INSERT INTO valoracions VALUES (3374, 27, '13/04/2010', 6);
INSERT INTO valoracions VALUES (3375, 28, '12/01/2008', 9);
INSERT INTO valoracions VALUES (3375, 63, '06/09/2003', 4);
INSERT INTO valoracions VALUES (3375, 26, '15/08/2003', 8);
INSERT INTO valoracions VALUES (3375, 90, '09/05/2009', 3);
INSERT INTO valoracions VALUES (3375, 111, '11/04/2004', 3);
INSERT INTO valoracions VALUES (3376, 91, '04/01/2007', 7);
INSERT INTO valoracions VALUES (3377, 53, '03/06/2007', 8);
INSERT INTO valoracions VALUES (3377, 88, '19/10/2007', 4);
INSERT INTO valoracions VALUES (3377, 44, '05/07/2008', 6);
INSERT INTO valoracions VALUES (3377, 68, '05/04/2003', 6);
INSERT INTO valoracions VALUES (3377, 23, '25/07/2009', 8);
INSERT INTO valoracions VALUES (3378, 36, '28/04/2009', 7);
INSERT INTO valoracions VALUES (3379, 62, '22/02/2004', 8);
INSERT INTO valoracions VALUES (3379, 74, '15/01/2009', 3);
INSERT INTO valoracions VALUES (3379, 22, '14/07/2009', 8);
INSERT INTO valoracions VALUES (3379, 110, '25/07/2002', 2);
INSERT INTO valoracions VALUES (3379, 40, '28/12/2008', 5);
INSERT INTO valoracions VALUES (3379, 85, '18/02/2008', 7);
INSERT INTO valoracions VALUES (3379, 49, '13/01/2009', 9);
INSERT INTO valoracions VALUES (3380, 70, '17/03/2004', 4);
INSERT INTO valoracions VALUES (3380, 58, '19/12/2004', 6);
INSERT INTO valoracions VALUES (3380, 36, '10/11/2005', 8);
INSERT INTO valoracions VALUES (3380, 103, '21/09/2005', 2);
INSERT INTO valoracions VALUES (3381, 28, '01/09/2008', 8);
INSERT INTO valoracions VALUES (3381, 110, '09/10/2001', 7);
INSERT INTO valoracions VALUES (3381, 98, '04/05/2007', 9);
INSERT INTO valoracions VALUES (3381, 18, '02/10/2001', 4);
INSERT INTO valoracions VALUES (3381, 9, '18/08/2003', 6);
INSERT INTO valoracions VALUES (3381, 49, '14/07/2004', 6);
INSERT INTO valoracions VALUES (3381, 62, '11/04/2003', 3);
INSERT INTO valoracions VALUES (3381, 29, '20/05/2007', 9);
INSERT INTO valoracions VALUES (3381, 97, '26/07/2006', 10);
INSERT INTO valoracions VALUES (3382, 69, '11/02/2004', 4);
INSERT INTO valoracions VALUES (3382, 41, '30/07/2007', 3);
INSERT INTO valoracions VALUES (3382, 48, '03/08/2010', 3);
INSERT INTO valoracions VALUES (3382, 105, '28/06/2001', 9);
INSERT INTO valoracions VALUES (3382, 77, '05/01/2006', 4);
INSERT INTO valoracions VALUES (3383, 63, '03/09/2006', 6);
INSERT INTO valoracions VALUES (3383, 73, '08/02/2008', 4);
INSERT INTO valoracions VALUES (3383, 78, '01/03/2007', 7);
INSERT INTO valoracions VALUES (3383, 19, '05/04/2009', 5);
INSERT INTO valoracions VALUES (3383, 15, '07/10/2002', 6);
INSERT INTO valoracions VALUES (3383, 64, '18/12/2005', 5);
INSERT INTO valoracions VALUES (3384, 12, '03/12/2006', 5);
INSERT INTO valoracions VALUES (3384, 93, '26/05/2003', 9);
INSERT INTO valoracions VALUES (3384, 70, '13/07/2008', 7);
INSERT INTO valoracions VALUES (3385, 64, '03/11/2009', 8);
INSERT INTO valoracions VALUES (3385, 72, '10/01/2006', 6);
INSERT INTO valoracions VALUES (3385, 79, '28/08/2003', 6);
INSERT INTO valoracions VALUES (3385, 26, '04/12/2009', 5);
INSERT INTO valoracions VALUES (3385, 74, '16/04/2004', 6);
INSERT INTO valoracions VALUES (3386, 35, '13/09/2005', 7);
INSERT INTO valoracions VALUES (3386, 33, '03/09/2001', 7);
INSERT INTO valoracions VALUES (3386, 64, '22/09/2003', 5);
INSERT INTO valoracions VALUES (3386, 3, '02/12/2009', 7);
INSERT INTO valoracions VALUES (3386, 4, '21/09/2003', 9);
INSERT INTO valoracions VALUES (3386, 5, '29/10/2010', 8);
INSERT INTO valoracions VALUES (3386, 62, '28/07/2002', 6);
INSERT INTO valoracions VALUES (3386, 13, '20/01/2006', 9);
INSERT INTO valoracions VALUES (3387, 58, '02/02/2010', 7);
INSERT INTO valoracions VALUES (3387, 102, '15/12/2007', 1);
INSERT INTO valoracions VALUES (3388, 52, '06/04/2005', 3);
INSERT INTO valoracions VALUES (3388, 45, '09/02/2010', 7);
INSERT INTO valoracions VALUES (3388, 46, '21/12/2004', 5);
INSERT INTO valoracions VALUES (3388, 71, '17/04/2001', 8);
INSERT INTO valoracions VALUES (3389, 50, '07/08/2005', 9);
INSERT INTO valoracions VALUES (3389, 19, '08/08/2006', 5);
INSERT INTO valoracions VALUES (3389, 48, '16/11/2006', 4);
INSERT INTO valoracions VALUES (3389, 23, '19/10/2007', 9);
INSERT INTO valoracions VALUES (3389, 89, '26/09/2005', 8);
INSERT INTO valoracions VALUES (3389, 91, '06/05/2001', 1);
INSERT INTO valoracions VALUES (3389, 68, '08/08/2008', 9);
INSERT INTO valoracions VALUES (3390, 109, '17/01/2002', 9);
INSERT INTO valoracions VALUES (3390, 68, '16/11/2001', 5);
INSERT INTO valoracions VALUES (3390, 97, '27/10/2007', 5);
INSERT INTO valoracions VALUES (3390, 86, '14/12/2009', 4);
INSERT INTO valoracions VALUES (3390, 44, '28/09/2009', 6);
INSERT INTO valoracions VALUES (3390, 75, '05/04/2009', 4);
INSERT INTO valoracions VALUES (3390, 36, '31/03/2009', 7);
INSERT INTO valoracions VALUES (3391, 102, '11/09/2001', 8);
INSERT INTO valoracions VALUES (3391, 69, '20/02/2010', 4);
INSERT INTO valoracions VALUES (3391, 63, '20/01/2005', 5);
INSERT INTO valoracions VALUES (3391, 69, '06/04/2008', 4);
INSERT INTO valoracions VALUES (3392, 81, '04/09/2005', 7);
INSERT INTO valoracions VALUES (3392, 114, '07/07/2002', 7);
INSERT INTO valoracions VALUES (3392, 113, '01/08/2008', 10);
INSERT INTO valoracions VALUES (3393, 42, '04/12/2006', 4);
INSERT INTO valoracions VALUES (3393, 34, '16/09/2010', 4);
INSERT INTO valoracions VALUES (3393, 67, '23/11/2002', 5);
INSERT INTO valoracions VALUES (3393, 20, '31/10/2006', 5);
INSERT INTO valoracions VALUES (3393, 23, '05/05/2006', 7);
INSERT INTO valoracions VALUES (3394, 4, '10/12/2009', 6);
INSERT INTO valoracions VALUES (3394, 87, '19/09/2007', 5);
INSERT INTO valoracions VALUES (3394, 59, '16/03/2002', 9);
INSERT INTO valoracions VALUES (3395, 95, '15/07/2005', 2);
INSERT INTO valoracions VALUES (3395, 96, '03/03/2003', 2);
INSERT INTO valoracions VALUES (3395, 60, '12/04/2007', 5);
INSERT INTO valoracions VALUES (3397, 107, '27/09/2004', 5);
INSERT INTO valoracions VALUES (3397, 34, '24/05/2010', 4);
INSERT INTO valoracions VALUES (3397, 57, '02/04/2009', 7);
INSERT INTO valoracions VALUES (3397, 37, '24/04/2005', 9);
INSERT INTO valoracions VALUES (3397, 28, '21/12/2001', 9);
INSERT INTO valoracions VALUES (3398, 70, '18/08/2007', 5);
INSERT INTO valoracions VALUES (3398, 22, '15/12/2007', 6);
INSERT INTO valoracions VALUES (3398, 62, '21/07/2002', 8);
INSERT INTO valoracions VALUES (3399, 94, '17/06/2006', 7);
INSERT INTO valoracions VALUES (3399, 75, '25/01/2004', 9);
INSERT INTO valoracions VALUES (3399, 87, '30/04/2009', 3);
INSERT INTO valoracions VALUES (3399, 109, '18/08/2001', 4);
INSERT INTO valoracions VALUES (3399, 101, '05/01/2002', 7);
INSERT INTO valoracions VALUES (3399, 115, '07/06/2006', 6);
INSERT INTO valoracions VALUES (3400, 84, '23/09/2009', 10);
INSERT INTO valoracions VALUES (3400, 49, '28/03/2005', 8);
INSERT INTO valoracions VALUES (3400, 16, '01/03/2009', 10);
INSERT INTO valoracions VALUES (3400, 66, '03/05/2007', 7);
INSERT INTO valoracions VALUES (3401, 101, '10/08/2004', 8);
INSERT INTO valoracions VALUES (3401, 63, '12/02/2004', 6);
INSERT INTO valoracions VALUES (3401, 49, '31/08/2005', 10);
INSERT INTO valoracions VALUES (3402, 73, '16/03/2007', 8);
INSERT INTO valoracions VALUES (3402, 48, '08/10/2004', 8);
INSERT INTO valoracions VALUES (3403, 101, '08/06/2004', 9);
INSERT INTO valoracions VALUES (3404, 90, '28/08/2001', 8);
INSERT INTO valoracions VALUES (3404, 66, '14/03/2002', 7);
INSERT INTO valoracions VALUES (3405, 90, '11/03/2004', 2);
INSERT INTO valoracions VALUES (3405, 6, '05/09/2008', 5);
INSERT INTO valoracions VALUES (3405, 81, '11/09/2006', 6);
INSERT INTO valoracions VALUES (3405, 9, '20/11/2008', 9);
INSERT INTO valoracions VALUES (3405, 101, '03/09/2001', 7);
INSERT INTO valoracions VALUES (3406, 29, '08/02/2006', 8);
INSERT INTO valoracions VALUES (3407, 46, '22/09/2006', 8);
INSERT INTO valoracions VALUES (3407, 57, '16/06/2002', 7);
INSERT INTO valoracions VALUES (3407, 59, '16/10/2004', 9);
INSERT INTO valoracions VALUES (3408, 63, '26/11/2005', 5);
INSERT INTO valoracions VALUES (3408, 56, '14/12/2002', 10);
INSERT INTO valoracions VALUES (3408, 81, '11/05/2001', 8);
INSERT INTO valoracions VALUES (3409, 78, '16/04/2010', 4);
INSERT INTO valoracions VALUES (3409, 11, '20/03/2007', 8);
INSERT INTO valoracions VALUES (3409, 35, '04/09/2003', 7);
INSERT INTO valoracions VALUES (3409, 54, '24/06/2007', 5);
INSERT INTO valoracions VALUES (3409, 70, '27/05/2006', 7);
INSERT INTO valoracions VALUES (3410, 70, '01/02/2005', 4);
INSERT INTO valoracions VALUES (3410, 114, '05/02/2005', 5);
INSERT INTO valoracions VALUES (3410, 51, '04/05/2001', 9);
INSERT INTO valoracions VALUES (3411, 75, '19/10/2003', 3);
INSERT INTO valoracions VALUES (3411, 48, '13/03/2003', 7);
INSERT INTO valoracions VALUES (3411, 115, '08/05/2004', 2);
INSERT INTO valoracions VALUES (3411, 77, '11/09/2002', 8);
INSERT INTO valoracions VALUES (3412, 37, '24/12/2009', 4);
INSERT INTO valoracions VALUES (3412, 85, '09/04/2002', 8);
INSERT INTO valoracions VALUES (3412, 33, '27/04/2004', 6);
INSERT INTO valoracions VALUES (3412, 115, '14/07/2001', 7);
INSERT INTO valoracions VALUES (3413, 28, '04/10/2002', 4);
INSERT INTO valoracions VALUES (3413, 100, '10/12/2001', 8);
INSERT INTO valoracions VALUES (3413, 25, '30/12/2004', 9);
INSERT INTO valoracions VALUES (3414, 93, '04/06/2007', 4);
INSERT INTO valoracions VALUES (3414, 27, '31/03/2010', 8);
INSERT INTO valoracions VALUES (3414, 66, '06/06/2004', 5);
INSERT INTO valoracions VALUES (3414, 38, '27/08/2010', 5);
INSERT INTO valoracions VALUES (3414, 53, '05/03/2004', 8);
INSERT INTO valoracions VALUES (3415, 3, '20/12/2007', 8);
INSERT INTO valoracions VALUES (3415, 60, '26/05/2008', 3);
INSERT INTO valoracions VALUES (3415, 44, '12/08/2007', 9);
INSERT INTO valoracions VALUES (3416, 7, '06/05/2010', 8);
INSERT INTO valoracions VALUES (3416, 73, '24/02/2008', 6);
INSERT INTO valoracions VALUES (3417, 104, '20/03/2002', 4);
INSERT INTO valoracions VALUES (3417, 95, '08/09/2006', 7);
INSERT INTO valoracions VALUES (3417, 65, '17/04/2002', 7);
INSERT INTO valoracions VALUES (3418, 9, '25/09/2008', 8);
INSERT INTO valoracions VALUES (3418, 109, '11/01/2007', 6);
INSERT INTO valoracions VALUES (3419, 40, '23/03/2009', 10);
INSERT INTO valoracions VALUES (3419, 42, '15/05/2002', 7);
INSERT INTO valoracions VALUES (3419, 82, '20/05/2005', 10);
INSERT INTO valoracions VALUES (3419, 113, '05/06/2001', 7);
INSERT INTO valoracions VALUES (3420, 60, '08/06/2001', 8);
INSERT INTO valoracions VALUES (3420, 102, '05/03/2007', 10);
INSERT INTO valoracions VALUES (3420, 11, '02/09/2009', 9);
INSERT INTO valoracions VALUES (3421, 58, '18/07/2003', 5);
INSERT INTO valoracions VALUES (3421, 99, '25/07/2009', 5);
INSERT INTO valoracions VALUES (3422, 19, '06/08/2003', 5);
INSERT INTO valoracions VALUES (3422, 12, '06/11/2004', 6);
INSERT INTO valoracions VALUES (3422, 46, '26/01/2006', 7);
INSERT INTO valoracions VALUES (3422, 19, '21/11/2009', 7);
INSERT INTO valoracions VALUES (3422, 89, '11/04/2002', 2);
INSERT INTO valoracions VALUES (3422, 43, '01/11/2006', 5);
INSERT INTO valoracions VALUES (3423, 70, '09/11/2009', 3);
INSERT INTO valoracions VALUES (3423, 26, '29/07/2009', 9);
INSERT INTO valoracions VALUES (3423, 100, '25/02/2007', 5);
INSERT INTO valoracions VALUES (3423, 96, '02/06/2005', 4);
INSERT INTO valoracions VALUES (3423, 26, '11/04/2004', 9);
INSERT INTO valoracions VALUES (3423, 96, '07/05/2009', 5);
INSERT INTO valoracions VALUES (3424, 82, '25/10/2003', 2);
INSERT INTO valoracions VALUES (3424, 23, '01/09/2002', 6);
INSERT INTO valoracions VALUES (3424, 72, '22/06/2003', 8);
INSERT INTO valoracions VALUES (3425, 41, '06/04/2010', 5);
INSERT INTO valoracions VALUES (3425, 91, '29/05/2008', 7);
INSERT INTO valoracions VALUES (3425, 47, '04/03/2002', 4);
INSERT INTO valoracions VALUES (3425, 58, '09/05/2004', 10);
INSERT INTO valoracions VALUES (3425, 100, '16/04/2003', 8);
INSERT INTO valoracions VALUES (3425, 26, '28/10/2009', 6);
INSERT INTO valoracions VALUES (3426, 78, '13/05/2002', 8);
INSERT INTO valoracions VALUES (3426, 80, '04/11/2009', 2);
INSERT INTO valoracions VALUES (3426, 19, '13/07/2008', 4);
INSERT INTO valoracions VALUES (3427, 25, '14/01/2004', 7);
INSERT INTO valoracions VALUES (3427, 49, '05/11/2009', 4);
INSERT INTO valoracions VALUES (3427, 65, '04/01/2009', 8);
INSERT INTO valoracions VALUES (3428, 86, '10/04/2006', 1);
INSERT INTO valoracions VALUES (3428, 38, '31/05/2002', 3);
INSERT INTO valoracions VALUES (3428, 10, '20/07/2006', 7);
INSERT INTO valoracions VALUES (3428, 83, '10/09/2005', 7);
INSERT INTO valoracions VALUES (3428, 2, '18/06/2006', 7);
INSERT INTO valoracions VALUES (3428, 85, '04/10/2010', 10);
INSERT INTO valoracions VALUES (3429, 115, '17/08/2007', 5);
INSERT INTO valoracions VALUES (3429, 95, '21/07/2009', 5);
INSERT INTO valoracions VALUES (3429, 27, '11/10/2007', 8);
INSERT INTO valoracions VALUES (3429, 58, '09/05/2009', 9);
INSERT INTO valoracions VALUES (3430, 99, '24/07/2008', 2);
INSERT INTO valoracions VALUES (3430, 113, '14/10/2005', 8);
INSERT INTO valoracions VALUES (3430, 80, '09/08/2010', 7);
INSERT INTO valoracions VALUES (3430, 93, '08/08/2002', 6);
INSERT INTO valoracions VALUES (3430, 64, '01/01/2003', 5);
INSERT INTO valoracions VALUES (3431, 61, '18/07/2001', 6);
INSERT INTO valoracions VALUES (3431, 105, '09/03/2007', 3);
INSERT INTO valoracions VALUES (3431, 34, '08/03/2008', 7);
INSERT INTO valoracions VALUES (3431, 40, '10/07/2004', 8);
INSERT INTO valoracions VALUES (3431, 61, '04/07/2009', 4);
INSERT INTO valoracions VALUES (3431, 72, '01/03/2008', 8);
INSERT INTO valoracions VALUES (3432, 11, '04/04/2010', 9);
INSERT INTO valoracions VALUES (3432, 34, '09/05/2005', 5);
INSERT INTO valoracions VALUES (3432, 22, '04/12/2009', 5);
INSERT INTO valoracions VALUES (3432, 92, '01/02/2006', 8);
INSERT INTO valoracions VALUES (3432, 114, '22/03/2005', 8);
INSERT INTO valoracions VALUES (3432, 9, '21/05/2002', 9);
INSERT INTO valoracions VALUES (3432, 27, '19/02/2008', 9);
INSERT INTO valoracions VALUES (3432, 2, '15/05/2008', 6);
INSERT INTO valoracions VALUES (3432, 58, '08/01/2004', 7);
INSERT INTO valoracions VALUES (3433, 81, '27/09/2006', 4);
INSERT INTO valoracions VALUES (3434, 2, '30/12/2007', 7);
INSERT INTO valoracions VALUES (3434, 22, '23/12/2008', 5);
INSERT INTO valoracions VALUES (3434, 115, '25/07/2006', 4);
INSERT INTO valoracions VALUES (3434, 25, '21/07/2007', 6);
INSERT INTO valoracions VALUES (3434, 44, '02/12/2003', 3);
INSERT INTO valoracions VALUES (3434, 3, '08/02/2010', 7);
INSERT INTO valoracions VALUES (3435, 58, '05/03/2009', 3);
INSERT INTO valoracions VALUES (3435, 58, '05/01/2009', 5);
INSERT INTO valoracions VALUES (3435, 42, '08/04/2005', 5);
INSERT INTO valoracions VALUES (3436, 65, '29/03/2006', 8);
INSERT INTO valoracions VALUES (3436, 95, '20/06/2004', 5);
INSERT INTO valoracions VALUES (3436, 101, '22/09/2010', 3);
INSERT INTO valoracions VALUES (3436, 28, '23/03/2004', 9);
INSERT INTO valoracions VALUES (3436, 89, '28/05/2009', 8);
INSERT INTO valoracions VALUES (3436, 57, '08/11/2005', 3);
INSERT INTO valoracions VALUES (3436, 16, '07/01/2005', 9);
INSERT INTO valoracions VALUES (3436, 22, '18/08/2005', 6);
INSERT INTO valoracions VALUES (3436, 7, '02/03/2004', 9);
INSERT INTO valoracions VALUES (3437, 101, '02/08/2003', 3);
INSERT INTO valoracions VALUES (3437, 79, '11/03/2002', 7);
INSERT INTO valoracions VALUES (3437, 18, '04/03/2003', 9);
INSERT INTO valoracions VALUES (3437, 36, '16/03/2003', 8);
INSERT INTO valoracions VALUES (3438, 74, '14/08/2009', 6);
INSERT INTO valoracions VALUES (3438, 70, '28/12/2001', 8);
INSERT INTO valoracions VALUES (3439, 69, '22/06/2002', 3);
INSERT INTO valoracions VALUES (3439, 38, '19/01/2003', 9);
INSERT INTO valoracions VALUES (3439, 76, '15/08/2005', 8);
INSERT INTO valoracions VALUES (3440, 69, '22/09/2002', 3);
INSERT INTO valoracions VALUES (3440, 80, '08/05/2002', 8);
INSERT INTO valoracions VALUES (3440, 41, '07/06/2008', 9);
INSERT INTO valoracions VALUES (3440, 82, '04/08/2004', 3);
INSERT INTO valoracions VALUES (3441, 103, '11/08/2008', 5);
INSERT INTO valoracions VALUES (3441, 68, '24/03/2005', 4);
INSERT INTO valoracions VALUES (3441, 90, '06/06/2007', 2);
INSERT INTO valoracions VALUES (3441, 78, '25/05/2008', 2);
INSERT INTO valoracions VALUES (3441, 23, '16/07/2010', 6);
INSERT INTO valoracions VALUES (3441, 115, '27/04/2007', 2);
INSERT INTO valoracions VALUES (3441, 17, '07/06/2008', 8);
INSERT INTO valoracions VALUES (3441, 83, '09/05/2007', 2);
INSERT INTO valoracions VALUES (3442, 12, '01/01/2005', 6);
INSERT INTO valoracions VALUES (3442, 63, '14/12/2001', 9);
INSERT INTO valoracions VALUES (3442, 85, '05/08/2007', 1);
INSERT INTO valoracions VALUES (3442, 35, '28/03/2006', 8);
INSERT INTO valoracions VALUES (3442, 114, '10/04/2001', 8);
INSERT INTO valoracions VALUES (3442, 95, '21/02/2006', 4);
INSERT INTO valoracions VALUES (3443, 103, '16/08/2009', 3);
INSERT INTO valoracions VALUES (3443, 17, '15/11/2005', 7);
INSERT INTO valoracions VALUES (3444, 45, '23/05/2008', 5);
INSERT INTO valoracions VALUES (3444, 102, '29/08/2010', 2);
INSERT INTO valoracions VALUES (3444, 80, '28/08/2008', 9);
INSERT INTO valoracions VALUES (3445, 14, '09/10/2002', 7);
INSERT INTO valoracions VALUES (3445, 99, '22/06/2009', 9);
INSERT INTO valoracions VALUES (3446, 73, '12/08/2003', 2);
INSERT INTO valoracions VALUES (3446, 28, '22/06/2006', 6);
INSERT INTO valoracions VALUES (3446, 64, '29/06/2002', 8);
INSERT INTO valoracions VALUES (3446, 65, '21/07/2006', 8);
INSERT INTO valoracions VALUES (3446, 32, '19/01/2007', 10);
INSERT INTO valoracions VALUES (3447, 42, '27/12/2007', 8);
INSERT INTO valoracions VALUES (3447, 43, '13/04/2009', 7);
INSERT INTO valoracions VALUES (3448, 104, '13/02/2007', 2);
INSERT INTO valoracions VALUES (3448, 26, '09/04/2010', 5);
INSERT INTO valoracions VALUES (3448, 79, '15/02/2006', 2);
INSERT INTO valoracions VALUES (3448, 67, '04/09/2010', 10);
INSERT INTO valoracions VALUES (3448, 60, '11/08/2010', 7);
INSERT INTO valoracions VALUES (3449, 101, '01/04/2003', 3);
INSERT INTO valoracions VALUES (3449, 71, '06/09/2007', 4);
INSERT INTO valoracions VALUES (3449, 51, '14/05/2005', 8);
INSERT INTO valoracions VALUES (3449, 103, '29/08/2006', 6);
INSERT INTO valoracions VALUES (3450, 33, '02/10/2010', 6);
INSERT INTO valoracions VALUES (3450, 92, '14/02/2005', 5);
INSERT INTO valoracions VALUES (3450, 105, '17/02/2006', 2);
INSERT INTO valoracions VALUES (3450, 114, '03/03/2010', 4);
INSERT INTO valoracions VALUES (3450, 16, '19/04/2002', 9);
INSERT INTO valoracions VALUES (3451, 20, '08/08/2005', 7);
INSERT INTO valoracions VALUES (3451, 111, '02/02/2008', 2);
INSERT INTO valoracions VALUES (3451, 107, '14/12/2009', 6);
INSERT INTO valoracions VALUES (3451, 30, '03/07/2005', 10);
INSERT INTO valoracions VALUES (3452, 63, '03/12/2006', 7);
INSERT INTO valoracions VALUES (3453, 61, '12/01/2003', 4);
INSERT INTO valoracions VALUES (3453, 79, '21/04/2008', 4);
INSERT INTO valoracions VALUES (3453, 90, '28/04/2005', 5);
INSERT INTO valoracions VALUES (3454, 7, '10/09/2006', 7);
INSERT INTO valoracions VALUES (3454, 59, '16/08/2002', 5);
INSERT INTO valoracions VALUES (3454, 106, '25/12/2009', 4);
INSERT INTO valoracions VALUES (3454, 32, '25/05/2008', 9);
INSERT INTO valoracions VALUES (3455, 70, '11/07/2001', 6);
INSERT INTO valoracions VALUES (3455, 35, '15/07/2003', 8);
INSERT INTO valoracions VALUES (3455, 19, '27/09/2006', 8);
INSERT INTO valoracions VALUES (3455, 78, '18/04/2002', 3);
INSERT INTO valoracions VALUES (3455, 10, '28/04/2007', 6);
INSERT INTO valoracions VALUES (3456, 95, '11/07/2002', 6);
INSERT INTO valoracions VALUES (3456, 88, '07/08/2002', 5);
INSERT INTO valoracions VALUES (3456, 91, '28/01/2007', 8);
INSERT INTO valoracions VALUES (3456, 111, '20/07/2005', 9);
INSERT INTO valoracions VALUES (3456, 6, '05/12/2001', 9);
INSERT INTO valoracions VALUES (3457, 83, '22/12/2005', 7);
INSERT INTO valoracions VALUES (3457, 19, '05/10/2004', 9);
INSERT INTO valoracions VALUES (3457, 69, '14/03/2003', 9);
INSERT INTO valoracions VALUES (3457, 9, '14/08/2008', 6);
INSERT INTO valoracions VALUES (3457, 26, '19/11/2004', 8);
INSERT INTO valoracions VALUES (3457, 49, '05/10/2003', 7);
INSERT INTO valoracions VALUES (3458, 22, '07/02/2005', 7);
INSERT INTO valoracions VALUES (3458, 114, '24/11/2004', 5);
INSERT INTO valoracions VALUES (3459, 9, '19/10/2004', 8);
INSERT INTO valoracions VALUES (3459, 97, '23/07/2010', 6);
INSERT INTO valoracions VALUES (3459, 61, '29/12/2009', 5);
INSERT INTO valoracions VALUES (3459, 18, '21/05/2005', 10);
INSERT INTO valoracions VALUES (3459, 75, '26/09/2007', 8);
INSERT INTO valoracions VALUES (3459, 32, '14/12/2001', 7);
INSERT INTO valoracions VALUES (3459, 109, '18/05/2002', 6);
INSERT INTO valoracions VALUES (3459, 9, '30/01/2002', 8);
INSERT INTO valoracions VALUES (3459, 22, '26/03/2005', 7);
INSERT INTO valoracions VALUES (3460, 6, '02/04/2003', 8);
INSERT INTO valoracions VALUES (3460, 70, '08/03/2008', 4);
INSERT INTO valoracions VALUES (3460, 65, '30/08/2004', 3);
INSERT INTO valoracions VALUES (3460, 72, '18/09/2001', 3);
INSERT INTO valoracions VALUES (3461, 106, '28/04/2010', 4);
INSERT INTO valoracions VALUES (3461, 8, '27/08/2006', 7);
INSERT INTO valoracions VALUES (3461, 86, '18/08/2005', 2);
INSERT INTO valoracions VALUES (3461, 116, '18/12/2009', 8);
INSERT INTO valoracions VALUES (3461, 33, '20/05/2001', 10);
INSERT INTO valoracions VALUES (3461, 81, '19/09/2009', 3);
INSERT INTO valoracions VALUES (3462, 26, '12/12/2008', 5);
INSERT INTO valoracions VALUES (3462, 115, '16/02/2009', 5);
INSERT INTO valoracions VALUES (3462, 107, '26/01/2004', 6);
INSERT INTO valoracions VALUES (3462, 91, '29/01/2009', 6);
INSERT INTO valoracions VALUES (3462, 103, '25/04/2004', 6);
INSERT INTO valoracions VALUES (3462, 24, '03/12/2003', 6);
INSERT INTO valoracions VALUES (3462, 116, '09/08/2008', 7);
INSERT INTO valoracions VALUES (3463, 43, '23/07/2006', 7);
INSERT INTO valoracions VALUES (3463, 18, '27/06/2006', 4);
INSERT INTO valoracions VALUES (3463, 43, '25/03/2008', 3);
INSERT INTO valoracions VALUES (3463, 43, '06/03/2010', 6);
INSERT INTO valoracions VALUES (3464, 92, '30/06/2007', 3);
INSERT INTO valoracions VALUES (3464, 29, '03/07/2003', 6);
INSERT INTO valoracions VALUES (3464, 80, '04/04/2005', 2);
INSERT INTO valoracions VALUES (3464, 17, '17/01/2002', 9);
INSERT INTO valoracions VALUES (3465, 71, '09/04/2004', 4);
INSERT INTO valoracions VALUES (3466, 102, '06/07/2006', 9);
INSERT INTO valoracions VALUES (3466, 4, '22/07/2003', 5);
INSERT INTO valoracions VALUES (3466, 55, '10/08/2003', 6);
INSERT INTO valoracions VALUES (3466, 108, '14/06/2004', 3);
INSERT INTO valoracions VALUES (3466, 107, '19/06/2001', 6);
INSERT INTO valoracions VALUES (3466, 1, '25/06/2008', 7);
INSERT INTO valoracions VALUES (3466, 57, '22/10/2006', 6);
INSERT INTO valoracions VALUES (3466, 12, '19/08/2004', 9);
INSERT INTO valoracions VALUES (3466, 80, '26/06/2004', 4);
INSERT INTO valoracions VALUES (3467, 22, '18/12/2002', 5);
INSERT INTO valoracions VALUES (3467, 21, '24/08/2006', 6);
INSERT INTO valoracions VALUES (3467, 46, '10/11/2007', 9);
INSERT INTO valoracions VALUES (3468, 5, '08/12/2008', 8);
INSERT INTO valoracions VALUES (3468, 110, '09/08/2009', 5);
INSERT INTO valoracions VALUES (3468, 32, '27/06/2008', 6);
INSERT INTO valoracions VALUES (3468, 2, '26/10/2007', 5);
INSERT INTO valoracions VALUES (3469, 47, '23/03/2003', 4);
INSERT INTO valoracions VALUES (3469, 96, '01/11/2001', 5);
INSERT INTO valoracions VALUES (3469, 13, '26/09/2009', 6);
INSERT INTO valoracions VALUES (3469, 24, '15/07/2002', 8);
INSERT INTO valoracions VALUES (3469, 78, '28/06/2002', 4);
INSERT INTO valoracions VALUES (3470, 56, '09/10/2010', 7);
INSERT INTO valoracions VALUES (3470, 13, '11/12/2001', 7);
INSERT INTO valoracions VALUES (3471, 94, '03/05/2001', 6);
INSERT INTO valoracions VALUES (3471, 80, '13/07/2001', 9);
INSERT INTO valoracions VALUES (3471, 83, '27/11/2005', 5);
INSERT INTO valoracions VALUES (3471, 11, '07/08/2001', 6);
INSERT INTO valoracions VALUES (3471, 33, '14/11/2003', 5);
INSERT INTO valoracions VALUES (3472, 90, '02/02/2005', 9);
INSERT INTO valoracions VALUES (3472, 40, '04/06/2009', 4);
INSERT INTO valoracions VALUES (3472, 76, '04/10/2003', 4);
INSERT INTO valoracions VALUES (3473, 83, '24/11/2002', 7);
INSERT INTO valoracions VALUES (3473, 12, '18/03/2007', 7);
INSERT INTO valoracions VALUES (3473, 85, '22/01/2007', 7);
INSERT INTO valoracions VALUES (3473, 62, '06/09/2010', 2);
INSERT INTO valoracions VALUES (3473, 15, '27/03/2009', 5);
INSERT INTO valoracions VALUES (3473, 9, '19/07/2002', 6);
INSERT INTO valoracions VALUES (3474, 34, '02/12/2001', 10);
INSERT INTO valoracions VALUES (3474, 24, '13/06/2002', 5);
INSERT INTO valoracions VALUES (3475, 44, '25/09/2010', 7);
INSERT INTO valoracions VALUES (3476, 53, '26/08/2008', 9);
INSERT INTO valoracions VALUES (3476, 21, '01/12/2009', 6);
INSERT INTO valoracions VALUES (3476, 4, '01/02/2006', 7);
INSERT INTO valoracions VALUES (3476, 81, '28/05/2005', 10);
INSERT INTO valoracions VALUES (3476, 29, '21/06/2008', 8);
INSERT INTO valoracions VALUES (3476, 103, '28/12/2009', 4);
INSERT INTO valoracions VALUES (3477, 35, '27/06/2003', 4);
INSERT INTO valoracions VALUES (3477, 62, '29/05/2003', 9);
INSERT INTO valoracions VALUES (3477, 7, '28/11/2001', 9);
INSERT INTO valoracions VALUES (3477, 71, '30/11/2009', 6);
INSERT INTO valoracions VALUES (3477, 20, '14/12/2008', 7);
INSERT INTO valoracions VALUES (3477, 107, '04/03/2007', 7);
INSERT INTO valoracions VALUES (3478, 42, '03/05/2001', 10);
INSERT INTO valoracions VALUES (3478, 31, '02/11/2008', 6);
INSERT INTO valoracions VALUES (3478, 27, '31/05/2003', 6);
INSERT INTO valoracions VALUES (3478, 28, '09/02/2010', 5);
INSERT INTO valoracions VALUES (3478, 59, '19/06/2001', 4);
INSERT INTO valoracions VALUES (3478, 71, '19/05/2006', 2);
INSERT INTO valoracions VALUES (3478, 9, '10/04/2004', 10);
INSERT INTO valoracions VALUES (3478, 60, '12/05/2004', 7);
INSERT INTO valoracions VALUES (3480, 70, '30/01/2007', 5);
INSERT INTO valoracions VALUES (3480, 15, '16/12/2007', 9);
INSERT INTO valoracions VALUES (3480, 7, '28/03/2004', 7);
INSERT INTO valoracions VALUES (3480, 47, '11/04/2006', 4);
INSERT INTO valoracions VALUES (3481, 106, '17/04/2001', 6);
INSERT INTO valoracions VALUES (3481, 26, '31/03/2005', 5);
INSERT INTO valoracions VALUES (3481, 9, '08/05/2008', 6);
INSERT INTO valoracions VALUES (3481, 39, '05/04/2002', 7);
INSERT INTO valoracions VALUES (3482, 79, '13/02/2002', 6);
INSERT INTO valoracions VALUES (3482, 102, '14/02/2005', 6);
INSERT INTO valoracions VALUES (3482, 89, '13/06/2004', 2);
INSERT INTO valoracions VALUES (3483, 97, '09/10/2005', 7);
INSERT INTO valoracions VALUES (3483, 115, '11/04/2001', 2);
INSERT INTO valoracions VALUES (3483, 99, '11/06/2001', 4);
INSERT INTO valoracions VALUES (3483, 74, '21/10/2008', 10);
INSERT INTO valoracions VALUES (3484, 108, '06/11/2001', 7);
INSERT INTO valoracions VALUES (3484, 86, '30/03/2010', 2);
INSERT INTO valoracions VALUES (3484, 29, '03/09/2001', 6);
INSERT INTO valoracions VALUES (3484, 37, '20/11/2005', 8);
INSERT INTO valoracions VALUES (3484, 83, '04/04/2002', 6);
INSERT INTO valoracions VALUES (3485, 61, '01/06/2001', 5);
INSERT INTO valoracions VALUES (3485, 63, '07/01/2005', 6);
INSERT INTO valoracions VALUES (3486, 4, '26/01/2010', 5);
INSERT INTO valoracions VALUES (3486, 41, '08/01/2002', 7);
INSERT INTO valoracions VALUES (3486, 15, '28/10/2009', 5);
INSERT INTO valoracions VALUES (3486, 110, '25/10/2009', 3);
INSERT INTO valoracions VALUES (3487, 29, '02/03/2006', 7);
INSERT INTO valoracions VALUES (3487, 69, '30/06/2001', 8);
INSERT INTO valoracions VALUES (3487, 9, '10/04/2009', 9);
INSERT INTO valoracions VALUES (3488, 63, '13/07/2002', 8);
INSERT INTO valoracions VALUES (3488, 16, '10/03/2004', 4);
INSERT INTO valoracions VALUES (3489, 10, '26/08/2006', 8);
INSERT INTO valoracions VALUES (3489, 84, '19/08/2008', 4);
INSERT INTO valoracions VALUES (3489, 103, '20/03/2002', 4);
INSERT INTO valoracions VALUES (3489, 14, '24/09/2005', 5);
INSERT INTO valoracions VALUES (3490, 61, '26/03/2008', 5);
INSERT INTO valoracions VALUES (3490, 68, '13/09/2008', 3);
INSERT INTO valoracions VALUES (3490, 12, '30/04/2007', 9);
INSERT INTO valoracions VALUES (3490, 57, '13/06/2006', 3);
INSERT INTO valoracions VALUES (3491, 24, '05/07/2007', 8);
INSERT INTO valoracions VALUES (3491, 1, '02/09/2010', 10);
INSERT INTO valoracions VALUES (3491, 1, '31/08/2007', 8);
INSERT INTO valoracions VALUES (3491, 100, '30/11/2007', 6);
INSERT INTO valoracions VALUES (3491, 7, '20/04/2001', 10);
INSERT INTO valoracions VALUES (3492, 28, '26/06/2003', 6);
INSERT INTO valoracions VALUES (3492, 57, '22/03/2010', 6);
INSERT INTO valoracions VALUES (3492, 55, '09/05/2004', 9);
INSERT INTO valoracions VALUES (3492, 43, '09/11/2002', 7);
INSERT INTO valoracions VALUES (3493, 86, '30/11/2002', 8);
INSERT INTO valoracions VALUES (3493, 60, '04/01/2006', 2);
INSERT INTO valoracions VALUES (3493, 42, '15/09/2008', 9);
INSERT INTO valoracions VALUES (3493, 24, '25/02/2005', 8);
INSERT INTO valoracions VALUES (3493, 78, '11/02/2004', 8);
INSERT INTO valoracions VALUES (3494, 103, '19/12/2002', 5);
INSERT INTO valoracions VALUES (3494, 52, '27/07/2009', 10);
INSERT INTO valoracions VALUES (3494, 70, '26/05/2008', 5);
INSERT INTO valoracions VALUES (3496, 5, '09/09/2009', 9);
INSERT INTO valoracions VALUES (3496, 20, '08/07/2010', 9);
INSERT INTO valoracions VALUES (3496, 25, '20/05/2001', 9);
INSERT INTO valoracions VALUES (3497, 77, '02/03/2008', 6);
INSERT INTO valoracions VALUES (3497, 52, '09/04/2010', 4);
INSERT INTO valoracions VALUES (3497, 67, '03/01/2006', 8);
INSERT INTO valoracions VALUES (3498, 50, '21/01/2004', 4);
INSERT INTO valoracions VALUES (3498, 88, '31/08/2007', 8);
INSERT INTO valoracions VALUES (3498, 9, '19/07/2005', 9);
INSERT INTO valoracions VALUES (3498, 50, '01/06/2004', 10);
INSERT INTO valoracions VALUES (3499, 93, '11/03/2009', 6);
INSERT INTO valoracions VALUES (3499, 105, '02/11/2002', 9);
INSERT INTO valoracions VALUES (3499, 15, '18/05/2005', 6);
INSERT INTO valoracions VALUES (3499, 114, '19/07/2006', 0);
INSERT INTO valoracions VALUES (3499, 94, '20/03/2003', 8);
INSERT INTO valoracions VALUES (3500, 114, '13/09/2001', 3);
INSERT INTO valoracions VALUES (3500, 43, '05/08/2009', 7);
INSERT INTO valoracions VALUES (3500, 40, '24/07/2006', 7);
INSERT INTO valoracions VALUES (3501, 101, '06/03/2002', 7);
INSERT INTO valoracions VALUES (3501, 107, '17/08/2009', 2);
INSERT INTO valoracions VALUES (3501, 96, '14/07/2006', 6);
INSERT INTO valoracions VALUES (3502, 54, '29/11/2007', 3);
INSERT INTO valoracions VALUES (3502, 104, '31/08/2004', 9);
INSERT INTO valoracions VALUES (3502, 32, '06/02/2009', 5);
INSERT INTO valoracions VALUES (3502, 15, '26/01/2005', 9);
INSERT INTO valoracions VALUES (3502, 64, '26/03/2007', 4);
INSERT INTO valoracions VALUES (3502, 78, '27/04/2004', 2);
INSERT INTO valoracions VALUES (3502, 65, '14/08/2010', 10);
INSERT INTO valoracions VALUES (3503, 6, '28/12/2004', 8);
INSERT INTO valoracions VALUES (3503, 99, '29/09/2009', 4);
INSERT INTO valoracions VALUES (3503, 72, '21/03/2003', 6);
INSERT INTO valoracions VALUES (3503, 86, '04/10/2005', 5);
INSERT INTO valoracions VALUES (3503, 95, '10/03/2007', 7);
INSERT INTO valoracions VALUES (3503, 61, '20/10/2008', 5);
INSERT INTO valoracions VALUES (3503, 23, '21/03/2009', 10);
INSERT INTO valoracions VALUES (3504, 1, '13/03/2004', 9);
INSERT INTO valoracions VALUES (3504, 94, '23/01/2009', 5);
INSERT INTO valoracions VALUES (3505, 87, '12/11/2007', 4);
INSERT INTO valoracions VALUES (3505, 79, '24/05/2007', 5);
INSERT INTO valoracions VALUES (3505, 21, '01/12/2003', 7);
INSERT INTO valoracions VALUES (3505, 32, '26/01/2005', 9);
INSERT INTO valoracions VALUES (3505, 96, '28/05/2005', 5);
INSERT INTO valoracions VALUES (3505, 18, '26/04/2003', 7);
INSERT INTO valoracions VALUES (3506, 9, '06/01/2009', 10);
INSERT INTO valoracions VALUES (3506, 60, '08/06/2002', 4);
INSERT INTO valoracions VALUES (3506, 81, '14/10/2009', 2);
INSERT INTO valoracions VALUES (3506, 56, '28/01/2006', 10);
INSERT INTO valoracions VALUES (3506, 21, '09/01/2002', 8);
INSERT INTO valoracions VALUES (3506, 61, '27/06/2010', 3);
INSERT INTO valoracions VALUES (3506, 34, '11/10/2008', 6);
INSERT INTO valoracions VALUES (3507, 85, '18/06/2006', 8);
INSERT INTO valoracions VALUES (3507, 37, '14/08/2003', 5);
INSERT INTO valoracions VALUES (3507, 14, '04/10/2003', 10);
INSERT INTO valoracions VALUES (3507, 6, '27/02/2002', 9);
INSERT INTO valoracions VALUES (3507, 41, '18/11/2002', 5);
INSERT INTO valoracions VALUES (3508, 65, '26/08/2006', 2);
INSERT INTO valoracions VALUES (3508, 90, '30/04/2007', 7);
INSERT INTO valoracions VALUES (3508, 8, '24/10/2002', 7);
INSERT INTO valoracions VALUES (3509, 38, '16/06/2009', 9);
INSERT INTO valoracions VALUES (3509, 48, '11/08/2008', 10);
INSERT INTO valoracions VALUES (3509, 23, '28/01/2002', 6);
INSERT INTO valoracions VALUES (3509, 66, '20/09/2002', 5);
INSERT INTO valoracions VALUES (3509, 38, '02/04/2006', 7);
INSERT INTO valoracions VALUES (3509, 116, '11/10/2007', 4);
INSERT INTO valoracions VALUES (3510, 79, '02/01/2004', 7);
INSERT INTO valoracions VALUES (3510, 94, '20/10/2003', 2);
INSERT INTO valoracions VALUES (3511, 23, '25/04/2002', 7);
INSERT INTO valoracions VALUES (3512, 78, '24/01/2008', 3);
INSERT INTO valoracions VALUES (3512, 78, '24/03/2003', 8);
INSERT INTO valoracions VALUES (3512, 45, '03/10/2006', 5);
INSERT INTO valoracions VALUES (3512, 22, '14/10/2001', 6);
INSERT INTO valoracions VALUES (3513, 87, '20/04/2007', 3);
INSERT INTO valoracions VALUES (3513, 38, '19/09/2008', 4);
INSERT INTO valoracions VALUES (3513, 17, '27/08/2005', 7);
INSERT INTO valoracions VALUES (3514, 32, '28/06/2002', 10);
INSERT INTO valoracions VALUES (3514, 44, '27/02/2009', 9);
INSERT INTO valoracions VALUES (3514, 23, '13/05/2006', 8);
INSERT INTO valoracions VALUES (3514, 95, '28/12/2003', 7);
INSERT INTO valoracions VALUES (3515, 71, '16/06/2008', 7);
INSERT INTO valoracions VALUES (3515, 39, '15/03/2005', 4);
INSERT INTO valoracions VALUES (3515, 83, '12/03/2006', 1);
INSERT INTO valoracions VALUES (3515, 67, '22/07/2005', 6);
INSERT INTO valoracions VALUES (3515, 2, '07/09/2009', 7);
INSERT INTO valoracions VALUES (3515, 14, '19/11/2006', 9);
INSERT INTO valoracions VALUES (3516, 19, '14/07/2009', 6);
INSERT INTO valoracions VALUES (3516, 1, '28/10/2001', 5);
INSERT INTO valoracions VALUES (3516, 31, '16/01/2009', 7);
INSERT INTO valoracions VALUES (3517, 33, '14/07/2001', 4);
INSERT INTO valoracions VALUES (3517, 5, '16/09/2004', 9);
INSERT INTO valoracions VALUES (3517, 32, '06/07/2005', 7);
INSERT INTO valoracions VALUES (3517, 62, '03/06/2009', 9);
INSERT INTO valoracions VALUES (3517, 98, '01/03/2007', 3);
INSERT INTO valoracions VALUES (3517, 87, '23/07/2010', 3);
INSERT INTO valoracions VALUES (3517, 93, '03/05/2003', 8);
INSERT INTO valoracions VALUES (3518, 11, '14/05/2008', 7);
INSERT INTO valoracions VALUES (3518, 94, '25/05/2002', 4);
INSERT INTO valoracions VALUES (3518, 86, '19/04/2001', 7);
INSERT INTO valoracions VALUES (3518, 58, '03/12/2002', 5);
INSERT INTO valoracions VALUES (3519, 80, '11/04/2003', 3);
INSERT INTO valoracions VALUES (3519, 23, '16/07/2008', 7);
INSERT INTO valoracions VALUES (3519, 98, '10/08/2009', 1);
INSERT INTO valoracions VALUES (3520, 28, '23/07/2005', 9);
INSERT INTO valoracions VALUES (3520, 116, '09/11/2008', 0);
INSERT INTO valoracions VALUES (3520, 29, '03/06/2008', 8);
INSERT INTO valoracions VALUES (3520, 19, '17/09/2010', 5);
INSERT INTO valoracions VALUES (3520, 89, '29/06/2001', 4);
INSERT INTO valoracions VALUES (3521, 15, '23/05/2001', 8);
INSERT INTO valoracions VALUES (3521, 11, '14/03/2006', 8);
INSERT INTO valoracions VALUES (3521, 80, '14/04/2004', 4);
INSERT INTO valoracions VALUES (3521, 106, '23/06/2004', 6);
INSERT INTO valoracions VALUES (3522, 6, '20/05/2001', 5);
INSERT INTO valoracions VALUES (3522, 64, '07/01/2009', 9);
INSERT INTO valoracions VALUES (3522, 65, '27/04/2005', 5);
INSERT INTO valoracions VALUES (3523, 80, '02/10/2003', 6);
INSERT INTO valoracions VALUES (3523, 86, '02/08/2007', 7);
INSERT INTO valoracions VALUES (3523, 57, '23/03/2006', 3);
INSERT INTO valoracions VALUES (3523, 78, '30/03/2010', 10);
INSERT INTO valoracions VALUES (3523, 90, '17/10/2001', 5);
INSERT INTO valoracions VALUES (3524, 70, '20/06/2010', 9);
INSERT INTO valoracions VALUES (3524, 102, '23/11/2007', 8);
INSERT INTO valoracions VALUES (3524, 53, '13/09/2007', 9);
INSERT INTO valoracions VALUES (3524, 115, '28/07/2008', 7);
INSERT INTO valoracions VALUES (3525, 6, '14/12/2003', 7);
INSERT INTO valoracions VALUES (3525, 75, '26/03/2006', 4);
INSERT INTO valoracions VALUES (3525, 55, '17/05/2005', 6);
INSERT INTO valoracions VALUES (3525, 32, '25/01/2009', 10);
INSERT INTO valoracions VALUES (3526, 26, '20/06/2003', 7);
INSERT INTO valoracions VALUES (3526, 101, '03/04/2003', 5);
INSERT INTO valoracions VALUES (3526, 44, '15/01/2004', 7);
INSERT INTO valoracions VALUES (3526, 18, '22/08/2005', 10);
INSERT INTO valoracions VALUES (3527, 111, '09/09/2002', 5);
INSERT INTO valoracions VALUES (3527, 37, '26/03/2002', 3);
INSERT INTO valoracions VALUES (3528, 75, '17/01/2004', 7);
INSERT INTO valoracions VALUES (3529, 58, '13/02/2009', 6);
INSERT INTO valoracions VALUES (3529, 31, '22/04/2002', 6);
INSERT INTO valoracions VALUES (3529, 66, '04/01/2009', 7);
INSERT INTO valoracions VALUES (3530, 40, '03/06/2010', 6);
INSERT INTO valoracions VALUES (3530, 96, '23/09/2008', 8);
INSERT INTO valoracions VALUES (3530, 72, '19/01/2007', 4);
INSERT INTO valoracions VALUES (3530, 15, '30/05/2010', 6);
INSERT INTO valoracions VALUES (3530, 83, '13/10/2008', 3);
INSERT INTO valoracions VALUES (3530, 54, '25/08/2009', 3);
INSERT INTO valoracions VALUES (3530, 77, '07/04/2010', 3);
INSERT INTO valoracions VALUES (3531, 55, '23/08/2008', 9);
INSERT INTO valoracions VALUES (3531, 112, '23/07/2008', 1);
INSERT INTO valoracions VALUES (3531, 64, '03/01/2010', 4);
INSERT INTO valoracions VALUES (3531, 15, '02/03/2007', 6);
INSERT INTO valoracions VALUES (3531, 4, '01/12/2008', 5);
INSERT INTO valoracions VALUES (3531, 72, '28/06/2006', 4);
INSERT INTO valoracions VALUES (3531, 62, '20/06/2001', 6);
INSERT INTO valoracions VALUES (3532, 71, '08/11/2008', 4);
INSERT INTO valoracions VALUES (3532, 97, '09/08/2004', 4);
INSERT INTO valoracions VALUES (3532, 61, '21/10/2003', 7);
INSERT INTO valoracions VALUES (3533, 88, '03/03/2005', 5);
INSERT INTO valoracions VALUES (3533, 92, '03/08/2005', 8);
INSERT INTO valoracions VALUES (3534, 89, '21/09/2001', 5);
INSERT INTO valoracions VALUES (3534, 101, '23/10/2009', 4);
INSERT INTO valoracions VALUES (3534, 75, '05/09/2007', 9);
INSERT INTO valoracions VALUES (3534, 65, '09/02/2003', 2);
INSERT INTO valoracions VALUES (3535, 29, '09/10/2007', 9);
INSERT INTO valoracions VALUES (3535, 43, '09/02/2008', 10);
INSERT INTO valoracions VALUES (3536, 105, '23/09/2004', 3);
INSERT INTO valoracions VALUES (3536, 113, '30/04/2003', 7);
INSERT INTO valoracions VALUES (3536, 53, '09/12/2009', 3);
INSERT INTO valoracions VALUES (3536, 3, '21/11/2008', 9);
INSERT INTO valoracions VALUES (3536, 17, '01/03/2002', 5);
INSERT INTO valoracions VALUES (3537, 57, '12/07/2008', 4);
INSERT INTO valoracions VALUES (3538, 39, '29/04/2010', 9);
INSERT INTO valoracions VALUES (3538, 26, '16/10/2009', 9);
INSERT INTO valoracions VALUES (3539, 50, '02/07/2005', 9);
INSERT INTO valoracions VALUES (3539, 51, '10/04/2003', 8);
INSERT INTO valoracions VALUES (3539, 59, '01/08/2006', 7);
INSERT INTO valoracions VALUES (3539, 82, '18/07/2009', 8);
INSERT INTO valoracions VALUES (3540, 98, '18/08/2007', 1);
INSERT INTO valoracions VALUES (3540, 46, '16/06/2009', 7);
INSERT INTO valoracions VALUES (3541, 88, '16/01/2002', 8);
INSERT INTO valoracions VALUES (3541, 92, '04/11/2007', 8);
INSERT INTO valoracions VALUES (3541, 39, '07/10/2008', 6);
INSERT INTO valoracions VALUES (3541, 30, '19/05/2004', 6);
INSERT INTO valoracions VALUES (3541, 23, '22/12/2005', 5);
INSERT INTO valoracions VALUES (3541, 41, '16/10/2001', 7);
INSERT INTO valoracions VALUES (3541, 96, '23/11/2009', 1);
INSERT INTO valoracions VALUES (3542, 65, '11/05/2009', 7);
INSERT INTO valoracions VALUES (3542, 50, '20/05/2007', 4);
INSERT INTO valoracions VALUES (3542, 47, '01/04/2002', 3);
INSERT INTO valoracions VALUES (3542, 43, '22/04/2004', 7);
INSERT INTO valoracions VALUES (3542, 30, '26/11/2003', 6);
INSERT INTO valoracions VALUES (3542, 46, '21/01/2002', 5);
INSERT INTO valoracions VALUES (3543, 3, '10/10/2010', 6);
INSERT INTO valoracions VALUES (3543, 41, '06/09/2005', 9);
INSERT INTO valoracions VALUES (3543, 48, '19/06/2008', 9);
INSERT INTO valoracions VALUES (3543, 14, '18/07/2002', 9);
INSERT INTO valoracions VALUES (3543, 60, '15/01/2009', 3);
INSERT INTO valoracions VALUES (3543, 78, '18/11/2002', 4);
INSERT INTO valoracions VALUES (3543, 104, '10/07/2007', 4);
INSERT INTO valoracions VALUES (3544, 72, '10/06/2009', 4);
INSERT INTO valoracions VALUES (3544, 22, '23/11/2007', 8);
INSERT INTO valoracions VALUES (3544, 97, '29/07/2008', 5);
INSERT INTO valoracions VALUES (3544, 58, '14/09/2010', 3);
INSERT INTO valoracions VALUES (3545, 25, '24/05/2008', 5);
INSERT INTO valoracions VALUES (3545, 62, '01/07/2010', 8);
INSERT INTO valoracions VALUES (3545, 18, '19/04/2005', 5);
INSERT INTO valoracions VALUES (3546, 96, '27/03/2004', 5);
INSERT INTO valoracions VALUES (3546, 6, '11/02/2003', 5);
INSERT INTO valoracions VALUES (3546, 32, '12/05/2006', 6);
INSERT INTO valoracions VALUES (3546, 72, '24/01/2009', 4);
INSERT INTO valoracions VALUES (3546, 17, '23/10/2006', 5);
INSERT INTO valoracions VALUES (3546, 113, '28/06/2002', 5);
INSERT INTO valoracions VALUES (3547, 96, '01/02/2003', 5);
INSERT INTO valoracions VALUES (3547, 63, '08/05/2001', 9);
INSERT INTO valoracions VALUES (3547, 24, '21/12/2008', 6);
INSERT INTO valoracions VALUES (3547, 54, '19/08/2001', 5);
INSERT INTO valoracions VALUES (3547, 66, '27/07/2006', 4);
INSERT INTO valoracions VALUES (3547, 97, '16/11/2003', 2);
INSERT INTO valoracions VALUES (3547, 100, '10/10/2008', 5);
INSERT INTO valoracions VALUES (3547, 38, '31/03/2001', 3);
INSERT INTO valoracions VALUES (3547, 45, '16/09/2010', 5);
INSERT INTO valoracions VALUES (3548, 101, '21/06/2001', 7);
INSERT INTO valoracions VALUES (3548, 97, '27/06/2001', 2);
INSERT INTO valoracions VALUES (3548, 43, '25/05/2005', 7);
INSERT INTO valoracions VALUES (3549, 65, '12/06/2010', 5);
INSERT INTO valoracions VALUES (3549, 35, '19/09/2010', 10);
INSERT INTO valoracions VALUES (3549, 68, '04/04/2007', 6);
INSERT INTO valoracions VALUES (3549, 9, '04/04/2003', 6);
INSERT INTO valoracions VALUES (3549, 69, '13/02/2003', 4);
INSERT INTO valoracions VALUES (3549, 96, '07/07/2002', 4);
INSERT INTO valoracions VALUES (3549, 112, '13/02/2004', 9);
INSERT INTO valoracions VALUES (3550, 95, '08/12/2005', 5);
INSERT INTO valoracions VALUES (3550, 6, '24/03/2004', 7);
INSERT INTO valoracions VALUES (3550, 111, '30/06/2005', 8);
INSERT INTO valoracions VALUES (3550, 53, '07/06/2010', 6);
INSERT INTO valoracions VALUES (3550, 22, '29/12/2005', 5);
INSERT INTO valoracions VALUES (3550, 41, '26/06/2009', 3);
INSERT INTO valoracions VALUES (3551, 58, '13/02/2005', 8);
INSERT INTO valoracions VALUES (3551, 48, '06/08/2005', 4);
INSERT INTO valoracions VALUES (3551, 87, '02/02/2002', 7);
INSERT INTO valoracions VALUES (3551, 70, '02/06/2004', 7);
INSERT INTO valoracions VALUES (3551, 5, '13/04/2005', 7);
INSERT INTO valoracions VALUES (3551, 114, '09/03/2004', 1);
INSERT INTO valoracions VALUES (3552, 105, '17/01/2007', 9);
INSERT INTO valoracions VALUES (3552, 115, '24/10/2004', 3);
INSERT INTO valoracions VALUES (3552, 97, '21/10/2006', 5);
INSERT INTO valoracions VALUES (3553, 36, '16/03/2005', 9);
INSERT INTO valoracions VALUES (3553, 45, '13/12/2004', 9);
INSERT INTO valoracions VALUES (3553, 58, '08/08/2001', 9);
INSERT INTO valoracions VALUES (3554, 100, '22/05/2009', 4);
INSERT INTO valoracions VALUES (3554, 37, '12/01/2005', 7);
INSERT INTO valoracions VALUES (3555, 21, '18/04/2010', 5);
INSERT INTO valoracions VALUES (3555, 34, '09/05/2006', 9);
INSERT INTO valoracions VALUES (3555, 75, '13/12/2003', 7);
INSERT INTO valoracions VALUES (3556, 13, '05/08/2007', 8);
INSERT INTO valoracions VALUES (3556, 23, '25/10/2006', 5);
INSERT INTO valoracions VALUES (3556, 42, '22/10/2005', 10);
INSERT INTO valoracions VALUES (3557, 12, '06/12/2004', 5);
INSERT INTO valoracions VALUES (3557, 53, '24/03/2006', 9);
INSERT INTO valoracions VALUES (3558, 78, '01/10/2003', 8);
INSERT INTO valoracions VALUES (3558, 104, '03/03/2002', 8);
INSERT INTO valoracions VALUES (3558, 35, '15/10/2010', 8);
INSERT INTO valoracions VALUES (3559, 26, '20/11/2003', 8);
INSERT INTO valoracions VALUES (3559, 54, '18/01/2008', 7);
INSERT INTO valoracions VALUES (3559, 113, '27/09/2005', 1);
INSERT INTO valoracions VALUES (3559, 57, '21/04/2001', 5);
INSERT INTO valoracions VALUES (3559, 33, '02/11/2003', 6);
INSERT INTO valoracions VALUES (3559, 101, '06/04/2002', 4);
INSERT INTO valoracions VALUES (3559, 15, '02/08/2010', 8);
INSERT INTO valoracions VALUES (3559, 70, '03/02/2006', 3);
INSERT INTO valoracions VALUES (3560, 46, '02/10/2009', 9);
INSERT INTO valoracions VALUES (3561, 65, '07/05/2003', 5);
INSERT INTO valoracions VALUES (3561, 23, '24/05/2007', 6);
INSERT INTO valoracions VALUES (3561, 74, '29/04/2002', 7);
INSERT INTO valoracions VALUES (3561, 4, '31/10/2001', 6);
INSERT INTO valoracions VALUES (3561, 20, '15/10/2006', 7);
INSERT INTO valoracions VALUES (3562, 114, '26/06/2010', 3);
INSERT INTO valoracions VALUES (3562, 44, '11/01/2005', 9);
INSERT INTO valoracions VALUES (3562, 106, '02/10/2005', 2);
INSERT INTO valoracions VALUES (3562, 99, '15/02/2004', 3);
INSERT INTO valoracions VALUES (3562, 98, '17/10/2002', 5);
INSERT INTO valoracions VALUES (3563, 108, '11/06/2004', 6);
INSERT INTO valoracions VALUES (3563, 39, '18/11/2003', 5);
INSERT INTO valoracions VALUES (3563, 8, '05/09/2010', 8);
INSERT INTO valoracions VALUES (3563, 107, '21/12/2006', 1);
INSERT INTO valoracions VALUES (3564, 60, '17/04/2004', 7);
INSERT INTO valoracions VALUES (3564, 29, '26/05/2010', 8);
INSERT INTO valoracions VALUES (3564, 102, '24/10/2001', 7);
INSERT INTO valoracions VALUES (3564, 104, '25/05/2007', 9);
INSERT INTO valoracions VALUES (3564, 112, '26/10/2004', 2);
INSERT INTO valoracions VALUES (3565, 31, '16/09/2004', 4);
INSERT INTO valoracions VALUES (3565, 47, '08/02/2006', 4);
INSERT INTO valoracions VALUES (3565, 71, '09/06/2004', 7);
INSERT INTO valoracions VALUES (3567, 62, '29/06/2004', 6);
INSERT INTO valoracions VALUES (3567, 89, '08/02/2007', 2);
INSERT INTO valoracions VALUES (3567, 69, '19/02/2007', 9);
INSERT INTO valoracions VALUES (3567, 23, '25/05/2002', 4);
INSERT INTO valoracions VALUES (3567, 88, '25/09/2004', 3);
INSERT INTO valoracions VALUES (3567, 32, '11/07/2007', 6);
INSERT INTO valoracions VALUES (3568, 106, '25/05/2005', 4);
INSERT INTO valoracions VALUES (3568, 71, '02/06/2009', 8);
INSERT INTO valoracions VALUES (3568, 27, '09/10/2004', 6);
INSERT INTO valoracions VALUES (3568, 64, '21/12/2008', 6);
INSERT INTO valoracions VALUES (3568, 82, '30/12/2003', 6);
INSERT INTO valoracions VALUES (3569, 114, '03/12/2007', 7);
INSERT INTO valoracions VALUES (3569, 115, '20/08/2006', 1);
INSERT INTO valoracions VALUES (3569, 54, '10/10/2001', 5);
INSERT INTO valoracions VALUES (3570, 87, '11/04/2003', 7);
INSERT INTO valoracions VALUES (3570, 11, '14/10/2008', 5);
INSERT INTO valoracions VALUES (3570, 45, '16/06/2010', 7);
INSERT INTO valoracions VALUES (3570, 100, '01/08/2010', 9);
INSERT INTO valoracions VALUES (3570, 39, '11/07/2005', 5);
INSERT INTO valoracions VALUES (3571, 32, '07/01/2006', 5);
INSERT INTO valoracions VALUES (3571, 81, '11/10/2005', 2);
INSERT INTO valoracions VALUES (3572, 69, '30/06/2005', 8);
INSERT INTO valoracions VALUES (3572, 71, '21/01/2007', 8);
INSERT INTO valoracions VALUES (3572, 69, '19/10/2006', 8);
INSERT INTO valoracions VALUES (3573, 69, '07/10/2009', 7);
INSERT INTO valoracions VALUES (3573, 41, '01/02/2005', 7);
INSERT INTO valoracions VALUES (3573, 93, '29/04/2002', 4);
INSERT INTO valoracions VALUES (3574, 5, '16/01/2006', 5);
INSERT INTO valoracions VALUES (3574, 70, '13/07/2005', 4);
INSERT INTO valoracions VALUES (3575, 90, '15/03/2009', 10);
INSERT INTO valoracions VALUES (3575, 37, '11/09/2009', 8);
INSERT INTO valoracions VALUES (3576, 7, '11/12/2003', 9);
INSERT INTO valoracions VALUES (3576, 57, '17/01/2005', 5);
INSERT INTO valoracions VALUES (3576, 91, '21/10/2009', 6);
INSERT INTO valoracions VALUES (3576, 66, '04/08/2001', 10);
INSERT INTO valoracions VALUES (3576, 97, '31/01/2007', 1);
INSERT INTO valoracions VALUES (3576, 55, '04/05/2001', 6);
INSERT INTO valoracions VALUES (3576, 33, '26/09/2007', 9);
INSERT INTO valoracions VALUES (3576, 116, '02/10/2002', 2);
INSERT INTO valoracions VALUES (3576, 44, '01/09/2005', 5);
INSERT INTO valoracions VALUES (3576, 78, '30/04/2004', 5);
INSERT INTO valoracions VALUES (3577, 12, '25/07/2006', 5);
INSERT INTO valoracions VALUES (3578, 102, '12/10/2003', 7);
INSERT INTO valoracions VALUES (3578, 102, '22/07/2004', 3);
INSERT INTO valoracions VALUES (3578, 8, '25/12/2008', 5);
INSERT INTO valoracions VALUES (3578, 99, '26/05/2005', 4);
INSERT INTO valoracions VALUES (3579, 114, '12/08/2005', 9);
INSERT INTO valoracions VALUES (3579, 55, '08/04/2008', 5);
INSERT INTO valoracions VALUES (3579, 50, '20/09/2006', 10);
INSERT INTO valoracions VALUES (3580, 24, '23/11/2006', 8);
INSERT INTO valoracions VALUES (3581, 89, '01/08/2009', 3);
INSERT INTO valoracions VALUES (3581, 96, '08/12/2005', 5);
INSERT INTO valoracions VALUES (3582, 55, '08/02/2006', 10);
INSERT INTO valoracions VALUES (3582, 68, '28/11/2005', 2);
INSERT INTO valoracions VALUES (3582, 93, '13/12/2008', 7);
INSERT INTO valoracions VALUES (3582, 50, '13/09/2009', 6);
INSERT INTO valoracions VALUES (3582, 101, '08/09/2003', 7);
INSERT INTO valoracions VALUES (3582, 2, '01/10/2010', 10);
INSERT INTO valoracions VALUES (3582, 63, '04/03/2004', 7);
INSERT INTO valoracions VALUES (3582, 79, '14/08/2008', 6);
INSERT INTO valoracions VALUES (3583, 60, '26/12/2001', 7);
INSERT INTO valoracions VALUES (3583, 88, '04/05/2005', 4);
INSERT INTO valoracions VALUES (3583, 78, '01/10/2008', 9);
INSERT INTO valoracions VALUES (3583, 111, '04/06/2010', 5);
INSERT INTO valoracions VALUES (3583, 88, '07/09/2002', 7);
INSERT INTO valoracions VALUES (3584, 104, '13/05/2010', 9);
INSERT INTO valoracions VALUES (3584, 99, '27/08/2001', 3);
INSERT INTO valoracions VALUES (3584, 30, '16/12/2009', 6);
INSERT INTO valoracions VALUES (3585, 46, '25/07/2004', 4);
INSERT INTO valoracions VALUES (3585, 76, '07/06/2006', 7);
INSERT INTO valoracions VALUES (3585, 51, '17/09/2008', 7);
INSERT INTO valoracions VALUES (3585, 85, '31/03/2001', 8);
INSERT INTO valoracions VALUES (3585, 66, '19/10/2002', 4);
INSERT INTO valoracions VALUES (3586, 103, '12/06/2007', 2);
INSERT INTO valoracions VALUES (3586, 45, '04/10/2005', 8);
INSERT INTO valoracions VALUES (3586, 12, '08/01/2005', 9);
INSERT INTO valoracions VALUES (3586, 91, '02/04/2003', 5);
INSERT INTO valoracions VALUES (3587, 91, '22/10/2003', 6);
INSERT INTO valoracions VALUES (3587, 41, '27/08/2005', 10);
INSERT INTO valoracions VALUES (3588, 87, '08/01/2003', 7);
INSERT INTO valoracions VALUES (3588, 15, '21/06/2009', 9);
INSERT INTO valoracions VALUES (3588, 52, '01/07/2003', 6);
INSERT INTO valoracions VALUES (3588, 21, '27/05/2005', 7);
INSERT INTO valoracions VALUES (3588, 59, '14/09/2006', 8);
INSERT INTO valoracions VALUES (3589, 60, '22/05/2001', 3);
INSERT INTO valoracions VALUES (3589, 58, '07/07/2004', 4);
INSERT INTO valoracions VALUES (3590, 75, '28/01/2006', 4);
INSERT INTO valoracions VALUES (3590, 36, '13/12/2003', 6);
INSERT INTO valoracions VALUES (3590, 82, '16/02/2008', 6);
INSERT INTO valoracions VALUES (3590, 67, '13/04/2006', 7);
INSERT INTO valoracions VALUES (3591, 32, '18/02/2008', 7);
INSERT INTO valoracions VALUES (3591, 48, '25/04/2009', 4);
INSERT INTO valoracions VALUES (3591, 110, '14/12/2006', 1);
INSERT INTO valoracions VALUES (3591, 26, '01/12/2007', 7);
INSERT INTO valoracions VALUES (3592, 63, '03/08/2009', 3);
INSERT INTO valoracions VALUES (3592, 101, '11/12/2003', 3);
INSERT INTO valoracions VALUES (3592, 93, '23/06/2001', 9);
INSERT INTO valoracions VALUES (3592, 98, '14/01/2007', 6);
INSERT INTO valoracions VALUES (3592, 15, '25/01/2006', 9);
INSERT INTO valoracions VALUES (3592, 50, '05/11/2005', 9);
INSERT INTO valoracions VALUES (3592, 30, '01/05/2003', 6);
INSERT INTO valoracions VALUES (3593, 99, '08/02/2009', 9);
INSERT INTO valoracions VALUES (3593, 32, '04/02/2007', 4);
INSERT INTO valoracions VALUES (3593, 74, '22/06/2001', 6);
INSERT INTO valoracions VALUES (3593, 3, '13/01/2005', 8);
INSERT INTO valoracions VALUES (3593, 62, '09/10/2008', 3);
INSERT INTO valoracions VALUES (3593, 59, '10/01/2005', 6);
INSERT INTO valoracions VALUES (3594, 109, '05/04/2002', 0);
INSERT INTO valoracions VALUES (3594, 55, '27/05/2007', 4);
INSERT INTO valoracions VALUES (3595, 8, '31/03/2006', 5);
INSERT INTO valoracions VALUES (3595, 97, '29/02/2004', 4);
INSERT INTO valoracions VALUES (3595, 46, '22/04/2005', 6);
INSERT INTO valoracions VALUES (3595, 116, '15/04/2007', 4);
INSERT INTO valoracions VALUES (3595, 6, '20/08/2006', 6);
INSERT INTO valoracions VALUES (3595, 106, '02/11/2003', 1);
INSERT INTO valoracions VALUES (3595, 101, '12/07/2005', 4);
INSERT INTO valoracions VALUES (3596, 88, '12/01/2005', 2);
INSERT INTO valoracions VALUES (3596, 46, '07/09/2001', 5);
INSERT INTO valoracions VALUES (3596, 100, '04/07/2008', 5);
INSERT INTO valoracions VALUES (3597, 97, '22/03/2005', 3);
INSERT INTO valoracions VALUES (3597, 114, '01/11/2001', 8);
INSERT INTO valoracions VALUES (3597, 52, '15/07/2009', 7);
INSERT INTO valoracions VALUES (3597, 3, '17/06/2001', 9);
INSERT INTO valoracions VALUES (3597, 25, '19/05/2006', 9);
INSERT INTO valoracions VALUES (3598, 100, '13/07/2005', 3);
INSERT INTO valoracions VALUES (3598, 82, '19/09/2005', 7);
INSERT INTO valoracions VALUES (3599, 64, '01/05/2002', 5);
INSERT INTO valoracions VALUES (3599, 11, '22/04/2008', 7);
INSERT INTO valoracions VALUES (3600, 16, '26/02/2010', 9);
INSERT INTO valoracions VALUES (3600, 50, '21/07/2003', 4);
INSERT INTO valoracions VALUES (3601, 75, '12/11/2001', 5);
INSERT INTO valoracions VALUES (3601, 9, '31/01/2005', 6);
INSERT INTO valoracions VALUES (3601, 68, '17/06/2003', 4);
INSERT INTO valoracions VALUES (3601, 18, '12/10/2007', 5);
INSERT INTO valoracions VALUES (3601, 18, '11/05/2003', 7);
INSERT INTO valoracions VALUES (3601, 109, '13/01/2010', 2);
INSERT INTO valoracions VALUES (3601, 1, '07/01/2003', 6);
INSERT INTO valoracions VALUES (3603, 86, '04/03/2008', 3);
INSERT INTO valoracions VALUES (3603, 14, '29/11/2004', 6);
INSERT INTO valoracions VALUES (3603, 40, '23/06/2010', 4);
INSERT INTO valoracions VALUES (3603, 115, '30/09/2008', 2);
INSERT INTO valoracions VALUES (3605, 59, '10/01/2003', 6);
INSERT INTO valoracions VALUES (3605, 42, '26/09/2004', 4);
INSERT INTO valoracions VALUES (3605, 59, '10/06/2007', 5);
INSERT INTO valoracions VALUES (3606, 65, '22/01/2002', 3);
INSERT INTO valoracions VALUES (3606, 115, '03/12/2008', 9);
INSERT INTO valoracions VALUES (3606, 66, '10/04/2002', 6);
INSERT INTO valoracions VALUES (3606, 29, '20/10/2010', 10);
INSERT INTO valoracions VALUES (3606, 36, '03/08/2008', 5);
INSERT INTO valoracions VALUES (3607, 65, '11/05/2008', 8);
INSERT INTO valoracions VALUES (3607, 105, '13/11/2005', 6);
INSERT INTO valoracions VALUES (3607, 26, '11/03/2002', 9);
INSERT INTO valoracions VALUES (3607, 113, '13/11/2005', 2);
INSERT INTO valoracions VALUES (3607, 64, '10/09/2004', 6);
INSERT INTO valoracions VALUES (3607, 91, '31/03/2008', 2);
INSERT INTO valoracions VALUES (3608, 68, '03/10/2006', 6);
INSERT INTO valoracions VALUES (3608, 93, '07/01/2010', 3);
INSERT INTO valoracions VALUES (3608, 98, '25/02/2004', 5);
INSERT INTO valoracions VALUES (3608, 114, '24/11/2007', 2);
INSERT INTO valoracions VALUES (3608, 22, '29/07/2009', 5);
INSERT INTO valoracions VALUES (3609, 102, '14/12/2007', 2);
INSERT INTO valoracions VALUES (3609, 14, '15/09/2009', 6);
INSERT INTO valoracions VALUES (3609, 36, '21/04/2003', 7);
INSERT INTO valoracions VALUES (3609, 20, '12/08/2005', 4);
INSERT INTO valoracions VALUES (3609, 104, '30/12/2009', 4);
INSERT INTO valoracions VALUES (3609, 106, '11/08/2002', 0);
INSERT INTO valoracions VALUES (3609, 39, '02/05/2008', 6);
INSERT INTO valoracions VALUES (3609, 103, '07/06/2004', 8);
INSERT INTO valoracions VALUES (3610, 74, '04/05/2009', 4);
INSERT INTO valoracions VALUES (3611, 12, '21/04/2010', 9);
INSERT INTO valoracions VALUES (3611, 107, '26/07/2010', 4);
INSERT INTO valoracions VALUES (3612, 43, '28/02/2005', 9);
INSERT INTO valoracions VALUES (3612, 14, '14/03/2003', 7);
INSERT INTO valoracions VALUES (3613, 108, '09/08/2003', 1);
INSERT INTO valoracions VALUES (3613, 16, '25/10/2007', 8);
INSERT INTO valoracions VALUES (3613, 75, '27/05/2002', 8);
INSERT INTO valoracions VALUES (3613, 4, '04/05/2010', 7);
INSERT INTO valoracions VALUES (3614, 84, '18/09/2003', 4);
INSERT INTO valoracions VALUES (3614, 105, '01/09/2009', 3);
INSERT INTO valoracions VALUES (3614, 97, '25/08/2003', 8);
INSERT INTO valoracions VALUES (3614, 84, '17/04/2002', 9);
INSERT INTO valoracions VALUES (3614, 100, '24/04/2002', 4);
INSERT INTO valoracions VALUES (3615, 39, '11/08/2007', 7);
INSERT INTO valoracions VALUES (3615, 56, '08/07/2002', 9);
INSERT INTO valoracions VALUES (3615, 66, '22/05/2007', 8);
INSERT INTO valoracions VALUES (3615, 39, '29/06/2009', 5);
INSERT INTO valoracions VALUES (3615, 107, '01/12/2001', 9);
INSERT INTO valoracions VALUES (3616, 32, '21/11/2003', 4);
INSERT INTO valoracions VALUES (3616, 11, '02/10/2006', 7);
INSERT INTO valoracions VALUES (3616, 9, '11/09/2004', 8);
INSERT INTO valoracions VALUES (3616, 46, '14/02/2005', 3);
INSERT INTO valoracions VALUES (3616, 114, '16/03/2006', 6);
INSERT INTO valoracions VALUES (3617, 26, '21/04/2006', 9);
INSERT INTO valoracions VALUES (3617, 100, '25/05/2006', 5);
INSERT INTO valoracions VALUES (3618, 22, '24/02/2005', 6);
INSERT INTO valoracions VALUES (3618, 99, '04/06/2002', 2);
INSERT INTO valoracions VALUES (3619, 71, '22/05/2001', 6);
INSERT INTO valoracions VALUES (3619, 63, '17/02/2008', 6);
INSERT INTO valoracions VALUES (3619, 63, '25/05/2002', 4);
INSERT INTO valoracions VALUES (3620, 35, '27/04/2003', 9);
INSERT INTO valoracions VALUES (3621, 110, '20/06/2007', 7);
INSERT INTO valoracions VALUES (3621, 76, '23/09/2002', 5);
INSERT INTO valoracions VALUES (3621, 97, '01/11/2003', 9);
INSERT INTO valoracions VALUES (3621, 60, '13/11/2005', 8);
INSERT INTO valoracions VALUES (3621, 113, '06/02/2002', 8);
INSERT INTO valoracions VALUES (3622, 50, '21/09/2002', 9);
INSERT INTO valoracions VALUES (3622, 15, '26/09/2003', 7);
INSERT INTO valoracions VALUES (3622, 28, '07/12/2005', 9);
INSERT INTO valoracions VALUES (3622, 6, '09/09/2002', 5);
INSERT INTO valoracions VALUES (3622, 107, '10/06/2002', 2);
INSERT INTO valoracions VALUES (3623, 104, '19/05/2009', 10);
INSERT INTO valoracions VALUES (3623, 63, '29/06/2007', 6);
INSERT INTO valoracions VALUES (3624, 19, '01/05/2006', 7);
INSERT INTO valoracions VALUES (3624, 68, '23/03/2004', 8);
INSERT INTO valoracions VALUES (3624, 72, '18/09/2003', 6);
INSERT INTO valoracions VALUES (3624, 3, '15/09/2004', 5);
INSERT INTO valoracions VALUES (3625, 2, '12/01/2002', 8);
INSERT INTO valoracions VALUES (3625, 86, '06/04/2006', 7);
INSERT INTO valoracions VALUES (3625, 111, '23/08/2002', 8);
INSERT INTO valoracions VALUES (3625, 49, '28/09/2005', 6);
INSERT INTO valoracions VALUES (3625, 12, '11/10/2003', 5);
INSERT INTO valoracions VALUES (3626, 116, '01/05/2008', 0);
INSERT INTO valoracions VALUES (3626, 99, '18/11/2001', 4);
INSERT INTO valoracions VALUES (3626, 48, '21/07/2010', 4);
INSERT INTO valoracions VALUES (3626, 90, '23/12/2004', 1);
INSERT INTO valoracions VALUES (3626, 7, '18/10/2001', 7);
INSERT INTO valoracions VALUES (3627, 100, '10/01/2004', 8);
INSERT INTO valoracions VALUES (3627, 10, '09/09/2004', 7);
INSERT INTO valoracions VALUES (3627, 103, '25/12/2003', 8);
INSERT INTO valoracions VALUES (3627, 85, '15/10/2004', 4);
INSERT INTO valoracions VALUES (3628, 75, '21/04/2010', 5);
INSERT INTO valoracions VALUES (3628, 114, '21/09/2003', 4);
INSERT INTO valoracions VALUES (3628, 61, '06/02/2003', 9);
INSERT INTO valoracions VALUES (3628, 25, '10/10/2005', 9);
INSERT INTO valoracions VALUES (3628, 2, '22/08/2008', 10);
INSERT INTO valoracions VALUES (3629, 70, '01/03/2005', 3);
INSERT INTO valoracions VALUES (3629, 76, '08/06/2007', 3);
INSERT INTO valoracions VALUES (3630, 102, '06/10/2004', 9);
INSERT INTO valoracions VALUES (3630, 49, '24/08/2004', 8);
INSERT INTO valoracions VALUES (3630, 48, '02/04/2001', 10);
INSERT INTO valoracions VALUES (3630, 66, '05/01/2007', 5);
INSERT INTO valoracions VALUES (3631, 105, '29/05/2005', 3);
INSERT INTO valoracions VALUES (3631, 62, '13/07/2003', 9);
INSERT INTO valoracions VALUES (3631, 37, '13/07/2010', 7);
INSERT INTO valoracions VALUES (3632, 92, '29/05/2010', 6);
INSERT INTO valoracions VALUES (3632, 76, '11/09/2002', 3);
INSERT INTO valoracions VALUES (3632, 90, '02/04/2010', 6);
INSERT INTO valoracions VALUES (3632, 102, '05/08/2010', 8);
INSERT INTO valoracions VALUES (3633, 96, '05/12/2002', 8);
INSERT INTO valoracions VALUES (3633, 90, '05/10/2007', 3);
INSERT INTO valoracions VALUES (3633, 27, '02/07/2009', 5);
INSERT INTO valoracions VALUES (3633, 83, '01/06/2009', 3);
INSERT INTO valoracions VALUES (3633, 3, '16/07/2001', 7);
INSERT INTO valoracions VALUES (3634, 36, '02/01/2006', 5);
INSERT INTO valoracions VALUES (3634, 42, '15/09/2007', 9);
INSERT INTO valoracions VALUES (3635, 116, '01/12/2002', 10);
INSERT INTO valoracions VALUES (3635, 102, '05/07/2006', 1);
INSERT INTO valoracions VALUES (3635, 98, '29/03/2002', 4);
INSERT INTO valoracions VALUES (3636, 66, '08/05/2008', 5);
INSERT INTO valoracions VALUES (3636, 9, '23/05/2006', 9);
INSERT INTO valoracions VALUES (3636, 69, '23/11/2007', 8);
INSERT INTO valoracions VALUES (3636, 50, '02/06/2002', 7);
INSERT INTO valoracions VALUES (3636, 97, '08/10/2005', 9);
INSERT INTO valoracions VALUES (3636, 61, '24/09/2003', 5);
INSERT INTO valoracions VALUES (3637, 105, '27/09/2002', 8);
INSERT INTO valoracions VALUES (3637, 77, '15/09/2001', 4);
INSERT INTO valoracions VALUES (3637, 73, '13/09/2005', 4);
INSERT INTO valoracions VALUES (3637, 38, '25/12/2006', 9);
INSERT INTO valoracions VALUES (3638, 2, '26/05/2005', 8);
INSERT INTO valoracions VALUES (3638, 24, '28/07/2005', 7);
INSERT INTO valoracions VALUES (3639, 28, '21/07/2004', 5);
INSERT INTO valoracions VALUES (3640, 73, '04/03/2003', 8);
INSERT INTO valoracions VALUES (3640, 9, '08/06/2006', 7);
INSERT INTO valoracions VALUES (3641, 105, '30/04/2009', 1);
INSERT INTO valoracions VALUES (3641, 3, '21/12/2002', 9);
INSERT INTO valoracions VALUES (3641, 24, '24/05/2008', 10);
INSERT INTO valoracions VALUES (3641, 34, '29/02/2008', 7);
INSERT INTO valoracions VALUES (3642, 50, '12/04/2004', 4);
INSERT INTO valoracions VALUES (3642, 25, '22/02/2006', 6);
INSERT INTO valoracions VALUES (3643, 9, '18/03/2002', 7);
INSERT INTO valoracions VALUES (3643, 78, '08/01/2009', 7);
INSERT INTO valoracions VALUES (3643, 23, '17/10/2001', 7);
INSERT INTO valoracions VALUES (3643, 87, '22/02/2002', 2);
INSERT INTO valoracions VALUES (3643, 75, '27/03/2004', 4);
INSERT INTO valoracions VALUES (3644, 14, '27/03/2008', 8);
INSERT INTO valoracions VALUES (3644, 37, '24/05/2002', 9);
INSERT INTO valoracions VALUES (3644, 89, '11/06/2007', 3);
INSERT INTO valoracions VALUES (3644, 36, '18/04/2010', 9);
INSERT INTO valoracions VALUES (3644, 70, '05/11/2002', 4);
INSERT INTO valoracions VALUES (3644, 91, '09/04/2010', 6);
INSERT INTO valoracions VALUES (3645, 47, '13/03/2002', 7);
INSERT INTO valoracions VALUES (3645, 61, '05/03/2003', 8);
INSERT INTO valoracions VALUES (3645, 101, '01/01/2007', 8);
INSERT INTO valoracions VALUES (3645, 101, '19/11/2001', 3);
INSERT INTO valoracions VALUES (3645, 11, '15/12/2002', 8);
INSERT INTO valoracions VALUES (3645, 88, '31/03/2006', 5);
INSERT INTO valoracions VALUES (3646, 25, '23/07/2002', 9);
INSERT INTO valoracions VALUES (3646, 71, '10/09/2003', 10);
INSERT INTO valoracions VALUES (3646, 30, '16/09/2004', 8);
INSERT INTO valoracions VALUES (3646, 52, '22/05/2006', 8);
INSERT INTO valoracions VALUES (3646, 94, '02/02/2009', 6);
INSERT INTO valoracions VALUES (3646, 115, '14/05/2002', 4);
INSERT INTO valoracions VALUES (3646, 108, '31/10/2007', 6);
INSERT INTO valoracions VALUES (3647, 90, '27/11/2002', 10);
INSERT INTO valoracions VALUES (3647, 70, '25/10/2005', 9);
INSERT INTO valoracions VALUES (3647, 46, '11/07/2004', 7);
INSERT INTO valoracions VALUES (3647, 91, '18/11/2001', 5);
INSERT INTO valoracions VALUES (3648, 78, '03/04/2009', 6);
INSERT INTO valoracions VALUES (3648, 31, '22/10/2002', 5);
INSERT INTO valoracions VALUES (3648, 95, '13/09/2007', 8);
INSERT INTO valoracions VALUES (3649, 6, '19/04/2001', 6);
INSERT INTO valoracions VALUES (3649, 17, '10/11/2009', 7);
INSERT INTO valoracions VALUES (3649, 85, '03/04/2004', 4);
INSERT INTO valoracions VALUES (3649, 90, '12/11/2008', 4);
INSERT INTO valoracions VALUES (3650, 89, '22/11/2004', 3);
INSERT INTO valoracions VALUES (3651, 56, '20/09/2003', 7);
INSERT INTO valoracions VALUES (3651, 11, '20/01/2007', 6);
INSERT INTO valoracions VALUES (3651, 70, '26/12/2006', 7);
INSERT INTO valoracions VALUES (3652, 24, '14/07/2007', 6);
INSERT INTO valoracions VALUES (3652, 109, '09/09/2006', 9);
INSERT INTO valoracions VALUES (3652, 11, '19/12/2005', 6);
INSERT INTO valoracions VALUES (3652, 109, '17/02/2002', 4);
INSERT INTO valoracions VALUES (3652, 61, '21/05/2004', 4);
INSERT INTO valoracions VALUES (3652, 68, '15/06/2009', 4);
INSERT INTO valoracions VALUES (3653, 55, '21/10/2007', 4);
INSERT INTO valoracions VALUES (3653, 55, '10/07/2006', 10);
INSERT INTO valoracions VALUES (3653, 93, '01/04/2004', 6);
INSERT INTO valoracions VALUES (3653, 59, '28/12/2004', 6);
INSERT INTO valoracions VALUES (3653, 80, '07/01/2009', 10);
INSERT INTO valoracions VALUES (3653, 81, '25/08/2002', 7);
INSERT INTO valoracions VALUES (3653, 87, '30/06/2007', 6);
INSERT INTO valoracions VALUES (3653, 7, '17/01/2008', 6);
INSERT INTO valoracions VALUES (3654, 42, '08/03/2002', 7);
INSERT INTO valoracions VALUES (3654, 74, '16/08/2001', 7);
INSERT INTO valoracions VALUES (3654, 46, '18/01/2010', 9);
INSERT INTO valoracions VALUES (3654, 44, '04/03/2009', 10);
INSERT INTO valoracions VALUES (3655, 7, '08/10/2003', 10);
INSERT INTO valoracions VALUES (3655, 32, '25/06/2008', 7);
INSERT INTO valoracions VALUES (3655, 34, '24/11/2002', 4);
INSERT INTO valoracions VALUES (3655, 32, '15/01/2004', 7);
INSERT INTO valoracions VALUES (3655, 104, '17/10/2003', 9);
INSERT INTO valoracions VALUES (3655, 83, '02/12/2008', 7);
INSERT INTO valoracions VALUES (3655, 69, '23/09/2006', 8);
INSERT INTO valoracions VALUES (3656, 42, '02/08/2001', 7);
INSERT INTO valoracions VALUES (3656, 108, '25/10/2006', 7);
INSERT INTO valoracions VALUES (3656, 71, '28/10/2004', 4);
INSERT INTO valoracions VALUES (3656, 100, '24/09/2003', 10);
INSERT INTO valoracions VALUES (3656, 103, '19/01/2008', 3);
INSERT INTO valoracions VALUES (3657, 2, '11/10/2005', 9);
INSERT INTO valoracions VALUES (3658, 83, '07/02/2005', 4);
INSERT INTO valoracions VALUES (3658, 12, '21/04/2002', 8);
INSERT INTO valoracions VALUES (3658, 50, '20/08/2006', 4);
INSERT INTO valoracions VALUES (3658, 27, '30/07/2003', 8);
INSERT INTO valoracions VALUES (3658, 111, '24/06/2006', 3);
INSERT INTO valoracions VALUES (3658, 46, '18/09/2003', 6);
INSERT INTO valoracions VALUES (3659, 106, '27/09/2009', 5);
INSERT INTO valoracions VALUES (3659, 106, '12/01/2004', 4);
INSERT INTO valoracions VALUES (3659, 112, '18/11/2004', 1);
INSERT INTO valoracions VALUES (3659, 112, '26/02/2005', 4);
INSERT INTO valoracions VALUES (3659, 34, '07/12/2007', 7);
INSERT INTO valoracions VALUES (3659, 49, '27/06/2008', 5);
INSERT INTO valoracions VALUES (3660, 80, '18/06/2009', 2);
INSERT INTO valoracions VALUES (3660, 71, '28/04/2004', 7);
INSERT INTO valoracions VALUES (3660, 96, '03/09/2009', 5);
INSERT INTO valoracions VALUES (3660, 106, '23/03/2009', 5);
INSERT INTO valoracions VALUES (3661, 65, '09/11/2007', 5);
INSERT INTO valoracions VALUES (3661, 59, '11/08/2003', 8);
INSERT INTO valoracions VALUES (3661, 73, '17/09/2009', 8);
INSERT INTO valoracions VALUES (3661, 103, '08/10/2001', 1);
INSERT INTO valoracions VALUES (3661, 61, '10/10/2002', 3);
INSERT INTO valoracions VALUES (3662, 91, '21/04/2006', 7);
INSERT INTO valoracions VALUES (3663, 96, '09/09/2005', 3);
INSERT INTO valoracions VALUES (3663, 67, '13/11/2004', 8);
INSERT INTO valoracions VALUES (3663, 101, '04/09/2010', 7);
INSERT INTO valoracions VALUES (3664, 37, '11/02/2007', 7);
INSERT INTO valoracions VALUES (3664, 52, '09/12/2003', 4);
INSERT INTO valoracions VALUES (3664, 13, '08/12/2007', 6);
INSERT INTO valoracions VALUES (3665, 69, '12/01/2002', 8);
INSERT INTO valoracions VALUES (3666, 95, '22/09/2008', 9);
INSERT INTO valoracions VALUES (3666, 8, '08/03/2002', 9);
INSERT INTO valoracions VALUES (3666, 87, '27/08/2007', 2);
INSERT INTO valoracions VALUES (3666, 19, '22/05/2005', 8);
INSERT INTO valoracions VALUES (3667, 108, '13/04/2002', 2);
INSERT INTO valoracions VALUES (3667, 87, '23/12/2007', 5);
INSERT INTO valoracions VALUES (3667, 94, '23/09/2003', 5);
INSERT INTO valoracions VALUES (3667, 27, '13/02/2010', 9);
INSERT INTO valoracions VALUES (3668, 78, '21/12/2002', 10);
INSERT INTO valoracions VALUES (3668, 34, '27/07/2008', 9);
INSERT INTO valoracions VALUES (3668, 58, '27/08/2003', 9);
INSERT INTO valoracions VALUES (3668, 47, '01/01/2003', 8);
INSERT INTO valoracions VALUES (3669, 21, '14/09/2005', 5);
INSERT INTO valoracions VALUES (3669, 38, '05/10/2003', 10);
INSERT INTO valoracions VALUES (3669, 102, '12/03/2005', 2);
INSERT INTO valoracions VALUES (3669, 74, '12/08/2004', 5);
INSERT INTO valoracions VALUES (3669, 83, '31/10/2004', 10);
INSERT INTO valoracions VALUES (3670, 54, '18/06/2007', 3);
INSERT INTO valoracions VALUES (3670, 106, '07/01/2007', 6);
INSERT INTO valoracions VALUES (3670, 15, '25/09/2009', 10);
INSERT INTO valoracions VALUES (3670, 59, '16/11/2003', 6);
INSERT INTO valoracions VALUES (3670, 29, '02/01/2007', 5);
INSERT INTO valoracions VALUES (3671, 45, '29/03/2006', 5);
INSERT INTO valoracions VALUES (3671, 100, '20/12/2009', 4);
INSERT INTO valoracions VALUES (3671, 114, '17/03/2006', 3);
INSERT INTO valoracions VALUES (3671, 76, '03/04/2008', 10);
INSERT INTO valoracions VALUES (3672, 114, '14/11/2005', 8);
INSERT INTO valoracions VALUES (3672, 68, '13/02/2008', 9);
INSERT INTO valoracions VALUES (3672, 102, '26/12/2009', 2);
INSERT INTO valoracions VALUES (3672, 101, '28/11/2006', 2);
INSERT INTO valoracions VALUES (3672, 46, '20/02/2009', 7);
INSERT INTO valoracions VALUES (3672, 55, '09/06/2002', 9);
INSERT INTO valoracions VALUES (3672, 47, '17/07/2006', 6);
INSERT INTO valoracions VALUES (3672, 113, '30/04/2002', 4);
INSERT INTO valoracions VALUES (3672, 70, '31/05/2003', 4);
INSERT INTO valoracions VALUES (3672, 3, '01/01/2006', 5);
INSERT INTO valoracions VALUES (3673, 101, '10/09/2007', 10);
INSERT INTO valoracions VALUES (3673, 11, '12/03/2005', 5);
INSERT INTO valoracions VALUES (3673, 10, '22/06/2008', 6);
INSERT INTO valoracions VALUES (3673, 40, '18/01/2002', 8);
INSERT INTO valoracions VALUES (3673, 83, '02/03/2009', 2);
INSERT INTO valoracions VALUES (3673, 28, '06/09/2002', 6);
INSERT INTO valoracions VALUES (3673, 94, '17/03/2004', 1);
INSERT INTO valoracions VALUES (3674, 91, '16/07/2006', 3);
INSERT INTO valoracions VALUES (3674, 54, '06/09/2004', 9);
INSERT INTO valoracions VALUES (3675, 87, '28/04/2008', 9);
INSERT INTO valoracions VALUES (3675, 70, '16/04/2005', 4);
INSERT INTO valoracions VALUES (3676, 13, '17/05/2010', 9);
INSERT INTO valoracions VALUES (3676, 33, '12/05/2005', 7);
INSERT INTO valoracions VALUES (3676, 58, '24/12/2007', 9);
INSERT INTO valoracions VALUES (3676, 69, '19/07/2010', 8);
INSERT INTO valoracions VALUES (3676, 84, '27/10/2004', 3);
INSERT INTO valoracions VALUES (3677, 53, '08/11/2008', 4);
INSERT INTO valoracions VALUES (3677, 54, '01/07/2004', 8);
INSERT INTO valoracions VALUES (3677, 77, '10/03/2007', 8);
INSERT INTO valoracions VALUES (3677, 15, '22/11/2002', 6);
INSERT INTO valoracions VALUES (3677, 67, '14/05/2006', 9);
INSERT INTO valoracions VALUES (3677, 5, '14/10/2001', 5);
INSERT INTO valoracions VALUES (3677, 80, '15/07/2002', 7);
INSERT INTO valoracions VALUES (3677, 17, '15/11/2001', 9);
INSERT INTO valoracions VALUES (3678, 105, '21/02/2002', 10);
INSERT INTO valoracions VALUES (3678, 28, '19/12/2001', 4);
INSERT INTO valoracions VALUES (3678, 111, '18/04/2009', 7);
INSERT INTO valoracions VALUES (3679, 42, '24/07/2006', 6);
INSERT INTO valoracions VALUES (3679, 114, '10/09/2003', 7);
INSERT INTO valoracions VALUES (3679, 55, '18/03/2003', 3);
INSERT INTO valoracions VALUES (3679, 4, '13/03/2004', 5);
INSERT INTO valoracions VALUES (3680, 35, '22/11/2007', 8);
INSERT INTO valoracions VALUES (3680, 93, '09/04/2006', 5);
INSERT INTO valoracions VALUES (3681, 89, '19/05/2002', 7);
INSERT INTO valoracions VALUES (3681, 4, '11/02/2006', 9);
INSERT INTO valoracions VALUES (3681, 79, '19/11/2002', 3);
INSERT INTO valoracions VALUES (3681, 16, '18/02/2010', 9);
INSERT INTO valoracions VALUES (3681, 113, '16/09/2010', 8);
INSERT INTO valoracions VALUES (3681, 111, '05/05/2009', 6);
INSERT INTO valoracions VALUES (3681, 23, '09/06/2001', 6);
INSERT INTO valoracions VALUES (3682, 113, '04/04/2010', 6);
INSERT INTO valoracions VALUES (3682, 51, '20/02/2003', 6);
INSERT INTO valoracions VALUES (3682, 58, '29/03/2010', 4);
INSERT INTO valoracions VALUES (3682, 98, '29/12/2002', 2);
INSERT INTO valoracions VALUES (3683, 39, '24/03/2004', 9);
INSERT INTO valoracions VALUES (3683, 32, '27/11/2004', 4);
INSERT INTO valoracions VALUES (3683, 43, '16/12/2008', 9);
INSERT INTO valoracions VALUES (3683, 96, '20/04/2001', 6);
INSERT INTO valoracions VALUES (3684, 42, '20/09/2003', 4);
INSERT INTO valoracions VALUES (3684, 5, '09/04/2007', 8);
INSERT INTO valoracions VALUES (3685, 100, '26/09/2002', 7);
INSERT INTO valoracions VALUES (3685, 30, '08/06/2009', 4);
INSERT INTO valoracions VALUES (3685, 13, '17/08/2008', 9);
INSERT INTO valoracions VALUES (3685, 108, '29/10/2004', 3);
INSERT INTO valoracions VALUES (3685, 49, '24/02/2007', 6);
INSERT INTO valoracions VALUES (3686, 13, '18/12/2007', 8);
INSERT INTO valoracions VALUES (3686, 89, '24/03/2009', 9);
INSERT INTO valoracions VALUES (3686, 58, '27/07/2009', 3);
INSERT INTO valoracions VALUES (3686, 42, '04/12/2008', 7);
INSERT INTO valoracions VALUES (3687, 90, '01/05/2009', 6);
INSERT INTO valoracions VALUES (3687, 116, '27/07/2009', 8);
INSERT INTO valoracions VALUES (3687, 32, '29/09/2004', 7);
INSERT INTO valoracions VALUES (3687, 1, '15/06/2008', 8);
INSERT INTO valoracions VALUES (3687, 87, '16/12/2001', 2);
INSERT INTO valoracions VALUES (3688, 60, '25/04/2005', 7);
INSERT INTO valoracions VALUES (3689, 60, '16/08/2005', 7);
INSERT INTO valoracions VALUES (3689, 86, '15/11/2002', 5);
INSERT INTO valoracions VALUES (3689, 99, '22/01/2005', 9);
INSERT INTO valoracions VALUES (3689, 102, '19/05/2006', 10);
INSERT INTO valoracions VALUES (3690, 97, '02/03/2003', 6);
INSERT INTO valoracions VALUES (3690, 115, '03/07/2005', 9);
INSERT INTO valoracions VALUES (3690, 112, '09/06/2001', 2);
INSERT INTO valoracions VALUES (3690, 66, '23/01/2003', 8);
INSERT INTO valoracions VALUES (3690, 36, '30/09/2008', 7);
INSERT INTO valoracions VALUES (3690, 114, '02/12/2001', 4);
INSERT INTO valoracions VALUES (3690, 112, '31/10/2009', 5);
INSERT INTO valoracions VALUES (3691, 17, '29/05/2002', 9);
INSERT INTO valoracions VALUES (3691, 96, '13/12/2005', 8);
INSERT INTO valoracions VALUES (3691, 24, '02/05/2008', 5);
INSERT INTO valoracions VALUES (3691, 21, '22/03/2002', 5);
INSERT INTO valoracions VALUES (3692, 68, '12/06/2010', 7);
INSERT INTO valoracions VALUES (3692, 58, '03/06/2004', 9);
INSERT INTO valoracions VALUES (3692, 92, '14/07/2006', 9);
INSERT INTO valoracions VALUES (3692, 70, '06/10/2010', 9);
INSERT INTO valoracions VALUES (3692, 36, '28/05/2002', 7);
INSERT INTO valoracions VALUES (3693, 115, '16/01/2009', 9);
INSERT INTO valoracions VALUES (3693, 5, '07/02/2007', 10);
INSERT INTO valoracions VALUES (3693, 106, '21/02/2005', 8);
INSERT INTO valoracions VALUES (3693, 63, '20/03/2009', 8);
INSERT INTO valoracions VALUES (3693, 50, '22/01/2009', 5);
INSERT INTO valoracions VALUES (3693, 64, '26/09/2001', 8);
INSERT INTO valoracions VALUES (3694, 49, '08/12/2003', 6);
INSERT INTO valoracions VALUES (3694, 112, '07/02/2003', 0);
INSERT INTO valoracions VALUES (3695, 116, '24/01/2007', 9);
INSERT INTO valoracions VALUES (3695, 48, '28/07/2005', 4);
INSERT INTO valoracions VALUES (3695, 96, '17/05/2003', 8);
INSERT INTO valoracions VALUES (3695, 77, '02/04/2004', 8);
INSERT INTO valoracions VALUES (3696, 50, '17/05/2002', 7);
INSERT INTO valoracions VALUES (3696, 5, '12/05/2006', 5);
INSERT INTO valoracions VALUES (3696, 23, '30/11/2003', 6);
INSERT INTO valoracions VALUES (3696, 23, '12/10/2005', 9);
INSERT INTO valoracions VALUES (3696, 78, '27/01/2004', 8);
INSERT INTO valoracions VALUES (3696, 10, '17/03/2007', 8);
INSERT INTO valoracions VALUES (3696, 77, '22/05/2005', 8);
INSERT INTO valoracions VALUES (3696, 16, '24/10/2008', 7);
INSERT INTO valoracions VALUES (3697, 13, '26/07/2005', 9);
INSERT INTO valoracions VALUES (3697, 74, '11/02/2003', 5);
INSERT INTO valoracions VALUES (3697, 91, '08/03/2009', 4);
INSERT INTO valoracions VALUES (3697, 63, '18/11/2008', 9);
INSERT INTO valoracions VALUES (3697, 13, '07/10/2007', 7);
INSERT INTO valoracions VALUES (3698, 16, '26/07/2005', 6);
INSERT INTO valoracions VALUES (3698, 95, '27/07/2006', 2);
INSERT INTO valoracions VALUES (3698, 26, '18/12/2005', 4);
INSERT INTO valoracions VALUES (3698, 106, '14/01/2002', 4);
INSERT INTO valoracions VALUES (3699, 61, '30/09/2002', 5);
INSERT INTO valoracions VALUES (3699, 76, '10/09/2010', 7);
INSERT INTO valoracions VALUES (3699, 4, '17/11/2009', 6);
INSERT INTO valoracions VALUES (3700, 7, '12/07/2006', 7);
INSERT INTO valoracions VALUES (3700, 108, '11/10/2010', 4);
INSERT INTO valoracions VALUES (3700, 85, '20/05/2005', 9);
INSERT INTO valoracions VALUES (3701, 73, '21/06/2010', 10);
INSERT INTO valoracions VALUES (3701, 32, '24/02/2008', 9);
INSERT INTO valoracions VALUES (3701, 55, '16/08/2010', 8);
INSERT INTO valoracions VALUES (3701, 85, '04/11/2005', 9);
INSERT INTO valoracions VALUES (3701, 82, '19/09/2006', 5);
INSERT INTO valoracions VALUES (3702, 96, '23/07/2005', 3);
INSERT INTO valoracions VALUES (3702, 72, '22/08/2007', 4);
INSERT INTO valoracions VALUES (3702, 29, '01/06/2001', 8);
INSERT INTO valoracions VALUES (3703, 31, '21/10/2008', 10);
INSERT INTO valoracions VALUES (3703, 9, '08/12/2008', 6);
INSERT INTO valoracions VALUES (3703, 77, '27/12/2001', 3);
INSERT INTO valoracions VALUES (3703, 110, '25/07/2004', 6);
INSERT INTO valoracions VALUES (3704, 63, '31/05/2005', 5);
INSERT INTO valoracions VALUES (3704, 14, '22/02/2004', 7);
INSERT INTO valoracions VALUES (3704, 52, '15/11/2002', 8);
INSERT INTO valoracions VALUES (3704, 66, '10/04/2006', 3);
INSERT INTO valoracions VALUES (3704, 11, '07/08/2008', 6);
INSERT INTO valoracions VALUES (3704, 99, '09/04/2001', 7);
INSERT INTO valoracions VALUES (3704, 16, '27/05/2010', 5);
INSERT INTO valoracions VALUES (3704, 84, '09/07/2010', 7);
INSERT INTO valoracions VALUES (3705, 115, '02/09/2004', 2);
INSERT INTO valoracions VALUES (3705, 12, '08/09/2005', 6);
INSERT INTO valoracions VALUES (3705, 78, '14/04/2002', 4);
INSERT INTO valoracions VALUES (3705, 58, '20/08/2001', 7);
INSERT INTO valoracions VALUES (3706, 47, '11/11/2002', 9);
INSERT INTO valoracions VALUES (3706, 61, '18/05/2008', 8);
INSERT INTO valoracions VALUES (3706, 16, '22/03/2006', 9);
INSERT INTO valoracions VALUES (3706, 110, '26/07/2009', 2);
INSERT INTO valoracions VALUES (3706, 17, '31/12/2003', 7);
INSERT INTO valoracions VALUES (3707, 56, '08/11/2004', 3);
INSERT INTO valoracions VALUES (3707, 81, '08/07/2003', 7);
INSERT INTO valoracions VALUES (3707, 88, '05/11/2008', 8);
INSERT INTO valoracions VALUES (3707, 25, '17/04/2006', 5);
INSERT INTO valoracions VALUES (3708, 2, '25/12/2001', 8);
INSERT INTO valoracions VALUES (3708, 73, '22/05/2008', 4);
INSERT INTO valoracions VALUES (3708, 34, '25/07/2007', 4);
INSERT INTO valoracions VALUES (3708, 31, '07/09/2009', 4);
INSERT INTO valoracions VALUES (3708, 26, '24/06/2003', 4);
INSERT INTO valoracions VALUES (3708, 85, '19/03/2008', 7);
INSERT INTO valoracions VALUES (3709, 24, '02/03/2005', 9);
INSERT INTO valoracions VALUES (3709, 63, '11/03/2009', 9);
INSERT INTO valoracions VALUES (3709, 17, '04/06/2006', 8);
INSERT INTO valoracions VALUES (3709, 17, '04/06/2002', 5);
INSERT INTO valoracions VALUES (3709, 71, '29/09/2008', 4);
INSERT INTO valoracions VALUES (3710, 93, '13/05/2005', 6);
INSERT INTO valoracions VALUES (3710, 2, '29/05/2001', 10);
INSERT INTO valoracions VALUES (3710, 25, '30/07/2004', 5);
INSERT INTO valoracions VALUES (3711, 108, '26/04/2006', 3);
INSERT INTO valoracions VALUES (3711, 8, '10/10/2010', 8);
INSERT INTO valoracions VALUES (3711, 49, '26/12/2002', 6);
INSERT INTO valoracions VALUES (3711, 19, '06/07/2009', 5);
INSERT INTO valoracions VALUES (3711, 77, '13/08/2001', 8);
INSERT INTO valoracions VALUES (3712, 115, '11/01/2004', 3);
INSERT INTO valoracions VALUES (3712, 38, '18/03/2009', 9);
INSERT INTO valoracions VALUES (3712, 116, '25/07/2006', 6);
INSERT INTO valoracions VALUES (3712, 39, '29/09/2009', 4);
INSERT INTO valoracions VALUES (3712, 61, '20/04/2003', 9);
INSERT INTO valoracions VALUES (3713, 4, '13/06/2003', 9);
INSERT INTO valoracions VALUES (3713, 33, '05/05/2005', 9);
INSERT INTO valoracions VALUES (3713, 81, '27/12/2004', 8);
INSERT INTO valoracions VALUES (3713, 95, '25/04/2001', 3);
INSERT INTO valoracions VALUES (3713, 44, '03/09/2008', 5);
INSERT INTO valoracions VALUES (3713, 89, '07/08/2006', 8);
INSERT INTO valoracions VALUES (3714, 115, '19/06/2007', 9);
INSERT INTO valoracions VALUES (3714, 21, '08/01/2010', 10);
INSERT INTO valoracions VALUES (3714, 84, '19/12/2009', 2);
INSERT INTO valoracions VALUES (3715, 35, '02/11/2009', 9);
INSERT INTO valoracions VALUES (3715, 87, '14/08/2008', 7);
INSERT INTO valoracions VALUES (3715, 111, '07/11/2002', 1);
INSERT INTO valoracions VALUES (3715, 61, '19/06/2003', 5);
INSERT INTO valoracions VALUES (3716, 12, '13/04/2002', 8);
INSERT INTO valoracions VALUES (3716, 84, '26/04/2002', 4);
INSERT INTO valoracions VALUES (3716, 106, '24/07/2002', 6);
INSERT INTO valoracions VALUES (3717, 31, '10/07/2001', 6);
INSERT INTO valoracions VALUES (3717, 88, '08/03/2003', 3);
INSERT INTO valoracions VALUES (3717, 39, '15/02/2006', 4);
INSERT INTO valoracions VALUES (3717, 96, '15/06/2006', 6);
INSERT INTO valoracions VALUES (3718, 15, '11/04/2006', 4);
INSERT INTO valoracions VALUES (3718, 30, '12/08/2007', 9);
INSERT INTO valoracions VALUES (3718, 34, '21/10/2007', 5);
INSERT INTO valoracions VALUES (3719, 75, '02/01/2007', 9);
INSERT INTO valoracions VALUES (3719, 107, '16/03/2010', 3);
INSERT INTO valoracions VALUES (3719, 74, '20/10/2001', 8);
INSERT INTO valoracions VALUES (3721, 64, '06/01/2003', 7);
INSERT INTO valoracions VALUES (3721, 71, '02/06/2009', 9);
INSERT INTO valoracions VALUES (3722, 67, '13/05/2006', 5);
INSERT INTO valoracions VALUES (3722, 102, '03/09/2001', 1);
INSERT INTO valoracions VALUES (3722, 11, '27/12/2009', 9);
INSERT INTO valoracions VALUES (3723, 63, '08/07/2005', 8);
INSERT INTO valoracions VALUES (3723, 5, '24/01/2006', 6);
INSERT INTO valoracions VALUES (3723, 1, '11/10/2005', 5);
INSERT INTO valoracions VALUES (3723, 66, '16/09/2002', 9);
INSERT INTO valoracions VALUES (3723, 94, '17/11/2009', 7);
INSERT INTO valoracions VALUES (3723, 68, '14/02/2008', 8);
INSERT INTO valoracions VALUES (3724, 68, '10/07/2010', 8);
INSERT INTO valoracions VALUES (3724, 97, '02/08/2001', 8);
INSERT INTO valoracions VALUES (3724, 89, '24/04/2003', 4);
INSERT INTO valoracions VALUES (3725, 33, '06/03/2003', 4);
INSERT INTO valoracions VALUES (3725, 86, '16/09/2009', 4);
INSERT INTO valoracions VALUES (3726, 43, '19/11/2007', 8);
INSERT INTO valoracions VALUES (3726, 33, '03/07/2006', 9);
INSERT INTO valoracions VALUES (3726, 87, '17/08/2001', 9);
INSERT INTO valoracions VALUES (3726, 39, '31/03/2009', 7);
INSERT INTO valoracions VALUES (3726, 12, '14/07/2008', 8);
INSERT INTO valoracions VALUES (3727, 99, '31/08/2010', 5);
INSERT INTO valoracions VALUES (3727, 97, '20/02/2005', 7);
INSERT INTO valoracions VALUES (3727, 40, '05/07/2006', 10);
INSERT INTO valoracions VALUES (3727, 85, '16/12/2009', 8);
INSERT INTO valoracions VALUES (3728, 60, '28/09/2002', 5);
INSERT INTO valoracions VALUES (3728, 102, '19/08/2007', 2);
INSERT INTO valoracions VALUES (3728, 66, '04/09/2005', 2);
INSERT INTO valoracions VALUES (3729, 71, '10/03/2003', 5);
INSERT INTO valoracions VALUES (3729, 29, '08/08/2005', 9);
INSERT INTO valoracions VALUES (3729, 47, '09/10/2006', 7);
INSERT INTO valoracions VALUES (3729, 68, '06/06/2004', 3);
INSERT INTO valoracions VALUES (3729, 91, '17/04/2008', 3);
INSERT INTO valoracions VALUES (3729, 34, '23/12/2004', 7);
INSERT INTO valoracions VALUES (3729, 27, '01/11/2003', 7);
INSERT INTO valoracions VALUES (3729, 105, '01/10/2003', 7);
INSERT INTO valoracions VALUES (3730, 29, '15/08/2006', 4);
INSERT INTO valoracions VALUES (3730, 45, '08/10/2009', 6);
INSERT INTO valoracions VALUES (3730, 111, '08/10/2003', 10);
INSERT INTO valoracions VALUES (3730, 74, '23/05/2008', 9);
INSERT INTO valoracions VALUES (3731, 71, '09/01/2006', 3);
INSERT INTO valoracions VALUES (3731, 89, '08/11/2006', 4);
INSERT INTO valoracions VALUES (3731, 9, '18/09/2003', 10);
INSERT INTO valoracions VALUES (3731, 44, '17/04/2002', 5);
INSERT INTO valoracions VALUES (3731, 107, '23/11/2007', 3);
INSERT INTO valoracions VALUES (3731, 1, '28/09/2008', 9);
INSERT INTO valoracions VALUES (3731, 28, '04/11/2003', 6);
INSERT INTO valoracions VALUES (3732, 6, '17/08/2003', 6);
INSERT INTO valoracions VALUES (3732, 37, '09/08/2005', 7);
INSERT INTO valoracions VALUES (3732, 62, '30/07/2006', 9);
INSERT INTO valoracions VALUES (3732, 32, '05/07/2005', 9);
INSERT INTO valoracions VALUES (3733, 26, '22/07/2005', 6);
INSERT INTO valoracions VALUES (3733, 15, '24/05/2005', 5);
INSERT INTO valoracions VALUES (3733, 40, '19/10/2003', 7);
INSERT INTO valoracions VALUES (3734, 39, '21/04/2010', 9);
INSERT INTO valoracions VALUES (3734, 96, '29/08/2009', 5);
INSERT INTO valoracions VALUES (3734, 70, '23/01/2009', 9);
INSERT INTO valoracions VALUES (3734, 73, '03/10/2003', 8);
INSERT INTO valoracions VALUES (3734, 29, '18/05/2001', 9);
INSERT INTO valoracions VALUES (3734, 39, '15/03/2007', 7);
INSERT INTO valoracions VALUES (3734, 35, '29/08/2007', 4);
INSERT INTO valoracions VALUES (3735, 9, '11/07/2009', 8);
INSERT INTO valoracions VALUES (3735, 25, '14/12/2003', 9);
INSERT INTO valoracions VALUES (3735, 66, '20/12/2002', 7);
INSERT INTO valoracions VALUES (3735, 21, '01/10/2003', 10);
INSERT INTO valoracions VALUES (3735, 63, '03/10/2002', 8);
INSERT INTO valoracions VALUES (3735, 34, '03/04/2008', 7);
INSERT INTO valoracions VALUES (3736, 56, '19/01/2007', 3);
INSERT INTO valoracions VALUES (3736, 26, '11/08/2008', 8);
INSERT INTO valoracions VALUES (3736, 83, '16/08/2006', 4);
INSERT INTO valoracions VALUES (3736, 67, '09/09/2007', 5);
INSERT INTO valoracions VALUES (3737, 85, '16/09/2007', 1);
INSERT INTO valoracions VALUES (3737, 21, '08/12/2007', 6);
INSERT INTO valoracions VALUES (3738, 67, '13/11/2006', 9);
INSERT INTO valoracions VALUES (3738, 36, '16/05/2009', 8);
INSERT INTO valoracions VALUES (3738, 25, '01/01/2005', 8);
INSERT INTO valoracions VALUES (3739, 50, '02/03/2004', 4);
INSERT INTO valoracions VALUES (3739, 64, '02/06/2008', 4);
INSERT INTO valoracions VALUES (3739, 19, '16/01/2008', 4);
INSERT INTO valoracions VALUES (3739, 58, '05/08/2003', 3);
INSERT INTO valoracions VALUES (3739, 42, '11/05/2006', 6);
INSERT INTO valoracions VALUES (3739, 72, '18/09/2005', 7);
INSERT INTO valoracions VALUES (3740, 31, '07/10/2003', 4);
INSERT INTO valoracions VALUES (3740, 84, '22/06/2002', 6);
INSERT INTO valoracions VALUES (3740, 56, '22/09/2004', 3);
INSERT INTO valoracions VALUES (3741, 5, '23/09/2008', 5);
INSERT INTO valoracions VALUES (3741, 97, '09/02/2002', 8);
INSERT INTO valoracions VALUES (3742, 4, '14/08/2003', 6);
INSERT INTO valoracions VALUES (3742, 112, '25/12/2002', 7);
INSERT INTO valoracions VALUES (3742, 17, '10/10/2009', 5);
INSERT INTO valoracions VALUES (3743, 87, '20/10/2007', 5);
INSERT INTO valoracions VALUES (3743, 95, '12/06/2009', 7);
INSERT INTO valoracions VALUES (3743, 10, '23/06/2002', 10);
INSERT INTO valoracions VALUES (3743, 46, '08/02/2008', 9);
INSERT INTO valoracions VALUES (3743, 51, '23/09/2003', 9);
INSERT INTO valoracions VALUES (3743, 73, '01/11/2009', 8);
INSERT INTO valoracions VALUES (3743, 102, '30/11/2009', 3);
INSERT INTO valoracions VALUES (3744, 104, '07/04/2006', 8);
INSERT INTO valoracions VALUES (3744, 8, '08/09/2004', 6);
INSERT INTO valoracions VALUES (3744, 29, '21/11/2009', 8);
INSERT INTO valoracions VALUES (3744, 33, '22/04/2007', 6);
INSERT INTO valoracions VALUES (3744, 46, '19/02/2010', 4);
INSERT INTO valoracions VALUES (3744, 62, '31/05/2005', 2);
INSERT INTO valoracions VALUES (3744, 36, '15/11/2004', 6);
INSERT INTO valoracions VALUES (3745, 17, '21/03/2009', 9);
INSERT INTO valoracions VALUES (3745, 43, '24/01/2007', 8);
INSERT INTO valoracions VALUES (3746, 31, '23/06/2006', 8);
INSERT INTO valoracions VALUES (3746, 31, '04/04/2008', 5);
INSERT INTO valoracions VALUES (3746, 2, '26/02/2005', 7);
INSERT INTO valoracions VALUES (3746, 66, '27/01/2006', 7);
INSERT INTO valoracions VALUES (3746, 60, '13/12/2003', 7);
INSERT INTO valoracions VALUES (3747, 57, '09/06/2007', 5);
INSERT INTO valoracions VALUES (3747, 96, '13/11/2008', 1);
INSERT INTO valoracions VALUES (3747, 22, '28/10/2010', 10);
INSERT INTO valoracions VALUES (3747, 23, '08/05/2001', 9);
INSERT INTO valoracions VALUES (3748, 109, '07/03/2003', 0);
INSERT INTO valoracions VALUES (3748, 59, '05/01/2004', 7);
INSERT INTO valoracions VALUES (3749, 72, '29/06/2009', 7);
INSERT INTO valoracions VALUES (3749, 49, '15/07/2004', 5);
INSERT INTO valoracions VALUES (3749, 77, '05/02/2003', 8);
INSERT INTO valoracions VALUES (3750, 20, '19/03/2002', 9);
INSERT INTO valoracions VALUES (3750, 71, '08/05/2004', 10);
INSERT INTO valoracions VALUES (3750, 36, '04/05/2006', 9);
INSERT INTO valoracions VALUES (3750, 76, '19/09/2001', 6);
INSERT INTO valoracions VALUES (3750, 85, '03/12/2006', 6);
INSERT INTO valoracions VALUES (3751, 59, '14/07/2005', 7);
INSERT INTO valoracions VALUES (3751, 47, '07/05/2006', 5);
INSERT INTO valoracions VALUES (3751, 7, '27/03/2002', 6);
INSERT INTO valoracions VALUES (3752, 68, '28/08/2003', 2);
INSERT INTO valoracions VALUES (3752, 57, '29/10/2010', 3);
INSERT INTO valoracions VALUES (3752, 24, '26/05/2004', 9);
INSERT INTO valoracions VALUES (3752, 27, '10/08/2007', 10);
INSERT INTO valoracions VALUES (3752, 100, '07/05/2010', 2);
INSERT INTO valoracions VALUES (3752, 6, '20/04/2008', 7);
INSERT INTO valoracions VALUES (3752, 48, '08/02/2002', 6);
INSERT INTO valoracions VALUES (3753, 40, '29/01/2002', 9);
INSERT INTO valoracions VALUES (3753, 12, '21/10/2007', 10);
INSERT INTO valoracions VALUES (3753, 16, '23/11/2002', 7);
INSERT INTO valoracions VALUES (3753, 18, '03/09/2009', 8);
INSERT INTO valoracions VALUES (3754, 44, '10/02/2008', 7);
INSERT INTO valoracions VALUES (3754, 29, '02/02/2006', 5);
INSERT INTO valoracions VALUES (3754, 60, '21/09/2002', 9);
INSERT INTO valoracions VALUES (3754, 114, '03/07/2008', 5);
INSERT INTO valoracions VALUES (3754, 116, '04/03/2008', 6);
INSERT INTO valoracions VALUES (3754, 97, '28/03/2005', 2);
INSERT INTO valoracions VALUES (3755, 51, '17/02/2003', 4);
INSERT INTO valoracions VALUES (3756, 47, '30/05/2008', 4);
INSERT INTO valoracions VALUES (3756, 101, '08/01/2010', 4);
INSERT INTO valoracions VALUES (3756, 4, '28/09/2008', 6);
INSERT INTO valoracions VALUES (3757, 3, '27/09/2007', 5);
INSERT INTO valoracions VALUES (3757, 98, '28/06/2005', 4);
INSERT INTO valoracions VALUES (3758, 79, '04/07/2006', 7);
INSERT INTO valoracions VALUES (3758, 115, '03/10/2001', 9);
INSERT INTO valoracions VALUES (3758, 96, '29/07/2009', 8);
INSERT INTO valoracions VALUES (3758, 31, '25/02/2009', 4);
INSERT INTO valoracions VALUES (3758, 78, '24/11/2003', 8);
INSERT INTO valoracions VALUES (3759, 47, '11/04/2001', 8);
INSERT INTO valoracions VALUES (3759, 69, '09/05/2008', 2);
INSERT INTO valoracions VALUES (3760, 116, '18/07/2006', 0);
INSERT INTO valoracions VALUES (3760, 113, '07/01/2009', 2);
INSERT INTO valoracions VALUES (3761, 9, '30/04/2007', 7);
INSERT INTO valoracions VALUES (3762, 34, '21/09/2010', 4);
INSERT INTO valoracions VALUES (3762, 33, '11/01/2008', 6);
INSERT INTO valoracions VALUES (3762, 3, '21/02/2002', 7);
INSERT INTO valoracions VALUES (3762, 61, '20/01/2009', 5);
INSERT INTO valoracions VALUES (3762, 26, '05/11/2009', 5);
INSERT INTO valoracions VALUES (3762, 82, '28/10/2007', 8);
INSERT INTO valoracions VALUES (3763, 97, '28/05/2008', 3);
INSERT INTO valoracions VALUES (3764, 53, '24/09/2005', 5);
INSERT INTO valoracions VALUES (3764, 101, '09/08/2009', 4);
INSERT INTO valoracions VALUES (3764, 8, '10/12/2004', 8);
INSERT INTO valoracions VALUES (3764, 114, '14/02/2008', 5);
INSERT INTO valoracions VALUES (3764, 73, '03/03/2010', 10);
INSERT INTO valoracions VALUES (3765, 66, '03/07/2007', 2);
INSERT INTO valoracions VALUES (3765, 23, '02/05/2006', 9);
INSERT INTO valoracions VALUES (3765, 47, '17/09/2010', 9);
INSERT INTO valoracions VALUES (3765, 81, '18/05/2009', 9);
INSERT INTO valoracions VALUES (3766, 116, '23/02/2005', 3);
INSERT INTO valoracions VALUES (3766, 114, '13/10/2004', 3);
INSERT INTO valoracions VALUES (3766, 38, '06/11/2002', 5);
INSERT INTO valoracions VALUES (3766, 68, '04/12/2002', 9);
INSERT INTO valoracions VALUES (3766, 38, '07/02/2002', 5);
INSERT INTO valoracions VALUES (3767, 91, '02/06/2003', 1);
INSERT INTO valoracions VALUES (3767, 20, '17/07/2004', 7);
INSERT INTO valoracions VALUES (3767, 73, '07/11/2002', 4);
INSERT INTO valoracions VALUES (3767, 102, '06/09/2004', 3);
INSERT INTO valoracions VALUES (3767, 112, '26/07/2003', 3);
INSERT INTO valoracions VALUES (3768, 68, '10/02/2004', 8);
INSERT INTO valoracions VALUES (3768, 78, '31/10/2005', 7);
INSERT INTO valoracions VALUES (3768, 17, '20/08/2008', 6);
INSERT INTO valoracions VALUES (3769, 11, '26/03/2002', 6);
INSERT INTO valoracions VALUES (3769, 109, '16/11/2009', 5);
INSERT INTO valoracions VALUES (3770, 52, '19/01/2010', 6);
INSERT INTO valoracions VALUES (3770, 92, '03/12/2006', 6);
INSERT INTO valoracions VALUES (3771, 37, '18/12/2001', 9);
INSERT INTO valoracions VALUES (3771, 40, '06/02/2002', 9);
INSERT INTO valoracions VALUES (3771, 3, '08/04/2008', 8);
INSERT INTO valoracions VALUES (3771, 8, '08/03/2010', 9);
INSERT INTO valoracions VALUES (3771, 107, '08/07/2009', 1);
INSERT INTO valoracions VALUES (3772, 24, '17/12/2009', 7);
INSERT INTO valoracions VALUES (3773, 73, '05/07/2001', 5);
INSERT INTO valoracions VALUES (3773, 105, '03/01/2004', 6);
INSERT INTO valoracions VALUES (3773, 15, '11/05/2001', 9);
INSERT INTO valoracions VALUES (3773, 45, '19/10/2006', 4);
INSERT INTO valoracions VALUES (3773, 8, '05/01/2003', 5);
INSERT INTO valoracions VALUES (3774, 33, '26/11/2009', 10);
INSERT INTO valoracions VALUES (3774, 49, '04/01/2008', 7);
INSERT INTO valoracions VALUES (3774, 70, '13/12/2003', 3);
INSERT INTO valoracions VALUES (3774, 82, '12/02/2005', 4);
INSERT INTO valoracions VALUES (3775, 81, '03/08/2004', 3);
INSERT INTO valoracions VALUES (3775, 86, '13/05/2010', 3);
INSERT INTO valoracions VALUES (3775, 47, '06/02/2002', 10);
INSERT INTO valoracions VALUES (3775, 8, '20/05/2010', 9);
INSERT INTO valoracions VALUES (3776, 75, '11/12/2004', 10);
INSERT INTO valoracions VALUES (3776, 52, '05/03/2007', 7);
INSERT INTO valoracions VALUES (3776, 71, '12/05/2006', 10);
INSERT INTO valoracions VALUES (3777, 65, '11/10/2003', 3);
INSERT INTO valoracions VALUES (3778, 95, '14/08/2007', 9);
INSERT INTO valoracions VALUES (3778, 90, '17/11/2004', 6);
INSERT INTO valoracions VALUES (3778, 92, '07/05/2007', 3);
INSERT INTO valoracions VALUES (3779, 95, '21/11/2001', 5);
INSERT INTO valoracions VALUES (3779, 109, '30/10/2010', 2);
INSERT INTO valoracions VALUES (3779, 110, '20/10/2001', 10);
INSERT INTO valoracions VALUES (3779, 95, '24/11/2002', 2);
INSERT INTO valoracions VALUES (3779, 88, '03/08/2010', 9);
INSERT INTO valoracions VALUES (3780, 65, '09/07/2002', 3);
INSERT INTO valoracions VALUES (3780, 72, '09/05/2003', 8);
INSERT INTO valoracions VALUES (3780, 51, '11/04/2005', 6);
INSERT INTO valoracions VALUES (3781, 116, '18/12/2007', 10);
INSERT INTO valoracions VALUES (3781, 94, '16/09/2003', 7);
INSERT INTO valoracions VALUES (3782, 101, '24/02/2007', 1);
INSERT INTO valoracions VALUES (3782, 96, '15/09/2007', 9);
INSERT INTO valoracions VALUES (3783, 41, '24/05/2010', 6);
INSERT INTO valoracions VALUES (3783, 98, '15/04/2005', 8);
INSERT INTO valoracions VALUES (3783, 54, '12/01/2003', 3);
INSERT INTO valoracions VALUES (3784, 79, '04/07/2008', 4);
INSERT INTO valoracions VALUES (3784, 24, '23/11/2001', 5);
INSERT INTO valoracions VALUES (3784, 23, '19/10/2010', 5);
INSERT INTO valoracions VALUES (3784, 21, '21/05/2004', 9);
INSERT INTO valoracions VALUES (3784, 77, '06/05/2002', 4);
INSERT INTO valoracions VALUES (3784, 49, '08/06/2002', 7);
INSERT INTO valoracions VALUES (3784, 30, '21/10/2007', 7);
INSERT INTO valoracions VALUES (3785, 72, '14/04/2006', 2);
INSERT INTO valoracions VALUES (3785, 12, '13/10/2003', 7);
INSERT INTO valoracions VALUES (3785, 54, '09/01/2009', 4);
INSERT INTO valoracions VALUES (3785, 33, '17/04/2001', 8);
INSERT INTO valoracions VALUES (3785, 87, '25/09/2003', 2);
INSERT INTO valoracions VALUES (3785, 55, '07/07/2003', 9);
INSERT INTO valoracions VALUES (3786, 21, '08/11/2005', 10);
INSERT INTO valoracions VALUES (3786, 20, '10/04/2006', 5);
INSERT INTO valoracions VALUES (3786, 31, '30/07/2007', 9);
INSERT INTO valoracions VALUES (3786, 73, '06/04/2007', 5);
INSERT INTO valoracions VALUES (3787, 98, '15/01/2003', 7);
INSERT INTO valoracions VALUES (3787, 30, '04/08/2003', 5);
INSERT INTO valoracions VALUES (3788, 60, '08/08/2008', 7);
INSERT INTO valoracions VALUES (3788, 109, '13/06/2010', 1);
INSERT INTO valoracions VALUES (3789, 36, '18/11/2009', 7);
INSERT INTO valoracions VALUES (3789, 12, '31/07/2003', 9);
INSERT INTO valoracions VALUES (3790, 32, '05/01/2008', 6);
INSERT INTO valoracions VALUES (3790, 84, '10/01/2006', 2);
INSERT INTO valoracions VALUES (3790, 56, '07/10/2004', 8);
INSERT INTO valoracions VALUES (3791, 7, '28/10/2003', 5);
INSERT INTO valoracions VALUES (3792, 30, '11/06/2009', 8);
INSERT INTO valoracions VALUES (3792, 85, '26/04/2010', 6);
INSERT INTO valoracions VALUES (3792, 2, '01/03/2003', 9);
INSERT INTO valoracions VALUES (3792, 113, '26/04/2001', 4);
INSERT INTO valoracions VALUES (3792, 64, '16/12/2007', 8);
INSERT INTO valoracions VALUES (3793, 45, '06/10/2006', 7);
INSERT INTO valoracions VALUES (3793, 98, '17/04/2006', 8);
INSERT INTO valoracions VALUES (3793, 67, '18/10/2010', 8);
INSERT INTO valoracions VALUES (3794, 102, '07/04/2005', 3);
INSERT INTO valoracions VALUES (3794, 70, '19/06/2004', 4);
INSERT INTO valoracions VALUES (3794, 33, '04/06/2006', 10);
INSERT INTO valoracions VALUES (3794, 103, '27/05/2010', 4);
INSERT INTO valoracions VALUES (3794, 113, '19/09/2007', 5);
INSERT INTO valoracions VALUES (3795, 76, '06/09/2001', 8);
INSERT INTO valoracions VALUES (3795, 68, '05/10/2004', 4);
INSERT INTO valoracions VALUES (3795, 48, '29/01/2004', 7);
INSERT INTO valoracions VALUES (3795, 23, '22/08/2010', 6);
INSERT INTO valoracions VALUES (3795, 59, '30/07/2008', 9);
INSERT INTO valoracions VALUES (3796, 10, '09/05/2009', 10);
INSERT INTO valoracions VALUES (3796, 31, '22/07/2002', 9);
INSERT INTO valoracions VALUES (3796, 56, '30/04/2004', 6);
INSERT INTO valoracions VALUES (3796, 90, '22/05/2003', 6);
INSERT INTO valoracions VALUES (3796, 10, '01/03/2008', 6);
INSERT INTO valoracions VALUES (3797, 28, '08/07/2005', 7);
INSERT INTO valoracions VALUES (3797, 104, '04/10/2010', 8);
INSERT INTO valoracions VALUES (3797, 90, '11/10/2004', 8);
INSERT INTO valoracions VALUES (3797, 111, '01/02/2010', 6);
INSERT INTO valoracions VALUES (3798, 24, '17/08/2002', 8);
INSERT INTO valoracions VALUES (3798, 72, '02/01/2003', 5);
INSERT INTO valoracions VALUES (3798, 26, '20/01/2005', 8);
INSERT INTO valoracions VALUES (3798, 16, '27/03/2006', 9);
INSERT INTO valoracions VALUES (3798, 64, '09/03/2003', 4);
INSERT INTO valoracions VALUES (3798, 54, '08/01/2003', 8);
INSERT INTO valoracions VALUES (3799, 26, '19/07/2006', 10);
INSERT INTO valoracions VALUES (3799, 116, '05/03/2006', 3);
INSERT INTO valoracions VALUES (3799, 12, '13/09/2005', 6);
INSERT INTO valoracions VALUES (3799, 101, '22/01/2004', 7);
INSERT INTO valoracions VALUES (3800, 55, '30/08/2003', 5);
INSERT INTO valoracions VALUES (3800, 10, '31/12/2004', 8);
INSERT INTO valoracions VALUES (3800, 15, '26/07/2001', 4);
INSERT INTO valoracions VALUES (3800, 65, '28/12/2008', 5);
INSERT INTO valoracions VALUES (3800, 109, '06/02/2008', 9);
INSERT INTO valoracions VALUES (3801, 82, '23/09/2005', 7);
INSERT INTO valoracions VALUES (3801, 34, '03/02/2006', 7);
INSERT INTO valoracions VALUES (3801, 49, '18/08/2001', 10);
INSERT INTO valoracions VALUES (3801, 111, '24/05/2003', 7);
INSERT INTO valoracions VALUES (3802, 22, '13/05/2005', 8);
INSERT INTO valoracions VALUES (3802, 116, '05/12/2007', 5);
INSERT INTO valoracions VALUES (3803, 80, '08/03/2006', 9);
INSERT INTO valoracions VALUES (3803, 76, '15/09/2003', 8);
INSERT INTO valoracions VALUES (3803, 115, '13/04/2009', 4);
INSERT INTO valoracions VALUES (3803, 15, '26/04/2010', 7);
INSERT INTO valoracions VALUES (3804, 69, '29/06/2009', 7);
INSERT INTO valoracions VALUES (3804, 70, '26/03/2007', 5);
INSERT INTO valoracions VALUES (3804, 108, '16/03/2007', 9);
INSERT INTO valoracions VALUES (3804, 93, '07/10/2004', 4);
INSERT INTO valoracions VALUES (3805, 57, '04/08/2007', 9);
INSERT INTO valoracions VALUES (3805, 1, '19/10/2001', 6);
INSERT INTO valoracions VALUES (3806, 74, '06/08/2010', 8);
INSERT INTO valoracions VALUES (3806, 61, '14/04/2002', 7);
INSERT INTO valoracions VALUES (3806, 60, '22/05/2001', 4);
INSERT INTO valoracions VALUES (3806, 45, '22/01/2008', 9);
INSERT INTO valoracions VALUES (3806, 76, '07/09/2007', 9);
INSERT INTO valoracions VALUES (3806, 101, '14/10/2008', 10);
INSERT INTO valoracions VALUES (3807, 18, '29/04/2007', 5);
INSERT INTO valoracions VALUES (3807, 13, '04/02/2002', 8);
INSERT INTO valoracions VALUES (3807, 34, '07/06/2003', 7);
INSERT INTO valoracions VALUES (3807, 32, '19/01/2002', 4);
INSERT INTO valoracions VALUES (3807, 91, '10/07/2001', 3);
INSERT INTO valoracions VALUES (3808, 63, '28/10/2006', 5);
INSERT INTO valoracions VALUES (3808, 105, '16/03/2002', 4);
INSERT INTO valoracions VALUES (3809, 72, '08/09/2002', 4);
INSERT INTO valoracions VALUES (3809, 93, '22/10/2010', 3);
INSERT INTO valoracions VALUES (3809, 94, '10/04/2002', 3);
INSERT INTO valoracions VALUES (3810, 96, '06/04/2005', 8);
INSERT INTO valoracions VALUES (3810, 7, '22/08/2009', 5);
INSERT INTO valoracions VALUES (3810, 50, '15/09/2008', 5);
INSERT INTO valoracions VALUES (3810, 13, '08/01/2008', 6);
INSERT INTO valoracions VALUES (3810, 51, '17/08/2010', 4);
INSERT INTO valoracions VALUES (3810, 42, '17/11/2001', 9);
INSERT INTO valoracions VALUES (3810, 23, '04/01/2007', 7);
INSERT INTO valoracions VALUES (3811, 23, '06/10/2006', 7);
INSERT INTO valoracions VALUES (3811, 89, '20/01/2002', 7);
INSERT INTO valoracions VALUES (3811, 71, '04/11/2003', 9);
INSERT INTO valoracions VALUES (3811, 81, '26/06/2005', 3);
INSERT INTO valoracions VALUES (3812, 114, '01/06/2004', 5);
INSERT INTO valoracions VALUES (3812, 52, '08/04/2003', 4);
INSERT INTO valoracions VALUES (3812, 83, '23/07/2002', 5);
INSERT INTO valoracions VALUES (3813, 108, '18/12/2007', 4);
INSERT INTO valoracions VALUES (3813, 107, '24/03/2002', 2);
INSERT INTO valoracions VALUES (3813, 67, '24/10/2005', 2);
INSERT INTO valoracions VALUES (3813, 15, '14/09/2009', 6);
INSERT INTO valoracions VALUES (3813, 7, '16/11/2005', 5);
INSERT INTO valoracions VALUES (3813, 58, '25/11/2007', 5);
INSERT INTO valoracions VALUES (3814, 27, '30/05/2005', 5);
INSERT INTO valoracions VALUES (3814, 103, '12/04/2006', 3);
INSERT INTO valoracions VALUES (3814, 115, '13/05/2009', 4);
INSERT INTO valoracions VALUES (3814, 61, '04/05/2008', 5);
INSERT INTO valoracions VALUES (3815, 49, '11/05/2009', 5);
INSERT INTO valoracions VALUES (3815, 87, '03/10/2006', 3);
INSERT INTO valoracions VALUES (3815, 97, '29/11/2007', 5);
INSERT INTO valoracions VALUES (3815, 34, '27/03/2010', 6);
INSERT INTO valoracions VALUES (3815, 46, '15/10/2001', 9);
INSERT INTO valoracions VALUES (3815, 21, '29/10/2006', 5);
INSERT INTO valoracions VALUES (3815, 16, '16/02/2006', 6);
INSERT INTO valoracions VALUES (3816, 58, '07/03/2005', 4);
INSERT INTO valoracions VALUES (3816, 89, '30/04/2006', 10);
INSERT INTO valoracions VALUES (3816, 100, '24/06/2007', 3);
INSERT INTO valoracions VALUES (3816, 47, '28/05/2003', 4);
INSERT INTO valoracions VALUES (3816, 96, '01/04/2005', 5);
INSERT INTO valoracions VALUES (3816, 80, '13/07/2009', 6);
INSERT INTO valoracions VALUES (3817, 105, '14/10/2006', 3);
INSERT INTO valoracions VALUES (3817, 115, '14/10/2010', 8);
INSERT INTO valoracions VALUES (3817, 51, '04/10/2010', 6);
INSERT INTO valoracions VALUES (3817, 113, '10/04/2009', 9);
INSERT INTO valoracions VALUES (3817, 20, '25/08/2010', 9);
INSERT INTO valoracions VALUES (3818, 82, '28/06/2005', 2);
INSERT INTO valoracions VALUES (3818, 54, '11/01/2003', 3);
INSERT INTO valoracions VALUES (3818, 36, '30/11/2004', 9);
INSERT INTO valoracions VALUES (3818, 30, '01/10/2001', 9);
INSERT INTO valoracions VALUES (3819, 29, '09/08/2003', 4);
INSERT INTO valoracions VALUES (3819, 16, '25/01/2002', 9);
INSERT INTO valoracions VALUES (3819, 83, '12/03/2009', 6);
INSERT INTO valoracions VALUES (3819, 11, '07/01/2004', 5);
INSERT INTO valoracions VALUES (3819, 47, '09/04/2010', 9);
INSERT INTO valoracions VALUES (3820, 109, '03/12/2003', 2);
INSERT INTO valoracions VALUES (3820, 69, '22/06/2004', 8);
INSERT INTO valoracions VALUES (3820, 44, '22/01/2002', 6);
INSERT INTO valoracions VALUES (3820, 116, '09/01/2008', 7);
INSERT INTO valoracions VALUES (3820, 113, '18/06/2001', 2);
INSERT INTO valoracions VALUES (3821, 30, '22/06/2008', 8);
INSERT INTO valoracions VALUES (3821, 26, '13/05/2004', 5);
INSERT INTO valoracions VALUES (3821, 13, '09/08/2010', 5);
INSERT INTO valoracions VALUES (3822, 43, '13/12/2008', 6);
INSERT INTO valoracions VALUES (3822, 83, '16/11/2008', 4);
INSERT INTO valoracions VALUES (3822, 33, '29/01/2002', 9);
INSERT INTO valoracions VALUES (3822, 108, '26/03/2007', 3);
INSERT INTO valoracions VALUES (3823, 2, '30/09/2008', 10);
INSERT INTO valoracions VALUES (3823, 50, '19/08/2003', 9);
INSERT INTO valoracions VALUES (3823, 49, '07/11/2003', 6);
INSERT INTO valoracions VALUES (3823, 26, '27/05/2001', 9);
INSERT INTO valoracions VALUES (3824, 3, '21/03/2002', 6);
INSERT INTO valoracions VALUES (3824, 101, '16/06/2009', 1);
INSERT INTO valoracions VALUES (3824, 10, '20/02/2009', 9);
INSERT INTO valoracions VALUES (3825, 1, '13/09/2007', 9);
INSERT INTO valoracions VALUES (3825, 44, '08/10/2003', 6);
INSERT INTO valoracions VALUES (3825, 83, '19/04/2001', 4);
INSERT INTO valoracions VALUES (3825, 37, '28/03/2010', 3);
INSERT INTO valoracions VALUES (3826, 114, '27/11/2001', 6);
INSERT INTO valoracions VALUES (3826, 34, '15/01/2010', 9);
INSERT INTO valoracions VALUES (3826, 71, '11/04/2003', 8);
INSERT INTO valoracions VALUES (3826, 73, '28/03/2010', 8);
INSERT INTO valoracions VALUES (3826, 74, '20/09/2001', 8);
INSERT INTO valoracions VALUES (3826, 24, '25/05/2008', 8);
INSERT INTO valoracions VALUES (3826, 78, '04/06/2005', 3);
INSERT INTO valoracions VALUES (3826, 11, '10/02/2002', 9);
INSERT INTO valoracions VALUES (3827, 35, '20/07/2001', 8);
INSERT INTO valoracions VALUES (3827, 99, '07/10/2006', 6);
INSERT INTO valoracions VALUES (3827, 66, '10/06/2005', 7);
INSERT INTO valoracions VALUES (3827, 34, '14/02/2008', 6);
INSERT INTO valoracions VALUES (3827, 2, '26/08/2002', 7);
INSERT INTO valoracions VALUES (3827, 40, '14/02/2007', 7);
INSERT INTO valoracions VALUES (3827, 22, '09/05/2008', 4);
INSERT INTO valoracions VALUES (3828, 11, '19/02/2004', 8);
INSERT INTO valoracions VALUES (3828, 99, '12/12/2001', 5);
INSERT INTO valoracions VALUES (3828, 55, '10/03/2009', 6);
INSERT INTO valoracions VALUES (3828, 108, '21/05/2002', 3);
INSERT INTO valoracions VALUES (3829, 24, '27/04/2010', 5);
INSERT INTO valoracions VALUES (3829, 20, '20/01/2010', 7);
INSERT INTO valoracions VALUES (3829, 53, '09/01/2007', 4);
INSERT INTO valoracions VALUES (3829, 87, '22/08/2010', 4);
INSERT INTO valoracions VALUES (3830, 26, '10/07/2008', 9);
INSERT INTO valoracions VALUES (3830, 21, '05/01/2007', 5);
INSERT INTO valoracions VALUES (3831, 108, '02/03/2004', 2);
INSERT INTO valoracions VALUES (3831, 85, '12/05/2005', 7);
INSERT INTO valoracions VALUES (3831, 26, '03/05/2004', 4);
INSERT INTO valoracions VALUES (3831, 79, '03/02/2002', 2);
INSERT INTO valoracions VALUES (3831, 61, '27/02/2008', 2);
INSERT INTO valoracions VALUES (3831, 70, '19/11/2001', 7);
INSERT INTO valoracions VALUES (3832, 56, '20/05/2009', 9);
INSERT INTO valoracions VALUES (3832, 52, '27/07/2010', 7);
INSERT INTO valoracions VALUES (3832, 29, '25/05/2009', 6);
INSERT INTO valoracions VALUES (3832, 88, '08/02/2008', 6);
INSERT INTO valoracions VALUES (3833, 54, '23/03/2004', 8);
INSERT INTO valoracions VALUES (3833, 72, '10/08/2006', 8);
INSERT INTO valoracions VALUES (3833, 56, '13/05/2007', 3);
INSERT INTO valoracions VALUES (3833, 10, '17/11/2009', 9);
INSERT INTO valoracions VALUES (3833, 36, '11/09/2006', 4);
INSERT INTO valoracions VALUES (3833, 66, '21/05/2010', 9);
INSERT INTO valoracions VALUES (3834, 92, '27/08/2009', 8);
INSERT INTO valoracions VALUES (3834, 44, '05/10/2006', 5);
INSERT INTO valoracions VALUES (3834, 104, '06/05/2005', 7);
INSERT INTO valoracions VALUES (3834, 92, '02/03/2002', 4);
INSERT INTO valoracions VALUES (3834, 5, '28/10/2009', 7);
INSERT INTO valoracions VALUES (3834, 57, '28/06/2002', 9);
INSERT INTO valoracions VALUES (3835, 19, '17/01/2005', 5);
INSERT INTO valoracions VALUES (3835, 64, '16/06/2008', 7);
INSERT INTO valoracions VALUES (3835, 31, '23/09/2004', 9);
INSERT INTO valoracions VALUES (3835, 70, '01/12/2004', 3);
INSERT INTO valoracions VALUES (3835, 35, '28/08/2006', 8);
INSERT INTO valoracions VALUES (3835, 52, '23/05/2004', 4);
INSERT INTO valoracions VALUES (3836, 107, '24/06/2009', 2);
INSERT INTO valoracions VALUES (3836, 31, '10/08/2009', 4);
INSERT INTO valoracions VALUES (3836, 53, '13/03/2010', 4);
INSERT INTO valoracions VALUES (3836, 109, '19/12/2006', 7);
INSERT INTO valoracions VALUES (3836, 35, '22/05/2001', 8);
INSERT INTO valoracions VALUES (3836, 26, '30/07/2009', 9);
INSERT INTO valoracions VALUES (3837, 63, '08/05/2010', 5);
INSERT INTO valoracions VALUES (3837, 17, '12/08/2006', 9);
INSERT INTO valoracions VALUES (3837, 73, '03/07/2010', 6);
INSERT INTO valoracions VALUES (3837, 52, '04/12/2004', 6);
INSERT INTO valoracions VALUES (3837, 82, '07/09/2003', 7);
INSERT INTO valoracions VALUES (3837, 83, '28/01/2007', 2);
INSERT INTO valoracions VALUES (3837, 103, '15/12/2005', 8);
INSERT INTO valoracions VALUES (3838, 20, '26/07/2004', 5);
INSERT INTO valoracions VALUES (3838, 4, '25/09/2005', 6);
INSERT INTO valoracions VALUES (3838, 37, '20/09/2006', 9);
INSERT INTO valoracions VALUES (3838, 18, '01/10/2005', 9);
INSERT INTO valoracions VALUES (3838, 21, '10/05/2007', 8);
INSERT INTO valoracions VALUES (3838, 63, '24/03/2004', 4);
INSERT INTO valoracions VALUES (3838, 85, '13/07/2004', 5);
INSERT INTO valoracions VALUES (3839, 40, '18/10/2007', 5);
INSERT INTO valoracions VALUES (3839, 55, '01/02/2003', 9);
INSERT INTO valoracions VALUES (3839, 16, '14/10/2001', 7);
INSERT INTO valoracions VALUES (3839, 106, '06/11/2009', 6);
INSERT INTO valoracions VALUES (3840, 65, '25/03/2005', 4);
INSERT INTO valoracions VALUES (3840, 53, '17/07/2007', 5);
INSERT INTO valoracions VALUES (3840, 12, '29/10/2005', 7);
INSERT INTO valoracions VALUES (3840, 7, '18/05/2002', 8);
INSERT INTO valoracions VALUES (3840, 61, '15/02/2007', 8);
INSERT INTO valoracions VALUES (3841, 43, '16/07/2002', 6);
INSERT INTO valoracions VALUES (3841, 84, '08/03/2004', 3);
INSERT INTO valoracions VALUES (3841, 112, '24/03/2005', 0);
INSERT INTO valoracions VALUES (3842, 112, '17/10/2007', 5);
INSERT INTO valoracions VALUES (3842, 106, '29/10/2007', 6);
INSERT INTO valoracions VALUES (3842, 4, '26/10/2002', 6);
INSERT INTO valoracions VALUES (3842, 19, '17/07/2001', 9);
INSERT INTO valoracions VALUES (3842, 86, '19/06/2007', 7);
INSERT INTO valoracions VALUES (3843, 5, '15/05/2009', 5);
INSERT INTO valoracions VALUES (3843, 78, '01/04/2005', 10);
INSERT INTO valoracions VALUES (3843, 23, '26/09/2009', 9);
INSERT INTO valoracions VALUES (3843, 95, '20/12/2009', 4);
INSERT INTO valoracions VALUES (3844, 114, '02/12/2007', 6);
INSERT INTO valoracions VALUES (3844, 102, '16/04/2009', 6);
INSERT INTO valoracions VALUES (3844, 112, '04/11/2007', 6);
INSERT INTO valoracions VALUES (3844, 89, '08/09/2006', 6);
INSERT INTO valoracions VALUES (3844, 5, '04/08/2006', 6);
INSERT INTO valoracions VALUES (3844, 27, '22/04/2006', 9);
INSERT INTO valoracions VALUES (3844, 87, '27/10/2010', 4);
INSERT INTO valoracions VALUES (3845, 62, '22/04/2003', 5);
INSERT INTO valoracions VALUES (3846, 41, '26/12/2006', 4);
INSERT INTO valoracions VALUES (3846, 60, '19/04/2010', 5);
INSERT INTO valoracions VALUES (3846, 8, '23/09/2001', 5);
INSERT INTO valoracions VALUES (3846, 13, '29/09/2009', 8);
INSERT INTO valoracions VALUES (3846, 36, '23/10/2010', 7);
INSERT INTO valoracions VALUES (3846, 37, '23/12/2005', 9);
INSERT INTO valoracions VALUES (3847, 96, '18/12/2009', 8);
INSERT INTO valoracions VALUES (3848, 37, '04/03/2003', 6);
INSERT INTO valoracions VALUES (3848, 8, '10/12/2004', 8);
INSERT INTO valoracions VALUES (3849, 110, '04/04/2007', 1);
INSERT INTO valoracions VALUES (3849, 6, '24/10/2001', 10);
INSERT INTO valoracions VALUES (3849, 41, '03/12/2007', 7);
INSERT INTO valoracions VALUES (3850, 54, '13/07/2010', 3);
INSERT INTO valoracions VALUES (3850, 101, '09/04/2009', 7);
INSERT INTO valoracions VALUES (3850, 55, '15/08/2002', 3);
INSERT INTO valoracions VALUES (3850, 27, '14/01/2006', 7);
INSERT INTO valoracions VALUES (3851, 81, '06/09/2006', 7);
INSERT INTO valoracions VALUES (3851, 11, '08/07/2004', 8);
INSERT INTO valoracions VALUES (3851, 95, '25/01/2002', 5);
INSERT INTO valoracions VALUES (3851, 13, '01/05/2004', 7);
INSERT INTO valoracions VALUES (3851, 76, '23/02/2010', 5);
INSERT INTO valoracions VALUES (3852, 76, '28/11/2003', 3);
INSERT INTO valoracions VALUES (3852, 39, '12/05/2007', 4);
INSERT INTO valoracions VALUES (3852, 51, '31/12/2008', 5);
INSERT INTO valoracions VALUES (3852, 39, '01/09/2009', 8);
INSERT INTO valoracions VALUES (3853, 68, '11/11/2005', 7);
INSERT INTO valoracions VALUES (3853, 2, '16/12/2009', 6);
INSERT INTO valoracions VALUES (3854, 67, '07/08/2001', 4);
INSERT INTO valoracions VALUES (3854, 76, '07/02/2009', 9);
INSERT INTO valoracions VALUES (3854, 33, '20/11/2004', 4);
INSERT INTO valoracions VALUES (3854, 68, '19/09/2006', 9);
INSERT INTO valoracions VALUES (3854, 101, '30/10/2009', 4);
INSERT INTO valoracions VALUES (3855, 37, '13/09/2002', 10);
INSERT INTO valoracions VALUES (3855, 63, '17/06/2002', 6);
INSERT INTO valoracions VALUES (3856, 18, '01/04/2006', 8);
INSERT INTO valoracions VALUES (3856, 45, '05/04/2005', 7);
INSERT INTO valoracions VALUES (3856, 55, '08/11/2006', 8);
INSERT INTO valoracions VALUES (3856, 28, '29/07/2004', 9);
INSERT INTO valoracions VALUES (3857, 72, '06/05/2001', 4);
INSERT INTO valoracions VALUES (3857, 45, '26/12/2009', 5);
INSERT INTO valoracions VALUES (3857, 71, '01/03/2006', 7);
INSERT INTO valoracions VALUES (3858, 55, '22/02/2003', 6);
INSERT INTO valoracions VALUES (3858, 43, '27/01/2002', 8);
INSERT INTO valoracions VALUES (3858, 74, '30/10/2008', 9);
INSERT INTO valoracions VALUES (3858, 77, '25/10/2002', 3);
INSERT INTO valoracions VALUES (3858, 111, '04/04/2009', 2);
INSERT INTO valoracions VALUES (3859, 47, '24/06/2009', 7);
INSERT INTO valoracions VALUES (3859, 99, '05/12/2003', 3);
INSERT INTO valoracions VALUES (3859, 86, '08/12/2009', 6);
INSERT INTO valoracions VALUES (3859, 62, '21/06/2004', 5);
INSERT INTO valoracions VALUES (3859, 22, '12/04/2010', 6);
INSERT INTO valoracions VALUES (3859, 101, '19/01/2008', 5);
INSERT INTO valoracions VALUES (3859, 11, '18/06/2009', 8);
INSERT INTO valoracions VALUES (3859, 7, '22/11/2003', 5);
INSERT INTO valoracions VALUES (3859, 2, '15/10/2009', 10);
INSERT INTO valoracions VALUES (3859, 94, '08/11/2002', 1);
INSERT INTO valoracions VALUES (3860, 115, '23/11/2003', 2);
INSERT INTO valoracions VALUES (3860, 83, '22/09/2005', 4);
INSERT INTO valoracions VALUES (3861, 95, '03/11/2001', 9);
INSERT INTO valoracions VALUES (3861, 32, '09/04/2006', 5);
INSERT INTO valoracions VALUES (3861, 70, '24/05/2004', 3);
INSERT INTO valoracions VALUES (3862, 35, '11/08/2003', 9);
INSERT INTO valoracions VALUES (3862, 92, '20/12/2002', 7);
INSERT INTO valoracions VALUES (3862, 9, '31/01/2010', 9);
INSERT INTO valoracions VALUES (3863, 24, '20/09/2001', 7);
INSERT INTO valoracions VALUES (3863, 6, '11/03/2009', 8);
INSERT INTO valoracions VALUES (3863, 10, '05/03/2006', 7);
INSERT INTO valoracions VALUES (3863, 104, '22/03/2010', 2);
INSERT INTO valoracions VALUES (3863, 110, '18/08/2010', 9);
INSERT INTO valoracions VALUES (3863, 99, '22/01/2010', 2);
INSERT INTO valoracions VALUES (3864, 79, '20/12/2007', 7);
INSERT INTO valoracions VALUES (3864, 47, '25/01/2003', 5);
INSERT INTO valoracions VALUES (3864, 25, '03/12/2008', 7);
INSERT INTO valoracions VALUES (3864, 27, '14/12/2007', 10);
INSERT INTO valoracions VALUES (3864, 75, '07/03/2010', 3);
INSERT INTO valoracions VALUES (3865, 82, '03/06/2002', 3);
INSERT INTO valoracions VALUES (3865, 40, '13/05/2003', 7);
INSERT INTO valoracions VALUES (3865, 22, '25/07/2007', 8);
INSERT INTO valoracions VALUES (3866, 86, '17/07/2006', 7);
INSERT INTO valoracions VALUES (3866, 91, '24/05/2007', 4);
INSERT INTO valoracions VALUES (3866, 57, '18/01/2003', 3);
INSERT INTO valoracions VALUES (3866, 24, '21/01/2005', 9);
INSERT INTO valoracions VALUES (3866, 36, '08/06/2006', 7);
INSERT INTO valoracions VALUES (3867, 105, '12/08/2007', 5);
INSERT INTO valoracions VALUES (3867, 63, '05/08/2010', 4);
INSERT INTO valoracions VALUES (3867, 61, '03/08/2008', 5);
INSERT INTO valoracions VALUES (3867, 25, '06/01/2003', 9);
INSERT INTO valoracions VALUES (3868, 2, '16/12/2002', 7);
INSERT INTO valoracions VALUES (3868, 105, '01/01/2002', 5);
INSERT INTO valoracions VALUES (3868, 61, '07/02/2003', 10);
INSERT INTO valoracions VALUES (3869, 21, '03/09/2008', 9);
INSERT INTO valoracions VALUES (3869, 92, '10/03/2007', 1);
INSERT INTO valoracions VALUES (3869, 70, '13/09/2003', 8);
INSERT INTO valoracions VALUES (3869, 25, '16/07/2003', 5);
INSERT INTO valoracions VALUES (3870, 71, '18/01/2003', 7);
INSERT INTO valoracions VALUES (3870, 17, '11/12/2009', 9);
INSERT INTO valoracions VALUES (3870, 6, '11/05/2002', 7);
INSERT INTO valoracions VALUES (3870, 99, '08/05/2005', 4);
INSERT INTO valoracions VALUES (3871, 54, '01/05/2006', 6);
INSERT INTO valoracions VALUES (3871, 76, '11/01/2009', 8);
INSERT INTO valoracions VALUES (3871, 41, '14/07/2009', 4);
INSERT INTO valoracions VALUES (3871, 7, '11/09/2005', 7);
INSERT INTO valoracions VALUES (3872, 40, '01/09/2002', 9);
INSERT INTO valoracions VALUES (3872, 97, '30/01/2005', 2);
INSERT INTO valoracions VALUES (3872, 94, '05/02/2007', 2);
INSERT INTO valoracions VALUES (3873, 70, '29/07/2006', 4);
INSERT INTO valoracions VALUES (3873, 42, '15/04/2001', 5);
INSERT INTO valoracions VALUES (3873, 23, '28/09/2005', 4);
INSERT INTO valoracions VALUES (3873, 72, '03/06/2008', 4);
INSERT INTO valoracions VALUES (3873, 103, '22/10/2008', 5);
INSERT INTO valoracions VALUES (3873, 113, '15/07/2007', 5);
INSERT INTO valoracions VALUES (3874, 24, '12/11/2006', 4);
INSERT INTO valoracions VALUES (3874, 85, '18/08/2009', 3);
INSERT INTO valoracions VALUES (3875, 9, '27/06/2002', 6);
INSERT INTO valoracions VALUES (3875, 86, '10/11/2002', 9);
INSERT INTO valoracions VALUES (3875, 4, '06/09/2003', 5);
INSERT INTO valoracions VALUES (3875, 10, '08/09/2008', 8);
INSERT INTO valoracions VALUES (3875, 17, '21/08/2004', 8);
INSERT INTO valoracions VALUES (3876, 84, '08/02/2004', 4);
INSERT INTO valoracions VALUES (3876, 51, '10/06/2001', 7);
INSERT INTO valoracions VALUES (3876, 98, '26/09/2009', 8);
INSERT INTO valoracions VALUES (3876, 39, '02/04/2005', 9);
INSERT INTO valoracions VALUES (3877, 48, '09/07/2007', 4);
INSERT INTO valoracions VALUES (3877, 107, '02/04/2001', 8);
INSERT INTO valoracions VALUES (3877, 15, '12/11/2002', 5);
INSERT INTO valoracions VALUES (3877, 116, '12/12/2009', 2);
INSERT INTO valoracions VALUES (3878, 5, '04/10/2007', 5);
INSERT INTO valoracions VALUES (3878, 71, '04/04/2004', 8);
INSERT INTO valoracions VALUES (3878, 18, '20/01/2002', 5);
INSERT INTO valoracions VALUES (3878, 35, '22/09/2002', 9);
INSERT INTO valoracions VALUES (3879, 12, '31/05/2007', 7);
INSERT INTO valoracions VALUES (3879, 2, '23/07/2008', 10);
INSERT INTO valoracions VALUES (3879, 88, '20/04/2004', 7);
INSERT INTO valoracions VALUES (3879, 61, '27/04/2006', 5);
INSERT INTO valoracions VALUES (3879, 55, '14/01/2004', 9);
INSERT INTO valoracions VALUES (3880, 73, '04/07/2006', 8);
INSERT INTO valoracions VALUES (3880, 95, '10/03/2010', 6);
INSERT INTO valoracions VALUES (3880, 38, '18/09/2002', 8);
INSERT INTO valoracions VALUES (3881, 62, '25/07/2001', 7);
INSERT INTO valoracions VALUES (3881, 4, '01/08/2002', 8);
INSERT INTO valoracions VALUES (3881, 21, '28/02/2003', 6);
INSERT INTO valoracions VALUES (3881, 98, '01/12/2009', 7);
INSERT INTO valoracions VALUES (3881, 19, '17/06/2002', 5);
INSERT INTO valoracions VALUES (3881, 106, '17/02/2007', 5);
INSERT INTO valoracions VALUES (3882, 89, '17/04/2005', 6);
INSERT INTO valoracions VALUES (3882, 24, '26/05/2005', 5);
INSERT INTO valoracions VALUES (3883, 31, '16/08/2003', 6);
INSERT INTO valoracions VALUES (3883, 58, '13/07/2004', 9);
INSERT INTO valoracions VALUES (3884, 116, '04/12/2008', 2);
INSERT INTO valoracions VALUES (3884, 57, '13/07/2007', 9);
INSERT INTO valoracions VALUES (3885, 98, '08/10/2007', 10);
INSERT INTO valoracions VALUES (3885, 110, '16/04/2010', 7);
INSERT INTO valoracions VALUES (3885, 44, '30/03/2007', 9);
INSERT INTO valoracions VALUES (3885, 47, '18/06/2009', 4);
INSERT INTO valoracions VALUES (3885, 103, '07/11/2004', 5);
INSERT INTO valoracions VALUES (3886, 98, '08/07/2010', 4);
INSERT INTO valoracions VALUES (3886, 96, '28/07/2004', 8);
INSERT INTO valoracions VALUES (3886, 55, '10/10/2007', 4);
INSERT INTO valoracions VALUES (3886, 57, '16/06/2002', 3);
INSERT INTO valoracions VALUES (3887, 85, '20/01/2005', 1);
INSERT INTO valoracions VALUES (3887, 28, '02/05/2002', 9);
INSERT INTO valoracions VALUES (3887, 95, '29/07/2001', 6);
INSERT INTO valoracions VALUES (3887, 22, '09/11/2006', 7);
INSERT INTO valoracions VALUES (3887, 35, '06/10/2009', 7);
INSERT INTO valoracions VALUES (3888, 57, '11/08/2004', 7);
INSERT INTO valoracions VALUES (3888, 67, '10/02/2005', 7);
INSERT INTO valoracions VALUES (3888, 52, '01/04/2005', 3);
INSERT INTO valoracions VALUES (3888, 111, '22/09/2003', 1);
INSERT INTO valoracions VALUES (3888, 32, '17/11/2005', 9);
INSERT INTO valoracions VALUES (3889, 51, '07/11/2003', 6);
INSERT INTO valoracions VALUES (3889, 96, '06/06/2007', 9);
INSERT INTO valoracions VALUES (3889, 112, '13/01/2003', 1);
INSERT INTO valoracions VALUES (3890, 85, '22/03/2010', 1);
INSERT INTO valoracions VALUES (3890, 95, '17/01/2009', 3);
INSERT INTO valoracions VALUES (3890, 105, '24/12/2001', 6);
INSERT INTO valoracions VALUES (3890, 97, '28/03/2007', 6);
INSERT INTO valoracions VALUES (3891, 33, '26/07/2007', 6);
INSERT INTO valoracions VALUES (3891, 49, '05/11/2009', 5);
INSERT INTO valoracions VALUES (3891, 33, '15/08/2008', 5);
INSERT INTO valoracions VALUES (3891, 109, '13/03/2009', 9);
INSERT INTO valoracions VALUES (3891, 56, '16/12/2008', 3);
INSERT INTO valoracions VALUES (3891, 90, '08/10/2007', 6);
INSERT INTO valoracions VALUES (3892, 23, '16/04/2009', 5);
INSERT INTO valoracions VALUES (3892, 52, '09/04/2003', 3);
INSERT INTO valoracions VALUES (3892, 24, '02/03/2002', 6);
INSERT INTO valoracions VALUES (3892, 62, '24/11/2003', 8);
INSERT INTO valoracions VALUES (3893, 42, '10/06/2010', 5);
INSERT INTO valoracions VALUES (3893, 19, '19/07/2004', 7);
INSERT INTO valoracions VALUES (3893, 11, '11/06/2005', 9);
INSERT INTO valoracions VALUES (3893, 50, '10/11/2004', 8);
INSERT INTO valoracions VALUES (3893, 83, '06/03/2009', 8);
INSERT INTO valoracions VALUES (3894, 85, '08/12/2004', 7);
INSERT INTO valoracions VALUES (3894, 10, '12/08/2005', 5);
INSERT INTO valoracions VALUES (3894, 2, '28/11/2004', 6);
INSERT INTO valoracions VALUES (3894, 110, '04/08/2004', 2);
INSERT INTO valoracions VALUES (3894, 68, '30/03/2008', 10);
INSERT INTO valoracions VALUES (3894, 42, '24/03/2007', 8);
INSERT INTO valoracions VALUES (3895, 79, '18/04/2006', 8);
INSERT INTO valoracions VALUES (3896, 30, '09/07/2010', 8);
INSERT INTO valoracions VALUES (3896, 115, '28/03/2003', 3);
INSERT INTO valoracions VALUES (3896, 90, '30/09/2004', 4);
INSERT INTO valoracions VALUES (3896, 18, '19/02/2004', 7);
INSERT INTO valoracions VALUES (3896, 20, '25/03/2002', 5);
INSERT INTO valoracions VALUES (3897, 9, '15/09/2003', 9);
INSERT INTO valoracions VALUES (3897, 73, '29/09/2001', 9);
INSERT INTO valoracions VALUES (3897, 96, '04/10/2009', 7);
INSERT INTO valoracions VALUES (3897, 16, '30/04/2006', 6);
INSERT INTO valoracions VALUES (3898, 25, '06/06/2007', 9);
INSERT INTO valoracions VALUES (3898, 79, '30/11/2003', 2);
INSERT INTO valoracions VALUES (3898, 74, '06/08/2006', 6);
INSERT INTO valoracions VALUES (3898, 111, '23/04/2008', 2);
INSERT INTO valoracions VALUES (3898, 90, '25/01/2007', 3);
INSERT INTO valoracions VALUES (3898, 96, '10/08/2004', 5);
INSERT INTO valoracions VALUES (3899, 29, '17/08/2006', 9);
INSERT INTO valoracions VALUES (3899, 6, '19/08/2007', 9);
INSERT INTO valoracions VALUES (3899, 97, '04/06/2004', 5);
INSERT INTO valoracions VALUES (3900, 83, '27/04/2005', 2);
INSERT INTO valoracions VALUES (3900, 12, '19/08/2007', 8);
INSERT INTO valoracions VALUES (3900, 71, '24/06/2007', 2);
INSERT INTO valoracions VALUES (3901, 68, '01/05/2010', 9);
INSERT INTO valoracions VALUES (3901, 52, '09/06/2009', 7);
INSERT INTO valoracions VALUES (3901, 37, '03/07/2001', 5);
INSERT INTO valoracions VALUES (3901, 101, '04/07/2001', 6);
INSERT INTO valoracions VALUES (3902, 25, '12/01/2005', 5);
INSERT INTO valoracions VALUES (3903, 102, '23/10/2005', 8);
INSERT INTO valoracions VALUES (3903, 76, '10/04/2005', 4);
INSERT INTO valoracions VALUES (3903, 23, '26/11/2005', 4);
INSERT INTO valoracions VALUES (3903, 77, '23/03/2007', 3);
INSERT INTO valoracions VALUES (3903, 18, '15/06/2009', 9);
INSERT INTO valoracions VALUES (3904, 80, '21/04/2004', 4);
INSERT INTO valoracions VALUES (3904, 57, '02/06/2007', 8);
INSERT INTO valoracions VALUES (3904, 71, '13/08/2008', 6);
INSERT INTO valoracions VALUES (3904, 92, '11/12/2003', 10);
INSERT INTO valoracions VALUES (3904, 74, '31/10/2006', 8);
INSERT INTO valoracions VALUES (3905, 10, '21/05/2004', 9);
INSERT INTO valoracions VALUES (3905, 92, '26/08/2010', 8);
INSERT INTO valoracions VALUES (3905, 87, '18/02/2003', 8);
INSERT INTO valoracions VALUES (3906, 33, '03/12/2002', 8);
INSERT INTO valoracions VALUES (3906, 63, '17/05/2001', 7);
INSERT INTO valoracions VALUES (3906, 57, '31/10/2007', 9);
INSERT INTO valoracions VALUES (3906, 6, '17/05/2002', 6);
INSERT INTO valoracions VALUES (3906, 13, '10/04/2010', 8);
INSERT INTO valoracions VALUES (3907, 75, '03/11/2003', 6);
INSERT INTO valoracions VALUES (3907, 37, '24/08/2008', 9);
INSERT INTO valoracions VALUES (3907, 33, '02/10/2001', 5);
INSERT INTO valoracions VALUES (3907, 64, '09/12/2008', 7);
INSERT INTO valoracions VALUES (3907, 89, '13/12/2003', 3);
INSERT INTO valoracions VALUES (3907, 98, '22/09/2009', 8);
INSERT INTO valoracions VALUES (3908, 43, '19/10/2008', 6);
INSERT INTO valoracions VALUES (3908, 11, '15/10/2010', 7);
INSERT INTO valoracions VALUES (3908, 96, '12/01/2003', 10);
INSERT INTO valoracions VALUES (3909, 44, '19/08/2002', 4);
INSERT INTO valoracions VALUES (3909, 79, '10/10/2005', 8);
INSERT INTO valoracions VALUES (3910, 69, '20/04/2010', 3);
INSERT INTO valoracions VALUES (3910, 97, '10/02/2004', 2);
INSERT INTO valoracions VALUES (3910, 57, '31/10/2007', 3);
INSERT INTO valoracions VALUES (3910, 45, '25/10/2010', 5);
INSERT INTO valoracions VALUES (3910, 115, '08/12/2005', 0);
INSERT INTO valoracions VALUES (3910, 17, '24/03/2002', 9);
INSERT INTO valoracions VALUES (3911, 91, '14/04/2004', 1);
INSERT INTO valoracions VALUES (3912, 15, '06/06/2010', 6);
INSERT INTO valoracions VALUES (3912, 86, '23/07/2010', 6);
INSERT INTO valoracions VALUES (3912, 105, '10/07/2007', 8);
INSERT INTO valoracions VALUES (3912, 115, '01/06/2004', 5);
INSERT INTO valoracions VALUES (3912, 115, '28/11/2005', 9);
INSERT INTO valoracions VALUES (3912, 98, '05/08/2006', 2);
INSERT INTO valoracions VALUES (3913, 43, '12/05/2008', 9);
INSERT INTO valoracions VALUES (3913, 89, '01/05/2008', 4);
INSERT INTO valoracions VALUES (3913, 78, '01/01/2002', 2);
INSERT INTO valoracions VALUES (3913, 19, '12/01/2002', 7);
INSERT INTO valoracions VALUES (3914, 34, '27/12/2001', 4);
INSERT INTO valoracions VALUES (3914, 65, '09/08/2009', 5);
INSERT INTO valoracions VALUES (3914, 94, '30/10/2006', 6);
INSERT INTO valoracions VALUES (3914, 89, '22/12/2001', 2);
INSERT INTO valoracions VALUES (3914, 99, '27/10/2007', 3);
INSERT INTO valoracions VALUES (3915, 47, '12/08/2004', 10);
INSERT INTO valoracions VALUES (3915, 115, '30/08/2001', 6);
INSERT INTO valoracions VALUES (3915, 94, '12/11/2008', 2);
INSERT INTO valoracions VALUES (3915, 60, '09/09/2002', 8);
INSERT INTO valoracions VALUES (3915, 82, '22/05/2004', 9);
INSERT INTO valoracions VALUES (3915, 87, '28/04/2004', 5);
INSERT INTO valoracions VALUES (3915, 100, '13/03/2005', 1);
INSERT INTO valoracions VALUES (3916, 8, '12/07/2001', 7);
INSERT INTO valoracions VALUES (3916, 19, '30/06/2003', 7);
INSERT INTO valoracions VALUES (3918, 59, '15/10/2004', 4);
INSERT INTO valoracions VALUES (3918, 12, '27/09/2008', 8);
INSERT INTO valoracions VALUES (3918, 26, '02/11/2007', 5);
INSERT INTO valoracions VALUES (3918, 64, '04/11/2002', 5);
INSERT INTO valoracions VALUES (3918, 42, '05/03/2003', 9);
INSERT INTO valoracions VALUES (3918, 90, '04/08/2010', 6);
INSERT INTO valoracions VALUES (3919, 21, '20/08/2001', 8);
INSERT INTO valoracions VALUES (3919, 90, '17/12/2005', 9);
INSERT INTO valoracions VALUES (3919, 24, '23/08/2009', 8);
INSERT INTO valoracions VALUES (3919, 30, '01/05/2007', 4);
INSERT INTO valoracions VALUES (3920, 56, '25/04/2008', 7);
INSERT INTO valoracions VALUES (3920, 97, '13/03/2006', 3);
INSERT INTO valoracions VALUES (3920, 76, '12/06/2003', 3);
INSERT INTO valoracions VALUES (3920, 84, '24/12/2006', 10);
INSERT INTO valoracions VALUES (3921, 100, '02/03/2005', 6);
INSERT INTO valoracions VALUES (3921, 103, '20/08/2006', 5);
INSERT INTO valoracions VALUES (3921, 84, '13/10/2001', 9);
INSERT INTO valoracions VALUES (3921, 58, '22/05/2006', 6);
INSERT INTO valoracions VALUES (3922, 72, '18/10/2007', 8);
INSERT INTO valoracions VALUES (3922, 112, '23/04/2002', 7);
INSERT INTO valoracions VALUES (3923, 70, '27/06/2003', 5);
INSERT INTO valoracions VALUES (3923, 87, '15/06/2005', 3);
INSERT INTO valoracions VALUES (3923, 41, '17/02/2008', 4);
INSERT INTO valoracions VALUES (3923, 41, '24/10/2004', 7);
INSERT INTO valoracions VALUES (3924, 96, '06/10/2009', 10);
INSERT INTO valoracions VALUES (3924, 8, '14/02/2004', 9);
INSERT INTO valoracions VALUES (3924, 15, '12/02/2003', 8);
INSERT INTO valoracions VALUES (3924, 6, '21/02/2006', 9);
INSERT INTO valoracions VALUES (3924, 77, '25/09/2004', 5);
INSERT INTO valoracions VALUES (3925, 20, '20/10/2003', 8);
INSERT INTO valoracions VALUES (3925, 113, '27/06/2010', 3);
INSERT INTO valoracions VALUES (3925, 82, '05/10/2004', 7);
INSERT INTO valoracions VALUES (3927, 7, '04/12/2008', 9);
INSERT INTO valoracions VALUES (3927, 23, '11/11/2001', 9);
INSERT INTO valoracions VALUES (3927, 116, '08/01/2002', 6);
INSERT INTO valoracions VALUES (3928, 32, '08/07/2001', 6);
INSERT INTO valoracions VALUES (3928, 116, '12/05/2002', 3);
INSERT INTO valoracions VALUES (3928, 29, '24/09/2001', 10);
INSERT INTO valoracions VALUES (3928, 98, '20/06/2005', 4);
INSERT INTO valoracions VALUES (3929, 69, '25/01/2009', 8);
INSERT INTO valoracions VALUES (3929, 77, '21/07/2010', 2);
INSERT INTO valoracions VALUES (3929, 107, '22/05/2008', 3);
INSERT INTO valoracions VALUES (3929, 82, '04/03/2010', 9);
INSERT INTO valoracions VALUES (3930, 43, '16/04/2004', 8);
INSERT INTO valoracions VALUES (3930, 114, '19/02/2010', 4);
INSERT INTO valoracions VALUES (3930, 16, '28/11/2008', 9);
INSERT INTO valoracions VALUES (3931, 104, '18/09/2008', 8);
INSERT INTO valoracions VALUES (3931, 43, '14/05/2003', 7);
INSERT INTO valoracions VALUES (3932, 8, '08/11/2001', 8);
INSERT INTO valoracions VALUES (3932, 19, '30/07/2005', 8);
INSERT INTO valoracions VALUES (3932, 106, '03/07/2002', 5);
INSERT INTO valoracions VALUES (3932, 50, '26/12/2001', 3);
INSERT INTO valoracions VALUES (3932, 79, '27/12/2001', 5);
INSERT INTO valoracions VALUES (3932, 57, '21/04/2010', 8);
INSERT INTO valoracions VALUES (3932, 90, '09/08/2003', 9);
INSERT INTO valoracions VALUES (3932, 31, '10/10/2005', 5);
INSERT INTO valoracions VALUES (3932, 69, '24/09/2008', 10);
INSERT INTO valoracions VALUES (3933, 93, '01/07/2003', 4);
INSERT INTO valoracions VALUES (3933, 11, '01/06/2003', 5);
INSERT INTO valoracions VALUES (3933, 10, '19/10/2004', 7);
INSERT INTO valoracions VALUES (3934, 55, '13/12/2003', 6);
INSERT INTO valoracions VALUES (3934, 62, '27/11/2008', 9);
INSERT INTO valoracions VALUES (3935, 18, '19/11/2008', 7);
INSERT INTO valoracions VALUES (3935, 31, '14/09/2001', 7);
INSERT INTO valoracions VALUES (3935, 72, '11/07/2008', 9);
INSERT INTO valoracions VALUES (3936, 86, '23/10/2008', 6);
INSERT INTO valoracions VALUES (3936, 96, '26/08/2010', 8);
INSERT INTO valoracions VALUES (3936, 57, '28/02/2009', 4);
INSERT INTO valoracions VALUES (3936, 60, '17/07/2009', 8);
INSERT INTO valoracions VALUES (3936, 54, '07/09/2009', 8);
INSERT INTO valoracions VALUES (3937, 47, '13/09/2004', 8);
INSERT INTO valoracions VALUES (3937, 44, '03/01/2009', 5);
INSERT INTO valoracions VALUES (3937, 95, '10/09/2010', 10);
INSERT INTO valoracions VALUES (3937, 7, '03/09/2006', 9);
INSERT INTO valoracions VALUES (3937, 77, '05/04/2006', 10);
INSERT INTO valoracions VALUES (3937, 79, '21/07/2008', 10);
INSERT INTO valoracions VALUES (3937, 63, '31/08/2006', 7);
INSERT INTO valoracions VALUES (3938, 109, '04/01/2009', 4);
INSERT INTO valoracions VALUES (3938, 104, '31/07/2008', 6);
INSERT INTO valoracions VALUES (3938, 85, '01/10/2009', 7);
INSERT INTO valoracions VALUES (3938, 105, '02/09/2008', 1);
INSERT INTO valoracions VALUES (3939, 61, '18/01/2006', 6);
INSERT INTO valoracions VALUES (3939, 105, '17/01/2003', 2);
INSERT INTO valoracions VALUES (3939, 81, '06/11/2001', 4);
INSERT INTO valoracions VALUES (3939, 61, '15/06/2004', 9);
INSERT INTO valoracions VALUES (3940, 107, '12/01/2004', 6);
INSERT INTO valoracions VALUES (3940, 54, '22/09/2003', 5);
INSERT INTO valoracions VALUES (3940, 32, '23/05/2005', 7);
INSERT INTO valoracions VALUES (3941, 89, '19/07/2006', 9);
INSERT INTO valoracions VALUES (3941, 2, '14/01/2004', 7);
INSERT INTO valoracions VALUES (3941, 11, '21/10/2007', 8);
INSERT INTO valoracions VALUES (3941, 71, '16/06/2001', 4);
INSERT INTO valoracions VALUES (3941, 66, '20/01/2004', 3);
INSERT INTO valoracions VALUES (3941, 94, '30/04/2010', 7);
INSERT INTO valoracions VALUES (3942, 27, '28/04/2007', 8);
INSERT INTO valoracions VALUES (3942, 47, '18/08/2001', 10);
INSERT INTO valoracions VALUES (3942, 66, '24/08/2001', 4);
INSERT INTO valoracions VALUES (3942, 96, '23/12/2004', 6);
INSERT INTO valoracions VALUES (3943, 108, '02/10/2005', 7);
INSERT INTO valoracions VALUES (3943, 78, '08/01/2008', 3);
INSERT INTO valoracions VALUES (3943, 104, '30/12/2002', 9);
INSERT INTO valoracions VALUES (3943, 7, '29/11/2002', 7);
INSERT INTO valoracions VALUES (3943, 51, '09/12/2009', 6);
INSERT INTO valoracions VALUES (3943, 80, '03/09/2007', 4);
INSERT INTO valoracions VALUES (3943, 53, '21/10/2006', 10);
INSERT INTO valoracions VALUES (3944, 95, '24/09/2008', 5);
INSERT INTO valoracions VALUES (3944, 60, '04/11/2009', 8);
INSERT INTO valoracions VALUES (3944, 64, '06/11/2007', 5);
INSERT INTO valoracions VALUES (3944, 57, '30/04/2003', 6);
INSERT INTO valoracions VALUES (3944, 112, '16/05/2005', 0);
INSERT INTO valoracions VALUES (3945, 48, '27/08/2009', 3);
INSERT INTO valoracions VALUES (3945, 2, '01/01/2006', 8);
INSERT INTO valoracions VALUES (3945, 4, '11/01/2009', 7);
INSERT INTO valoracions VALUES (3945, 7, '27/12/2008', 5);
INSERT INTO valoracions VALUES (3945, 61, '20/08/2009', 7);
INSERT INTO valoracions VALUES (3945, 108, '28/05/2006', 6);
INSERT INTO valoracions VALUES (3947, 15, '17/10/2006', 7);
INSERT INTO valoracions VALUES (3947, 116, '21/10/2002', 9);
INSERT INTO valoracions VALUES (3947, 80, '17/06/2002', 2);
INSERT INTO valoracions VALUES (3947, 114, '14/08/2008', 8);
INSERT INTO valoracions VALUES (3947, 99, '22/11/2001', 1);
INSERT INTO valoracions VALUES (3947, 41, '08/01/2009', 4);
INSERT INTO valoracions VALUES (3947, 10, '25/05/2010', 6);
INSERT INTO valoracions VALUES (3947, 25, '09/06/2001', 9);
INSERT INTO valoracions VALUES (3947, 83, '18/08/2006', 3);
INSERT INTO valoracions VALUES (3948, 65, '03/01/2006', 5);
INSERT INTO valoracions VALUES (3948, 2, '11/09/2004', 8);
INSERT INTO valoracions VALUES (3948, 67, '11/05/2007', 5);
INSERT INTO valoracions VALUES (3948, 88, '29/10/2007', 7);
INSERT INTO valoracions VALUES (3949, 17, '31/05/2010', 7);
INSERT INTO valoracions VALUES (3949, 75, '13/10/2008', 4);
INSERT INTO valoracions VALUES (3950, 84, '19/12/2001', 6);
INSERT INTO valoracions VALUES (3951, 27, '17/12/2002', 7);
INSERT INTO valoracions VALUES (3951, 40, '25/04/2003', 4);
INSERT INTO valoracions VALUES (3952, 24, '28/02/2007', 9);
INSERT INTO valoracions VALUES (3952, 7, '24/04/2010', 8);
INSERT INTO valoracions VALUES (3953, 12, '19/02/2010', 9);
INSERT INTO valoracions VALUES (3953, 91, '24/11/2003', 9);
INSERT INTO valoracions VALUES (3953, 20, '18/08/2007', 9);
INSERT INTO valoracions VALUES (3953, 75, '09/12/2008', 8);
INSERT INTO valoracions VALUES (3953, 42, '13/05/2005', 5);
INSERT INTO valoracions VALUES (3953, 72, '30/05/2004', 7);
INSERT INTO valoracions VALUES (3953, 111, '26/07/2004', 0);
INSERT INTO valoracions VALUES (3953, 75, '06/09/2005', 3);
INSERT INTO valoracions VALUES (3954, 4, '14/12/2005', 7);
INSERT INTO valoracions VALUES (3955, 94, '23/06/2001', 3);
INSERT INTO valoracions VALUES (3955, 39, '21/02/2008', 6);
INSERT INTO valoracions VALUES (3955, 57, '13/06/2007', 3);
INSERT INTO valoracions VALUES (3955, 71, '16/10/2009', 7);
INSERT INTO valoracions VALUES (3956, 108, '13/04/2007', 5);
INSERT INTO valoracions VALUES (3956, 19, '24/10/2010', 10);
INSERT INTO valoracions VALUES (3956, 53, '22/09/2003', 6);
INSERT INTO valoracions VALUES (3956, 97, '08/06/2005', 6);
INSERT INTO valoracions VALUES (3956, 96, '30/06/2004', 5);
INSERT INTO valoracions VALUES (3957, 45, '01/02/2003', 3);
INSERT INTO valoracions VALUES (3957, 114, '23/04/2003', 5);
INSERT INTO valoracions VALUES (3957, 48, '28/05/2002', 9);
INSERT INTO valoracions VALUES (3957, 21, '14/11/2003', 9);
INSERT INTO valoracions VALUES (3957, 43, '18/05/2003', 5);
INSERT INTO valoracions VALUES (3958, 75, '20/03/2004', 8);
INSERT INTO valoracions VALUES (3958, 65, '14/10/2003', 6);
INSERT INTO valoracions VALUES (3958, 28, '25/10/2009', 10);
INSERT INTO valoracions VALUES (3958, 85, '28/03/2002', 6);
INSERT INTO valoracions VALUES (3959, 104, '19/08/2003', 7);
INSERT INTO valoracions VALUES (3959, 106, '02/09/2006', 8);
INSERT INTO valoracions VALUES (3960, 94, '24/02/2007', 2);
INSERT INTO valoracions VALUES (3960, 69, '16/06/2003', 3);
INSERT INTO valoracions VALUES (3960, 20, '06/02/2003', 7);
INSERT INTO valoracions VALUES (3961, 33, '23/01/2005', 8);
INSERT INTO valoracions VALUES (3961, 58, '06/04/2002', 9);
INSERT INTO valoracions VALUES (3961, 8, '12/11/2003', 10);
INSERT INTO valoracions VALUES (3961, 5, '01/05/2005', 8);
INSERT INTO valoracions VALUES (3962, 85, '24/09/2001', 4);
INSERT INTO valoracions VALUES (3962, 35, '06/07/2003', 9);
INSERT INTO valoracions VALUES (3962, 57, '12/11/2008', 5);
INSERT INTO valoracions VALUES (3962, 37, '15/06/2010', 4);
INSERT INTO valoracions VALUES (3962, 93, '09/11/2009', 3);
INSERT INTO valoracions VALUES (3962, 31, '28/05/2008', 8);
INSERT INTO valoracions VALUES (3963, 50, '14/10/2010', 4);
INSERT INTO valoracions VALUES (3963, 84, '25/03/2009', 1);
INSERT INTO valoracions VALUES (3965, 112, '26/01/2009', 1);
INSERT INTO valoracions VALUES (3965, 60, '16/09/2001', 6);
INSERT INTO valoracions VALUES (3965, 42, '25/12/2006', 5);
INSERT INTO valoracions VALUES (3965, 7, '15/08/2004', 5);
INSERT INTO valoracions VALUES (3965, 106, '09/08/2007', 8);
INSERT INTO valoracions VALUES (3966, 8, '23/03/2009', 7);
INSERT INTO valoracions VALUES (3966, 60, '26/05/2008', 8);
INSERT INTO valoracions VALUES (3966, 88, '30/10/2007', 8);
INSERT INTO valoracions VALUES (3966, 43, '13/07/2004', 7);
INSERT INTO valoracions VALUES (3967, 97, '28/03/2002', 10);
INSERT INTO valoracions VALUES (3967, 104, '19/07/2005', 4);
INSERT INTO valoracions VALUES (3967, 59, '17/07/2009', 9);
INSERT INTO valoracions VALUES (3967, 69, '17/08/2003', 10);
INSERT INTO valoracions VALUES (3967, 73, '16/08/2004', 6);
INSERT INTO valoracions VALUES (3968, 81, '11/02/2003', 7);
INSERT INTO valoracions VALUES (3968, 96, '14/01/2002', 9);
INSERT INTO valoracions VALUES (3968, 56, '24/12/2004', 3);
INSERT INTO valoracions VALUES (3968, 54, '22/08/2008', 6);
INSERT INTO valoracions VALUES (3969, 23, '30/05/2008', 9);
INSERT INTO valoracions VALUES (3969, 99, '30/12/2005', 7);
INSERT INTO valoracions VALUES (3970, 42, '13/05/2009', 4);
INSERT INTO valoracions VALUES (3970, 43, '11/09/2007', 9);
INSERT INTO valoracions VALUES (3970, 102, '14/05/2006', 5);
INSERT INTO valoracions VALUES (3970, 96, '20/03/2002', 7);
INSERT INTO valoracions VALUES (3971, 34, '06/03/2003', 6);
INSERT INTO valoracions VALUES (3971, 46, '29/01/2004', 6);
INSERT INTO valoracions VALUES (3971, 60, '02/05/2010', 5);
INSERT INTO valoracions VALUES (3971, 19, '03/05/2004', 4);
INSERT INTO valoracions VALUES (3971, 76, '11/02/2010', 4);
INSERT INTO valoracions VALUES (3971, 21, '28/06/2007', 10);
INSERT INTO valoracions VALUES (3972, 18, '12/11/2008', 6);
INSERT INTO valoracions VALUES (3972, 25, '21/05/2007', 9);
INSERT INTO valoracions VALUES (3972, 42, '18/11/2007', 7);
INSERT INTO valoracions VALUES (3973, 99, '13/06/2002', 10);
INSERT INTO valoracions VALUES (3973, 97, '18/10/2002', 9);
INSERT INTO valoracions VALUES (3973, 60, '24/05/2003', 5);
INSERT INTO valoracions VALUES (3973, 60, '25/11/2004', 7);
INSERT INTO valoracions VALUES (3973, 52, '16/10/2008', 5);
INSERT INTO valoracions VALUES (3975, 58, '26/10/2002', 8);
INSERT INTO valoracions VALUES (3975, 43, '09/10/2010', 9);
INSERT INTO valoracions VALUES (3975, 59, '07/09/2005', 7);
INSERT INTO valoracions VALUES (3975, 42, '25/01/2008', 4);
INSERT INTO valoracions VALUES (3975, 45, '26/09/2002', 9);
INSERT INTO valoracions VALUES (3975, 69, '16/10/2003', 5);
INSERT INTO valoracions VALUES (3976, 78, '29/09/2009', 10);
INSERT INTO valoracions VALUES (3976, 45, '02/03/2007', 9);
INSERT INTO valoracions VALUES (3976, 51, '02/07/2007', 8);
INSERT INTO valoracions VALUES (3976, 90, '04/02/2010', 2);
INSERT INTO valoracions VALUES (3976, 17, '09/07/2010', 9);
INSERT INTO valoracions VALUES (3977, 108, '26/04/2006', 1);
INSERT INTO valoracions VALUES (3977, 53, '26/04/2009', 4);
INSERT INTO valoracions VALUES (3977, 71, '13/11/2009', 8);
INSERT INTO valoracions VALUES (3977, 72, '15/01/2007', 5);
INSERT INTO valoracions VALUES (3977, 27, '04/02/2007', 7);
INSERT INTO valoracions VALUES (3977, 40, '20/07/2001', 7);
INSERT INTO valoracions VALUES (3977, 53, '30/01/2006', 6);
INSERT INTO valoracions VALUES (3977, 23, '27/08/2001', 5);
INSERT INTO valoracions VALUES (3978, 78, '04/12/2001', 5);
INSERT INTO valoracions VALUES (3978, 97, '08/12/2003', 7);
INSERT INTO valoracions VALUES (3979, 27, '20/03/2006', 5);
INSERT INTO valoracions VALUES (3979, 112, '18/08/2001', 2);
INSERT INTO valoracions VALUES (3980, 27, '24/09/2010', 8);
INSERT INTO valoracions VALUES (3980, 87, '13/08/2001', 10);
INSERT INTO valoracions VALUES (3980, 116, '10/01/2008', 7);
INSERT INTO valoracions VALUES (3980, 107, '20/07/2001', 6);
INSERT INTO valoracions VALUES (3981, 83, '29/01/2008', 3);
INSERT INTO valoracions VALUES (3981, 18, '15/12/2004', 7);
INSERT INTO valoracions VALUES (3981, 98, '09/08/2009', 9);
INSERT INTO valoracions VALUES (3981, 48, '29/03/2005', 6);
INSERT INTO valoracions VALUES (3981, 2, '02/02/2006', 6);
INSERT INTO valoracions VALUES (3982, 29, '19/08/2002', 6);
INSERT INTO valoracions VALUES (3982, 23, '03/07/2006', 5);
INSERT INTO valoracions VALUES (3982, 106, '14/07/2005', 3);
INSERT INTO valoracions VALUES (3982, 86, '18/06/2001', 7);
INSERT INTO valoracions VALUES (3982, 71, '02/04/2008', 8);
INSERT INTO valoracions VALUES (3982, 107, '17/01/2002', 0);
INSERT INTO valoracions VALUES (3982, 102, '29/09/2010', 6);
INSERT INTO valoracions VALUES (3983, 75, '29/04/2010', 7);
INSERT INTO valoracions VALUES (3983, 86, '29/08/2008', 3);
INSERT INTO valoracions VALUES (3983, 30, '25/09/2001', 6);
INSERT INTO valoracions VALUES (3984, 73, '11/06/2002', 4);
INSERT INTO valoracions VALUES (3984, 73, '17/01/2003', 10);
INSERT INTO valoracions VALUES (3984, 29, '16/09/2002', 6);
INSERT INTO valoracions VALUES (3985, 28, '27/07/2001', 9);
INSERT INTO valoracions VALUES (3985, 57, '01/09/2008', 3);
INSERT INTO valoracions VALUES (3985, 84, '11/10/2009', 8);
INSERT INTO valoracions VALUES (3985, 14, '25/01/2008', 7);
INSERT INTO valoracions VALUES (3985, 8, '30/09/2010', 8);
INSERT INTO valoracions VALUES (3985, 116, '18/08/2006', 4);
INSERT INTO valoracions VALUES (3985, 73, '26/01/2009', 8);
INSERT INTO valoracions VALUES (3985, 78, '21/07/2007', 4);
INSERT INTO valoracions VALUES (3985, 58, '24/03/2010', 3);
INSERT INTO valoracions VALUES (3985, 100, '27/02/2009', 4);
INSERT INTO valoracions VALUES (3985, 16, '20/11/2007', 8);
INSERT INTO valoracions VALUES (3986, 92, '29/07/2004', 8);
INSERT INTO valoracions VALUES (3986, 24, '22/04/2003', 6);
INSERT INTO valoracions VALUES (3986, 109, '17/09/2006', 3);
INSERT INTO valoracions VALUES (3986, 11, '25/06/2008', 7);
INSERT INTO valoracions VALUES (3986, 71, '03/07/2004', 7);
INSERT INTO valoracions VALUES (3987, 72, '05/12/2001', 4);
INSERT INTO valoracions VALUES (3987, 17, '13/04/2002', 7);
INSERT INTO valoracions VALUES (3987, 76, '16/12/2003', 6);
INSERT INTO valoracions VALUES (3987, 58, '24/09/2004', 6);
INSERT INTO valoracions VALUES (3987, 70, '11/02/2003', 8);
INSERT INTO valoracions VALUES (3988, 97, '24/09/2010', 5);
INSERT INTO valoracions VALUES (3988, 42, '07/05/2007', 3);
INSERT INTO valoracions VALUES (3988, 30, '14/05/2002', 8);
INSERT INTO valoracions VALUES (3988, 94, '27/04/2002', 6);
INSERT INTO valoracions VALUES (3989, 105, '07/11/2003', 10);
INSERT INTO valoracions VALUES (3989, 40, '31/03/2001', 9);
INSERT INTO valoracions VALUES (3989, 94, '08/06/2003', 5);
INSERT INTO valoracions VALUES (3990, 53, '01/10/2003', 5);
INSERT INTO valoracions VALUES (3990, 39, '17/03/2005', 7);
INSERT INTO valoracions VALUES (3990, 20, '12/05/2006', 10);
INSERT INTO valoracions VALUES (3990, 108, '07/07/2005', 4);
INSERT INTO valoracions VALUES (3990, 94, '26/11/2005', 6);
INSERT INTO valoracions VALUES (3991, 52, '22/10/2002', 4);
INSERT INTO valoracions VALUES (3991, 50, '31/07/2008', 9);
INSERT INTO valoracions VALUES (3991, 19, '06/01/2006', 5);
INSERT INTO valoracions VALUES (3991, 57, '07/01/2009', 6);
INSERT INTO valoracions VALUES (3991, 78, '11/02/2010', 10);
INSERT INTO valoracions VALUES (3992, 40, '27/09/2006', 5);
INSERT INTO valoracions VALUES (3992, 57, '12/09/2008', 6);
INSERT INTO valoracions VALUES (3992, 47, '01/02/2004', 9);
INSERT INTO valoracions VALUES (3992, 104, '06/05/2003', 5);
INSERT INTO valoracions VALUES (3992, 33, '27/10/2005', 10);
INSERT INTO valoracions VALUES (3993, 84, '06/08/2008', 2);
INSERT INTO valoracions VALUES (3993, 71, '20/04/2009', 2);
INSERT INTO valoracions VALUES (3994, 17, '10/12/2008', 9);
INSERT INTO valoracions VALUES (3994, 72, '11/06/2006', 3);
INSERT INTO valoracions VALUES (3994, 13, '05/07/2008', 9);
INSERT INTO valoracions VALUES (3995, 14, '14/07/2009', 9);
INSERT INTO valoracions VALUES (3995, 71, '26/10/2009', 5);
INSERT INTO valoracions VALUES (3995, 14, '12/12/2008', 8);
INSERT INTO valoracions VALUES (3995, 50, '12/04/2003', 9);
INSERT INTO valoracions VALUES (3995, 57, '25/01/2007', 3);
INSERT INTO valoracions VALUES (3995, 8, '07/07/2003', 9);
INSERT INTO valoracions VALUES (3995, 56, '16/10/2001', 8);
INSERT INTO valoracions VALUES (3996, 91, '27/04/2010', 3);
INSERT INTO valoracions VALUES (3996, 53, '24/03/2002', 9);
INSERT INTO valoracions VALUES (3996, 67, '01/10/2003', 3);
INSERT INTO valoracions VALUES (3996, 23, '21/02/2010', 4);
INSERT INTO valoracions VALUES (3996, 34, '18/12/2008', 5);
INSERT INTO valoracions VALUES (3996, 24, '21/12/2004', 8);
INSERT INTO valoracions VALUES (3997, 21, '27/03/2007', 7);
INSERT INTO valoracions VALUES (3997, 49, '06/06/2001', 9);
INSERT INTO valoracions VALUES (3997, 102, '19/08/2002', 6);
INSERT INTO valoracions VALUES (3997, 104, '25/03/2008', 2);
INSERT INTO valoracions VALUES (3997, 50, '24/12/2007', 7);
INSERT INTO valoracions VALUES (3997, 3, '19/12/2006', 9);
INSERT INTO valoracions VALUES (3998, 91, '12/12/2006', 6);
INSERT INTO valoracions VALUES (3998, 31, '16/07/2003', 6);
INSERT INTO valoracions VALUES (3998, 32, '23/11/2009', 6);
INSERT INTO valoracions VALUES (3998, 78, '20/09/2001', 6);
INSERT INTO valoracions VALUES (3999, 22, '14/02/2004', 9);
INSERT INTO valoracions VALUES (4000, 116, '20/07/2001', 3);
INSERT INTO valoracions VALUES (4000, 52, '18/09/2009', 7);
INSERT INTO valoracions VALUES (4000, 8, '08/07/2002', 9);
INSERT INTO valoracions VALUES (4000, 37, '29/04/2004', 5);
INSERT INTO valoracions VALUES (4000, 61, '25/02/2008', 4);
INSERT INTO valoracions VALUES (4001, 113, '18/12/2004', 6);
INSERT INTO valoracions VALUES (4001, 115, '14/12/2005', 9);
INSERT INTO valoracions VALUES (4001, 55, '28/09/2006', 7);
INSERT INTO valoracions VALUES (4001, 20, '15/04/2003', 6);
INSERT INTO valoracions VALUES (4002, 49, '30/10/2004', 9);
INSERT INTO valoracions VALUES (4002, 86, '11/02/2009', 7);
INSERT INTO valoracions VALUES (4002, 39, '01/02/2004', 6);
INSERT INTO valoracions VALUES (4002, 102, '15/01/2008', 3);
INSERT INTO valoracions VALUES (4002, 98, '22/02/2005', 3);
INSERT INTO valoracions VALUES (4002, 86, '06/04/2004', 7);
INSERT INTO valoracions VALUES (4003, 34, '31/12/2008', 4);
INSERT INTO valoracions VALUES (4003, 71, '09/07/2007', 7);
INSERT INTO valoracions VALUES (4003, 98, '10/12/2009', 5);
INSERT INTO valoracions VALUES (4004, 69, '13/05/2004', 8);
INSERT INTO valoracions VALUES (4004, 4, '10/04/2007', 6);
INSERT INTO valoracions VALUES (4005, 47, '08/02/2008', 5);
INSERT INTO valoracions VALUES (4005, 111, '18/08/2010', 3);
INSERT INTO valoracions VALUES (4005, 2, '20/04/2007', 9);
INSERT INTO valoracions VALUES (4005, 7, '30/07/2005', 6);
INSERT INTO valoracions VALUES (4006, 15, '25/09/2004', 5);
INSERT INTO valoracions VALUES (4006, 104, '21/10/2006', 9);
INSERT INTO valoracions VALUES (4006, 82, '08/06/2009', 8);
INSERT INTO valoracions VALUES (4007, 22, '23/03/2002', 7);
INSERT INTO valoracions VALUES (4007, 60, '13/05/2004', 10);
INSERT INTO valoracions VALUES (4007, 4, '29/01/2007', 8);
INSERT INTO valoracions VALUES (4007, 3, '28/06/2007', 7);
INSERT INTO valoracions VALUES (4008, 2, '25/02/2002', 7);
INSERT INTO valoracions VALUES (4008, 86, '16/01/2003', 8);
INSERT INTO valoracions VALUES (4008, 83, '08/10/2001', 8);
INSERT INTO valoracions VALUES (4008, 105, '27/01/2009', 1);
INSERT INTO valoracions VALUES (4008, 15, '21/10/2009', 4);
INSERT INTO valoracions VALUES (4008, 26, '28/06/2003', 6);
INSERT INTO valoracions VALUES (4008, 111, '16/05/2009', 5);
INSERT INTO valoracions VALUES (4008, 5, '17/07/2002', 7);
INSERT INTO valoracions VALUES (4009, 99, '09/09/2007', 6);
INSERT INTO valoracions VALUES (4009, 25, '11/04/2004', 6);
INSERT INTO valoracions VALUES (4009, 3, '23/01/2007', 7);
INSERT INTO valoracions VALUES (4009, 94, '10/11/2006', 3);
INSERT INTO valoracions VALUES (4010, 28, '25/02/2008', 8);
INSERT INTO valoracions VALUES (4010, 107, '31/12/2001', 6);
INSERT INTO valoracions VALUES (4010, 10, '23/05/2001', 8);
INSERT INTO valoracions VALUES (4011, 106, '30/07/2003', 1);
INSERT INTO valoracions VALUES (4011, 89, '13/11/2008', 10);
INSERT INTO valoracions VALUES (4011, 103, '18/05/2005', 3);
INSERT INTO valoracions VALUES (4011, 17, '21/02/2003', 8);
INSERT INTO valoracions VALUES (4011, 63, '04/12/2003', 6);
INSERT INTO valoracions VALUES (4012, 83, '24/04/2005', 10);
INSERT INTO valoracions VALUES (4012, 66, '08/04/2007', 9);
INSERT INTO valoracions VALUES (4013, 96, '19/01/2008', 3);
INSERT INTO valoracions VALUES (4013, 72, '05/11/2003', 8);
INSERT INTO valoracions VALUES (4013, 17, '13/12/2001', 9);
INSERT INTO valoracions VALUES (4013, 52, '08/01/2005', 10);
INSERT INTO valoracions VALUES (4014, 4, '05/12/2004', 7);
INSERT INTO valoracions VALUES (4014, 55, '28/02/2004', 9);
INSERT INTO valoracions VALUES (4014, 69, '31/05/2003', 6);
INSERT INTO valoracions VALUES (4014, 4, '07/08/2008', 6);
INSERT INTO valoracions VALUES (4015, 116, '13/04/2010', 9);
INSERT INTO valoracions VALUES (4015, 9, '15/05/2007', 6);
INSERT INTO valoracions VALUES (4015, 59, '31/07/2003', 5);
INSERT INTO valoracions VALUES (4016, 62, '26/06/2001', 7);
INSERT INTO valoracions VALUES (4016, 69, '01/07/2009', 3);
INSERT INTO valoracions VALUES (4016, 33, '12/03/2009', 4);
INSERT INTO valoracions VALUES (4016, 63, '14/11/2003', 8);
INSERT INTO valoracions VALUES (4016, 107, '22/10/2002', 3);
INSERT INTO valoracions VALUES (4016, 40, '19/08/2002', 5);
INSERT INTO valoracions VALUES (4017, 67, '27/02/2010', 10);
INSERT INTO valoracions VALUES (4017, 70, '25/08/2005', 4);
INSERT INTO valoracions VALUES (4017, 41, '04/06/2009', 9);
INSERT INTO valoracions VALUES (4017, 16, '24/12/2008', 9);
INSERT INTO valoracions VALUES (4017, 22, '17/10/2002', 10);
INSERT INTO valoracions VALUES (4017, 54, '10/08/2006', 6);
INSERT INTO valoracions VALUES (4018, 43, '26/04/2006', 7);
INSERT INTO valoracions VALUES (4019, 55, '14/03/2005', 5);
INSERT INTO valoracions VALUES (4019, 11, '10/10/2008', 8);
INSERT INTO valoracions VALUES (4019, 40, '28/01/2003', 7);
INSERT INTO valoracions VALUES (4019, 44, '01/11/2004', 8);
INSERT INTO valoracions VALUES (4019, 99, '30/03/2004', 7);
INSERT INTO valoracions VALUES (4019, 4, '05/10/2009', 9);
INSERT INTO valoracions VALUES (4021, 67, '23/02/2002', 2);
INSERT INTO valoracions VALUES (4021, 70, '14/06/2003', 9);
INSERT INTO valoracions VALUES (4022, 1, '09/10/2004', 9);
INSERT INTO valoracions VALUES (4022, 69, '05/11/2009', 9);
INSERT INTO valoracions VALUES (4022, 50, '29/10/2010', 6);
INSERT INTO valoracions VALUES (4022, 94, '07/11/2009', 2);
INSERT INTO valoracions VALUES (4022, 1, '08/03/2002', 7);
INSERT INTO valoracions VALUES (4022, 92, '31/03/2002', 10);
INSERT INTO valoracions VALUES (4022, 66, '20/03/2008', 3);
INSERT INTO valoracions VALUES (4022, 88, '25/08/2002', 6);
INSERT INTO valoracions VALUES (4022, 1, '27/04/2007', 10);
INSERT INTO valoracions VALUES (4023, 22, '11/02/2004', 10);
INSERT INTO valoracions VALUES (4023, 76, '15/05/2007', 4);
INSERT INTO valoracions VALUES (4023, 19, '28/08/2002', 7);
INSERT INTO valoracions VALUES (4023, 6, '12/01/2003', 8);
INSERT INTO valoracions VALUES (4023, 82, '16/05/2006', 10);
INSERT INTO valoracions VALUES (4023, 28, '22/10/2009', 10);
INSERT INTO valoracions VALUES (4024, 12, '28/01/2005', 9);
INSERT INTO valoracions VALUES (4025, 5, '04/09/2008', 8);
INSERT INTO valoracions VALUES (4025, 74, '06/03/2005', 8);
INSERT INTO valoracions VALUES (4025, 116, '15/12/2005', 8);
INSERT INTO valoracions VALUES (4025, 12, '10/05/2001', 6);
INSERT INTO valoracions VALUES (4025, 41, '15/04/2008', 5);
INSERT INTO valoracions VALUES (4026, 108, '05/05/2006', 6);
INSERT INTO valoracions VALUES (4026, 46, '28/05/2003', 8);
INSERT INTO valoracions VALUES (4026, 104, '03/02/2008', 2);
INSERT INTO valoracions VALUES (4026, 66, '21/09/2010', 7);
INSERT INTO valoracions VALUES (4027, 35, '09/06/2002', 7);
INSERT INTO valoracions VALUES (4027, 24, '02/10/2007', 6);
INSERT INTO valoracions VALUES (4027, 20, '13/11/2009', 5);
INSERT INTO valoracions VALUES (4028, 95, '15/09/2002', 9);
INSERT INTO valoracions VALUES (4028, 112, '30/10/2009', 0);
INSERT INTO valoracions VALUES (4028, 3, '09/09/2008', 6);
INSERT INTO valoracions VALUES (4028, 74, '01/10/2003', 10);
INSERT INTO valoracions VALUES (4028, 74, '13/10/2001', 3);
INSERT INTO valoracions VALUES (4028, 48, '02/09/2003', 7);
INSERT INTO valoracions VALUES (4029, 43, '23/06/2009', 6);
INSERT INTO valoracions VALUES (4029, 40, '13/10/2002', 7);
INSERT INTO valoracions VALUES (4029, 114, '26/02/2010', 3);
INSERT INTO valoracions VALUES (4029, 4, '13/06/2009', 5);
INSERT INTO valoracions VALUES (4029, 50, '27/01/2008', 10);
INSERT INTO valoracions VALUES (4030, 96, '06/11/2001', 2);
INSERT INTO valoracions VALUES (4030, 43, '07/04/2001', 5);
INSERT INTO valoracions VALUES (4030, 11, '02/02/2005', 7);
INSERT INTO valoracions VALUES (4030, 102, '20/01/2006', 3);
INSERT INTO valoracions VALUES (4030, 57, '21/09/2001', 6);
INSERT INTO valoracions VALUES (4031, 60, '03/04/2001', 3);
INSERT INTO valoracions VALUES (4031, 56, '25/12/2009', 6);
INSERT INTO valoracions VALUES (4032, 48, '22/07/2002', 5);
INSERT INTO valoracions VALUES (4032, 6, '19/03/2004', 7);
INSERT INTO valoracions VALUES (4032, 88, '30/05/2003', 3);
INSERT INTO valoracions VALUES (4033, 21, '29/07/2008', 9);
INSERT INTO valoracions VALUES (4033, 45, '16/02/2010', 6);
INSERT INTO valoracions VALUES (4033, 57, '17/08/2010', 7);
INSERT INTO valoracions VALUES (4033, 54, '15/01/2009', 9);
INSERT INTO valoracions VALUES (4033, 15, '16/03/2009', 6);
INSERT INTO valoracions VALUES (4033, 6, '03/06/2009', 10);
INSERT INTO valoracions VALUES (4034, 30, '10/10/2001', 4);
INSERT INTO valoracions VALUES (4034, 1, '10/04/2001', 10);
INSERT INTO valoracions VALUES (4034, 27, '23/02/2007', 6);
INSERT INTO valoracions VALUES (4035, 60, '23/10/2007', 5);
INSERT INTO valoracions VALUES (4035, 15, '25/04/2008', 10);
INSERT INTO valoracions VALUES (4035, 51, '23/04/2007', 5);
INSERT INTO valoracions VALUES (4035, 18, '16/05/2005', 4);
INSERT INTO valoracions VALUES (4035, 30, '03/10/2005', 9);
INSERT INTO valoracions VALUES (4036, 78, '31/10/2005', 4);
INSERT INTO valoracions VALUES (4036, 21, '23/10/2002', 8);
INSERT INTO valoracions VALUES (4036, 53, '21/02/2003', 9);
INSERT INTO valoracions VALUES (4036, 74, '04/05/2006', 7);
INSERT INTO valoracions VALUES (4036, 4, '18/12/2004', 9);
INSERT INTO valoracions VALUES (4036, 83, '18/12/2001', 2);
INSERT INTO valoracions VALUES (4036, 72, '02/10/2003', 4);
INSERT INTO valoracions VALUES (4037, 109, '09/12/2003', 7);
INSERT INTO valoracions VALUES (4037, 101, '12/09/2005', 2);
INSERT INTO valoracions VALUES (4038, 4, '19/11/2009', 6);
INSERT INTO valoracions VALUES (4038, 29, '12/02/2002', 8);
INSERT INTO valoracions VALUES (4038, 63, '27/08/2009', 8);
INSERT INTO valoracions VALUES (4039, 8, '13/10/2009', 7);
INSERT INTO valoracions VALUES (4039, 86, '20/04/2003', 2);
INSERT INTO valoracions VALUES (4039, 2, '27/07/2008', 6);
INSERT INTO valoracions VALUES (4039, 107, '24/06/2002', 0);
INSERT INTO valoracions VALUES (4040, 95, '25/08/2009', 4);
INSERT INTO valoracions VALUES (4040, 58, '21/02/2002', 8);
INSERT INTO valoracions VALUES (4041, 53, '21/03/2003', 6);
INSERT INTO valoracions VALUES (4041, 90, '17/05/2009', 6);
INSERT INTO valoracions VALUES (4041, 34, '20/08/2009', 6);
INSERT INTO valoracions VALUES (4042, 86, '17/08/2009', 8);
INSERT INTO valoracions VALUES (4042, 58, '30/11/2004', 4);
INSERT INTO valoracions VALUES (4042, 97, '12/03/2006', 9);
INSERT INTO valoracions VALUES (4043, 20, '10/05/2001', 6);
INSERT INTO valoracions VALUES (4043, 61, '19/11/2009', 9);
INSERT INTO valoracions VALUES (4043, 84, '26/11/2009', 5);
INSERT INTO valoracions VALUES (4043, 47, '21/06/2006', 9);
INSERT INTO valoracions VALUES (4043, 70, '29/10/2002', 6);
INSERT INTO valoracions VALUES (4044, 75, '25/05/2007', 10);
INSERT INTO valoracions VALUES (4044, 58, '04/11/2001', 6);
INSERT INTO valoracions VALUES (4045, 70, '26/07/2007', 3);
INSERT INTO valoracions VALUES (4045, 82, '22/01/2002', 5);
INSERT INTO valoracions VALUES (4046, 110, '03/02/2002', 5);
INSERT INTO valoracions VALUES (4046, 50, '18/12/2003', 3);
INSERT INTO valoracions VALUES (4046, 111, '08/04/2005', 6);
INSERT INTO valoracions VALUES (4046, 114, '26/02/2009', 1);
INSERT INTO valoracions VALUES (4046, 81, '02/06/2001', 5);
INSERT INTO valoracions VALUES (4047, 23, '21/10/2003', 5);
INSERT INTO valoracions VALUES (4048, 72, '17/12/2001', 9);
INSERT INTO valoracions VALUES (4048, 115, '12/06/2003', 8);
INSERT INTO valoracions VALUES (4048, 101, '09/06/2001', 1);
INSERT INTO valoracions VALUES (4048, 103, '31/12/2007', 2);
INSERT INTO valoracions VALUES (4048, 61, '12/10/2008', 8);
INSERT INTO valoracions VALUES (4049, 39, '03/07/2004', 4);
INSERT INTO valoracions VALUES (4049, 107, '26/03/2008', 10);
INSERT INTO valoracions VALUES (4049, 35, '30/09/2001', 4);
INSERT INTO valoracions VALUES (4050, 32, '28/11/2008', 10);
INSERT INTO valoracions VALUES (4050, 19, '21/03/2008', 5);
INSERT INTO valoracions VALUES (4051, 58, '17/10/2001', 5);
INSERT INTO valoracions VALUES (4051, 26, '28/07/2001', 6);
INSERT INTO valoracions VALUES (4051, 1, '27/02/2007', 9);
INSERT INTO valoracions VALUES (4051, 24, '16/07/2010', 4);
INSERT INTO valoracions VALUES (4053, 56, '27/04/2002', 3);
INSERT INTO valoracions VALUES (4053, 9, '13/09/2007', 8);
INSERT INTO valoracions VALUES (4053, 78, '30/07/2007', 7);
INSERT INTO valoracions VALUES (4054, 20, '03/04/2001', 5);
INSERT INTO valoracions VALUES (4054, 2, '08/05/2009', 9);
INSERT INTO valoracions VALUES (4054, 70, '08/01/2009', 3);
INSERT INTO valoracions VALUES (4054, 73, '31/01/2005', 6);
INSERT INTO valoracions VALUES (4054, 85, '05/04/2001', 8);
INSERT INTO valoracions VALUES (4055, 17, '19/09/2010', 7);
INSERT INTO valoracions VALUES (4055, 57, '28/06/2007', 10);
INSERT INTO valoracions VALUES (4055, 112, '11/01/2005', 6);
INSERT INTO valoracions VALUES (4055, 69, '14/02/2007', 8);
INSERT INTO valoracions VALUES (4055, 23, '27/05/2009', 8);
INSERT INTO valoracions VALUES (4055, 20, '03/04/2004', 8);
INSERT INTO valoracions VALUES (4055, 1, '14/02/2006', 8);
INSERT INTO valoracions VALUES (4055, 92, '04/07/2005', 2);
INSERT INTO valoracions VALUES (4056, 55, '28/08/2009', 6);
INSERT INTO valoracions VALUES (4056, 18, '22/10/2009', 4);
INSERT INTO valoracions VALUES (4057, 62, '08/04/2001', 7);
INSERT INTO valoracions VALUES (4057, 116, '07/02/2002', 6);
INSERT INTO valoracions VALUES (4057, 2, '29/01/2003', 9);
INSERT INTO valoracions VALUES (4057, 91, '23/12/2006', 5);
INSERT INTO valoracions VALUES (4057, 19, '16/12/2005', 9);
INSERT INTO valoracions VALUES (4058, 100, '08/06/2001', 10);
INSERT INTO valoracions VALUES (4058, 60, '28/09/2002', 9);
INSERT INTO valoracions VALUES (4059, 29, '09/08/2006', 10);
INSERT INTO valoracions VALUES (4059, 63, '14/07/2003', 8);
INSERT INTO valoracions VALUES (4059, 44, '12/04/2004', 6);
INSERT INTO valoracions VALUES (4060, 24, '12/06/2001', 6);
INSERT INTO valoracions VALUES (4060, 3, '20/01/2003', 5);
INSERT INTO valoracions VALUES (4060, 35, '17/01/2009', 6);
INSERT INTO valoracions VALUES (4060, 109, '01/01/2004', 2);
INSERT INTO valoracions VALUES (4061, 67, '06/01/2002', 9);
INSERT INTO valoracions VALUES (4061, 114, '20/01/2010', 1);
INSERT INTO valoracions VALUES (4061, 51, '02/10/2010', 7);
INSERT INTO valoracions VALUES (4062, 46, '21/08/2005', 4);
INSERT INTO valoracions VALUES (4062, 44, '15/04/2003', 8);
INSERT INTO valoracions VALUES (4062, 25, '24/10/2002', 9);
INSERT INTO valoracions VALUES (4063, 47, '09/05/2001', 3);
INSERT INTO valoracions VALUES (4063, 17, '06/09/2008', 4);
INSERT INTO valoracions VALUES (4063, 23, '22/02/2006', 5);
INSERT INTO valoracions VALUES (4063, 21, '29/12/2008', 9);
INSERT INTO valoracions VALUES (4063, 99, '18/03/2002', 9);
INSERT INTO valoracions VALUES (4064, 77, '13/06/2006', 9);
INSERT INTO valoracions VALUES (4064, 11, '03/12/2005', 8);
INSERT INTO valoracions VALUES (4064, 93, '03/06/2007', 2);
INSERT INTO valoracions VALUES (4064, 56, '02/09/2009', 7);
INSERT INTO valoracions VALUES (4064, 18, '20/06/2005', 5);
INSERT INTO valoracions VALUES (4065, 34, '20/12/2009', 4);
INSERT INTO valoracions VALUES (4066, 60, '30/06/2005', 7);
INSERT INTO valoracions VALUES (4066, 90, '14/04/2006', 4);
INSERT INTO valoracions VALUES (4066, 69, '24/02/2003', 4);
INSERT INTO valoracions VALUES (4066, 97, '24/12/2002', 5);
INSERT INTO valoracions VALUES (4067, 13, '13/05/2007', 6);
INSERT INTO valoracions VALUES (4068, 64, '25/10/2006', 5);
INSERT INTO valoracions VALUES (4068, 22, '14/03/2009', 8);
INSERT INTO valoracions VALUES (4068, 96, '29/06/2002', 5);
INSERT INTO valoracions VALUES (4068, 42, '21/11/2003', 9);
INSERT INTO valoracions VALUES (4069, 15, '31/05/2006', 6);
INSERT INTO valoracions VALUES (4069, 114, '12/03/2009', 10);
INSERT INTO valoracions VALUES (4069, 3, '03/06/2004', 6);
INSERT INTO valoracions VALUES (4070, 69, '30/05/2005', 8);
INSERT INTO valoracions VALUES (4070, 72, '02/02/2002', 3);
INSERT INTO valoracions VALUES (4070, 107, '14/02/2004', 9);
INSERT INTO valoracions VALUES (4070, 98, '03/09/2009', 4);
INSERT INTO valoracions VALUES (4070, 91, '22/03/2002', 2);
INSERT INTO valoracions VALUES (4070, 43, '21/12/2002', 5);
INSERT INTO valoracions VALUES (4071, 71, '03/02/2005', 5);
INSERT INTO valoracions VALUES (4071, 94, '05/11/2002', 4);
INSERT INTO valoracions VALUES (4071, 50, '17/02/2005', 4);
INSERT INTO valoracions VALUES (4072, 103, '10/04/2001', 7);
INSERT INTO valoracions VALUES (4072, 27, '10/12/2003', 6);
INSERT INTO valoracions VALUES (4072, 71, '28/03/2006', 9);
INSERT INTO valoracions VALUES (4072, 36, '30/04/2006', 6);
INSERT INTO valoracions VALUES (4072, 38, '13/05/2004', 10);
INSERT INTO valoracions VALUES (4072, 3, '10/04/2009', 10);
INSERT INTO valoracions VALUES (4073, 33, '10/09/2004', 5);
INSERT INTO valoracions VALUES (4073, 97, '02/12/2008', 5);
INSERT INTO valoracions VALUES (4073, 113, '24/02/2009', 7);
INSERT INTO valoracions VALUES (4073, 74, '12/04/2009', 8);
INSERT INTO valoracions VALUES (4073, 64, '24/12/2002', 10);
INSERT INTO valoracions VALUES (4073, 103, '10/03/2007', 6);
INSERT INTO valoracions VALUES (4073, 30, '18/07/2003', 5);
INSERT INTO valoracions VALUES (4074, 38, '16/11/2001', 6);
INSERT INTO valoracions VALUES (4074, 61, '30/12/2005', 5);
INSERT INTO valoracions VALUES (4074, 26, '08/12/2002', 5);
INSERT INTO valoracions VALUES (4074, 54, '22/07/2006', 5);
INSERT INTO valoracions VALUES (4074, 14, '23/01/2010', 8);
INSERT INTO valoracions VALUES (4074, 56, '09/02/2007', 6);
INSERT INTO valoracions VALUES (4075, 70, '12/03/2004', 6);
INSERT INTO valoracions VALUES (4075, 17, '10/10/2002', 8);
INSERT INTO valoracions VALUES (4075, 15, '19/10/2001', 7);
INSERT INTO valoracions VALUES (4075, 21, '21/03/2007', 9);
INSERT INTO valoracions VALUES (4076, 103, '08/02/2002', 4);
INSERT INTO valoracions VALUES (4076, 66, '06/11/2007', 9);
INSERT INTO valoracions VALUES (4076, 115, '04/06/2010', 3);
INSERT INTO valoracions VALUES (4077, 42, '24/05/2002', 9);
INSERT INTO valoracions VALUES (4077, 88, '21/10/2009', 7);
INSERT INTO valoracions VALUES (4078, 9, '20/05/2006', 6);
INSERT INTO valoracions VALUES (4078, 65, '18/05/2010', 10);
INSERT INTO valoracions VALUES (4078, 61, '22/05/2001', 7);
INSERT INTO valoracions VALUES (4078, 45, '29/12/2003', 4);
INSERT INTO valoracions VALUES (4079, 13, '09/07/2007', 9);
INSERT INTO valoracions VALUES (4079, 18, '21/01/2006', 5);
INSERT INTO valoracions VALUES (4079, 38, '29/05/2009', 8);
INSERT INTO valoracions VALUES (4080, 73, '27/12/2007', 8);
INSERT INTO valoracions VALUES (4081, 105, '16/03/2007', 9);
INSERT INTO valoracions VALUES (4081, 48, '24/09/2002', 9);
INSERT INTO valoracions VALUES (4081, 69, '13/01/2004', 3);
INSERT INTO valoracions VALUES (4082, 95, '02/07/2007', 5);
INSERT INTO valoracions VALUES (4082, 101, '07/05/2009', 4);
INSERT INTO valoracions VALUES (4082, 59, '16/02/2002', 9);
INSERT INTO valoracions VALUES (4082, 46, '03/04/2004', 9);
INSERT INTO valoracions VALUES (4082, 61, '30/09/2001', 3);
INSERT INTO valoracions VALUES (4083, 48, '29/11/2003', 7);
INSERT INTO valoracions VALUES (4083, 9, '14/03/2008', 8);
INSERT INTO valoracions VALUES (4083, 62, '09/09/2005', 4);
INSERT INTO valoracions VALUES (4084, 94, '27/03/2003', 4);
INSERT INTO valoracions VALUES (4084, 17, '02/09/2009', 5);
INSERT INTO valoracions VALUES (4084, 34, '16/10/2007', 6);
INSERT INTO valoracions VALUES (4084, 107, '26/12/2008', 5);
INSERT INTO valoracions VALUES (4084, 40, '09/01/2004', 10);
INSERT INTO valoracions VALUES (4084, 22, '22/06/2007', 7);
INSERT INTO valoracions VALUES (4084, 92, '28/03/2007', 5);
INSERT INTO valoracions VALUES (4085, 95, '24/12/2009', 7);
INSERT INTO valoracions VALUES (4085, 3, '08/10/2008', 5);
INSERT INTO valoracions VALUES (4085, 89, '22/06/2002', 3);
INSERT INTO valoracions VALUES (4086, 80, '15/04/2008', 9);
INSERT INTO valoracions VALUES (4086, 43, '13/07/2004', 7);
INSERT INTO valoracions VALUES (4086, 55, '30/10/2002', 6);
INSERT INTO valoracions VALUES (4086, 51, '31/07/2007', 6);
INSERT INTO valoracions VALUES (4086, 87, '29/10/2001', 2);
INSERT INTO valoracions VALUES (4087, 21, '16/03/2006', 8);
INSERT INTO valoracions VALUES (4087, 36, '28/08/2009', 4);
INSERT INTO valoracions VALUES (4087, 76, '08/05/2001', 8);
INSERT INTO valoracions VALUES (4087, 68, '06/01/2007', 3);
INSERT INTO valoracions VALUES (4088, 63, '29/07/2004', 3);
INSERT INTO valoracions VALUES (4088, 86, '04/06/2005', 7);
INSERT INTO valoracions VALUES (4088, 79, '04/08/2005', 3);
INSERT INTO valoracions VALUES (4088, 32, '22/01/2010', 7);
INSERT INTO valoracions VALUES (4088, 4, '16/05/2004', 6);
INSERT INTO valoracions VALUES (4088, 8, '14/02/2009', 7);
INSERT INTO valoracions VALUES (4089, 59, '01/04/2008', 7);
INSERT INTO valoracions VALUES (4089, 94, '15/11/2005', 7);
INSERT INTO valoracions VALUES (4089, 108, '27/12/2001', 7);
INSERT INTO valoracions VALUES (4090, 4, '21/10/2009', 5);
INSERT INTO valoracions VALUES (4090, 82, '25/05/2010', 4);
INSERT INTO valoracions VALUES (4090, 16, '09/06/2006', 9);
INSERT INTO valoracions VALUES (4090, 73, '21/07/2009', 4);
INSERT INTO valoracions VALUES (4090, 77, '01/07/2005', 6);
INSERT INTO valoracions VALUES (4090, 32, '17/06/2010', 7);
INSERT INTO valoracions VALUES (4091, 11, '17/08/2006', 9);
INSERT INTO valoracions VALUES (4091, 96, '08/09/2001', 6);
INSERT INTO valoracions VALUES (4091, 60, '17/11/2006', 10);
INSERT INTO valoracions VALUES (4092, 111, '10/03/2003', 7);
INSERT INTO valoracions VALUES (4092, 114, '06/08/2004', 5);
INSERT INTO valoracions VALUES (4092, 46, '05/06/2003', 6);
INSERT INTO valoracions VALUES (4093, 112, '07/01/2005', 6);
INSERT INTO valoracions VALUES (4093, 79, '29/01/2010', 8);
INSERT INTO valoracions VALUES (4093, 35, '09/09/2008', 4);
INSERT INTO valoracions VALUES (4093, 76, '20/07/2005', 7);
INSERT INTO valoracions VALUES (4093, 56, '21/06/2009', 6);
INSERT INTO valoracions VALUES (4094, 97, '01/05/2006', 3);
INSERT INTO valoracions VALUES (4094, 25, '16/06/2006', 7);
INSERT INTO valoracions VALUES (4095, 116, '12/12/2005', 3);
INSERT INTO valoracions VALUES (4095, 30, '11/11/2009', 5);
INSERT INTO valoracions VALUES (4095, 69, '03/01/2002', 9);
INSERT INTO valoracions VALUES (4095, 64, '12/05/2003', 4);
INSERT INTO valoracions VALUES (4095, 75, '20/11/2009', 3);
INSERT INTO valoracions VALUES (4095, 30, '17/12/2008', 9);
INSERT INTO valoracions VALUES (4095, 34, '02/02/2009', 10);
INSERT INTO valoracions VALUES (4095, 19, '06/03/2005', 4);
INSERT INTO valoracions VALUES (4096, 72, '13/12/2002', 10);
INSERT INTO valoracions VALUES (4096, 22, '15/04/2008', 4);
INSERT INTO valoracions VALUES (4096, 22, '29/09/2008', 9);
INSERT INTO valoracions VALUES (4096, 76, '25/12/2004', 8);
INSERT INTO valoracions VALUES (4097, 115, '23/03/2002', 3);
INSERT INTO valoracions VALUES (4097, 108, '09/12/2005', 1);
INSERT INTO valoracions VALUES (4097, 3, '25/03/2009', 9);
INSERT INTO valoracions VALUES (4097, 59, '26/08/2004', 5);
INSERT INTO valoracions VALUES (4097, 13, '12/11/2004', 5);
INSERT INTO valoracions VALUES (4098, 101, '27/08/2010', 3);
INSERT INTO valoracions VALUES (4098, 108, '03/01/2008', 6);
INSERT INTO valoracions VALUES (4098, 18, '21/04/2002', 6);
INSERT INTO valoracions VALUES (4098, 67, '06/05/2006', 6);
INSERT INTO valoracions VALUES (4098, 5, '16/07/2010', 7);
INSERT INTO valoracions VALUES (4099, 50, '08/01/2007', 6);
INSERT INTO valoracions VALUES (4099, 106, '20/11/2005', 0);
INSERT INTO valoracions VALUES (4099, 39, '20/01/2008', 7);
INSERT INTO valoracions VALUES (4099, 104, '13/08/2002', 7);
INSERT INTO valoracions VALUES (4100, 63, '02/06/2007', 5);
INSERT INTO valoracions VALUES (4100, 106, '21/03/2003', 6);
INSERT INTO valoracions VALUES (4101, 37, '04/12/2002', 7);
INSERT INTO valoracions VALUES (4101, 114, '27/10/2009', 2);
INSERT INTO valoracions VALUES (4101, 95, '23/09/2004', 4);
INSERT INTO valoracions VALUES (4102, 81, '03/07/2009', 2);
INSERT INTO valoracions VALUES (4102, 20, '10/11/2004', 5);
INSERT INTO valoracions VALUES (4102, 1, '29/10/2003', 8);
INSERT INTO valoracions VALUES (4103, 30, '25/07/2002', 9);
INSERT INTO valoracions VALUES (4103, 6, '09/02/2008', 7);
INSERT INTO valoracions VALUES (4104, 65, '04/11/2006', 5);
INSERT INTO valoracions VALUES (4104, 27, '29/01/2009', 9);
INSERT INTO valoracions VALUES (4104, 95, '19/06/2010', 5);
INSERT INTO valoracions VALUES (4104, 92, '30/06/2006', 3);
INSERT INTO valoracions VALUES (4104, 72, '13/12/2007', 4);
INSERT INTO valoracions VALUES (4104, 106, '19/05/2004', 6);
INSERT INTO valoracions VALUES (4104, 72, '05/07/2001', 5);
INSERT INTO valoracions VALUES (4104, 115, '04/01/2005', 9);
INSERT INTO valoracions VALUES (4105, 94, '24/05/2004', 8);
INSERT INTO valoracions VALUES (4105, 114, '27/10/2009', 6);
INSERT INTO valoracions VALUES (4105, 99, '08/02/2007', 4);
INSERT INTO valoracions VALUES (4105, 37, '20/10/2002', 6);
INSERT INTO valoracions VALUES (4106, 76, '11/06/2005', 3);
INSERT INTO valoracions VALUES (4106, 50, '24/10/2002', 9);
INSERT INTO valoracions VALUES (4106, 21, '16/02/2004', 5);
INSERT INTO valoracions VALUES (4106, 50, '24/09/2005', 9);
INSERT INTO valoracions VALUES (4106, 10, '06/03/2004', 7);
INSERT INTO valoracions VALUES (4106, 97, '03/08/2003', 5);
INSERT INTO valoracions VALUES (4106, 60, '18/02/2008', 3);
INSERT INTO valoracions VALUES (4106, 71, '25/10/2008', 6);
INSERT INTO valoracions VALUES (4107, 90, '12/11/2004', 6);
INSERT INTO valoracions VALUES (4107, 4, '11/04/2006', 5);
INSERT INTO valoracions VALUES (4107, 21, '06/12/2002', 10);
INSERT INTO valoracions VALUES (4107, 113, '10/02/2003', 2);
INSERT INTO valoracions VALUES (4108, 59, '01/06/2007', 9);
INSERT INTO valoracions VALUES (4108, 17, '26/08/2006', 5);
INSERT INTO valoracions VALUES (4108, 101, '02/09/2007', 8);
INSERT INTO valoracions VALUES (4108, 80, '21/07/2008', 2);
INSERT INTO valoracions VALUES (4108, 88, '21/09/2003', 5);
INSERT INTO valoracions VALUES (4108, 91, '31/05/2008', 8);
INSERT INTO valoracions VALUES (4109, 88, '29/07/2004', 7);
INSERT INTO valoracions VALUES (4109, 94, '27/01/2002', 6);
INSERT INTO valoracions VALUES (4109, 70, '25/06/2009', 4);
INSERT INTO valoracions VALUES (4109, 108, '03/08/2007', 0);
INSERT INTO valoracions VALUES (4109, 115, '15/11/2003', 3);
INSERT INTO valoracions VALUES (4110, 42, '13/06/2007', 9);
INSERT INTO valoracions VALUES (4110, 80, '25/09/2007', 2);
INSERT INTO valoracions VALUES (4110, 51, '13/10/2001', 9);
INSERT INTO valoracions VALUES (4110, 36, '23/08/2007', 9);
INSERT INTO valoracions VALUES (4110, 40, '11/01/2008', 7);
INSERT INTO valoracions VALUES (4111, 47, '23/01/2005', 3);
INSERT INTO valoracions VALUES (4111, 79, '05/05/2003', 10);
INSERT INTO valoracions VALUES (4112, 32, '15/10/2001', 5);
INSERT INTO valoracions VALUES (4112, 81, '14/08/2005', 8);
INSERT INTO valoracions VALUES (4112, 70, '17/01/2008', 3);
INSERT INTO valoracions VALUES (4112, 49, '03/01/2003', 6);
INSERT INTO valoracions VALUES (4112, 109, '23/07/2004', 9);
INSERT INTO valoracions VALUES (4113, 86, '24/11/2009', 6);
INSERT INTO valoracions VALUES (4113, 32, '06/01/2002', 6);
INSERT INTO valoracions VALUES (4113, 76, '03/10/2002', 6);
INSERT INTO valoracions VALUES (4113, 112, '06/08/2006', 7);
INSERT INTO valoracions VALUES (4113, 24, '01/03/2005', 6);
INSERT INTO valoracions VALUES (4113, 18, '25/10/2004', 9);
INSERT INTO valoracions VALUES (4113, 91, '20/06/2001', 9);
INSERT INTO valoracions VALUES (4114, 7, '05/01/2003', 5);
INSERT INTO valoracions VALUES (4115, 74, '19/06/2005', 10);
INSERT INTO valoracions VALUES (4115, 6, '29/01/2010', 7);
INSERT INTO valoracions VALUES (4115, 16, '09/07/2001', 6);
INSERT INTO valoracions VALUES (4115, 77, '15/06/2004', 9);
INSERT INTO valoracions VALUES (4115, 15, '23/02/2007', 5);
INSERT INTO valoracions VALUES (4115, 111, '23/10/2002', 0);
INSERT INTO valoracions VALUES (4115, 101, '01/06/2007', 5);
INSERT INTO valoracions VALUES (4116, 3, '14/11/2007', 6);
INSERT INTO valoracions VALUES (4116, 30, '10/05/2003', 8);
INSERT INTO valoracions VALUES (4117, 83, '20/08/2001', 1);
INSERT INTO valoracions VALUES (4118, 86, '26/11/2001', 7);
INSERT INTO valoracions VALUES (4118, 30, '24/05/2003', 5);
INSERT INTO valoracions VALUES (4118, 46, '05/10/2001', 5);
INSERT INTO valoracions VALUES (4119, 115, '28/08/2009', 0);
INSERT INTO valoracions VALUES (4119, 39, '01/03/2010', 9);
INSERT INTO valoracions VALUES (4120, 27, '17/01/2008', 5);
INSERT INTO valoracions VALUES (4120, 42, '26/01/2003', 7);
INSERT INTO valoracions VALUES (4120, 109, '21/07/2008', 3);
INSERT INTO valoracions VALUES (4122, 8, '27/03/2007', 8);
INSERT INTO valoracions VALUES (4122, 28, '15/03/2004', 9);
INSERT INTO valoracions VALUES (4123, 9, '19/03/2008', 9);
INSERT INTO valoracions VALUES (4123, 22, '21/12/2003', 9);
INSERT INTO valoracions VALUES (4123, 75, '09/08/2010', 8);
INSERT INTO valoracions VALUES (4123, 39, '07/12/2007', 4);
INSERT INTO valoracions VALUES (4124, 80, '04/11/2003', 6);
INSERT INTO valoracions VALUES (4124, 35, '17/12/2003', 9);
INSERT INTO valoracions VALUES (4124, 36, '12/09/2003', 8);
INSERT INTO valoracions VALUES (4124, 53, '03/03/2004', 6);
INSERT INTO valoracions VALUES (4124, 86, '01/09/2001', 4);
INSERT INTO valoracions VALUES (4125, 62, '22/05/2008', 5);
INSERT INTO valoracions VALUES (4125, 46, '17/08/2003', 5);
INSERT INTO valoracions VALUES (4125, 20, '06/09/2003', 9);
INSERT INTO valoracions VALUES (4125, 5, '30/04/2010', 7);
INSERT INTO valoracions VALUES (4126, 2, '12/03/2004', 8);
INSERT INTO valoracions VALUES (4126, 73, '16/07/2006', 3);
INSERT INTO valoracions VALUES (4126, 18, '08/04/2006', 7);
INSERT INTO valoracions VALUES (4126, 26, '19/03/2003', 9);
INSERT INTO valoracions VALUES (4127, 64, '02/01/2010', 8);
INSERT INTO valoracions VALUES (4127, 64, '12/05/2010', 6);
INSERT INTO valoracions VALUES (4128, 56, '30/01/2008', 3);
INSERT INTO valoracions VALUES (4129, 6, '20/09/2009', 5);
INSERT INTO valoracions VALUES (4129, 67, '06/12/2008', 8);
INSERT INTO valoracions VALUES (4129, 76, '14/09/2002', 3);
INSERT INTO valoracions VALUES (4129, 65, '09/06/2006', 3);
INSERT INTO valoracions VALUES (4129, 48, '27/04/2009', 4);
INSERT INTO valoracions VALUES (4129, 51, '06/08/2001', 6);
INSERT INTO valoracions VALUES (4130, 73, '29/04/2007', 3);
INSERT INTO valoracions VALUES (4130, 38, '01/10/2005', 7);
INSERT INTO valoracions VALUES (4130, 35, '08/06/2006', 5);
INSERT INTO valoracions VALUES (4130, 35, '12/08/2005', 9);
INSERT INTO valoracions VALUES (4131, 41, '19/08/2001', 5);
INSERT INTO valoracions VALUES (4132, 42, '10/07/2002', 9);
INSERT INTO valoracions VALUES (4132, 19, '17/07/2006', 8);
INSERT INTO valoracions VALUES (4133, 15, '12/02/2003', 9);
INSERT INTO valoracions VALUES (4133, 80, '24/07/2007', 7);
INSERT INTO valoracions VALUES (4133, 72, '03/06/2004', 7);
INSERT INTO valoracions VALUES (4134, 66, '05/09/2008', 8);
INSERT INTO valoracions VALUES (4134, 85, '09/07/2008', 5);
INSERT INTO valoracions VALUES (4134, 81, '21/06/2009', 7);
INSERT INTO valoracions VALUES (4135, 97, '09/03/2003', 9);
INSERT INTO valoracions VALUES (4135, 67, '13/03/2007', 3);
INSERT INTO valoracions VALUES (4135, 38, '29/05/2006', 10);
INSERT INTO valoracions VALUES (4136, 48, '05/08/2002', 4);
INSERT INTO valoracions VALUES (4136, 97, '12/09/2006', 7);
INSERT INTO valoracions VALUES (4137, 58, '26/12/2008', 9);
INSERT INTO valoracions VALUES (4138, 17, '07/09/2001', 4);
INSERT INTO valoracions VALUES (4138, 14, '08/01/2007', 8);
INSERT INTO valoracions VALUES (4139, 113, '10/06/2009', 8);
INSERT INTO valoracions VALUES (4139, 96, '06/07/2009', 5);
INSERT INTO valoracions VALUES (4139, 30, '07/04/2005', 4);
INSERT INTO valoracions VALUES (4139, 115, '13/11/2008', 8);
INSERT INTO valoracions VALUES (4140, 36, '16/03/2010', 9);
INSERT INTO valoracions VALUES (4140, 108, '07/05/2007', 4);
INSERT INTO valoracions VALUES (4140, 51, '12/12/2004', 6);
INSERT INTO valoracions VALUES (4140, 59, '29/04/2010', 5);
INSERT INTO valoracions VALUES (4141, 36, '20/06/2010', 5);
INSERT INTO valoracions VALUES (4141, 103, '01/05/2007', 10);
INSERT INTO valoracions VALUES (4142, 50, '15/12/2009', 6);
INSERT INTO valoracions VALUES (4142, 109, '26/02/2010', 1);
INSERT INTO valoracions VALUES (4142, 77, '05/09/2010', 6);
INSERT INTO valoracions VALUES (4143, 49, '26/11/2009', 9);
INSERT INTO valoracions VALUES (4143, 84, '15/03/2007', 7);
INSERT INTO valoracions VALUES (4143, 109, '08/03/2007', 8);
INSERT INTO valoracions VALUES (4143, 56, '18/04/2010', 9);
INSERT INTO valoracions VALUES (4143, 35, '20/07/2002', 4);
INSERT INTO valoracions VALUES (4144, 82, '19/02/2008', 8);
INSERT INTO valoracions VALUES (4144, 58, '24/09/2003', 8);
INSERT INTO valoracions VALUES (4144, 72, '10/03/2007', 3);
INSERT INTO valoracions VALUES (4144, 16, '28/04/2001', 4);
INSERT INTO valoracions VALUES (4144, 68, '17/10/2001', 7);
INSERT INTO valoracions VALUES (4144, 61, '22/06/2003', 8);
INSERT INTO valoracions VALUES (4145, 96, '20/04/2009', 9);
INSERT INTO valoracions VALUES (4145, 63, '24/04/2004', 10);
INSERT INTO valoracions VALUES (4145, 11, '22/10/2002', 9);
INSERT INTO valoracions VALUES (4145, 93, '24/04/2003', 1);
INSERT INTO valoracions VALUES (4145, 86, '26/05/2001', 3);
INSERT INTO valoracions VALUES (4145, 69, '26/08/2009', 5);
INSERT INTO valoracions VALUES (4145, 14, '04/08/2009', 7);
INSERT INTO valoracions VALUES (4145, 47, '10/10/2002', 4);
INSERT INTO valoracions VALUES (4145, 34, '15/01/2002', 5);
INSERT INTO valoracions VALUES (4146, 42, '14/05/2009', 4);
INSERT INTO valoracions VALUES (4146, 26, '07/01/2009', 8);
INSERT INTO valoracions VALUES (4146, 88, '28/02/2007', 9);
INSERT INTO valoracions VALUES (4146, 45, '11/06/2010', 5);
INSERT INTO valoracions VALUES (4146, 53, '23/12/2003', 5);
INSERT INTO valoracions VALUES (4147, 87, '21/03/2007', 1);
INSERT INTO valoracions VALUES (4147, 79, '08/04/2008', 7);
INSERT INTO valoracions VALUES (4147, 113, '29/05/2010', 9);
INSERT INTO valoracions VALUES (4147, 78, '20/08/2004', 8);
INSERT INTO valoracions VALUES (4148, 37, '09/01/2008', 4);
INSERT INTO valoracions VALUES (4148, 108, '09/06/2008', 5);
INSERT INTO valoracions VALUES (4148, 76, '04/07/2004', 8);
INSERT INTO valoracions VALUES (4148, 36, '08/02/2004', 5);
INSERT INTO valoracions VALUES (4148, 113, '02/05/2006', 7);
INSERT INTO valoracions VALUES (4148, 66, '19/05/2004', 6);
INSERT INTO valoracions VALUES (4149, 18, '24/06/2002', 10);
INSERT INTO valoracions VALUES (4149, 59, '04/05/2004', 4);
INSERT INTO valoracions VALUES (4149, 4, '24/03/2009', 9);
INSERT INTO valoracions VALUES (4149, 61, '19/04/2007', 5);
INSERT INTO valoracions VALUES (4150, 54, '18/03/2007', 3);
INSERT INTO valoracions VALUES (4150, 58, '11/02/2010', 5);
INSERT INTO valoracions VALUES (4150, 63, '23/12/2006', 7);
INSERT INTO valoracions VALUES (4151, 75, '22/01/2009', 3);
INSERT INTO valoracions VALUES (4151, 109, '24/05/2007', 8);
INSERT INTO valoracions VALUES (4151, 36, '09/06/2008', 4);
INSERT INTO valoracions VALUES (4151, 93, '28/05/2005', 6);
INSERT INTO valoracions VALUES (4151, 55, '10/11/2008', 8);
INSERT INTO valoracions VALUES (4151, 46, '23/10/2007', 7);
INSERT INTO valoracions VALUES (4151, 33, '19/03/2005', 9);
INSERT INTO valoracions VALUES (4151, 97, '06/04/2010', 7);
INSERT INTO valoracions VALUES (4151, 68, '29/08/2005', 6);
INSERT INTO valoracions VALUES (4151, 60, '23/07/2008', 5);
INSERT INTO valoracions VALUES (4152, 95, '17/09/2006', 3);
INSERT INTO valoracions VALUES (4152, 89, '06/05/2005', 10);
INSERT INTO valoracions VALUES (4152, 26, '23/08/2009', 6);
INSERT INTO valoracions VALUES (4153, 32, '21/12/2005', 9);
INSERT INTO valoracions VALUES (4153, 98, '19/09/2005', 8);
INSERT INTO valoracions VALUES (4153, 95, '03/10/2006', 8);
INSERT INTO valoracions VALUES (4153, 93, '21/08/2004', 4);
INSERT INTO valoracions VALUES (4153, 80, '07/05/2009', 6);
INSERT INTO valoracions VALUES (4154, 82, '25/01/2005', 7);
INSERT INTO valoracions VALUES (4154, 51, '02/12/2005', 7);
INSERT INTO valoracions VALUES (4155, 57, '26/10/2002', 7);
INSERT INTO valoracions VALUES (4155, 66, '15/12/2003', 4);
INSERT INTO valoracions VALUES (4155, 87, '27/09/2008', 4);
INSERT INTO valoracions VALUES (4155, 57, '24/01/2005', 6);
INSERT INTO valoracions VALUES (4155, 21, '18/06/2001', 5);
INSERT INTO valoracions VALUES (4155, 86, '18/10/2006', 7);
INSERT INTO valoracions VALUES (4155, 50, '30/04/2001', 4);
INSERT INTO valoracions VALUES (4155, 80, '01/12/2007', 2);
INSERT INTO valoracions VALUES (4155, 38, '01/05/2010', 10);
INSERT INTO valoracions VALUES (4155, 72, '16/05/2001', 8);
INSERT INTO valoracions VALUES (4155, 18, '09/09/2006', 9);
INSERT INTO valoracions VALUES (4156, 107, '07/07/2002', 4);
INSERT INTO valoracions VALUES (4156, 31, '26/02/2010', 7);
INSERT INTO valoracions VALUES (4156, 83, '01/08/2006', 7);
INSERT INTO valoracions VALUES (4156, 73, '28/05/2009', 9);
INSERT INTO valoracions VALUES (4156, 75, '28/04/2004', 8);
INSERT INTO valoracions VALUES (4157, 57, '15/07/2006', 3);
INSERT INTO valoracions VALUES (4157, 37, '27/06/2010', 9);
INSERT INTO valoracions VALUES (4157, 91, '13/05/2006', 10);
INSERT INTO valoracions VALUES (4157, 36, '04/10/2010', 4);
INSERT INTO valoracions VALUES (4157, 27, '11/12/2004', 9);
INSERT INTO valoracions VALUES (4157, 104, '25/09/2003', 3);
INSERT INTO valoracions VALUES (4157, 28, '17/05/2009', 9);
INSERT INTO valoracions VALUES (4158, 29, '05/12/2002', 7);
INSERT INTO valoracions VALUES (4158, 107, '15/09/2006', 1);
INSERT INTO valoracions VALUES (4158, 100, '14/02/2002', 4);
INSERT INTO valoracions VALUES (4158, 101, '16/05/2002', 6);
INSERT INTO valoracions VALUES (4158, 95, '26/08/2009', 3);
INSERT INTO valoracions VALUES (4158, 69, '31/08/2010', 8);
INSERT INTO valoracions VALUES (4159, 110, '11/11/2004', 1);
INSERT INTO valoracions VALUES (4159, 68, '18/08/2007', 6);
INSERT INTO valoracions VALUES (4159, 17, '24/10/2007', 5);
INSERT INTO valoracions VALUES (4159, 72, '16/08/2006', 9);
INSERT INTO valoracions VALUES (4159, 37, '23/06/2008', 5);
INSERT INTO valoracions VALUES (4160, 99, '02/05/2004', 9);
INSERT INTO valoracions VALUES (4160, 92, '23/01/2006', 9);
INSERT INTO valoracions VALUES (4160, 53, '26/04/2008', 9);
INSERT INTO valoracions VALUES (4160, 46, '19/01/2003', 9);
INSERT INTO valoracions VALUES (4160, 23, '09/11/2007', 5);
INSERT INTO valoracions VALUES (4160, 14, '10/09/2006', 5);
INSERT INTO valoracions VALUES (4160, 70, '24/07/2006', 5);
INSERT INTO valoracions VALUES (4160, 72, '25/01/2009', 8);
INSERT INTO valoracions VALUES (4161, 69, '11/05/2010', 8);
INSERT INTO valoracions VALUES (4161, 16, '31/05/2004', 6);
INSERT INTO valoracions VALUES (4161, 50, '05/05/2007', 10);
INSERT INTO valoracions VALUES (4161, 70, '12/11/2004', 5);
INSERT INTO valoracions VALUES (4161, 22, '25/01/2010', 5);
INSERT INTO valoracions VALUES (4161, 21, '17/10/2009', 7);
INSERT INTO valoracions VALUES (4162, 114, '06/05/2006', 6);
INSERT INTO valoracions VALUES (4162, 104, '07/07/2001', 2);
INSERT INTO valoracions VALUES (4162, 60, '20/04/2010', 4);
INSERT INTO valoracions VALUES (4162, 70, '22/07/2010', 10);
INSERT INTO valoracions VALUES (4162, 6, '14/11/2006', 9);
INSERT INTO valoracions VALUES (4162, 112, '02/12/2007', 1);
INSERT INTO valoracions VALUES (4163, 36, '17/08/2005', 7);
INSERT INTO valoracions VALUES (4163, 75, '28/01/2004', 6);
INSERT INTO valoracions VALUES (4163, 28, '14/04/2005', 7);
INSERT INTO valoracions VALUES (4164, 10, '26/01/2009', 5);
INSERT INTO valoracions VALUES (4164, 93, '21/05/2005', 6);
INSERT INTO valoracions VALUES (4164, 95, '19/09/2008', 5);
INSERT INTO valoracions VALUES (4165, 81, '27/01/2002', 4);
INSERT INTO valoracions VALUES (4165, 92, '24/10/2001', 6);
INSERT INTO valoracions VALUES (4165, 38, '22/08/2007', 5);
INSERT INTO valoracions VALUES (4165, 16, '17/01/2005', 8);
INSERT INTO valoracions VALUES (4165, 90, '10/11/2009', 9);
INSERT INTO valoracions VALUES (4166, 22, '22/06/2009', 10);
INSERT INTO valoracions VALUES (4166, 62, '02/08/2007', 5);
INSERT INTO valoracions VALUES (4166, 93, '26/09/2010', 8);
INSERT INTO valoracions VALUES (4166, 116, '19/03/2002', 8);
INSERT INTO valoracions VALUES (4167, 87, '14/12/2001', 7);
INSERT INTO valoracions VALUES (4167, 97, '12/10/2007', 8);
INSERT INTO valoracions VALUES (4168, 112, '16/07/2009', 6);
INSERT INTO valoracions VALUES (4168, 64, '30/11/2004', 6);
INSERT INTO valoracions VALUES (4168, 25, '14/08/2006', 6);
INSERT INTO valoracions VALUES (4168, 39, '24/05/2007', 4);
INSERT INTO valoracions VALUES (4168, 5, '03/11/2005', 8);
INSERT INTO valoracions VALUES (4169, 42, '08/11/2008', 9);
INSERT INTO valoracions VALUES (4169, 74, '01/02/2009', 7);
INSERT INTO valoracions VALUES (4170, 11, '18/06/2006', 10);
INSERT INTO valoracions VALUES (4170, 48, '31/10/2004', 9);
INSERT INTO valoracions VALUES (4170, 40, '13/11/2009', 5);
INSERT INTO valoracions VALUES (4170, 77, '12/03/2005', 9);
INSERT INTO valoracions VALUES (4170, 95, '19/03/2005', 10);
INSERT INTO valoracions VALUES (4170, 114, '21/10/2002', 7);
INSERT INTO valoracions VALUES (4170, 13, '28/05/2009', 9);
INSERT INTO valoracions VALUES (4171, 92, '13/04/2002', 3);
INSERT INTO valoracions VALUES (4171, 115, '22/01/2004', 2);
INSERT INTO valoracions VALUES (4171, 67, '29/08/2001', 6);
INSERT INTO valoracions VALUES (4171, 66, '03/05/2007', 3);
INSERT INTO valoracions VALUES (4171, 75, '11/12/2008', 8);
INSERT INTO valoracions VALUES (4171, 42, '13/08/2009', 9);
INSERT INTO valoracions VALUES (4172, 111, '24/08/2010', 6);
INSERT INTO valoracions VALUES (4172, 75, '01/01/2009', 7);
INSERT INTO valoracions VALUES (4173, 115, '08/04/2008', 1);
INSERT INTO valoracions VALUES (4173, 36, '17/01/2007', 4);
INSERT INTO valoracions VALUES (4173, 91, '01/02/2010', 1);
INSERT INTO valoracions VALUES (4173, 4, '03/05/2008', 9);
INSERT INTO valoracions VALUES (4173, 106, '15/07/2005', 7);
INSERT INTO valoracions VALUES (4173, 116, '23/08/2009', 5);
INSERT INTO valoracions VALUES (4174, 46, '10/02/2007', 7);
INSERT INTO valoracions VALUES (4174, 94, '18/07/2003', 5);
INSERT INTO valoracions VALUES (4174, 94, '14/07/2002', 1);
INSERT INTO valoracions VALUES (4174, 77, '10/11/2007', 4);
INSERT INTO valoracions VALUES (4174, 67, '13/02/2002', 4);
INSERT INTO valoracions VALUES (4175, 69, '01/05/2009', 6);
INSERT INTO valoracions VALUES (4175, 99, '17/10/2003', 3);
INSERT INTO valoracions VALUES (4175, 61, '18/02/2005', 2);
INSERT INTO valoracions VALUES (4175, 10, '15/03/2005', 7);
INSERT INTO valoracions VALUES (4175, 68, '26/07/2002', 3);
INSERT INTO valoracions VALUES (4176, 5, '06/11/2001', 8);
INSERT INTO valoracions VALUES (4176, 95, '27/08/2002', 8);
INSERT INTO valoracions VALUES (4176, 68, '21/04/2008', 7);
INSERT INTO valoracions VALUES (4177, 88, '03/07/2002', 10);
INSERT INTO valoracions VALUES (4177, 22, '18/08/2009', 10);
INSERT INTO valoracions VALUES (4178, 53, '26/02/2003', 4);
INSERT INTO valoracions VALUES (4178, 29, '10/01/2008', 7);
INSERT INTO valoracions VALUES (4178, 89, '07/09/2005', 8);
INSERT INTO valoracions VALUES (4178, 71, '15/11/2002', 8);
INSERT INTO valoracions VALUES (4179, 40, '07/12/2006', 7);
INSERT INTO valoracions VALUES (4179, 14, '21/11/2004', 9);
INSERT INTO valoracions VALUES (4179, 41, '17/11/2006', 10);
INSERT INTO valoracions VALUES (4179, 73, '12/05/2004', 8);
INSERT INTO valoracions VALUES (4179, 33, '03/08/2001', 6);
INSERT INTO valoracions VALUES (4180, 24, '30/09/2003', 8);
INSERT INTO valoracions VALUES (4180, 80, '15/10/2001', 7);
INSERT INTO valoracions VALUES (4181, 85, '12/10/2001', 9);
INSERT INTO valoracions VALUES (4181, 109, '04/08/2001', 5);
INSERT INTO valoracions VALUES (4181, 107, '15/03/2009', 8);
INSERT INTO valoracions VALUES (4182, 28, '12/08/2006', 8);
INSERT INTO valoracions VALUES (4182, 93, '14/08/2006', 2);
INSERT INTO valoracions VALUES (4183, 105, '19/10/2005', 5);
INSERT INTO valoracions VALUES (4183, 21, '13/10/2004', 6);
INSERT INTO valoracions VALUES (4184, 96, '15/03/2003', 1);
INSERT INTO valoracions VALUES (4184, 91, '26/02/2010', 3);
INSERT INTO valoracions VALUES (4184, 110, '04/02/2007', 8);
INSERT INTO valoracions VALUES (4184, 9, '30/03/2009', 9);
INSERT INTO valoracions VALUES (4184, 4, '27/04/2008', 6);
INSERT INTO valoracions VALUES (4184, 82, '08/08/2006', 5);
INSERT INTO valoracions VALUES (4184, 47, '16/12/2001', 9);
INSERT INTO valoracions VALUES (4184, 102, '17/05/2007', 5);
INSERT INTO valoracions VALUES (4184, 40, '20/08/2010', 5);
INSERT INTO valoracions VALUES (4184, 3, '06/02/2004', 5);
INSERT INTO valoracions VALUES (4185, 89, '19/05/2005', 8);
INSERT INTO valoracions VALUES (4185, 36, '02/10/2008', 7);
INSERT INTO valoracions VALUES (4187, 28, '10/10/2008', 9);
INSERT INTO valoracions VALUES (4187, 98, '31/01/2002', 2);
INSERT INTO valoracions VALUES (4188, 18, '22/09/2004', 4);
INSERT INTO valoracions VALUES (4188, 84, '23/09/2007', 8);
INSERT INTO valoracions VALUES (4188, 33, '04/06/2005', 5);
INSERT INTO valoracions VALUES (4188, 108, '27/01/2010', 3);
INSERT INTO valoracions VALUES (4189, 63, '10/01/2008', 8);
INSERT INTO valoracions VALUES (4189, 110, '09/05/2007', 1);
INSERT INTO valoracions VALUES (4189, 101, '28/06/2001', 8);
INSERT INTO valoracions VALUES (4190, 55, '03/05/2010', 9);
INSERT INTO valoracions VALUES (4190, 87, '01/08/2006', 5);
INSERT INTO valoracions VALUES (4190, 55, '09/04/2002', 6);
INSERT INTO valoracions VALUES (4190, 79, '23/10/2001', 8);
INSERT INTO valoracions VALUES (4190, 30, '13/05/2004', 4);
INSERT INTO valoracions VALUES (4190, 86, '04/05/2006', 7);
INSERT INTO valoracions VALUES (4190, 64, '27/01/2004', 6);
INSERT INTO valoracions VALUES (4190, 8, '24/06/2006', 5);
INSERT INTO valoracions VALUES (4190, 67, '24/06/2003', 8);
INSERT INTO valoracions VALUES (4191, 34, '21/03/2010', 10);
INSERT INTO valoracions VALUES (4191, 4, '03/04/2006', 8);
INSERT INTO valoracions VALUES (4191, 89, '03/05/2002', 5);
INSERT INTO valoracions VALUES (4191, 66, '31/01/2005', 8);
INSERT INTO valoracions VALUES (4191, 2, '08/01/2008', 6);
INSERT INTO valoracions VALUES (4192, 14, '13/04/2010', 7);
INSERT INTO valoracions VALUES (4192, 2, '09/12/2002', 7);
INSERT INTO valoracions VALUES (4192, 83, '10/10/2002', 1);
INSERT INTO valoracions VALUES (4192, 23, '18/03/2004', 6);
INSERT INTO valoracions VALUES (4193, 44, '19/05/2007', 9);
INSERT INTO valoracions VALUES (4193, 88, '26/10/2006', 8);
INSERT INTO valoracions VALUES (4193, 1, '08/12/2009', 8);
INSERT INTO valoracions VALUES (4193, 46, '01/05/2003', 8);
INSERT INTO valoracions VALUES (4193, 101, '04/06/2003', 9);
INSERT INTO valoracions VALUES (4193, 38, '13/08/2005', 5);
INSERT INTO valoracions VALUES (4193, 103, '08/08/2010', 3);
INSERT INTO valoracions VALUES (4194, 7, '31/07/2006', 5);
INSERT INTO valoracions VALUES (4194, 15, '18/04/2006', 8);
INSERT INTO valoracions VALUES (4195, 41, '09/08/2008', 7);
INSERT INTO valoracions VALUES (4195, 20, '16/05/2004', 7);
INSERT INTO valoracions VALUES (4195, 109, '24/10/2004', 1);
INSERT INTO valoracions VALUES (4196, 87, '29/06/2006', 1);
INSERT INTO valoracions VALUES (4196, 62, '04/06/2001', 8);
INSERT INTO valoracions VALUES (4196, 37, '10/03/2008', 5);
INSERT INTO valoracions VALUES (4197, 80, '24/10/2005', 5);
INSERT INTO valoracions VALUES (4197, 111, '30/12/2003', 7);
INSERT INTO valoracions VALUES (4197, 107, '09/09/2004', 5);
INSERT INTO valoracions VALUES (4197, 42, '30/12/2006', 5);
INSERT INTO valoracions VALUES (4197, 43, '08/04/2005', 5);
INSERT INTO valoracions VALUES (4197, 70, '07/05/2010', 5);
INSERT INTO valoracions VALUES (4198, 50, '06/07/2003', 9);
INSERT INTO valoracions VALUES (4199, 9, '02/09/2008', 8);
INSERT INTO valoracions VALUES (4199, 6, '21/05/2004', 7);
INSERT INTO valoracions VALUES (4199, 1, '04/07/2010', 10);
INSERT INTO valoracions VALUES (4199, 30, '27/10/2008', 8);
INSERT INTO valoracions VALUES (4200, 14, '21/05/2009', 6);
INSERT INTO valoracions VALUES (4200, 18, '27/08/2010', 10);
INSERT INTO valoracions VALUES (4200, 63, '16/12/2001', 5);
INSERT INTO valoracions VALUES (4200, 43, '30/12/2007', 6);
INSERT INTO valoracions VALUES (4200, 109, '26/05/2001', 6);
INSERT INTO valoracions VALUES (4200, 113, '16/01/2007', 4);
INSERT INTO valoracions VALUES (4200, 70, '06/07/2006', 9);
INSERT INTO valoracions VALUES (4200, 3, '11/12/2002', 8);
INSERT INTO valoracions VALUES (4201, 94, '08/09/2003', 1);
INSERT INTO valoracions VALUES (4201, 39, '16/06/2003', 5);
INSERT INTO valoracions VALUES (4201, 46, '18/04/2001', 3);
INSERT INTO valoracions VALUES (4202, 19, '08/12/2001', 9);
INSERT INTO valoracions VALUES (4202, 63, '05/01/2004', 6);
INSERT INTO valoracions VALUES (4202, 82, '10/04/2010', 4);
INSERT INTO valoracions VALUES (4203, 7, '19/12/2006', 9);
INSERT INTO valoracions VALUES (4203, 89, '16/09/2008', 4);
INSERT INTO valoracions VALUES (4203, 107, '31/01/2007', 4);
INSERT INTO valoracions VALUES (4203, 13, '08/04/2010', 7);
INSERT INTO valoracions VALUES (4204, 89, '07/09/2008', 1);
INSERT INTO valoracions VALUES (4204, 95, '20/08/2003', 9);
INSERT INTO valoracions VALUES (4204, 97, '11/05/2008', 7);
INSERT INTO valoracions VALUES (4205, 90, '07/09/2005', 8);
INSERT INTO valoracions VALUES (4205, 17, '14/05/2006', 9);
INSERT INTO valoracions VALUES (4205, 60, '10/10/2005', 3);
INSERT INTO valoracions VALUES (4205, 49, '30/08/2002', 9);
INSERT INTO valoracions VALUES (4205, 6, '19/09/2008', 9);
INSERT INTO valoracions VALUES (4205, 56, '22/01/2009', 3);
INSERT INTO valoracions VALUES (4206, 41, '01/08/2005', 5);
INSERT INTO valoracions VALUES (4206, 39, '18/04/2008', 5);
INSERT INTO valoracions VALUES (4206, 2, '28/11/2008', 6);
INSERT INTO valoracions VALUES (4206, 32, '06/09/2003', 4);
INSERT INTO valoracions VALUES (4206, 46, '06/04/2001', 5);
INSERT INTO valoracions VALUES (4206, 28, '25/01/2007', 5);
INSERT INTO valoracions VALUES (4206, 85, '20/09/2005', 6);
INSERT INTO valoracions VALUES (4206, 26, '14/02/2004', 9);
INSERT INTO valoracions VALUES (4206, 116, '23/11/2006', 6);
INSERT INTO valoracions VALUES (4207, 78, '02/03/2005', 8);
INSERT INTO valoracions VALUES (4207, 35, '31/05/2006', 5);
INSERT INTO valoracions VALUES (4207, 40, '20/10/2001', 7);
INSERT INTO valoracions VALUES (4207, 89, '29/09/2001', 8);
INSERT INTO valoracions VALUES (4207, 47, '28/09/2008', 9);
INSERT INTO valoracions VALUES (4207, 41, '05/07/2002', 6);
INSERT INTO valoracions VALUES (4207, 31, '28/01/2008', 7);
INSERT INTO valoracions VALUES (4208, 37, '14/10/2008', 5);
INSERT INTO valoracions VALUES (4208, 14, '24/06/2010', 9);
INSERT INTO valoracions VALUES (4208, 92, '03/09/2001', 9);
INSERT INTO valoracions VALUES (4208, 85, '19/10/2006', 7);
INSERT INTO valoracions VALUES (4209, 81, '01/01/2004', 6);
INSERT INTO valoracions VALUES (4210, 104, '05/09/2005', 8);
INSERT INTO valoracions VALUES (4210, 34, '13/04/2003', 7);
INSERT INTO valoracions VALUES (4210, 94, '30/03/2005', 6);
INSERT INTO valoracions VALUES (4211, 112, '12/02/2010', 2);
INSERT INTO valoracions VALUES (4211, 82, '20/08/2001', 2);
INSERT INTO valoracions VALUES (4211, 19, '20/12/2003', 6);
INSERT INTO valoracions VALUES (4211, 73, '03/06/2007', 4);
INSERT INTO valoracions VALUES (4212, 40, '18/04/2001', 9);
INSERT INTO valoracions VALUES (4212, 67, '10/10/2010', 5);
INSERT INTO valoracions VALUES (4212, 77, '22/04/2003', 6);
INSERT INTO valoracions VALUES (4212, 87, '26/03/2009', 6);
INSERT INTO valoracions VALUES (4212, 3, '10/11/2006', 8);
INSERT INTO valoracions VALUES (4213, 52, '28/08/2009', 6);
INSERT INTO valoracions VALUES (4213, 63, '03/06/2006', 3);
INSERT INTO valoracions VALUES (4213, 27, '21/09/2008', 6);
INSERT INTO valoracions VALUES (4213, 35, '13/01/2008', 9);
INSERT INTO valoracions VALUES (4213, 69, '20/07/2007', 8);
INSERT INTO valoracions VALUES (4213, 49, '07/08/2007', 9);
INSERT INTO valoracions VALUES (4215, 7, '27/04/2006', 7);
INSERT INTO valoracions VALUES (4215, 106, '25/07/2002', 2);
INSERT INTO valoracions VALUES (4215, 74, '17/03/2006', 10);
INSERT INTO valoracions VALUES (4215, 99, '07/06/2010', 2);
INSERT INTO valoracions VALUES (4215, 97, '14/06/2001', 5);
INSERT INTO valoracions VALUES (4216, 23, '07/08/2009', 9);
INSERT INTO valoracions VALUES (4216, 30, '18/02/2005', 8);
INSERT INTO valoracions VALUES (4216, 89, '06/01/2005', 3);
INSERT INTO valoracions VALUES (4216, 77, '29/12/2007', 9);
INSERT INTO valoracions VALUES (4217, 110, '07/08/2009', 3);
INSERT INTO valoracions VALUES (4217, 13, '25/11/2006', 6);
INSERT INTO valoracions VALUES (4217, 20, '04/07/2009', 8);
INSERT INTO valoracions VALUES (4217, 4, '29/06/2008', 8);
INSERT INTO valoracions VALUES (4217, 30, '07/07/2003', 9);
INSERT INTO valoracions VALUES (4217, 10, '24/03/2004', 9);
INSERT INTO valoracions VALUES (4218, 21, '29/08/2004', 5);
INSERT INTO valoracions VALUES (4218, 71, '08/12/2003', 4);
INSERT INTO valoracions VALUES (4218, 91, '13/01/2004', 3);
INSERT INTO valoracions VALUES (4218, 1, '20/06/2007', 9);
INSERT INTO valoracions VALUES (4218, 56, '24/05/2003', 3);
INSERT INTO valoracions VALUES (4218, 64, '05/03/2005', 5);
INSERT INTO valoracions VALUES (4218, 33, '28/06/2002', 5);
INSERT INTO valoracions VALUES (4218, 27, '06/10/2001', 6);
INSERT INTO valoracions VALUES (4218, 45, '08/05/2003', 5);
INSERT INTO valoracions VALUES (4218, 39, '29/11/2006', 4);
INSERT INTO valoracions VALUES (4218, 6, '30/06/2008', 7);
INSERT INTO valoracions VALUES (4219, 89, '01/10/2004', 8);
INSERT INTO valoracions VALUES (4219, 50, '28/09/2010', 9);
INSERT INTO valoracions VALUES (4220, 99, '13/10/2008', 10);
INSERT INTO valoracions VALUES (4220, 92, '02/06/2002', 5);
INSERT INTO valoracions VALUES (4220, 45, '11/02/2006', 9);
INSERT INTO valoracions VALUES (4220, 12, '13/04/2010', 9);
INSERT INTO valoracions VALUES (4220, 57, '05/06/2006', 3);
INSERT INTO valoracions VALUES (4221, 17, '08/07/2010', 7);
INSERT INTO valoracions VALUES (4221, 11, '18/09/2001', 10);
INSERT INTO valoracions VALUES (4221, 12, '22/12/2002', 10);
INSERT INTO valoracions VALUES (4221, 29, '02/10/2004', 9);
INSERT INTO valoracions VALUES (4221, 26, '06/02/2004', 7);
INSERT INTO valoracions VALUES (4222, 28, '28/09/2005', 7);
INSERT INTO valoracions VALUES (4222, 63, '19/07/2010', 9);
INSERT INTO valoracions VALUES (4222, 65, '08/06/2003', 5);
INSERT INTO valoracions VALUES (4222, 22, '06/07/2010', 8);
INSERT INTO valoracions VALUES (4223, 74, '27/02/2009', 6);
INSERT INTO valoracions VALUES (4223, 99, '08/07/2005', 2);
INSERT INTO valoracions VALUES (4223, 57, '12/10/2003', 3);
INSERT INTO valoracions VALUES (4223, 61, '28/08/2010', 2);
INSERT INTO valoracions VALUES (4223, 96, '28/08/2006', 10);
INSERT INTO valoracions VALUES (4223, 40, '30/11/2009', 4);
INSERT INTO valoracions VALUES (4223, 87, '22/04/2005', 9);
INSERT INTO valoracions VALUES (4223, 61, '06/06/2001', 6);
INSERT INTO valoracions VALUES (4225, 52, '16/06/2008', 9);
INSERT INTO valoracions VALUES (4225, 90, '08/12/2001', 2);
INSERT INTO valoracions VALUES (4225, 11, '12/12/2008', 7);
INSERT INTO valoracions VALUES (4226, 10, '09/12/2002', 5);
INSERT INTO valoracions VALUES (4226, 25, '12/08/2010', 4);
INSERT INTO valoracions VALUES (4226, 111, '10/12/2003', 4);
INSERT INTO valoracions VALUES (4226, 12, '17/05/2005', 6);
INSERT INTO valoracions VALUES (4226, 66, '17/07/2006', 7);
INSERT INTO valoracions VALUES (4227, 88, '21/09/2002', 9);
INSERT INTO valoracions VALUES (4227, 99, '29/07/2001', 8);
INSERT INTO valoracions VALUES (4227, 2, '21/08/2005', 7);
INSERT INTO valoracions VALUES (4227, 24, '17/02/2010', 6);
INSERT INTO valoracions VALUES (4228, 36, '06/06/2001', 5);
INSERT INTO valoracions VALUES (4228, 21, '17/08/2004', 5);
INSERT INTO valoracions VALUES (4229, 13, '15/04/2005', 6);
INSERT INTO valoracions VALUES (4229, 108, '21/02/2004', 7);
INSERT INTO valoracions VALUES (4229, 92, '28/11/2003', 4);
INSERT INTO valoracions VALUES (4229, 72, '05/10/2005', 2);
INSERT INTO valoracions VALUES (4229, 11, '26/04/2007', 6);
INSERT INTO valoracions VALUES (4230, 79, '31/03/2008', 3);
INSERT INTO valoracions VALUES (4230, 48, '04/07/2002', 4);
INSERT INTO valoracions VALUES (4230, 45, '01/07/2009', 9);
INSERT INTO valoracions VALUES (4230, 109, '19/12/2001', 6);
INSERT INTO valoracions VALUES (4231, 33, '22/01/2005', 8);
INSERT INTO valoracions VALUES (4231, 113, '17/06/2010', 7);
INSERT INTO valoracions VALUES (4231, 79, '30/08/2001', 9);
INSERT INTO valoracions VALUES (4232, 106, '27/02/2008', 8);
INSERT INTO valoracions VALUES (4232, 69, '22/12/2008', 4);
INSERT INTO valoracions VALUES (4232, 115, '28/01/2010', 6);
INSERT INTO valoracions VALUES (4233, 115, '01/11/2006', 9);
INSERT INTO valoracions VALUES (4233, 53, '21/10/2001', 6);
INSERT INTO valoracions VALUES (4233, 97, '03/05/2006', 7);
INSERT INTO valoracions VALUES (4233, 20, '03/06/2008', 9);
INSERT INTO valoracions VALUES (4234, 28, '15/05/2005', 9);
INSERT INTO valoracions VALUES (4234, 83, '06/06/2008', 3);
INSERT INTO valoracions VALUES (4234, 30, '23/07/2001', 8);
INSERT INTO valoracions VALUES (4235, 14, '17/07/2009', 7);
INSERT INTO valoracions VALUES (4236, 49, '06/05/2010', 6);
INSERT INTO valoracions VALUES (4237, 90, '26/04/2007', 8);
INSERT INTO valoracions VALUES (4237, 57, '05/10/2006', 7);
INSERT INTO valoracions VALUES (4237, 97, '10/08/2004', 6);
INSERT INTO valoracions VALUES (4237, 57, '05/03/2007', 6);
INSERT INTO valoracions VALUES (4238, 54, '15/04/2002', 10);
INSERT INTO valoracions VALUES (4238, 22, '27/08/2003', 10);
INSERT INTO valoracions VALUES (4238, 71, '28/08/2010', 8);
INSERT INTO valoracions VALUES (4239, 21, '03/02/2002', 8);
INSERT INTO valoracions VALUES (4239, 4, '05/07/2001', 5);
INSERT INTO valoracions VALUES (4239, 6, '15/10/2002', 7);
INSERT INTO valoracions VALUES (4239, 101, '10/12/2007', 3);
INSERT INTO valoracions VALUES (4239, 50, '28/05/2009', 6);
INSERT INTO valoracions VALUES (4241, 92, '21/06/2004', 7);
INSERT INTO valoracions VALUES (4241, 116, '08/08/2004', 5);
INSERT INTO valoracions VALUES (4241, 103, '10/08/2010', 5);
INSERT INTO valoracions VALUES (4242, 65, '19/03/2009', 9);
INSERT INTO valoracions VALUES (4242, 2, '09/04/2009', 7);
INSERT INTO valoracions VALUES (4242, 98, '19/08/2007', 3);
INSERT INTO valoracions VALUES (4242, 25, '29/07/2010', 9);
INSERT INTO valoracions VALUES (4243, 90, '26/03/2004', 1);
INSERT INTO valoracions VALUES (4243, 65, '14/11/2009', 3);
INSERT INTO valoracions VALUES (4243, 89, '09/11/2009', 4);
INSERT INTO valoracions VALUES (4243, 59, '07/07/2006', 5);
INSERT INTO valoracions VALUES (4243, 15, '10/01/2005', 7);
INSERT INTO valoracions VALUES (4243, 67, '29/06/2007', 6);
INSERT INTO valoracions VALUES (4244, 89, '21/09/2003', 3);
INSERT INTO valoracions VALUES (4244, 4, '12/12/2002', 6);
INSERT INTO valoracions VALUES (4245, 106, '26/08/2001', 2);
INSERT INTO valoracions VALUES (4245, 60, '08/04/2008', 9);
INSERT INTO valoracions VALUES (4246, 60, '20/05/2002', 5);
INSERT INTO valoracions VALUES (4246, 89, '07/07/2003', 7);
INSERT INTO valoracions VALUES (4246, 64, '25/01/2009', 6);
INSERT INTO valoracions VALUES (4246, 57, '06/06/2007', 6);
INSERT INTO valoracions VALUES (4246, 99, '10/02/2004', 4);
INSERT INTO valoracions VALUES (4246, 44, '11/06/2008', 5);
INSERT INTO valoracions VALUES (4246, 42, '16/09/2001', 5);
INSERT INTO valoracions VALUES (4247, 60, '03/12/2002', 9);
INSERT INTO valoracions VALUES (4247, 90, '03/03/2002', 8);
INSERT INTO valoracions VALUES (4247, 62, '08/12/2005', 5);
INSERT INTO valoracions VALUES (4247, 99, '20/06/2002', 8);
INSERT INTO valoracions VALUES (4247, 24, '21/10/2004', 8);
INSERT INTO valoracions VALUES (4247, 55, '20/12/2004', 8);
INSERT INTO valoracions VALUES (4247, 54, '31/05/2005', 10);
INSERT INTO valoracions VALUES (4247, 55, '14/06/2001', 10);
INSERT INTO valoracions VALUES (4248, 53, '23/12/2006', 4);
INSERT INTO valoracions VALUES (4248, 12, '20/08/2001', 6);
INSERT INTO valoracions VALUES (4248, 2, '13/12/2005', 10);
INSERT INTO valoracions VALUES (4248, 13, '06/06/2008', 7);
INSERT INTO valoracions VALUES (4249, 5, '02/12/2005', 8);
INSERT INTO valoracions VALUES (4249, 106, '21/10/2002', 5);
INSERT INTO valoracions VALUES (4250, 3, '09/04/2005', 9);
INSERT INTO valoracions VALUES (4251, 104, '19/02/2008', 3);
INSERT INTO valoracions VALUES (4251, 95, '23/02/2010', 2);
INSERT INTO valoracions VALUES (4251, 95, '14/10/2002', 3);
INSERT INTO valoracions VALUES (4251, 42, '18/01/2009', 5);
INSERT INTO valoracions VALUES (4251, 36, '24/05/2010', 6);
INSERT INTO valoracions VALUES (4251, 91, '05/02/2009', 6);
INSERT INTO valoracions VALUES (4252, 35, '24/12/2005', 9);
INSERT INTO valoracions VALUES (4252, 24, '09/08/2008', 10);
INSERT INTO valoracions VALUES (4253, 66, '14/08/2005', 3);
INSERT INTO valoracions VALUES (4253, 12, '13/07/2004', 6);
INSERT INTO valoracions VALUES (4253, 6, '26/05/2004', 7);
INSERT INTO valoracions VALUES (4253, 28, '29/07/2008', 8);
INSERT INTO valoracions VALUES (4253, 6, '16/03/2009', 5);
INSERT INTO valoracions VALUES (4254, 5, '25/07/2003', 9);
INSERT INTO valoracions VALUES (4255, 69, '15/03/2005', 8);
INSERT INTO valoracions VALUES (4255, 24, '15/08/2004', 7);
INSERT INTO valoracions VALUES (4255, 112, '12/02/2006', 5);
INSERT INTO valoracions VALUES (4256, 58, '16/12/2002', 8);
INSERT INTO valoracions VALUES (4256, 23, '12/04/2010', 10);
INSERT INTO valoracions VALUES (4256, 17, '11/09/2006', 6);
INSERT INTO valoracions VALUES (4257, 5, '09/05/2004', 8);
INSERT INTO valoracions VALUES (4257, 63, '05/08/2001', 5);
INSERT INTO valoracions VALUES (4257, 73, '19/07/2004', 7);
INSERT INTO valoracions VALUES (4258, 52, '11/10/2010', 3);
INSERT INTO valoracions VALUES (4258, 68, '22/03/2010', 9);
INSERT INTO valoracions VALUES (4258, 51, '19/02/2006', 9);
INSERT INTO valoracions VALUES (4258, 56, '16/10/2005', 8);
INSERT INTO valoracions VALUES (4259, 100, '24/04/2003', 5);
INSERT INTO valoracions VALUES (4259, 54, '30/07/2001', 8);
INSERT INTO valoracions VALUES (4259, 34, '16/04/2003', 9);
INSERT INTO valoracions VALUES (4259, 67, '16/01/2005', 8);
INSERT INTO valoracions VALUES (4259, 79, '27/05/2009', 3);
INSERT INTO valoracions VALUES (4259, 27, '02/04/2008', 9);
INSERT INTO valoracions VALUES (4259, 22, '04/08/2010', 9);
INSERT INTO valoracions VALUES (4260, 15, '19/07/2004', 9);
INSERT INTO valoracions VALUES (4260, 103, '03/03/2008', 9);
INSERT INTO valoracions VALUES (4260, 23, '23/08/2003', 8);
INSERT INTO valoracions VALUES (4260, 10, '18/03/2007', 8);
INSERT INTO valoracions VALUES (4260, 84, '11/08/2009', 7);
INSERT INTO valoracions VALUES (4260, 114, '22/09/2008', 6);
INSERT INTO valoracions VALUES (4260, 47, '25/09/2003', 5);
INSERT INTO valoracions VALUES (4260, 53, '02/07/2007', 3);
INSERT INTO valoracions VALUES (4261, 58, '23/06/2010', 4);
INSERT INTO valoracions VALUES (4261, 97, '02/03/2006', 9);
INSERT INTO valoracions VALUES (4261, 91, '25/04/2003', 8);
INSERT INTO valoracions VALUES (4261, 102, '13/04/2007', 9);
INSERT INTO valoracions VALUES (4262, 47, '21/09/2004', 3);
INSERT INTO valoracions VALUES (4262, 55, '19/11/2001', 4);
INSERT INTO valoracions VALUES (4262, 105, '15/04/2010', 8);
INSERT INTO valoracions VALUES (4262, 108, '10/12/2007', 2);
INSERT INTO valoracions VALUES (4263, 93, '17/04/2004', 5);
INSERT INTO valoracions VALUES (4263, 18, '05/01/2006', 8);
INSERT INTO valoracions VALUES (4263, 28, '28/02/2003', 7);
INSERT INTO valoracions VALUES (4264, 38, '31/03/2006', 7);
INSERT INTO valoracions VALUES (4264, 88, '24/03/2009', 5);
INSERT INTO valoracions VALUES (4264, 69, '20/01/2009', 5);
INSERT INTO valoracions VALUES (4264, 86, '11/06/2009', 5);
INSERT INTO valoracions VALUES (4265, 72, '14/09/2005', 9);
INSERT INTO valoracions VALUES (4265, 96, '04/07/2003', 5);
INSERT INTO valoracions VALUES (4266, 43, '06/11/2008', 8);
INSERT INTO valoracions VALUES (4266, 13, '05/08/2004', 10);
INSERT INTO valoracions VALUES (4266, 112, '06/06/2002', 2);
INSERT INTO valoracions VALUES (4266, 48, '10/01/2007', 4);
INSERT INTO valoracions VALUES (4267, 50, '13/01/2007', 9);
INSERT INTO valoracions VALUES (4267, 7, '25/07/2008', 6);
INSERT INTO valoracions VALUES (4267, 63, '21/03/2005', 8);
INSERT INTO valoracions VALUES (4268, 72, '19/03/2010', 5);
INSERT INTO valoracions VALUES (4268, 103, '03/08/2007', 5);
INSERT INTO valoracions VALUES (4268, 96, '25/04/2003', 9);
INSERT INTO valoracions VALUES (4268, 82, '17/11/2009', 7);
INSERT INTO valoracions VALUES (4268, 53, '29/04/2007', 7);
INSERT INTO valoracions VALUES (4268, 75, '17/04/2009', 3);
INSERT INTO valoracions VALUES (4268, 79, '18/06/2010', 7);
INSERT INTO valoracions VALUES (4269, 46, '16/01/2007', 9);
INSERT INTO valoracions VALUES (4269, 73, '18/08/2008', 9);
INSERT INTO valoracions VALUES (4269, 5, '10/04/2006', 6);
INSERT INTO valoracions VALUES (4269, 28, '28/05/2006', 4);
INSERT INTO valoracions VALUES (4269, 37, '22/03/2007', 5);
INSERT INTO valoracions VALUES (4269, 30, '30/11/2007', 6);
INSERT INTO valoracions VALUES (4269, 89, '12/05/2007', 8);
INSERT INTO valoracions VALUES (4269, 107, '26/04/2010', 4);
INSERT INTO valoracions VALUES (4270, 29, '20/05/2008', 9);
INSERT INTO valoracions VALUES (4270, 78, '04/06/2005', 3);
INSERT INTO valoracions VALUES (4271, 6, '20/08/2009', 9);
INSERT INTO valoracions VALUES (4271, 10, '12/11/2001', 7);
INSERT INTO valoracions VALUES (4271, 27, '15/12/2003', 5);
INSERT INTO valoracions VALUES (4271, 90, '10/07/2005', 9);
INSERT INTO valoracions VALUES (4271, 31, '18/05/2004', 6);
INSERT INTO valoracions VALUES (4272, 99, '26/04/2010', 1);
INSERT INTO valoracions VALUES (4272, 74, '10/09/2008', 4);
INSERT INTO valoracions VALUES (4272, 81, '18/06/2009', 6);
INSERT INTO valoracions VALUES (4273, 100, '17/12/2009', 10);
INSERT INTO valoracions VALUES (4273, 57, '21/12/2005', 4);
INSERT INTO valoracions VALUES (4273, 40, '29/11/2004', 10);
INSERT INTO valoracions VALUES (4273, 92, '08/06/2003', 8);
INSERT INTO valoracions VALUES (4274, 103, '06/06/2009', 8);
INSERT INTO valoracions VALUES (4274, 110, '05/12/2008', 10);
INSERT INTO valoracions VALUES (4275, 100, '09/11/2008', 1);
INSERT INTO valoracions VALUES (4275, 97, '23/06/2010', 4);
INSERT INTO valoracions VALUES (4275, 100, '21/05/2004', 3);
INSERT INTO valoracions VALUES (4275, 116, '07/01/2009', 2);
INSERT INTO valoracions VALUES (4276, 67, '17/09/2009', 8);
INSERT INTO valoracions VALUES (4277, 90, '07/04/2003', 8);
INSERT INTO valoracions VALUES (4277, 6, '18/08/2009', 7);
INSERT INTO valoracions VALUES (4277, 113, '03/06/2005', 10);
INSERT INTO valoracions VALUES (4278, 24, '19/12/2004', 9);
INSERT INTO valoracions VALUES (4278, 101, '22/04/2001', 5);
INSERT INTO valoracions VALUES (4278, 54, '28/08/2002', 6);
INSERT INTO valoracions VALUES (4279, 52, '05/08/2006', 4);
INSERT INTO valoracions VALUES (4279, 96, '19/06/2003', 5);
INSERT INTO valoracions VALUES (4279, 96, '26/08/2007', 6);
INSERT INTO valoracions VALUES (4279, 89, '11/10/2005', 2);
INSERT INTO valoracions VALUES (4280, 35, '22/10/2010', 6);
INSERT INTO valoracions VALUES (4280, 76, '03/09/2004', 3);
INSERT INTO valoracions VALUES (4280, 80, '06/05/2003', 5);
INSERT INTO valoracions VALUES (4280, 53, '15/05/2008', 6);
INSERT INTO valoracions VALUES (4280, 111, '08/09/2001', 2);
INSERT INTO valoracions VALUES (4280, 107, '03/02/2003', 1);
INSERT INTO valoracions VALUES (4281, 61, '04/07/2005', 2);
INSERT INTO valoracions VALUES (4281, 84, '02/12/2009', 5);
INSERT INTO valoracions VALUES (4281, 78, '25/05/2005', 5);
INSERT INTO valoracions VALUES (4282, 62, '23/07/2002', 10);
INSERT INTO valoracions VALUES (4282, 41, '20/03/2006', 7);
INSERT INTO valoracions VALUES (4282, 47, '13/11/2001', 9);
INSERT INTO valoracions VALUES (4282, 103, '13/12/2009', 3);
INSERT INTO valoracions VALUES (4282, 22, '29/07/2008', 7);
INSERT INTO valoracions VALUES (4283, 113, '13/10/2010', 7);
INSERT INTO valoracions VALUES (4283, 67, '08/05/2002', 5);
INSERT INTO valoracions VALUES (4283, 15, '01/03/2002', 5);
INSERT INTO valoracions VALUES (4284, 71, '24/11/2005', 5);
INSERT INTO valoracions VALUES (4284, 66, '22/10/2009', 3);
INSERT INTO valoracions VALUES (4284, 3, '20/02/2008', 8);
INSERT INTO valoracions VALUES (4284, 46, '29/05/2003', 4);
INSERT INTO valoracions VALUES (4284, 11, '19/05/2006', 6);
INSERT INTO valoracions VALUES (4285, 3, '02/07/2005', 8);
INSERT INTO valoracions VALUES (4285, 73, '06/03/2010', 4);
INSERT INTO valoracions VALUES (4286, 80, '16/07/2002', 8);
INSERT INTO valoracions VALUES (4286, 92, '12/04/2004', 6);
INSERT INTO valoracions VALUES (4286, 31, '03/09/2001', 7);
INSERT INTO valoracions VALUES (4287, 77, '03/12/2008', 9);
INSERT INTO valoracions VALUES (4287, 53, '11/11/2009', 6);
INSERT INTO valoracions VALUES (4287, 97, '18/12/2006', 3);
INSERT INTO valoracions VALUES (4287, 83, '01/06/2001', 3);
INSERT INTO valoracions VALUES (4288, 93, '06/05/2008', 4);
INSERT INTO valoracions VALUES (4288, 46, '20/10/2003', 8);
INSERT INTO valoracions VALUES (4289, 92, '30/07/2009', 9);
INSERT INTO valoracions VALUES (4289, 68, '20/06/2007', 8);
INSERT INTO valoracions VALUES (4289, 78, '27/02/2007', 3);
INSERT INTO valoracions VALUES (4290, 49, '08/12/2007', 6);
INSERT INTO valoracions VALUES (4290, 60, '21/04/2003', 3);
INSERT INTO valoracions VALUES (4290, 5, '08/04/2005', 5);
INSERT INTO valoracions VALUES (4291, 95, '29/07/2007', 10);
INSERT INTO valoracions VALUES (4291, 35, '05/05/2010', 7);
INSERT INTO valoracions VALUES (4291, 9, '26/11/2002', 9);
INSERT INTO valoracions VALUES (4291, 114, '31/05/2001', 2);
INSERT INTO valoracions VALUES (4291, 50, '01/07/2007', 6);
INSERT INTO valoracions VALUES (4291, 68, '10/03/2005', 7);
INSERT INTO valoracions VALUES (4291, 47, '22/10/2007', 5);
INSERT INTO valoracions VALUES (4292, 73, '31/08/2006', 9);
INSERT INTO valoracions VALUES (4292, 71, '26/12/2003', 9);
INSERT INTO valoracions VALUES (4292, 61, '05/05/2004', 9);
INSERT INTO valoracions VALUES (4293, 2, '03/09/2002', 6);
INSERT INTO valoracions VALUES (4293, 111, '06/01/2009', 8);
INSERT INTO valoracions VALUES (4293, 102, '05/05/2009', 10);
INSERT INTO valoracions VALUES (4293, 32, '30/06/2009', 6);
INSERT INTO valoracions VALUES (4294, 25, '04/09/2008', 5);
INSERT INTO valoracions VALUES (4294, 105, '28/02/2010', 8);
INSERT INTO valoracions VALUES (4294, 81, '25/08/2009', 9);
INSERT INTO valoracions VALUES (4294, 32, '27/08/2001', 7);
INSERT INTO valoracions VALUES (4294, 47, '10/11/2005', 7);
INSERT INTO valoracions VALUES (4294, 32, '12/04/2005', 7);
INSERT INTO valoracions VALUES (4294, 103, '04/11/2004', 2);
INSERT INTO valoracions VALUES (4294, 24, '14/07/2009', 8);
INSERT INTO valoracions VALUES (4295, 98, '09/01/2007', 2);
INSERT INTO valoracions VALUES (4295, 82, '04/02/2003', 5);
INSERT INTO valoracions VALUES (4295, 88, '17/11/2008', 3);
INSERT INTO valoracions VALUES (4295, 42, '02/04/2001', 3);
INSERT INTO valoracions VALUES (4296, 60, '08/09/2003', 6);
INSERT INTO valoracions VALUES (4296, 60, '14/07/2010', 5);
INSERT INTO valoracions VALUES (4296, 80, '21/01/2006', 2);
INSERT INTO valoracions VALUES (4296, 103, '28/03/2004', 10);
INSERT INTO valoracions VALUES (4297, 90, '11/05/2003', 6);
INSERT INTO valoracions VALUES (4298, 78, '04/07/2004', 5);
INSERT INTO valoracions VALUES (4298, 100, '24/08/2001', 3);
INSERT INTO valoracions VALUES (4298, 55, '06/05/2005', 3);
INSERT INTO valoracions VALUES (4298, 101, '18/08/2002', 6);
INSERT INTO valoracions VALUES (4299, 114, '23/11/2006', 7);
INSERT INTO valoracions VALUES (4300, 77, '06/08/2009', 9);
INSERT INTO valoracions VALUES (4300, 54, '24/03/2004', 10);
INSERT INTO valoracions VALUES (4300, 76, '03/10/2001', 9);
INSERT INTO valoracions VALUES (4300, 101, '25/03/2006', 1);
INSERT INTO valoracions VALUES (4301, 38, '10/08/2009', 10);
INSERT INTO valoracions VALUES (4301, 105, '12/07/2007', 8);
INSERT INTO valoracions VALUES (4301, 1, '16/06/2004', 9);
INSERT INTO valoracions VALUES (4301, 32, '31/07/2004', 5);
INSERT INTO valoracions VALUES (4301, 9, '19/10/2003', 6);
INSERT INTO valoracions VALUES (4301, 24, '22/09/2001', 4);
INSERT INTO valoracions VALUES (4301, 12, '11/05/2007', 9);
INSERT INTO valoracions VALUES (4302, 42, '17/03/2004', 4);
INSERT INTO valoracions VALUES (4302, 7, '21/07/2003', 5);
INSERT INTO valoracions VALUES (4302, 76, '02/09/2008', 10);
INSERT INTO valoracions VALUES (4302, 42, '09/11/2004', 3);
INSERT INTO valoracions VALUES (4303, 95, '06/02/2002', 8);
INSERT INTO valoracions VALUES (4303, 38, '12/11/2007', 5);
INSERT INTO valoracions VALUES (4303, 16, '12/02/2007', 7);
INSERT INTO valoracions VALUES (4303, 22, '31/01/2007', 6);
INSERT INTO valoracions VALUES (4304, 7, '06/10/2003', 9);
INSERT INTO valoracions VALUES (4304, 86, '20/04/2010', 1);
INSERT INTO valoracions VALUES (4304, 66, '13/04/2002', 2);
INSERT INTO valoracions VALUES (4304, 69, '22/04/2004', 3);
INSERT INTO valoracions VALUES (4304, 5, '01/03/2006', 6);
INSERT INTO valoracions VALUES (4304, 85, '18/02/2007', 2);
INSERT INTO valoracions VALUES (4305, 82, '13/03/2007', 7);
INSERT INTO valoracions VALUES (4305, 87, '31/10/2003', 4);
INSERT INTO valoracions VALUES (4305, 39, '13/12/2002', 9);
INSERT INTO valoracions VALUES (4305, 6, '28/04/2001', 7);
INSERT INTO valoracions VALUES (4305, 114, '16/03/2003', 7);
INSERT INTO valoracions VALUES (4306, 73, '07/06/2003', 7);
INSERT INTO valoracions VALUES (4306, 10, '13/06/2004', 8);
INSERT INTO valoracions VALUES (4306, 28, '02/08/2007', 9);
INSERT INTO valoracions VALUES (4306, 61, '06/08/2002', 3);
INSERT INTO valoracions VALUES (4306, 100, '09/02/2007', 5);
INSERT INTO valoracions VALUES (4307, 76, '31/03/2006', 3);
INSERT INTO valoracions VALUES (4307, 91, '14/08/2007', 3);
INSERT INTO valoracions VALUES (4307, 48, '05/03/2005', 9);
INSERT INTO valoracions VALUES (4308, 39, '04/03/2005', 9);
INSERT INTO valoracions VALUES (4308, 26, '22/04/2007', 5);
INSERT INTO valoracions VALUES (4308, 31, '15/08/2008', 7);
INSERT INTO valoracions VALUES (4308, 42, '15/10/2001', 7);
INSERT INTO valoracions VALUES (4308, 104, '08/07/2001', 8);
INSERT INTO valoracions VALUES (4308, 71, '14/02/2003', 7);
INSERT INTO valoracions VALUES (4308, 11, '30/08/2001', 7);
INSERT INTO valoracions VALUES (4308, 114, '10/06/2004', 8);
INSERT INTO valoracions VALUES (4308, 105, '07/09/2004', 6);
INSERT INTO valoracions VALUES (4309, 80, '23/08/2006', 10);
INSERT INTO valoracions VALUES (4310, 37, '18/11/2005', 7);
INSERT INTO valoracions VALUES (4310, 97, '25/03/2002', 6);
INSERT INTO valoracions VALUES (4310, 22, '27/02/2007', 6);
INSERT INTO valoracions VALUES (4311, 23, '07/12/2004', 6);
INSERT INTO valoracions VALUES (4311, 1, '14/05/2010', 9);
INSERT INTO valoracions VALUES (4312, 97, '21/11/2006', 5);
INSERT INTO valoracions VALUES (4312, 28, '09/01/2003', 7);
INSERT INTO valoracions VALUES (4312, 72, '24/06/2007', 2);
INSERT INTO valoracions VALUES (4313, 81, '30/01/2004', 2);
INSERT INTO valoracions VALUES (4313, 45, '19/07/2010', 10);
INSERT INTO valoracions VALUES (4313, 54, '30/05/2003', 10);
INSERT INTO valoracions VALUES (4313, 73, '02/08/2009', 7);
INSERT INTO valoracions VALUES (4313, 36, '08/06/2009', 4);
INSERT INTO valoracions VALUES (4314, 85, '02/02/2002', 9);
INSERT INTO valoracions VALUES (4314, 39, '26/06/2002', 3);
INSERT INTO valoracions VALUES (4314, 46, '06/03/2005', 4);
INSERT INTO valoracions VALUES (4314, 36, '01/09/2009', 9);
INSERT INTO valoracions VALUES (4314, 75, '04/10/2002', 4);
INSERT INTO valoracions VALUES (4314, 80, '11/03/2006', 9);
INSERT INTO valoracions VALUES (4315, 96, '07/04/2009', 3);
INSERT INTO valoracions VALUES (4315, 32, '19/07/2005', 4);
INSERT INTO valoracions VALUES (4315, 76, '10/07/2001', 9);
INSERT INTO valoracions VALUES (4315, 48, '03/07/2010', 9);
INSERT INTO valoracions VALUES (4315, 29, '15/02/2007', 4);
INSERT INTO valoracions VALUES (4315, 107, '14/07/2006', 6);
INSERT INTO valoracions VALUES (4315, 98, '19/08/2006', 4);
INSERT INTO valoracions VALUES (4316, 28, '22/08/2002', 6);
INSERT INTO valoracions VALUES (4316, 26, '09/06/2001', 8);
INSERT INTO valoracions VALUES (4316, 84, '11/02/2003', 10);
INSERT INTO valoracions VALUES (4316, 78, '16/08/2009', 8);
INSERT INTO valoracions VALUES (4316, 78, '06/09/2009', 3);
INSERT INTO valoracions VALUES (4317, 97, '19/02/2008', 9);
INSERT INTO valoracions VALUES (4317, 62, '09/02/2009', 5);
INSERT INTO valoracions VALUES (4317, 53, '31/08/2007', 9);
INSERT INTO valoracions VALUES (4318, 84, '03/04/2009', 3);
INSERT INTO valoracions VALUES (4318, 15, '29/08/2006', 10);
INSERT INTO valoracions VALUES (4318, 86, '13/09/2003', 9);
INSERT INTO valoracions VALUES (4318, 91, '28/06/2002', 8);
INSERT INTO valoracions VALUES (4319, 92, '25/03/2008', 3);
INSERT INTO valoracions VALUES (4319, 60, '14/04/2003', 6);
INSERT INTO valoracions VALUES (4319, 84, '11/03/2002', 10);
INSERT INTO valoracions VALUES (4320, 59, '13/01/2002', 3);
INSERT INTO valoracions VALUES (4320, 114, '09/05/2010', 3);
INSERT INTO valoracions VALUES (4320, 9, '08/09/2004', 8);
INSERT INTO valoracions VALUES (4320, 116, '08/04/2003', 7);
INSERT INTO valoracions VALUES (4321, 114, '04/07/2002', 1);
INSERT INTO valoracions VALUES (4321, 39, '03/08/2008', 7);
INSERT INTO valoracions VALUES (4321, 87, '07/05/2004', 4);
INSERT INTO valoracions VALUES (4321, 111, '17/08/2007', 7);
INSERT INTO valoracions VALUES (4322, 5, '10/06/2008', 10);
INSERT INTO valoracions VALUES (4322, 104, '29/06/2008', 6);
INSERT INTO valoracions VALUES (4323, 78, '13/04/2002', 8);
INSERT INTO valoracions VALUES (4323, 51, '20/10/2008', 7);
INSERT INTO valoracions VALUES (4323, 5, '10/04/2002', 10);
INSERT INTO valoracions VALUES (4324, 12, '06/04/2004', 7);
INSERT INTO valoracions VALUES (4324, 63, '13/07/2004', 7);
INSERT INTO valoracions VALUES (4324, 99, '16/07/2004', 6);
INSERT INTO valoracions VALUES (4324, 96, '20/04/2006', 5);
INSERT INTO valoracions VALUES (4324, 46, '03/04/2001', 4);
INSERT INTO valoracions VALUES (4324, 41, '31/03/2006', 4);
INSERT INTO valoracions VALUES (4325, 27, '23/05/2005', 8);
INSERT INTO valoracions VALUES (4325, 86, '26/06/2005', 3);
INSERT INTO valoracions VALUES (4325, 92, '06/04/2007', 2);
INSERT INTO valoracions VALUES (4325, 80, '28/09/2009', 10);
INSERT INTO valoracions VALUES (4325, 14, '18/12/2006', 9);
INSERT INTO valoracions VALUES (4325, 46, '14/01/2005', 7);
INSERT INTO valoracions VALUES (4325, 2, '21/04/2001', 6);
INSERT INTO valoracions VALUES (4326, 58, '03/06/2007', 6);
INSERT INTO valoracions VALUES (4326, 81, '22/05/2005', 7);
INSERT INTO valoracions VALUES (4327, 35, '14/09/2008', 5);
INSERT INTO valoracions VALUES (4328, 77, '14/06/2006', 8);
INSERT INTO valoracions VALUES (4328, 20, '04/03/2008', 8);
INSERT INTO valoracions VALUES (4328, 96, '24/09/2009', 4);
INSERT INTO valoracions VALUES (4329, 87, '16/04/2010', 4);
INSERT INTO valoracions VALUES (4329, 58, '12/03/2002', 3);
INSERT INTO valoracions VALUES (4329, 42, '11/09/2008', 3);
INSERT INTO valoracions VALUES (4329, 83, '20/09/2001', 4);
INSERT INTO valoracions VALUES (4329, 27, '30/12/2001', 6);
INSERT INTO valoracions VALUES (4329, 78, '03/09/2001', 7);
INSERT INTO valoracions VALUES (4329, 96, '12/11/2001', 2);
INSERT INTO valoracions VALUES (4329, 87, '23/12/2007', 1);
INSERT INTO valoracions VALUES (4329, 85, '01/09/2006', 8);
INSERT INTO valoracions VALUES (4330, 63, '20/02/2009', 2);
INSERT INTO valoracions VALUES (4330, 24, '03/05/2004', 6);
INSERT INTO valoracions VALUES (4330, 37, '20/12/2003', 5);
INSERT INTO valoracions VALUES (4331, 72, '02/05/2007', 2);
INSERT INTO valoracions VALUES (4331, 64, '15/03/2003', 5);
INSERT INTO valoracions VALUES (4332, 36, '29/04/2008', 7);
INSERT INTO valoracions VALUES (4332, 12, '18/05/2006', 8);
INSERT INTO valoracions VALUES (4332, 36, '25/06/2003', 9);
INSERT INTO valoracions VALUES (4332, 47, '24/08/2009', 7);
INSERT INTO valoracions VALUES (4333, 88, '18/03/2008', 5);
INSERT INTO valoracions VALUES (4333, 45, '08/09/2004', 8);
INSERT INTO valoracions VALUES (4333, 24, '25/07/2005', 8);
INSERT INTO valoracions VALUES (4333, 116, '06/09/2001', 1);
INSERT INTO valoracions VALUES (4334, 44, '07/09/2003', 9);
INSERT INTO valoracions VALUES (4334, 113, '16/03/2005', 1);
INSERT INTO valoracions VALUES (4335, 97, '05/01/2006', 9);
INSERT INTO valoracions VALUES (4335, 38, '03/05/2006', 8);
INSERT INTO valoracions VALUES (4335, 111, '22/09/2010', 0);
INSERT INTO valoracions VALUES (4335, 31, '31/08/2010', 9);
INSERT INTO valoracions VALUES (4335, 73, '01/01/2005', 9);
INSERT INTO valoracions VALUES (4336, 111, '28/03/2008', 1);
INSERT INTO valoracions VALUES (4336, 29, '03/04/2010', 8);
INSERT INTO valoracions VALUES (4336, 66, '15/08/2008', 10);
INSERT INTO valoracions VALUES (4336, 100, '14/08/2005', 4);
INSERT INTO valoracions VALUES (4336, 71, '09/11/2001', 7);
INSERT INTO valoracions VALUES (4336, 111, '08/09/2002', 8);
INSERT INTO valoracions VALUES (4337, 5, '09/12/2005', 6);
INSERT INTO valoracions VALUES (4337, 58, '13/08/2006', 6);
INSERT INTO valoracions VALUES (4337, 80, '17/02/2005', 2);
INSERT INTO valoracions VALUES (4338, 78, '07/01/2007', 3);
INSERT INTO valoracions VALUES (4338, 99, '30/11/2006', 9);
INSERT INTO valoracions VALUES (4338, 30, '21/09/2005', 8);
INSERT INTO valoracions VALUES (4339, 21, '22/08/2006', 8);
INSERT INTO valoracions VALUES (4339, 56, '25/04/2004', 5);
INSERT INTO valoracions VALUES (4340, 84, '13/02/2002', 7);
INSERT INTO valoracions VALUES (4340, 3, '01/11/2006', 9);
INSERT INTO valoracions VALUES (4340, 31, '02/03/2005', 9);
INSERT INTO valoracions VALUES (4340, 83, '26/06/2008', 3);
INSERT INTO valoracions VALUES (4340, 108, '04/03/2002', 2);
INSERT INTO valoracions VALUES (4340, 41, '08/10/2004', 5);
INSERT INTO valoracions VALUES (4341, 91, '16/06/2002', 7);
INSERT INTO valoracions VALUES (4341, 13, '19/04/2009', 9);
INSERT INTO valoracions VALUES (4341, 55, '12/05/2007', 6);
INSERT INTO valoracions VALUES (4341, 78, '08/09/2009', 3);
INSERT INTO valoracions VALUES (4341, 75, '12/09/2007', 3);
INSERT INTO valoracions VALUES (4341, 103, '20/03/2010', 2);
INSERT INTO valoracions VALUES (4341, 15, '06/07/2009', 8);
INSERT INTO valoracions VALUES (4341, 50, '19/09/2008', 8);
INSERT INTO valoracions VALUES (4341, 56, '11/03/2004', 4);
INSERT INTO valoracions VALUES (4341, 96, '05/10/2001', 4);
INSERT INTO valoracions VALUES (4342, 55, '27/09/2010', 5);
INSERT INTO valoracions VALUES (4342, 88, '28/10/2003', 9);
INSERT INTO valoracions VALUES (4342, 51, '16/10/2010', 8);
INSERT INTO valoracions VALUES (4342, 115, '07/06/2003', 7);
INSERT INTO valoracions VALUES (4342, 26, '11/07/2008', 8);
INSERT INTO valoracions VALUES (4343, 7, '28/09/2008', 5);
INSERT INTO valoracions VALUES (4344, 93, '05/04/2008', 6);
INSERT INTO valoracions VALUES (4344, 66, '13/06/2004', 4);
INSERT INTO valoracions VALUES (4345, 41, '10/01/2004', 6);
INSERT INTO valoracions VALUES (4345, 65, '01/07/2001', 3);
INSERT INTO valoracions VALUES (4345, 36, '25/10/2010', 9);
INSERT INTO valoracions VALUES (4345, 90, '05/05/2007', 4);
INSERT INTO valoracions VALUES (4345, 54, '16/09/2002', 3);
INSERT INTO valoracions VALUES (4345, 116, '21/10/2004', 1);
INSERT INTO valoracions VALUES (4347, 58, '22/05/2001', 8);
INSERT INTO valoracions VALUES (4347, 24, '14/12/2006', 8);
INSERT INTO valoracions VALUES (4348, 19, '11/04/2009', 5);
INSERT INTO valoracions VALUES (4349, 96, '06/08/2010', 9);
INSERT INTO valoracions VALUES (4349, 98, '26/01/2010', 8);
INSERT INTO valoracions VALUES (4349, 73, '02/11/2006', 5);
INSERT INTO valoracions VALUES (4349, 18, '11/10/2001', 8);
INSERT INTO valoracions VALUES (4350, 9, '15/01/2003', 7);
INSERT INTO valoracions VALUES (4350, 106, '24/01/2010', 1);
INSERT INTO valoracions VALUES (4350, 105, '26/12/2002', 6);
INSERT INTO valoracions VALUES (4351, 74, '24/08/2005', 6);
INSERT INTO valoracions VALUES (4351, 50, '14/03/2003', 10);
INSERT INTO valoracions VALUES (4351, 70, '30/08/2009', 8);
INSERT INTO valoracions VALUES (4353, 115, '29/01/2009', 9);
INSERT INTO valoracions VALUES (4353, 7, '17/12/2001', 7);
INSERT INTO valoracions VALUES (4353, 97, '16/06/2010', 6);
INSERT INTO valoracions VALUES (4353, 37, '24/04/2001', 7);
INSERT INTO valoracions VALUES (4354, 89, '23/05/2001', 6);
INSERT INTO valoracions VALUES (4354, 114, '21/11/2009', 7);
INSERT INTO valoracions VALUES (4354, 62, '03/03/2005', 8);
INSERT INTO valoracions VALUES (4355, 38, '28/07/2005', 7);
INSERT INTO valoracions VALUES (4355, 51, '25/05/2002', 4);
INSERT INTO valoracions VALUES (4356, 38, '19/06/2009', 9);
INSERT INTO valoracions VALUES (4356, 7, '24/08/2002', 5);
INSERT INTO valoracions VALUES (4356, 25, '24/09/2002', 8);
INSERT INTO valoracions VALUES (4356, 77, '10/04/2001', 7);
INSERT INTO valoracions VALUES (4357, 28, '16/06/2006', 4);
INSERT INTO valoracions VALUES (4357, 80, '08/10/2004', 9);
INSERT INTO valoracions VALUES (4357, 61, '29/07/2009', 10);
INSERT INTO valoracions VALUES (4357, 24, '12/02/2002', 9);
INSERT INTO valoracions VALUES (4357, 31, '28/09/2008', 8);
INSERT INTO valoracions VALUES (4357, 79, '08/10/2002', 2);
INSERT INTO valoracions VALUES (4358, 32, '24/11/2005', 7);
INSERT INTO valoracions VALUES (4359, 42, '19/12/2004', 7);
INSERT INTO valoracions VALUES (4359, 78, '18/04/2006', 8);
INSERT INTO valoracions VALUES (4359, 101, '17/01/2002', 2);
INSERT INTO valoracions VALUES (4359, 35, '20/07/2008', 9);
INSERT INTO valoracions VALUES (4359, 82, '24/11/2005', 2);
INSERT INTO valoracions VALUES (4359, 102, '15/07/2006', 2);
INSERT INTO valoracions VALUES (4360, 22, '06/09/2007', 5);
INSERT INTO valoracions VALUES (4361, 3, '07/11/2005', 6);
INSERT INTO valoracions VALUES (4361, 3, '08/05/2004', 7);
INSERT INTO valoracions VALUES (4361, 42, '17/12/2008', 7);
INSERT INTO valoracions VALUES (4361, 60, '20/02/2008', 9);
INSERT INTO valoracions VALUES (4361, 31, '07/04/2001', 7);
INSERT INTO valoracions VALUES (4362, 54, '21/09/2010', 3);
INSERT INTO valoracions VALUES (4362, 107, '20/06/2003', 2);
INSERT INTO valoracions VALUES (4362, 115, '14/06/2008', 8);
INSERT INTO valoracions VALUES (4362, 33, '02/09/2004', 9);
INSERT INTO valoracions VALUES (4363, 109, '10/12/2002', 6);
INSERT INTO valoracions VALUES (4364, 8, '26/03/2007', 6);
INSERT INTO valoracions VALUES (4364, 56, '28/12/2009', 9);
INSERT INTO valoracions VALUES (4364, 23, '15/12/2006', 5);
INSERT INTO valoracions VALUES (4364, 16, '29/06/2009', 8);
INSERT INTO valoracions VALUES (4365, 92, '29/03/2006', 5);
INSERT INTO valoracions VALUES (4365, 45, '11/07/2001', 6);
INSERT INTO valoracions VALUES (4365, 39, '06/01/2003', 4);
INSERT INTO valoracions VALUES (4365, 93, '19/05/2010', 6);
INSERT INTO valoracions VALUES (4367, 58, '19/03/2007', 5);
INSERT INTO valoracions VALUES (4367, 15, '25/04/2001', 5);
INSERT INTO valoracions VALUES (4367, 93, '11/04/2002', 6);
INSERT INTO valoracions VALUES (4367, 32, '05/05/2008', 5);
INSERT INTO valoracions VALUES (4368, 63, '18/10/2010', 8);
INSERT INTO valoracions VALUES (4369, 73, '13/10/2009', 8);
INSERT INTO valoracions VALUES (4369, 57, '05/07/2009', 5);
INSERT INTO valoracions VALUES (4370, 65, '01/05/2008', 4);
INSERT INTO valoracions VALUES (4370, 105, '30/10/2006', 5);
INSERT INTO valoracions VALUES (4370, 85, '26/01/2005', 3);
INSERT INTO valoracions VALUES (4370, 16, '20/05/2003', 9);
INSERT INTO valoracions VALUES (4370, 42, '20/02/2010', 5);
INSERT INTO valoracions VALUES (4371, 76, '21/03/2003', 4);
INSERT INTO valoracions VALUES (4371, 71, '13/08/2010', 9);
INSERT INTO valoracions VALUES (4372, 100, '12/03/2005', 2);
INSERT INTO valoracions VALUES (4372, 73, '26/04/2010', 4);
INSERT INTO valoracions VALUES (4372, 43, '22/12/2004', 5);
INSERT INTO valoracions VALUES (4372, 13, '29/01/2004', 5);
INSERT INTO valoracions VALUES (4372, 79, '25/06/2007', 6);
INSERT INTO valoracions VALUES (4372, 60, '26/10/2006', 4);
INSERT INTO valoracions VALUES (4372, 13, '02/09/2002', 10);
INSERT INTO valoracions VALUES (4373, 30, '21/07/2002', 6);
INSERT INTO valoracions VALUES (4373, 35, '07/05/2005', 9);
INSERT INTO valoracions VALUES (4373, 49, '14/04/2002', 6);
INSERT INTO valoracions VALUES (4373, 14, '07/07/2004', 5);
INSERT INTO valoracions VALUES (4373, 92, '15/08/2004', 7);
INSERT INTO valoracions VALUES (4374, 109, '07/01/2004', 5);
INSERT INTO valoracions VALUES (4374, 21, '26/12/2002', 9);
INSERT INTO valoracions VALUES (4374, 88, '02/12/2004', 7);
INSERT INTO valoracions VALUES (4374, 79, '12/04/2005', 3);
INSERT INTO valoracions VALUES (4374, 6, '03/11/2008', 7);
INSERT INTO valoracions VALUES (4375, 26, '06/03/2010', 5);
INSERT INTO valoracions VALUES (4375, 50, '27/06/2007', 8);
INSERT INTO valoracions VALUES (4375, 17, '12/07/2010', 9);
INSERT INTO valoracions VALUES (4375, 40, '03/07/2008', 5);
INSERT INTO valoracions VALUES (4375, 52, '12/03/2002', 6);
INSERT INTO valoracions VALUES (4376, 99, '08/09/2005', 4);
INSERT INTO valoracions VALUES (4376, 104, '12/08/2009', 2);
INSERT INTO valoracions VALUES (4376, 74, '31/08/2003', 5);
INSERT INTO valoracions VALUES (4377, 14, '24/03/2003', 8);
INSERT INTO valoracions VALUES (4377, 113, '16/03/2009', 4);
INSERT INTO valoracions VALUES (4378, 47, '10/10/2001', 10);
INSERT INTO valoracions VALUES (4378, 29, '11/10/2009', 6);
INSERT INTO valoracions VALUES (4378, 11, '29/04/2001', 6);
INSERT INTO valoracions VALUES (4378, 74, '13/12/2001', 9);
INSERT INTO valoracions VALUES (4378, 14, '18/09/2004', 6);
INSERT INTO valoracions VALUES (4379, 48, '07/12/2004', 8);
INSERT INTO valoracions VALUES (4379, 53, '18/10/2007', 4);
INSERT INTO valoracions VALUES (4379, 97, '27/10/2007', 10);
INSERT INTO valoracions VALUES (4379, 35, '12/02/2002', 7);
INSERT INTO valoracions VALUES (4380, 115, '06/11/2001', 1);
INSERT INTO valoracions VALUES (4380, 39, '22/04/2007', 9);
INSERT INTO valoracions VALUES (4381, 84, '04/05/2007', 2);
INSERT INTO valoracions VALUES (4381, 107, '19/04/2008', 6);
INSERT INTO valoracions VALUES (4381, 17, '29/12/2008', 9);
INSERT INTO valoracions VALUES (4382, 98, '30/01/2009', 5);
INSERT INTO valoracions VALUES (4382, 12, '06/03/2007', 9);
INSERT INTO valoracions VALUES (4382, 91, '26/05/2008', 6);
INSERT INTO valoracions VALUES (4382, 90, '04/02/2006', 1);
INSERT INTO valoracions VALUES (4382, 31, '19/06/2003', 7);
INSERT INTO valoracions VALUES (4382, 57, '11/06/2003', 5);
INSERT INTO valoracions VALUES (4382, 54, '16/03/2004', 9);
INSERT INTO valoracions VALUES (4383, 1, '12/11/2007', 9);
INSERT INTO valoracions VALUES (4384, 104, '28/06/2010', 4);
INSERT INTO valoracions VALUES (4384, 50, '13/07/2009', 8);
INSERT INTO valoracions VALUES (4384, 75, '30/05/2004', 3);
INSERT INTO valoracions VALUES (4385, 71, '16/03/2005', 8);
INSERT INTO valoracions VALUES (4386, 86, '22/01/2004', 5);
INSERT INTO valoracions VALUES (4386, 107, '08/08/2003', 9);
INSERT INTO valoracions VALUES (4386, 74, '07/08/2006', 3);
INSERT INTO valoracions VALUES (4386, 67, '26/12/2005', 8);
INSERT INTO valoracions VALUES (4386, 88, '06/04/2001', 4);
INSERT INTO valoracions VALUES (4386, 88, '11/02/2007', 8);
INSERT INTO valoracions VALUES (4387, 37, '12/04/2003', 5);
INSERT INTO valoracions VALUES (4387, 12, '21/06/2008', 9);
INSERT INTO valoracions VALUES (4387, 36, '19/08/2006', 9);
INSERT INTO valoracions VALUES (4387, 5, '17/04/2010', 8);
INSERT INTO valoracions VALUES (4387, 54, '30/01/2009', 3);
INSERT INTO valoracions VALUES (4388, 50, '29/11/2006', 4);
INSERT INTO valoracions VALUES (4388, 64, '14/03/2003', 5);
INSERT INTO valoracions VALUES (4388, 101, '15/08/2001', 2);
INSERT INTO valoracions VALUES (4388, 84, '23/06/2006', 7);
INSERT INTO valoracions VALUES (4388, 103, '24/09/2010', 10);
INSERT INTO valoracions VALUES (4389, 22, '23/11/2008', 4);
INSERT INTO valoracions VALUES (4389, 111, '11/01/2008', 8);
INSERT INTO valoracions VALUES (4390, 10, '03/06/2004', 7);
INSERT INTO valoracions VALUES (4390, 16, '13/06/2002', 7);
INSERT INTO valoracions VALUES (4390, 87, '01/06/2001', 7);
INSERT INTO valoracions VALUES (4390, 61, '06/05/2007', 5);
INSERT INTO valoracions VALUES (4391, 47, '05/03/2003', 8);
INSERT INTO valoracions VALUES (4391, 36, '12/10/2003', 5);
INSERT INTO valoracions VALUES (4391, 86, '04/04/2008', 3);
INSERT INTO valoracions VALUES (4391, 65, '13/12/2007', 5);
INSERT INTO valoracions VALUES (4391, 107, '23/09/2003', 5);
INSERT INTO valoracions VALUES (4392, 4, '06/03/2010', 9);
INSERT INTO valoracions VALUES (4392, 6, '02/10/2007', 8);
INSERT INTO valoracions VALUES (4392, 31, '24/09/2009', 8);
INSERT INTO valoracions VALUES (4393, 81, '25/05/2006', 7);
INSERT INTO valoracions VALUES (4393, 45, '14/03/2009', 5);
INSERT INTO valoracions VALUES (4393, 51, '30/01/2005', 4);
INSERT INTO valoracions VALUES (4393, 49, '27/02/2007', 4);
INSERT INTO valoracions VALUES (4393, 87, '03/02/2010', 2);
INSERT INTO valoracions VALUES (4394, 8, '24/05/2004', 8);
INSERT INTO valoracions VALUES (4394, 5, '08/07/2010', 7);
INSERT INTO valoracions VALUES (4394, 35, '02/11/2007', 8);
INSERT INTO valoracions VALUES (4394, 15, '30/10/2009', 9);
INSERT INTO valoracions VALUES (4395, 29, '09/09/2009', 5);
INSERT INTO valoracions VALUES (4395, 37, '31/05/2004', 9);
INSERT INTO valoracions VALUES (4395, 98, '18/12/2009', 4);
INSERT INTO valoracions VALUES (4395, 113, '24/09/2006', 3);
INSERT INTO valoracions VALUES (4395, 90, '26/09/2005', 1);
INSERT INTO valoracions VALUES (4396, 57, '08/09/2005', 8);
INSERT INTO valoracions VALUES (4396, 111, '13/04/2008', 1);
INSERT INTO valoracions VALUES (4396, 95, '14/06/2004', 5);
INSERT INTO valoracions VALUES (4396, 41, '15/11/2002', 5);
INSERT INTO valoracions VALUES (4396, 65, '24/09/2002', 5);
INSERT INTO valoracions VALUES (4397, 110, '16/04/2002', 3);
INSERT INTO valoracions VALUES (4397, 88, '09/09/2009', 6);
INSERT INTO valoracions VALUES (4397, 105, '06/12/2007', 8);
INSERT INTO valoracions VALUES (4398, 36, '08/09/2010', 6);
INSERT INTO valoracions VALUES (4398, 8, '21/07/2008', 7);
INSERT INTO valoracions VALUES (4398, 107, '18/10/2004', 6);
INSERT INTO valoracions VALUES (4398, 43, '04/11/2005', 6);
INSERT INTO valoracions VALUES (4398, 24, '27/05/2008', 10);
INSERT INTO valoracions VALUES (4399, 52, '05/01/2010', 9);
INSERT INTO valoracions VALUES (4399, 78, '22/09/2006', 4);
INSERT INTO valoracions VALUES (4399, 28, '25/12/2005', 5);
INSERT INTO valoracions VALUES (4399, 10, '28/05/2010', 8);
INSERT INTO valoracions VALUES (4400, 46, '09/08/2009', 5);
INSERT INTO valoracions VALUES (4400, 85, '15/07/2008', 8);
INSERT INTO valoracions VALUES (4400, 88, '17/09/2001', 9);
INSERT INTO valoracions VALUES (4400, 63, '11/12/2009', 5);
INSERT INTO valoracions VALUES (4400, 12, '17/05/2006', 6);
INSERT INTO valoracions VALUES (4401, 12, '29/07/2002', 7);
INSERT INTO valoracions VALUES (4401, 5, '31/03/2004', 5);
INSERT INTO valoracions VALUES (4401, 68, '23/10/2003', 4);
INSERT INTO valoracions VALUES (4401, 61, '03/02/2002', 4);
INSERT INTO valoracions VALUES (4401, 61, '15/09/2005', 5);
INSERT INTO valoracions VALUES (4401, 114, '27/08/2008', 8);
INSERT INTO valoracions VALUES (4402, 72, '09/04/2009', 4);
INSERT INTO valoracions VALUES (4402, 84, '01/05/2009', 2);
INSERT INTO valoracions VALUES (4403, 48, '13/02/2003', 7);
INSERT INTO valoracions VALUES (4403, 93, '12/07/2008', 4);
INSERT INTO valoracions VALUES (4403, 69, '28/12/2003', 10);
INSERT INTO valoracions VALUES (4403, 107, '20/03/2006', 1);
INSERT INTO valoracions VALUES (4403, 44, '28/06/2008', 6);
INSERT INTO valoracions VALUES (4403, 75, '22/12/2004', 2);
INSERT INTO valoracions VALUES (4404, 68, '19/06/2003', 4);
INSERT INTO valoracions VALUES (4404, 23, '07/03/2008', 10);
INSERT INTO valoracions VALUES (4404, 9, '03/03/2004', 9);
INSERT INTO valoracions VALUES (4404, 86, '27/07/2001', 3);
INSERT INTO valoracions VALUES (4404, 87, '08/03/2006', 7);
INSERT INTO valoracions VALUES (4404, 40, '06/08/2005', 7);
INSERT INTO valoracions VALUES (4405, 62, '03/05/2008', 10);
INSERT INTO valoracions VALUES (4405, 42, '11/03/2010', 9);
INSERT INTO valoracions VALUES (4405, 54, '13/01/2009', 7);
INSERT INTO valoracions VALUES (4406, 81, '31/05/2004', 7);
INSERT INTO valoracions VALUES (4406, 80, '17/01/2009', 8);
INSERT INTO valoracions VALUES (4406, 19, '02/05/2010', 8);
INSERT INTO valoracions VALUES (4406, 69, '23/05/2004', 6);
INSERT INTO valoracions VALUES (4407, 82, '26/04/2008', 2);
INSERT INTO valoracions VALUES (4407, 97, '26/07/2006', 4);
INSERT INTO valoracions VALUES (4407, 69, '21/03/2009', 5);
INSERT INTO valoracions VALUES (4407, 84, '27/11/2009', 7);
INSERT INTO valoracions VALUES (4407, 63, '15/12/2005', 5);
INSERT INTO valoracions VALUES (4407, 39, '18/08/2007', 9);
INSERT INTO valoracions VALUES (4407, 57, '08/04/2009', 3);
INSERT INTO valoracions VALUES (4407, 4, '03/10/2009', 10);
INSERT INTO valoracions VALUES (4408, 54, '16/05/2001', 3);
INSERT INTO valoracions VALUES (4408, 5, '10/06/2009', 5);
INSERT INTO valoracions VALUES (4408, 51, '04/08/2004', 5);
INSERT INTO valoracions VALUES (4408, 107, '04/11/2009', 8);
INSERT INTO valoracions VALUES (4409, 53, '07/10/2004', 4);
INSERT INTO valoracions VALUES (4409, 69, '15/03/2010', 4);
INSERT INTO valoracions VALUES (4409, 15, '02/10/2005', 5);
INSERT INTO valoracions VALUES (4409, 101, '27/08/2004', 2);
INSERT INTO valoracions VALUES (4409, 4, '06/05/2001', 5);
INSERT INTO valoracions VALUES (4409, 48, '09/09/2002', 4);
INSERT INTO valoracions VALUES (4409, 74, '31/01/2003', 3);
INSERT INTO valoracions VALUES (4409, 116, '10/05/2005', 2);
INSERT INTO valoracions VALUES (4410, 13, '02/04/2007', 6);
INSERT INTO valoracions VALUES (4410, 26, '08/02/2009', 8);
INSERT INTO valoracions VALUES (4410, 102, '16/09/2009', 1);
INSERT INTO valoracions VALUES (4410, 71, '19/06/2003', 5);
INSERT INTO valoracions VALUES (4410, 66, '30/01/2007', 3);
INSERT INTO valoracions VALUES (4411, 45, '07/02/2009', 7);
INSERT INTO valoracions VALUES (4411, 17, '14/10/2003', 4);
INSERT INTO valoracions VALUES (4412, 28, '13/01/2008', 5);
INSERT INTO valoracions VALUES (4412, 47, '14/04/2007', 9);
INSERT INTO valoracions VALUES (4412, 68, '13/03/2006', 3);
INSERT INTO valoracions VALUES (4413, 93, '02/02/2003', 8);
INSERT INTO valoracions VALUES (4413, 96, '22/02/2007', 9);
INSERT INTO valoracions VALUES (4413, 94, '03/07/2008', 6);
INSERT INTO valoracions VALUES (4414, 90, '13/11/2005', 9);
INSERT INTO valoracions VALUES (4414, 38, '09/07/2009', 3);
INSERT INTO valoracions VALUES (4414, 31, '15/03/2005', 9);
INSERT INTO valoracions VALUES (4414, 64, '25/10/2006', 3);
INSERT INTO valoracions VALUES (4415, 99, '22/04/2008', 2);
INSERT INTO valoracions VALUES (4416, 34, '12/02/2005', 4);
INSERT INTO valoracions VALUES (4416, 110, '05/10/2008', 8);
INSERT INTO valoracions VALUES (4416, 23, '10/07/2001', 8);
INSERT INTO valoracions VALUES (4417, 63, '27/07/2005', 8);
INSERT INTO valoracions VALUES (4418, 75, '27/08/2005', 8);
INSERT INTO valoracions VALUES (4418, 56, '10/04/2001', 5);
INSERT INTO valoracions VALUES (4418, 64, '26/07/2004', 8);
INSERT INTO valoracions VALUES (4418, 87, '03/10/2009', 7);
INSERT INTO valoracions VALUES (4418, 37, '27/07/2010', 7);
INSERT INTO valoracions VALUES (4419, 104, '07/11/2001', 1);
INSERT INTO valoracions VALUES (4419, 60, '29/09/2005', 5);
INSERT INTO valoracions VALUES (4419, 87, '28/01/2007', 7);
INSERT INTO valoracions VALUES (4419, 32, '27/08/2003', 6);
INSERT INTO valoracions VALUES (4419, 82, '20/10/2010', 3);
INSERT INTO valoracions VALUES (4419, 7, '03/05/2001', 5);
INSERT INTO valoracions VALUES (4420, 81, '24/09/2002', 8);
INSERT INTO valoracions VALUES (4420, 105, '17/09/2003', 6);
INSERT INTO valoracions VALUES (4420, 8, '10/08/2006', 6);
INSERT INTO valoracions VALUES (4421, 54, '29/04/2001', 9);
INSERT INTO valoracions VALUES (4421, 52, '08/07/2009', 4);
INSERT INTO valoracions VALUES (4421, 71, '30/01/2009', 5);
INSERT INTO valoracions VALUES (4421, 39, '03/12/2001', 8);
INSERT INTO valoracions VALUES (4421, 104, '29/01/2006', 6);
INSERT INTO valoracions VALUES (4422, 88, '02/05/2003', 7);
INSERT INTO valoracions VALUES (4422, 17, '10/07/2005', 8);
INSERT INTO valoracions VALUES (4422, 86, '31/07/2006', 2);
INSERT INTO valoracions VALUES (4423, 87, '30/09/2003', 3);
INSERT INTO valoracions VALUES (4423, 80, '12/04/2002', 9);
INSERT INTO valoracions VALUES (4423, 85, '27/03/2006', 4);
INSERT INTO valoracions VALUES (4423, 12, '11/11/2002', 8);
INSERT INTO valoracions VALUES (4423, 77, '09/08/2006', 5);
INSERT INTO valoracions VALUES (4423, 48, '13/04/2005', 9);
INSERT INTO valoracions VALUES (4423, 114, '06/01/2002', 6);
INSERT INTO valoracions VALUES (4423, 30, '26/02/2008', 9);
INSERT INTO valoracions VALUES (4423, 115, '29/03/2002', 8);
INSERT INTO valoracions VALUES (4424, 82, '02/09/2010', 3);
INSERT INTO valoracions VALUES (4424, 18, '24/11/2008', 9);
INSERT INTO valoracions VALUES (4425, 51, '03/02/2002', 10);
INSERT INTO valoracions VALUES (4425, 65, '06/10/2008', 5);
INSERT INTO valoracions VALUES (4426, 9, '03/12/2001', 5);
INSERT INTO valoracions VALUES (4426, 26, '19/06/2010', 6);
INSERT INTO valoracions VALUES (4427, 23, '22/01/2004', 8);
INSERT INTO valoracions VALUES (4427, 94, '20/02/2005', 2);
INSERT INTO valoracions VALUES (4427, 111, '05/11/2008', 5);
INSERT INTO valoracions VALUES (4427, 38, '29/02/2004', 7);
INSERT INTO valoracions VALUES (4427, 75, '14/04/2007', 7);
INSERT INTO valoracions VALUES (4427, 51, '20/01/2007', 7);
INSERT INTO valoracions VALUES (4428, 41, '21/05/2002', 4);
INSERT INTO valoracions VALUES (4428, 30, '14/02/2007', 9);
INSERT INTO valoracions VALUES (4428, 101, '02/12/2009', 8);
INSERT INTO valoracions VALUES (4428, 82, '02/06/2008', 6);
INSERT INTO valoracions VALUES (4428, 74, '01/06/2010', 3);
INSERT INTO valoracions VALUES (4428, 69, '14/09/2007', 5);
INSERT INTO valoracions VALUES (4428, 98, '23/05/2010', 10);
INSERT INTO valoracions VALUES (4429, 90, '07/07/2005', 2);
INSERT INTO valoracions VALUES (4429, 91, '20/05/2001', 2);
INSERT INTO valoracions VALUES (4429, 45, '03/02/2003', 9);
INSERT INTO valoracions VALUES (4429, 82, '10/04/2006', 2);
INSERT INTO valoracions VALUES (4429, 103, '29/05/2010', 3);
INSERT INTO valoracions VALUES (4429, 111, '30/11/2005', 5);
INSERT INTO valoracions VALUES (4429, 44, '05/12/2004', 7);
INSERT INTO valoracions VALUES (4430, 52, '27/09/2005', 8);
INSERT INTO valoracions VALUES (4430, 30, '25/12/2005', 8);
INSERT INTO valoracions VALUES (4430, 100, '12/03/2003', 9);
INSERT INTO valoracions VALUES (4430, 25, '02/07/2010', 5);
INSERT INTO valoracions VALUES (4430, 58, '25/01/2008', 9);
INSERT INTO valoracions VALUES (4431, 111, '01/12/2008', 1);
INSERT INTO valoracions VALUES (4431, 84, '09/02/2004', 8);
INSERT INTO valoracions VALUES (4431, 12, '22/05/2007', 9);
INSERT INTO valoracions VALUES (4431, 100, '02/11/2004', 6);
INSERT INTO valoracions VALUES (4432, 41, '05/04/2009', 9);
INSERT INTO valoracions VALUES (4432, 22, '22/08/2008', 8);
INSERT INTO valoracions VALUES (4432, 8, '09/07/2009', 8);
INSERT INTO valoracions VALUES (4432, 93, '25/06/2006', 3);
INSERT INTO valoracions VALUES (4433, 34, '12/05/2003', 7);
INSERT INTO valoracions VALUES (4433, 63, '19/09/2001', 9);
INSERT INTO valoracions VALUES (4433, 49, '30/07/2004', 7);
INSERT INTO valoracions VALUES (4433, 48, '07/03/2005', 7);
INSERT INTO valoracions VALUES (4433, 74, '24/11/2004', 3);
INSERT INTO valoracions VALUES (4434, 8, '17/02/2009', 6);
INSERT INTO valoracions VALUES (4434, 44, '18/10/2002', 5);
INSERT INTO valoracions VALUES (4434, 111, '09/08/2008', 3);
INSERT INTO valoracions VALUES (4434, 104, '24/08/2007', 10);
INSERT INTO valoracions VALUES (4434, 79, '12/08/2003', 4);
INSERT INTO valoracions VALUES (4435, 110, '07/11/2008', 2);
INSERT INTO valoracions VALUES (4435, 17, '24/04/2005', 5);
INSERT INTO valoracions VALUES (4435, 16, '19/07/2003', 9);
INSERT INTO valoracions VALUES (4435, 43, '06/12/2009', 9);
INSERT INTO valoracions VALUES (4435, 115, '16/11/2007', 8);
INSERT INTO valoracions VALUES (4436, 100, '13/09/2007', 3);
INSERT INTO valoracions VALUES (4436, 8, '01/04/2003', 6);
INSERT INTO valoracions VALUES (4436, 33, '14/11/2006', 10);
INSERT INTO valoracions VALUES (4436, 40, '01/10/2007', 6);
INSERT INTO valoracions VALUES (4436, 96, '02/08/2006', 9);
INSERT INTO valoracions VALUES (4436, 13, '27/06/2010', 6);
INSERT INTO valoracions VALUES (4436, 13, '31/03/2004', 8);
INSERT INTO valoracions VALUES (4437, 8, '18/11/2001', 6);
INSERT INTO valoracions VALUES (4437, 53, '10/03/2010', 3);
INSERT INTO valoracions VALUES (4439, 38, '10/12/2004', 8);
INSERT INTO valoracions VALUES (4439, 4, '26/11/2009', 5);
INSERT INTO valoracions VALUES (4439, 37, '13/06/2006', 9);
INSERT INTO valoracions VALUES (4440, 65, '19/04/2006', 8);
INSERT INTO valoracions VALUES (4440, 29, '03/05/2004', 4);
INSERT INTO valoracions VALUES (4440, 77, '14/02/2004', 6);
INSERT INTO valoracions VALUES (4440, 102, '26/05/2010', 8);
INSERT INTO valoracions VALUES (4440, 96, '21/11/2008', 6);
INSERT INTO valoracions VALUES (4440, 69, '16/04/2001', 4);
INSERT INTO valoracions VALUES (4441, 20, '13/03/2008', 7);
INSERT INTO valoracions VALUES (4441, 13, '05/12/2004', 6);
INSERT INTO valoracions VALUES (4442, 109, '30/01/2007', 9);
INSERT INTO valoracions VALUES (4442, 113, '03/05/2004', 4);
INSERT INTO valoracions VALUES (4442, 13, '25/10/2001', 6);
INSERT INTO valoracions VALUES (4442, 56, '30/08/2001', 9);
INSERT INTO valoracions VALUES (4442, 43, '14/06/2001', 4);
INSERT INTO valoracions VALUES (4442, 74, '02/08/2008', 7);
INSERT INTO valoracions VALUES (4443, 50, '04/03/2005', 9);
INSERT INTO valoracions VALUES (4443, 65, '04/05/2009', 3);
INSERT INTO valoracions VALUES (4444, 34, '21/06/2009', 7);
INSERT INTO valoracions VALUES (4444, 45, '23/01/2010', 5);
INSERT INTO valoracions VALUES (4445, 49, '21/07/2006', 5);
INSERT INTO valoracions VALUES (4445, 56, '11/07/2001', 3);
INSERT INTO valoracions VALUES (4445, 100, '24/09/2004', 6);
INSERT INTO valoracions VALUES (4445, 28, '15/09/2002', 4);
INSERT INTO valoracions VALUES (4445, 63, '09/12/2009', 10);
INSERT INTO valoracions VALUES (4446, 42, '25/09/2001', 8);
INSERT INTO valoracions VALUES (4446, 105, '20/01/2006', 5);
INSERT INTO valoracions VALUES (4446, 24, '12/10/2009', 7);
INSERT INTO valoracions VALUES (4446, 34, '15/04/2002', 6);
INSERT INTO valoracions VALUES (4446, 75, '04/09/2001', 3);
INSERT INTO valoracions VALUES (4446, 85, '24/06/2007', 2);
INSERT INTO valoracions VALUES (4447, 84, '05/04/2004', 3);
INSERT INTO valoracions VALUES (4448, 2, '09/07/2004', 10);
INSERT INTO valoracions VALUES (4448, 40, '26/09/2002', 4);
INSERT INTO valoracions VALUES (4448, 12, '10/05/2002', 6);
INSERT INTO valoracions VALUES (4448, 8, '21/08/2002', 10);
INSERT INTO valoracions VALUES (4448, 83, '18/12/2009', 3);
INSERT INTO valoracions VALUES (4448, 54, '07/11/2006', 4);
INSERT INTO valoracions VALUES (4449, 50, '20/06/2006', 4);
INSERT INTO valoracions VALUES (4449, 47, '18/06/2003', 4);
INSERT INTO valoracions VALUES (4449, 104, '27/06/2010', 3);
INSERT INTO valoracions VALUES (4450, 65, '07/12/2001', 7);
INSERT INTO valoracions VALUES (4451, 25, '06/07/2001', 9);
INSERT INTO valoracions VALUES (4451, 66, '05/05/2002', 5);
INSERT INTO valoracions VALUES (4451, 20, '29/12/2002', 10);
INSERT INTO valoracions VALUES (4451, 47, '06/03/2002', 9);
INSERT INTO valoracions VALUES (4452, 102, '19/05/2008', 4);
INSERT INTO valoracions VALUES (4452, 75, '24/06/2001', 5);
INSERT INTO valoracions VALUES (4453, 92, '03/01/2006', 6);
INSERT INTO valoracions VALUES (4454, 86, '18/12/2008', 5);
INSERT INTO valoracions VALUES (4454, 49, '04/10/2002', 5);
INSERT INTO valoracions VALUES (4454, 24, '19/07/2007', 9);
INSERT INTO valoracions VALUES (4454, 63, '15/08/2002', 3);
INSERT INTO valoracions VALUES (4455, 108, '13/02/2006', 2);
INSERT INTO valoracions VALUES (4455, 8, '23/06/2008', 5);
INSERT INTO valoracions VALUES (4455, 101, '02/07/2006', 3);
INSERT INTO valoracions VALUES (4455, 19, '23/03/2002', 8);
INSERT INTO valoracions VALUES (4456, 31, '16/08/2005', 7);
INSERT INTO valoracions VALUES (4456, 26, '27/05/2005', 6);
INSERT INTO valoracions VALUES (4456, 9, '06/12/2004', 7);
INSERT INTO valoracions VALUES (4457, 18, '04/08/2010', 7);
INSERT INTO valoracions VALUES (4457, 72, '19/10/2005', 3);
INSERT INTO valoracions VALUES (4458, 76, '02/12/2002', 2);
INSERT INTO valoracions VALUES (4459, 43, '15/08/2003', 9);
INSERT INTO valoracions VALUES (4459, 115, '28/10/2010', 4);
INSERT INTO valoracions VALUES (4459, 21, '23/01/2010', 9);
INSERT INTO valoracions VALUES (4459, 9, '13/11/2001', 8);
INSERT INTO valoracions VALUES (4460, 92, '19/04/2003', 3);
INSERT INTO valoracions VALUES (4460, 85, '01/09/2004', 3);
INSERT INTO valoracions VALUES (4460, 35, '27/07/2005', 7);
INSERT INTO valoracions VALUES (4460, 90, '21/08/2010', 7);
INSERT INTO valoracions VALUES (4460, 26, '27/01/2007', 5);
INSERT INTO valoracions VALUES (4461, 55, '26/03/2007', 6);
INSERT INTO valoracions VALUES (4461, 66, '12/09/2009', 4);
INSERT INTO valoracions VALUES (4461, 27, '08/04/2005', 8);
INSERT INTO valoracions VALUES (4461, 52, '25/01/2002', 4);
INSERT INTO valoracions VALUES (4461, 116, '08/11/2004', 8);
INSERT INTO valoracions VALUES (4461, 82, '17/09/2008', 7);
INSERT INTO valoracions VALUES (4461, 22, '08/11/2003', 9);
INSERT INTO valoracions VALUES (4461, 80, '05/08/2010', 6);
INSERT INTO valoracions VALUES (4462, 31, '04/08/2009', 7);
INSERT INTO valoracions VALUES (4462, 65, '08/08/2009', 5);
INSERT INTO valoracions VALUES (4462, 100, '04/12/2002', 3);
INSERT INTO valoracions VALUES (4462, 72, '01/01/2010', 2);
INSERT INTO valoracions VALUES (4462, 23, '24/08/2006', 9);
INSERT INTO valoracions VALUES (4462, 106, '05/03/2005', 4);
INSERT INTO valoracions VALUES (4462, 84, '24/01/2003', 4);
INSERT INTO valoracions VALUES (4463, 28, '14/07/2005', 6);
INSERT INTO valoracions VALUES (4463, 32, '24/09/2008', 9);
INSERT INTO valoracions VALUES (4463, 109, '08/10/2005', 7);
INSERT INTO valoracions VALUES (4463, 2, '05/08/2006', 8);
INSERT INTO valoracions VALUES (4463, 1, '15/03/2006', 8);
INSERT INTO valoracions VALUES (4464, 51, '23/10/2004', 3);
INSERT INTO valoracions VALUES (4464, 108, '22/12/2004', 6);
INSERT INTO valoracions VALUES (4465, 31, '18/01/2008', 7);
INSERT INTO valoracions VALUES (4465, 18, '03/10/2006', 10);
INSERT INTO valoracions VALUES (4465, 51, '19/09/2009', 4);
INSERT INTO valoracions VALUES (4466, 45, '04/07/2006', 9);
INSERT INTO valoracions VALUES (4466, 110, '22/04/2010', 4);
INSERT INTO valoracions VALUES (4466, 15, '22/04/2004', 7);
INSERT INTO valoracions VALUES (4466, 57, '03/09/2002', 3);
INSERT INTO valoracions VALUES (4467, 71, '19/05/2002', 7);
INSERT INTO valoracions VALUES (4467, 81, '22/06/2003', 7);
INSERT INTO valoracions VALUES (4467, 41, '03/07/2002', 9);
INSERT INTO valoracions VALUES (4467, 67, '20/05/2007', 4);
INSERT INTO valoracions VALUES (4467, 18, '10/05/2005', 5);
INSERT INTO valoracions VALUES (4467, 95, '30/12/2001', 5);
INSERT INTO valoracions VALUES (4468, 84, '17/05/2001', 7);
INSERT INTO valoracions VALUES (4468, 70, '27/06/2008', 2);
INSERT INTO valoracions VALUES (4468, 111, '02/12/2009', 1);
INSERT INTO valoracions VALUES (4468, 40, '19/02/2002', 5);
INSERT INTO valoracions VALUES (4468, 41, '23/04/2010', 5);
INSERT INTO valoracions VALUES (4468, 43, '13/09/2006', 6);
INSERT INTO valoracions VALUES (4469, 91, '07/06/2005', 5);
INSERT INTO valoracions VALUES (4469, 62, '30/01/2005', 5);
INSERT INTO valoracions VALUES (4469, 1, '24/10/2005', 8);
INSERT INTO valoracions VALUES (4469, 90, '30/12/2002', 8);
INSERT INTO valoracions VALUES (4469, 66, '12/01/2008', 9);
INSERT INTO valoracions VALUES (4470, 52, '30/05/2008', 7);
INSERT INTO valoracions VALUES (4470, 40, '27/08/2002', 7);
INSERT INTO valoracions VALUES (4470, 28, '13/05/2009', 9);
INSERT INTO valoracions VALUES (4470, 31, '31/01/2006', 8);
INSERT INTO valoracions VALUES (4470, 7, '02/04/2010', 10);
INSERT INTO valoracions VALUES (4470, 59, '27/05/2009', 4);
INSERT INTO valoracions VALUES (4470, 37, '12/11/2008', 5);
INSERT INTO valoracions VALUES (4471, 45, '20/10/2007', 5);
INSERT INTO valoracions VALUES (4471, 38, '23/07/2004', 7);
INSERT INTO valoracions VALUES (4471, 1, '23/07/2002', 9);
INSERT INTO valoracions VALUES (4472, 18, '04/03/2009', 7);
INSERT INTO valoracions VALUES (4472, 107, '23/03/2007', 10);
INSERT INTO valoracions VALUES (4472, 55, '19/04/2009', 9);
INSERT INTO valoracions VALUES (4472, 26, '18/09/2004', 4);
INSERT INTO valoracions VALUES (4472, 93, '23/11/2006', 6);
INSERT INTO valoracions VALUES (4472, 67, '03/08/2002', 6);
INSERT INTO valoracions VALUES (4472, 105, '02/02/2004', 2);
INSERT INTO valoracions VALUES (4472, 105, '11/10/2003', 9);
INSERT INTO valoracions VALUES (4473, 75, '07/03/2005', 3);
INSERT INTO valoracions VALUES (4474, 110, '20/05/2010', 3);
INSERT INTO valoracions VALUES (4474, 22, '16/08/2002', 5);
INSERT INTO valoracions VALUES (4475, 22, '22/08/2002', 9);
INSERT INTO valoracions VALUES (4475, 7, '09/08/2006', 9);
INSERT INTO valoracions VALUES (4475, 115, '03/09/2005', 3);
INSERT INTO valoracions VALUES (4476, 38, '05/08/2006', 4);
INSERT INTO valoracions VALUES (4476, 57, '16/10/2003', 3);
INSERT INTO valoracions VALUES (4477, 70, '17/07/2004', 7);
INSERT INTO valoracions VALUES (4477, 37, '19/04/2010', 9);
INSERT INTO valoracions VALUES (4477, 18, '12/12/2007', 10);
INSERT INTO valoracions VALUES (4477, 104, '30/06/2010', 9);
INSERT INTO valoracions VALUES (4477, 33, '21/07/2008', 8);
INSERT INTO valoracions VALUES (4477, 25, '27/09/2006', 6);
INSERT INTO valoracions VALUES (4477, 36, '17/10/2006', 7);
INSERT INTO valoracions VALUES (4477, 18, '10/09/2004', 7);
INSERT INTO valoracions VALUES (4477, 65, '24/04/2002', 3);
INSERT INTO valoracions VALUES (4478, 82, '24/12/2005', 9);
INSERT INTO valoracions VALUES (4478, 45, '30/06/2004', 9);
INSERT INTO valoracions VALUES (4478, 14, '13/06/2005', 7);
INSERT INTO valoracions VALUES (4478, 86, '14/08/2001', 9);
INSERT INTO valoracions VALUES (4478, 80, '21/08/2002', 7);
INSERT INTO valoracions VALUES (4479, 85, '31/07/2010', 8);
INSERT INTO valoracions VALUES (4479, 37, '31/08/2006', 7);
INSERT INTO valoracions VALUES (4479, 13, '26/07/2004', 7);
INSERT INTO valoracions VALUES (4479, 93, '05/09/2004', 5);
INSERT INTO valoracions VALUES (4480, 83, '12/03/2008', 5);
INSERT INTO valoracions VALUES (4480, 75, '16/04/2008', 8);
INSERT INTO valoracions VALUES (4480, 9, '21/09/2003', 5);
INSERT INTO valoracions VALUES (4480, 71, '08/10/2002', 2);
INSERT INTO valoracions VALUES (4480, 69, '07/01/2010', 4);
INSERT INTO valoracions VALUES (4480, 50, '06/07/2006', 4);
INSERT INTO valoracions VALUES (4481, 32, '30/07/2009', 7);
INSERT INTO valoracions VALUES (4481, 35, '24/08/2009', 9);
INSERT INTO valoracions VALUES (4481, 54, '03/05/2006', 6);
INSERT INTO valoracions VALUES (4482, 54, '25/11/2007', 7);
INSERT INTO valoracions VALUES (4483, 44, '12/07/2009', 7);
INSERT INTO valoracions VALUES (4483, 6, '22/02/2004', 8);
INSERT INTO valoracions VALUES (4483, 52, '29/12/2001', 6);
INSERT INTO valoracions VALUES (4483, 114, '13/07/2005', 5);
INSERT INTO valoracions VALUES (4484, 54, '17/02/2009', 4);
INSERT INTO valoracions VALUES (4484, 21, '01/01/2002', 5);
INSERT INTO valoracions VALUES (4484, 26, '31/01/2010', 6);
INSERT INTO valoracions VALUES (4484, 14, '26/03/2005', 5);
INSERT INTO valoracions VALUES (4485, 67, '18/10/2006', 9);
INSERT INTO valoracions VALUES (4485, 27, '28/11/2008', 5);
INSERT INTO valoracions VALUES (4485, 64, '16/06/2010', 8);
INSERT INTO valoracions VALUES (4485, 10, '30/12/2005', 6);
INSERT INTO valoracions VALUES (4485, 77, '05/01/2006', 2);
INSERT INTO valoracions VALUES (4485, 54, '02/01/2005', 8);
INSERT INTO valoracions VALUES (4486, 116, '15/02/2007', 5);
INSERT INTO valoracions VALUES (4486, 58, '12/08/2006', 4);
INSERT INTO valoracions VALUES (4486, 104, '12/04/2009', 8);
INSERT INTO valoracions VALUES (4487, 86, '03/06/2010', 9);
INSERT INTO valoracions VALUES (4487, 50, '10/06/2008', 8);
INSERT INTO valoracions VALUES (4487, 108, '28/10/2009', 2);
INSERT INTO valoracions VALUES (4488, 19, '26/02/2009', 9);
INSERT INTO valoracions VALUES (4488, 61, '18/03/2006', 7);
INSERT INTO valoracions VALUES (4488, 3, '09/03/2006', 7);
INSERT INTO valoracions VALUES (4489, 81, '02/01/2009', 7);
INSERT INTO valoracions VALUES (4490, 92, '22/08/2001', 4);
INSERT INTO valoracions VALUES (4490, 2, '25/09/2006', 9);
INSERT INTO valoracions VALUES (4490, 32, '04/09/2010', 4);
INSERT INTO valoracions VALUES (4490, 22, '11/08/2005', 10);
INSERT INTO valoracions VALUES (4490, 24, '08/02/2009', 6);
INSERT INTO valoracions VALUES (4491, 43, '22/02/2009', 3);
INSERT INTO valoracions VALUES (4491, 84, '12/10/2003', 5);
INSERT INTO valoracions VALUES (4491, 46, '13/10/2009', 4);
INSERT INTO valoracions VALUES (4492, 86, '11/09/2006', 6);
INSERT INTO valoracions VALUES (4492, 5, '24/06/2007', 7);
INSERT INTO valoracions VALUES (4492, 22, '13/10/2003', 5);
INSERT INTO valoracions VALUES (4492, 45, '09/05/2003', 10);
INSERT INTO valoracions VALUES (4493, 110, '23/07/2007', 3);
INSERT INTO valoracions VALUES (4493, 65, '23/12/2005', 3);
INSERT INTO valoracions VALUES (4494, 71, '20/11/2007', 7);
INSERT INTO valoracions VALUES (4494, 49, '11/05/2010', 9);
INSERT INTO valoracions VALUES (4494, 62, '09/07/2005', 6);
INSERT INTO valoracions VALUES (4495, 34, '25/11/2001', 9);
INSERT INTO valoracions VALUES (4495, 81, '07/05/2002', 8);
INSERT INTO valoracions VALUES (4495, 115, '05/05/2008', 6);
INSERT INTO valoracions VALUES (4495, 27, '18/07/2002', 6);
INSERT INTO valoracions VALUES (4495, 5, '09/09/2007', 7);
INSERT INTO valoracions VALUES (4495, 13, '15/03/2003', 5);
INSERT INTO valoracions VALUES (4495, 112, '03/07/2008', 2);
INSERT INTO valoracions VALUES (4496, 71, '18/12/2003', 3);
INSERT INTO valoracions VALUES (4496, 43, '05/03/2004', 9);
INSERT INTO valoracions VALUES (4496, 2, '21/10/2005', 5);
INSERT INTO valoracions VALUES (4497, 17, '30/09/2006', 6);
INSERT INTO valoracions VALUES (4497, 29, '17/03/2002', 6);
INSERT INTO valoracions VALUES (4497, 106, '06/08/2002', 6);
INSERT INTO valoracions VALUES (4497, 3, '26/06/2009', 5);
INSERT INTO valoracions VALUES (4497, 26, '05/09/2008', 7);
INSERT INTO valoracions VALUES (4498, 34, '24/01/2002', 9);
INSERT INTO valoracions VALUES (4498, 80, '19/12/2008', 5);
INSERT INTO valoracions VALUES (4498, 70, '07/10/2003', 8);
INSERT INTO valoracions VALUES (4498, 20, '17/08/2004', 8);
INSERT INTO valoracions VALUES (4498, 104, '20/10/2002', 9);
INSERT INTO valoracions VALUES (4498, 66, '16/10/2006', 8);
INSERT INTO valoracions VALUES (4499, 30, '02/05/2007', 8);
INSERT INTO valoracions VALUES (4499, 4, '27/03/2005', 6);
INSERT INTO valoracions VALUES (4499, 4, '22/11/2001', 7);
INSERT INTO valoracions VALUES (4499, 95, '22/04/2007', 9);
INSERT INTO valoracions VALUES (4500, 63, '31/08/2004', 5);
INSERT INTO valoracions VALUES (4500, 73, '20/05/2007', 5);
INSERT INTO valoracions VALUES (4500, 39, '14/09/2008', 9);
INSERT INTO valoracions VALUES (4500, 73, '05/01/2010', 2);
INSERT INTO valoracions VALUES (4500, 104, '19/05/2002', 2);
INSERT INTO valoracions VALUES (4501, 7, '26/09/2008', 8);
INSERT INTO valoracions VALUES (4501, 90, '06/05/2001', 4);
INSERT INTO valoracions VALUES (4501, 29, '12/05/2009', 8);
INSERT INTO valoracions VALUES (4501, 35, '05/05/2005', 10);
INSERT INTO valoracions VALUES (4502, 102, '31/12/2002', 4);
INSERT INTO valoracions VALUES (4502, 9, '14/02/2005', 6);
INSERT INTO valoracions VALUES (4502, 17, '16/07/2005', 6);
INSERT INTO valoracions VALUES (4502, 7, '03/01/2003', 9);
INSERT INTO valoracions VALUES (4503, 24, '02/12/2008', 9);
INSERT INTO valoracions VALUES (4503, 91, '07/03/2003', 2);
INSERT INTO valoracions VALUES (4503, 47, '15/06/2001', 9);
INSERT INTO valoracions VALUES (4503, 90, '24/01/2005', 10);
INSERT INTO valoracions VALUES (4503, 46, '12/12/2005', 10);
INSERT INTO valoracions VALUES (4504, 14, '15/04/2008', 10);
INSERT INTO valoracions VALUES (4504, 13, '08/06/2010', 8);
INSERT INTO valoracions VALUES (4504, 36, '29/12/2005', 7);
INSERT INTO valoracions VALUES (4504, 26, '08/03/2004', 5);
INSERT INTO valoracions VALUES (4504, 25, '19/12/2007', 9);
INSERT INTO valoracions VALUES (4505, 47, '01/01/2003', 7);
INSERT INTO valoracions VALUES (4505, 82, '19/04/2007', 6);
INSERT INTO valoracions VALUES (4505, 99, '25/01/2009', 4);
INSERT INTO valoracions VALUES (4505, 99, '03/03/2004', 7);
INSERT INTO valoracions VALUES (4505, 95, '05/12/2004', 3);
INSERT INTO valoracions VALUES (4505, 39, '17/11/2007', 9);
INSERT INTO valoracions VALUES (4506, 113, '29/04/2003', 5);
INSERT INTO valoracions VALUES (4506, 116, '21/12/2005', 6);
INSERT INTO valoracions VALUES (4507, 71, '17/08/2010', 7);
INSERT INTO valoracions VALUES (4507, 47, '07/07/2006', 9);
INSERT INTO valoracions VALUES (4507, 103, '17/08/2001', 5);
INSERT INTO valoracions VALUES (4508, 11, '03/07/2002', 9);
INSERT INTO valoracions VALUES (4508, 82, '27/11/2009', 10);
INSERT INTO valoracions VALUES (4508, 14, '13/11/2005', 9);
INSERT INTO valoracions VALUES (4509, 62, '28/07/2001', 5);
INSERT INTO valoracions VALUES (4509, 63, '24/11/2002', 5);
INSERT INTO valoracions VALUES (4510, 63, '23/03/2002', 8);
INSERT INTO valoracions VALUES (4510, 48, '03/04/2006', 9);
INSERT INTO valoracions VALUES (4510, 41, '19/04/2003', 6);
INSERT INTO valoracions VALUES (4510, 5, '30/10/2003', 7);
INSERT INTO valoracions VALUES (4511, 49, '31/10/2002', 7);
INSERT INTO valoracions VALUES (4511, 100, '27/10/2006', 5);
INSERT INTO valoracions VALUES (4511, 60, '05/05/2001', 5);
INSERT INTO valoracions VALUES (4511, 38, '19/07/2001', 6);
INSERT INTO valoracions VALUES (4512, 87, '20/03/2002', 6);
INSERT INTO valoracions VALUES (4513, 38, '26/07/2008', 8);
INSERT INTO valoracions VALUES (4513, 33, '16/08/2003', 9);
INSERT INTO valoracions VALUES (4513, 72, '23/03/2007', 2);
INSERT INTO valoracions VALUES (4513, 63, '18/04/2009', 8);
INSERT INTO valoracions VALUES (4513, 10, '24/12/2004', 5);
INSERT INTO valoracions VALUES (4513, 15, '12/03/2009', 6);
INSERT INTO valoracions VALUES (4514, 1, '24/08/2008', 9);
INSERT INTO valoracions VALUES (4514, 32, '02/05/2001', 6);
INSERT INTO valoracions VALUES (4514, 96, '10/12/2006', 9);
INSERT INTO valoracions VALUES (4514, 80, '19/06/2005', 7);
INSERT INTO valoracions VALUES (4514, 5, '22/11/2003', 5);
INSERT INTO valoracions VALUES (4515, 72, '08/02/2009', 9);
INSERT INTO valoracions VALUES (4515, 73, '20/06/2009', 7);
INSERT INTO valoracions VALUES (4516, 82, '01/01/2008', 5);
INSERT INTO valoracions VALUES (4517, 113, '15/07/2003', 1);
INSERT INTO valoracions VALUES (4517, 108, '10/11/2002', 0);
INSERT INTO valoracions VALUES (4517, 85, '05/07/2006', 3);
INSERT INTO valoracions VALUES (4517, 107, '25/07/2002', 7);
INSERT INTO valoracions VALUES (4517, 65, '03/05/2010', 5);
INSERT INTO valoracions VALUES (4518, 111, '16/07/2004', 9);
INSERT INTO valoracions VALUES (4518, 67, '12/06/2001', 5);
INSERT INTO valoracions VALUES (4518, 53, '05/02/2002', 8);
INSERT INTO valoracions VALUES (4518, 48, '15/06/2004', 4);
INSERT INTO valoracions VALUES (4518, 88, '06/12/2002', 8);
INSERT INTO valoracions VALUES (4518, 2, '02/01/2002', 8);
INSERT INTO valoracions VALUES (4519, 81, '10/01/2009', 4);
INSERT INTO valoracions VALUES (4519, 86, '02/03/2007', 7);
INSERT INTO valoracions VALUES (4519, 8, '09/08/2001', 7);
INSERT INTO valoracions VALUES (4519, 113, '02/04/2001', 9);
INSERT INTO valoracions VALUES (4519, 29, '01/05/2004', 5);
INSERT INTO valoracions VALUES (4519, 82, '08/08/2008', 8);
INSERT INTO valoracions VALUES (4520, 55, '15/09/2010', 3);
INSERT INTO valoracions VALUES (4520, 56, '20/02/2006', 3);
INSERT INTO valoracions VALUES (4520, 19, '16/06/2008', 5);
INSERT INTO valoracions VALUES (4520, 25, '04/06/2004', 8);
INSERT INTO valoracions VALUES (4521, 92, '05/03/2005', 6);
INSERT INTO valoracions VALUES (4521, 44, '25/11/2009', 10);
INSERT INTO valoracions VALUES (4521, 67, '20/05/2008', 4);
INSERT INTO valoracions VALUES (4523, 78, '22/12/2004', 8);
INSERT INTO valoracions VALUES (4523, 93, '22/03/2005', 2);
INSERT INTO valoracions VALUES (4523, 74, '07/08/2005', 8);
INSERT INTO valoracions VALUES (4524, 50, '05/07/2004', 9);
INSERT INTO valoracions VALUES (4524, 47, '07/06/2005', 3);
INSERT INTO valoracions VALUES (4524, 11, '01/02/2004', 7);
INSERT INTO valoracions VALUES (4524, 80, '02/05/2003', 5);
INSERT INTO valoracions VALUES (4525, 44, '31/12/2001', 7);
INSERT INTO valoracions VALUES (4525, 9, '27/05/2001', 7);
INSERT INTO valoracions VALUES (4525, 32, '26/02/2008', 5);
INSERT INTO valoracions VALUES (4526, 50, '16/04/2003', 7);
INSERT INTO valoracions VALUES (4526, 24, '04/12/2008', 8);
INSERT INTO valoracions VALUES (4526, 67, '29/06/2009', 2);
INSERT INTO valoracions VALUES (4528, 69, '19/07/2009', 8);
INSERT INTO valoracions VALUES (4528, 101, '15/04/2004', 8);
INSERT INTO valoracions VALUES (4528, 60, '12/08/2007', 5);
INSERT INTO valoracions VALUES (4528, 106, '08/09/2009', 7);
INSERT INTO valoracions VALUES (4528, 69, '18/10/2003', 2);
INSERT INTO valoracions VALUES (4528, 97, '18/05/2001', 6);
INSERT INTO valoracions VALUES (4529, 45, '28/01/2003', 4);
INSERT INTO valoracions VALUES (4529, 58, '05/11/2004', 7);
INSERT INTO valoracions VALUES (4529, 15, '01/10/2004', 10);
INSERT INTO valoracions VALUES (4530, 17, '04/04/2005', 9);
INSERT INTO valoracions VALUES (4530, 110, '31/12/2003', 3);
INSERT INTO valoracions VALUES (4531, 23, '13/05/2007', 5);
INSERT INTO valoracions VALUES (4532, 91, '30/09/2001', 2);
INSERT INTO valoracions VALUES (4532, 98, '12/03/2003', 8);
INSERT INTO valoracions VALUES (4532, 75, '02/08/2004', 9);
INSERT INTO valoracions VALUES (4532, 53, '11/03/2006', 6);
INSERT INTO valoracions VALUES (4532, 86, '22/11/2009', 4);
INSERT INTO valoracions VALUES (4532, 7, '13/06/2002', 8);
INSERT INTO valoracions VALUES (4533, 78, '27/11/2001', 7);
INSERT INTO valoracions VALUES (4533, 68, '24/04/2003', 4);
INSERT INTO valoracions VALUES (4533, 18, '26/02/2003', 5);
INSERT INTO valoracions VALUES (4533, 106, '11/03/2009', 7);
INSERT INTO valoracions VALUES (4533, 105, '16/09/2005', 4);
INSERT INTO valoracions VALUES (4534, 87, '31/10/2007', 6);
INSERT INTO valoracions VALUES (4534, 34, '17/01/2010', 5);
INSERT INTO valoracions VALUES (4535, 94, '12/07/2010', 6);
INSERT INTO valoracions VALUES (4535, 63, '16/09/2008', 8);
INSERT INTO valoracions VALUES (4535, 9, '12/08/2001', 5);
INSERT INTO valoracions VALUES (4536, 35, '23/11/2004', 6);
INSERT INTO valoracions VALUES (4536, 79, '03/11/2008', 8);
INSERT INTO valoracions VALUES (4536, 43, '22/04/2010', 5);
INSERT INTO valoracions VALUES (4537, 3, '27/12/2007', 6);
INSERT INTO valoracions VALUES (4537, 99, '11/03/2006', 2);
INSERT INTO valoracions VALUES (4537, 42, '13/05/2002', 9);
INSERT INTO valoracions VALUES (4537, 81, '16/07/2005', 6);
INSERT INTO valoracions VALUES (4537, 62, '26/09/2007', 5);
INSERT INTO valoracions VALUES (4537, 60, '22/06/2003', 9);
INSERT INTO valoracions VALUES (4538, 106, '08/03/2008', 10);
INSERT INTO valoracions VALUES (4538, 26, '06/12/2001', 10);
INSERT INTO valoracions VALUES (4538, 3, '19/07/2010', 8);
INSERT INTO valoracions VALUES (4538, 58, '20/09/2007', 4);
INSERT INTO valoracions VALUES (4539, 6, '31/05/2004', 8);
INSERT INTO valoracions VALUES (4540, 23, '04/05/2007', 5);
INSERT INTO valoracions VALUES (4540, 115, '23/11/2008', 3);
INSERT INTO valoracions VALUES (4540, 112, '26/03/2005', 1);
INSERT INTO valoracions VALUES (4541, 22, '11/08/2002', 5);
INSERT INTO valoracions VALUES (4541, 116, '30/07/2006', 9);
INSERT INTO valoracions VALUES (4542, 91, '22/10/2004', 4);
INSERT INTO valoracions VALUES (4542, 89, '29/11/2004', 6);
INSERT INTO valoracions VALUES (4542, 51, '10/10/2008', 8);
INSERT INTO valoracions VALUES (4542, 4, '20/09/2009', 7);
INSERT INTO valoracions VALUES (4543, 112, '23/01/2010', 8);
INSERT INTO valoracions VALUES (4543, 12, '26/07/2008', 7);
INSERT INTO valoracions VALUES (4543, 105, '13/04/2003', 6);
INSERT INTO valoracions VALUES (4543, 19, '07/07/2006', 9);
INSERT INTO valoracions VALUES (4544, 51, '06/08/2006', 9);
INSERT INTO valoracions VALUES (4544, 32, '07/07/2007', 8);
INSERT INTO valoracions VALUES (4544, 89, '01/10/2001', 2);
INSERT INTO valoracions VALUES (4544, 39, '20/08/2009', 7);
INSERT INTO valoracions VALUES (4545, 81, '17/09/2003', 6);
INSERT INTO valoracions VALUES (4545, 23, '12/02/2005', 9);
INSERT INTO valoracions VALUES (4545, 113, '23/04/2008', 7);
INSERT INTO valoracions VALUES (4545, 74, '18/04/2007', 8);
INSERT INTO valoracions VALUES (4546, 65, '14/02/2007', 10);
INSERT INTO valoracions VALUES (4546, 84, '27/09/2002', 2);
INSERT INTO valoracions VALUES (4546, 88, '13/10/2003', 4);
INSERT INTO valoracions VALUES (4547, 46, '07/07/2007', 4);
INSERT INTO valoracions VALUES (4547, 58, '29/07/2002', 9);
INSERT INTO valoracions VALUES (4547, 33, '15/06/2007', 5);
INSERT INTO valoracions VALUES (4547, 83, '25/04/2003', 4);
INSERT INTO valoracions VALUES (4547, 98, '15/10/2005', 8);
INSERT INTO valoracions VALUES (4548, 50, '01/10/2008', 8);
INSERT INTO valoracions VALUES (4548, 65, '22/10/2001', 7);
INSERT INTO valoracions VALUES (4549, 44, '10/10/2001', 7);
INSERT INTO valoracions VALUES (4549, 90, '25/02/2007', 5);
INSERT INTO valoracions VALUES (4549, 49, '13/03/2004', 4);
INSERT INTO valoracions VALUES (4549, 108, '24/07/2003', 3);
INSERT INTO valoracions VALUES (4550, 116, '29/11/2009', 5);
INSERT INTO valoracions VALUES (4550, 2, '28/06/2004', 8);
INSERT INTO valoracions VALUES (4550, 51, '28/02/2007', 6);
INSERT INTO valoracions VALUES (4550, 47, '23/07/2003', 8);
INSERT INTO valoracions VALUES (4550, 17, '19/05/2006', 9);
INSERT INTO valoracions VALUES (4550, 44, '08/06/2001', 6);
INSERT INTO valoracions VALUES (4550, 10, '26/06/2004', 6);
INSERT INTO valoracions VALUES (4550, 33, '21/10/2001', 6);
INSERT INTO valoracions VALUES (4551, 26, '07/10/2003', 7);
INSERT INTO valoracions VALUES (4551, 32, '30/05/2004', 9);
INSERT INTO valoracions VALUES (4551, 57, '03/01/2009', 4);
INSERT INTO valoracions VALUES (4552, 4, '12/09/2005', 5);
INSERT INTO valoracions VALUES (4552, 82, '03/11/2007', 10);
INSERT INTO valoracions VALUES (4552, 16, '21/07/2004', 6);
INSERT INTO valoracions VALUES (4553, 22, '18/07/2004', 6);
INSERT INTO valoracions VALUES (4553, 92, '23/06/2001', 8);
INSERT INTO valoracions VALUES (4553, 15, '17/09/2009', 6);
INSERT INTO valoracions VALUES (4553, 76, '15/05/2007', 4);
INSERT INTO valoracions VALUES (4554, 30, '20/11/2006', 9);
INSERT INTO valoracions VALUES (4554, 82, '18/01/2009', 5);
INSERT INTO valoracions VALUES (4554, 49, '13/09/2007', 4);
INSERT INTO valoracions VALUES (4554, 88, '12/02/2007', 3);
INSERT INTO valoracions VALUES (4554, 17, '01/02/2003', 9);
INSERT INTO valoracions VALUES (4555, 18, '25/04/2006', 8);
INSERT INTO valoracions VALUES (4555, 37, '18/05/2006', 7);
INSERT INTO valoracions VALUES (4555, 81, '27/03/2007', 8);
INSERT INTO valoracions VALUES (4555, 36, '06/04/2007', 9);
INSERT INTO valoracions VALUES (4556, 9, '19/03/2007', 6);
INSERT INTO valoracions VALUES (4556, 35, '09/01/2003', 5);
INSERT INTO valoracions VALUES (4556, 59, '17/06/2003', 7);
INSERT INTO valoracions VALUES (4556, 16, '16/07/2006', 9);
INSERT INTO valoracions VALUES (4557, 56, '26/12/2001', 9);
INSERT INTO valoracions VALUES (4557, 78, '10/08/2009', 8);
INSERT INTO valoracions VALUES (4557, 41, '08/05/2005', 9);
INSERT INTO valoracions VALUES (4557, 92, '12/09/2004', 6);
INSERT INTO valoracions VALUES (4558, 24, '14/10/2005', 7);
INSERT INTO valoracions VALUES (4558, 24, '29/05/2008', 8);
INSERT INTO valoracions VALUES (4559, 56, '08/04/2002', 3);
INSERT INTO valoracions VALUES (4559, 68, '14/03/2005', 3);
INSERT INTO valoracions VALUES (4559, 38, '17/05/2010', 6);
INSERT INTO valoracions VALUES (4559, 78, '15/07/2002', 8);
INSERT INTO valoracions VALUES (4559, 7, '04/05/2004', 9);
INSERT INTO valoracions VALUES (4561, 65, '26/01/2004', 9);
INSERT INTO valoracions VALUES (4561, 96, '06/12/2008', 7);
INSERT INTO valoracions VALUES (4561, 27, '12/05/2007', 6);
INSERT INTO valoracions VALUES (4561, 103, '15/02/2006', 2);
INSERT INTO valoracions VALUES (4563, 74, '04/07/2001', 3);
INSERT INTO valoracions VALUES (4563, 53, '10/03/2004', 9);
INSERT INTO valoracions VALUES (4564, 84, '25/08/2008', 5);
INSERT INTO valoracions VALUES (4564, 95, '22/07/2003', 6);
INSERT INTO valoracions VALUES (4564, 68, '13/01/2005', 6);
INSERT INTO valoracions VALUES (4564, 60, '08/04/2006', 9);
INSERT INTO valoracions VALUES (4565, 4, '04/02/2009', 7);
INSERT INTO valoracions VALUES (4565, 29, '17/12/2009', 7);
INSERT INTO valoracions VALUES (4565, 34, '28/01/2009', 4);
INSERT INTO valoracions VALUES (4565, 60, '24/06/2008', 5);
INSERT INTO valoracions VALUES (4566, 106, '07/09/2007', 3);
INSERT INTO valoracions VALUES (4566, 112, '25/11/2001', 6);
INSERT INTO valoracions VALUES (4567, 48, '05/09/2003', 9);
INSERT INTO valoracions VALUES (4567, 112, '20/05/2008', 8);
INSERT INTO valoracions VALUES (4569, 73, '07/11/2006', 8);
INSERT INTO valoracions VALUES (4570, 9, '17/06/2002', 6);
INSERT INTO valoracions VALUES (4570, 27, '29/01/2010', 9);
INSERT INTO valoracions VALUES (4571, 70, '23/09/2007', 4);
INSERT INTO valoracions VALUES (4572, 101, '20/01/2003', 5);
INSERT INTO valoracions VALUES (4572, 97, '15/12/2009', 1);
INSERT INTO valoracions VALUES (4572, 100, '27/09/2005', 4);
INSERT INTO valoracions VALUES (4572, 94, '29/01/2006', 6);
INSERT INTO valoracions VALUES (4572, 86, '08/06/2004', 2);
INSERT INTO valoracions VALUES (4572, 50, '08/09/2007', 4);
INSERT INTO valoracions VALUES (4573, 2, '02/05/2005', 8);
INSERT INTO valoracions VALUES (4574, 105, '08/02/2003', 1);
INSERT INTO valoracions VALUES (4574, 102, '25/06/2010', 4);
INSERT INTO valoracions VALUES (4574, 47, '31/07/2004', 10);
INSERT INTO valoracions VALUES (4574, 34, '23/06/2009', 8);
INSERT INTO valoracions VALUES (4574, 17, '17/11/2003', 5);
INSERT INTO valoracions VALUES (4575, 14, '08/06/2006', 7);
INSERT INTO valoracions VALUES (4575, 82, '01/08/2005', 7);
INSERT INTO valoracions VALUES (4575, 73, '18/12/2008', 8);
INSERT INTO valoracions VALUES (4575, 73, '02/08/2007', 9);
INSERT INTO valoracions VALUES (4575, 65, '22/07/2001', 5);
INSERT INTO valoracions VALUES (4575, 97, '23/03/2008', 8);
INSERT INTO valoracions VALUES (4575, 85, '27/03/2006', 4);
INSERT INTO valoracions VALUES (4575, 116, '15/10/2004', 2);
INSERT INTO valoracions VALUES (4576, 36, '02/06/2001', 5);
INSERT INTO valoracions VALUES (4576, 91, '04/02/2005', 4);
INSERT INTO valoracions VALUES (4576, 100, '08/06/2008', 9);
INSERT INTO valoracions VALUES (4576, 59, '02/03/2004', 4);
INSERT INTO valoracions VALUES (4577, 46, '05/05/2007', 7);
INSERT INTO valoracions VALUES (4577, 14, '10/12/2003', 9);
INSERT INTO valoracions VALUES (4577, 98, '12/09/2008', 6);
INSERT INTO valoracions VALUES (4578, 47, '09/09/2001', 9);
INSERT INTO valoracions VALUES (4578, 70, '03/04/2007', 2);
INSERT INTO valoracions VALUES (4578, 113, '24/08/2009', 1);
INSERT INTO valoracions VALUES (4578, 14, '01/07/2009', 5);
INSERT INTO valoracions VALUES (4578, 80, '18/10/2005', 4);
INSERT INTO valoracions VALUES (4578, 91, '23/01/2009', 3);
INSERT INTO valoracions VALUES (4579, 40, '09/06/2003', 10);
INSERT INTO valoracions VALUES (4579, 102, '14/05/2006', 7);
INSERT INTO valoracions VALUES (4579, 43, '21/11/2009', 9);
INSERT INTO valoracions VALUES (4580, 80, '01/06/2009', 9);
INSERT INTO valoracions VALUES (4580, 59, '02/04/2007', 3);
INSERT INTO valoracions VALUES (4580, 46, '20/08/2007', 5);
INSERT INTO valoracions VALUES (4580, 105, '20/03/2003', 10);
INSERT INTO valoracions VALUES (4581, 24, '02/10/2004', 9);
INSERT INTO valoracions VALUES (4581, 13, '18/08/2009', 6);
INSERT INTO valoracions VALUES (4581, 31, '28/04/2005', 8);
INSERT INTO valoracions VALUES (4582, 107, '24/05/2007', 7);
INSERT INTO valoracions VALUES (4582, 87, '03/10/2003', 7);
INSERT INTO valoracions VALUES (4582, 112, '14/07/2008', 4);
INSERT INTO valoracions VALUES (4582, 95, '25/11/2004', 6);
INSERT INTO valoracions VALUES (4582, 67, '15/01/2004', 7);
INSERT INTO valoracions VALUES (4583, 16, '08/10/2010', 5);
INSERT INTO valoracions VALUES (4583, 7, '22/03/2009', 7);
INSERT INTO valoracions VALUES (4583, 47, '09/09/2002', 4);
INSERT INTO valoracions VALUES (4583, 19, '02/08/2010', 5);
INSERT INTO valoracions VALUES (4583, 30, '10/02/2005', 4);
INSERT INTO valoracions VALUES (4584, 65, '16/12/2007', 5);
INSERT INTO valoracions VALUES (4584, 59, '04/02/2002', 8);
INSERT INTO valoracions VALUES (4584, 96, '17/09/2001', 1);
INSERT INTO valoracions VALUES (4584, 14, '12/05/2008', 6);
INSERT INTO valoracions VALUES (4585, 58, '19/01/2010', 6);
INSERT INTO valoracions VALUES (4585, 54, '21/06/2010', 6);
INSERT INTO valoracions VALUES (4585, 68, '04/07/2009', 9);
INSERT INTO valoracions VALUES (4585, 78, '01/08/2005', 3);
INSERT INTO valoracions VALUES (4585, 39, '31/12/2005', 7);
INSERT INTO valoracions VALUES (4585, 14, '25/08/2002', 10);
INSERT INTO valoracions VALUES (4586, 103, '22/03/2010', 9);
INSERT INTO valoracions VALUES (4586, 43, '19/09/2007', 7);
INSERT INTO valoracions VALUES (4586, 59, '06/02/2003', 5);
INSERT INTO valoracions VALUES (4586, 24, '02/11/2005', 8);
INSERT INTO valoracions VALUES (4586, 19, '18/04/2007', 10);
INSERT INTO valoracions VALUES (4587, 28, '05/03/2003', 9);
INSERT INTO valoracions VALUES (4587, 57, '05/08/2001', 6);
INSERT INTO valoracions VALUES (4587, 36, '11/08/2008', 7);
INSERT INTO valoracions VALUES (4587, 60, '25/05/2002', 8);
INSERT INTO valoracions VALUES (4588, 58, '22/06/2003', 6);
INSERT INTO valoracions VALUES (4588, 63, '06/06/2001', 8);
INSERT INTO valoracions VALUES (4588, 15, '29/09/2001', 7);
INSERT INTO valoracions VALUES (4588, 24, '12/09/2009', 5);
INSERT INTO valoracions VALUES (4588, 2, '24/08/2002', 5);
INSERT INTO valoracions VALUES (4588, 74, '18/04/2004', 2);
INSERT INTO valoracions VALUES (4588, 52, '27/12/2007', 5);
INSERT INTO valoracions VALUES (4589, 67, '06/10/2005', 9);
INSERT INTO valoracions VALUES (4590, 38, '06/07/2004', 7);
INSERT INTO valoracions VALUES (4590, 45, '04/06/2010', 8);
INSERT INTO valoracions VALUES (4590, 35, '11/01/2006', 9);
INSERT INTO valoracions VALUES (4590, 89, '15/04/2005', 7);
INSERT INTO valoracions VALUES (4590, 47, '06/10/2005', 10);
INSERT INTO valoracions VALUES (4590, 53, '10/10/2002', 9);
INSERT INTO valoracions VALUES (4591, 74, '28/09/2008', 6);
INSERT INTO valoracions VALUES (4591, 37, '14/11/2002', 5);
INSERT INTO valoracions VALUES (4591, 28, '01/02/2009', 8);
INSERT INTO valoracions VALUES (4591, 11, '14/06/2004', 6);
INSERT INTO valoracions VALUES (4591, 107, '26/01/2010', 1);
INSERT INTO valoracions VALUES (4591, 113, '22/10/2005', 10);
INSERT INTO valoracions VALUES (4592, 26, '02/02/2003', 7);
INSERT INTO valoracions VALUES (4593, 20, '12/10/2004', 8);
INSERT INTO valoracions VALUES (4593, 97, '07/08/2005', 4);
INSERT INTO valoracions VALUES (4593, 55, '22/06/2008', 5);
INSERT INTO valoracions VALUES (4593, 108, '05/09/2002', 4);
INSERT INTO valoracions VALUES (4593, 91, '18/10/2004', 3);
INSERT INTO valoracions VALUES (4593, 83, '16/07/2008', 7);
INSERT INTO valoracions VALUES (4593, 15, '07/11/2007', 9);
INSERT INTO valoracions VALUES (4593, 34, '12/02/2002', 7);
INSERT INTO valoracions VALUES (4593, 46, '07/02/2005', 7);
INSERT INTO valoracions VALUES (4593, 39, '19/07/2009', 7);
INSERT INTO valoracions VALUES (4594, 110, '22/04/2003', 2);
INSERT INTO valoracions VALUES (4594, 34, '16/01/2006', 9);
INSERT INTO valoracions VALUES (4594, 29, '30/07/2008', 8);
INSERT INTO valoracions VALUES (4594, 88, '15/07/2005', 10);
INSERT INTO valoracions VALUES (4594, 94, '27/03/2010', 8);
INSERT INTO valoracions VALUES (4594, 103, '29/01/2002', 10);
INSERT INTO valoracions VALUES (4595, 88, '15/01/2006', 3);
INSERT INTO valoracions VALUES (4596, 69, '05/06/2002', 4);
INSERT INTO valoracions VALUES (4596, 108, '25/07/2001', 10);
INSERT INTO valoracions VALUES (4596, 7, '27/07/2002', 10);
INSERT INTO valoracions VALUES (4596, 75, '24/04/2001', 8);
INSERT INTO valoracions VALUES (4596, 86, '18/03/2008', 7);
INSERT INTO valoracions VALUES (4596, 63, '03/07/2004', 10);
INSERT INTO valoracions VALUES (4596, 62, '17/01/2002', 3);
INSERT INTO valoracions VALUES (4597, 105, '14/04/2003', 1);
INSERT INTO valoracions VALUES (4597, 97, '19/03/2007', 7);
INSERT INTO valoracions VALUES (4597, 28, '13/01/2002', 4);
INSERT INTO valoracions VALUES (4597, 40, '27/09/2006', 5);
INSERT INTO valoracions VALUES (4597, 14, '04/06/2008', 5);
INSERT INTO valoracions VALUES (4597, 68, '20/03/2007', 5);
INSERT INTO valoracions VALUES (4598, 98, '03/07/2001', 5);
INSERT INTO valoracions VALUES (4598, 85, '31/01/2007', 6);
INSERT INTO valoracions VALUES (4598, 41, '29/01/2002', 8);
INSERT INTO valoracions VALUES (4598, 42, '23/02/2002', 8);
INSERT INTO valoracions VALUES (4599, 22, '31/05/2008', 9);
INSERT INTO valoracions VALUES (4600, 85, '07/06/2003', 7);
INSERT INTO valoracions VALUES (4600, 106, '02/06/2008', 6);
INSERT INTO valoracions VALUES (4600, 100, '16/06/2002', 6);
INSERT INTO valoracions VALUES (4600, 64, '29/11/2002', 7);
INSERT INTO valoracions VALUES (4600, 103, '03/06/2003', 8);
INSERT INTO valoracions VALUES (4600, 7, '08/02/2003', 9);
INSERT INTO valoracions VALUES (4600, 24, '30/07/2003', 10);
INSERT INTO valoracions VALUES (4601, 100, '04/06/2008', 4);
INSERT INTO valoracions VALUES (4601, 42, '29/09/2003', 5);
INSERT INTO valoracions VALUES (4601, 94, '18/05/2007', 6);
INSERT INTO valoracions VALUES (4601, 91, '28/01/2002', 3);
INSERT INTO valoracions VALUES (4603, 1, '16/03/2004', 10);
INSERT INTO valoracions VALUES (4603, 39, '31/07/2005', 3);
INSERT INTO valoracions VALUES (4603, 13, '20/12/2007', 7);
INSERT INTO valoracions VALUES (4603, 32, '22/04/2010', 6);
INSERT INTO valoracions VALUES (4604, 104, '28/11/2009', 2);
INSERT INTO valoracions VALUES (4604, 97, '24/09/2004', 9);
INSERT INTO valoracions VALUES (4604, 104, '26/10/2001', 7);
INSERT INTO valoracions VALUES (4605, 85, '06/11/2004', 7);
INSERT INTO valoracions VALUES (4605, 90, '27/09/2003', 6);
INSERT INTO valoracions VALUES (4605, 10, '03/02/2007', 8);
INSERT INTO valoracions VALUES (4605, 49, '12/04/2003', 4);
INSERT INTO valoracions VALUES (4605, 101, '05/04/2010', 7);
INSERT INTO valoracions VALUES (4606, 50, '17/02/2009', 3);
INSERT INTO valoracions VALUES (4606, 112, '27/04/2006', 6);
INSERT INTO valoracions VALUES (4606, 86, '28/03/2007', 5);
INSERT INTO valoracions VALUES (4606, 56, '16/04/2002', 4);
INSERT INTO valoracions VALUES (4606, 73, '06/03/2002', 4);
INSERT INTO valoracions VALUES (4607, 37, '03/07/2007', 4);
INSERT INTO valoracions VALUES (4608, 107, '25/10/2002', 3);
INSERT INTO valoracions VALUES (4608, 20, '17/11/2004', 8);
INSERT INTO valoracions VALUES (4608, 85, '26/12/2002', 6);
INSERT INTO valoracions VALUES (4609, 101, '30/04/2006', 3);
INSERT INTO valoracions VALUES (4609, 15, '01/01/2005', 8);
INSERT INTO valoracions VALUES (4609, 89, '26/01/2005', 10);
INSERT INTO valoracions VALUES (4609, 107, '23/01/2007', 2);
INSERT INTO valoracions VALUES (4609, 19, '05/08/2009', 4);
INSERT INTO valoracions VALUES (4609, 11, '02/08/2002', 9);
INSERT INTO valoracions VALUES (4610, 86, '10/07/2010', 3);
INSERT INTO valoracions VALUES (4610, 47, '22/07/2009', 6);
INSERT INTO valoracions VALUES (4610, 85, '25/09/2006', 2);
INSERT INTO valoracions VALUES (4610, 57, '24/08/2003', 5);
INSERT INTO valoracions VALUES (4611, 25, '04/11/2009', 8);
INSERT INTO valoracions VALUES (4611, 50, '16/05/2010', 6);
INSERT INTO valoracions VALUES (4611, 78, '22/11/2005', 5);
INSERT INTO valoracions VALUES (4611, 52, '19/10/2004', 6);
INSERT INTO valoracions VALUES (4611, 102, '24/10/2005', 6);
INSERT INTO valoracions VALUES (4611, 6, '18/05/2003', 6);
INSERT INTO valoracions VALUES (4611, 81, '05/05/2006', 5);
INSERT INTO valoracions VALUES (4612, 101, '07/06/2004', 10);
INSERT INTO valoracions VALUES (4612, 4, '11/12/2004', 6);
INSERT INTO valoracions VALUES (4612, 107, '05/03/2002', 1);
INSERT INTO valoracions VALUES (4612, 94, '14/03/2004', 2);
INSERT INTO valoracions VALUES (4612, 98, '08/09/2001', 4);
INSERT INTO valoracions VALUES (4612, 103, '24/09/2006', 4);
INSERT INTO valoracions VALUES (4612, 103, '15/12/2003', 8);
INSERT INTO valoracions VALUES (4613, 39, '08/09/2007', 6);
INSERT INTO valoracions VALUES (4613, 29, '02/05/2003', 7);
INSERT INTO valoracions VALUES (4613, 19, '09/02/2004', 10);
INSERT INTO valoracions VALUES (4613, 56, '18/06/2004', 6);
INSERT INTO valoracions VALUES (4613, 61, '28/07/2003', 8);
INSERT INTO valoracions VALUES (4613, 43, '07/02/2005', 7);
INSERT INTO valoracions VALUES (4613, 77, '03/06/2005', 9);
INSERT INTO valoracions VALUES (4613, 8, '18/08/2002', 8);
INSERT INTO valoracions VALUES (4613, 87, '30/11/2005', 7);
INSERT INTO valoracions VALUES (4613, 19, '22/02/2008', 9);
INSERT INTO valoracions VALUES (4614, 79, '05/10/2002', 5);
INSERT INTO valoracions VALUES (4614, 87, '23/08/2007', 8);
INSERT INTO valoracions VALUES (4614, 88, '23/08/2001', 1);
INSERT INTO valoracions VALUES (4614, 66, '28/08/2004', 5);
INSERT INTO valoracions VALUES (4614, 21, '14/06/2008', 5);
INSERT INTO valoracions VALUES (4614, 102, '16/10/2002', 5);
INSERT INTO valoracions VALUES (4614, 27, '28/01/2008', 8);
INSERT INTO valoracions VALUES (4615, 13, '15/06/2001', 8);
INSERT INTO valoracions VALUES (4615, 49, '14/08/2009', 8);
INSERT INTO valoracions VALUES (4615, 88, '12/08/2001', 7);
INSERT INTO valoracions VALUES (4615, 8, '21/02/2004', 7);
INSERT INTO valoracions VALUES (4615, 79, '25/06/2007', 7);
INSERT INTO valoracions VALUES (4616, 23, '31/07/2007', 6);
INSERT INTO valoracions VALUES (4616, 2, '09/03/2002', 10);
INSERT INTO valoracions VALUES (4616, 103, '28/09/2007', 2);
INSERT INTO valoracions VALUES (4616, 61, '20/04/2010', 8);
INSERT INTO valoracions VALUES (4616, 48, '30/06/2003', 4);
INSERT INTO valoracions VALUES (4617, 61, '14/01/2002', 4);
INSERT INTO valoracions VALUES (4617, 48, '09/11/2008', 10);
INSERT INTO valoracions VALUES (4617, 26, '02/09/2003', 8);
INSERT INTO valoracions VALUES (4617, 14, '31/05/2002', 6);
INSERT INTO valoracions VALUES (4618, 41, '21/07/2005', 3);
INSERT INTO valoracions VALUES (4618, 19, '12/08/2005', 7);
INSERT INTO valoracions VALUES (4618, 35, '23/01/2008', 5);
INSERT INTO valoracions VALUES (4618, 6, '09/10/2005', 9);
INSERT INTO valoracions VALUES (4618, 2, '01/07/2001', 9);
INSERT INTO valoracions VALUES (4619, 100, '24/03/2004', 4);
INSERT INTO valoracions VALUES (4619, 78, '07/08/2007', 3);
INSERT INTO valoracions VALUES (4619, 79, '19/05/2003', 3);
INSERT INTO valoracions VALUES (4620, 85, '16/01/2004', 7);
INSERT INTO valoracions VALUES (4620, 74, '07/07/2009', 6);
INSERT INTO valoracions VALUES (4620, 5, '25/03/2005', 7);
INSERT INTO valoracions VALUES (4620, 42, '08/08/2010', 5);
INSERT INTO valoracions VALUES (4620, 88, '12/11/2002', 4);
INSERT INTO valoracions VALUES (4621, 31, '10/05/2005', 5);
INSERT INTO valoracions VALUES (4621, 19, '23/01/2009', 8);
INSERT INTO valoracions VALUES (4621, 88, '15/03/2003', 10);
INSERT INTO valoracions VALUES (4621, 66, '30/12/2002', 9);
INSERT INTO valoracions VALUES (4622, 55, '31/12/2003', 4);
INSERT INTO valoracions VALUES (4622, 25, '08/06/2009', 7);
INSERT INTO valoracions VALUES (4623, 18, '30/09/2001', 6);
INSERT INTO valoracions VALUES (4623, 83, '15/12/2001', 9);
INSERT INTO valoracions VALUES (4624, 91, '28/09/2008', 10);
INSERT INTO valoracions VALUES (4624, 19, '21/01/2008', 9);
INSERT INTO valoracions VALUES (4624, 22, '01/12/2005', 4);
INSERT INTO valoracions VALUES (4624, 114, '16/10/2008', 4);
INSERT INTO valoracions VALUES (4625, 40, '27/03/2005', 9);
INSERT INTO valoracions VALUES (4625, 46, '09/02/2003', 7);
INSERT INTO valoracions VALUES (4625, 7, '26/05/2001', 8);
INSERT INTO valoracions VALUES (4625, 98, '16/01/2009', 3);
INSERT INTO valoracions VALUES (4626, 86, '26/08/2005', 4);
INSERT INTO valoracions VALUES (4626, 21, '18/09/2007', 9);
INSERT INTO valoracions VALUES (4626, 78, '02/05/2001', 5);
INSERT INTO valoracions VALUES (4627, 83, '23/06/2004', 4);
INSERT INTO valoracions VALUES (4627, 60, '26/09/2001', 5);
INSERT INTO valoracions VALUES (4627, 52, '19/12/2006', 9);
INSERT INTO valoracions VALUES (4628, 42, '04/05/2009', 6);
INSERT INTO valoracions VALUES (4628, 81, '14/06/2005', 7);
INSERT INTO valoracions VALUES (4628, 46, '17/03/2010', 6);
INSERT INTO valoracions VALUES (4628, 64, '29/11/2001', 4);
INSERT INTO valoracions VALUES (4628, 87, '21/03/2004', 9);
INSERT INTO valoracions VALUES (4628, 84, '02/08/2008', 6);
INSERT INTO valoracions VALUES (4629, 109, '19/04/2007', 9);
INSERT INTO valoracions VALUES (4629, 89, '06/03/2003', 5);
INSERT INTO valoracions VALUES (4629, 101, '10/11/2002', 2);
INSERT INTO valoracions VALUES (4629, 9, '20/05/2003', 9);
INSERT INTO valoracions VALUES (4629, 46, '15/02/2008', 10);
INSERT INTO valoracions VALUES (4630, 74, '24/04/2003', 5);
INSERT INTO valoracions VALUES (4630, 46, '27/08/2006', 9);
INSERT INTO valoracions VALUES (4630, 52, '03/12/2007', 8);
INSERT INTO valoracions VALUES (4631, 65, '13/02/2005', 5);
INSERT INTO valoracions VALUES (4631, 82, '05/10/2001', 3);
INSERT INTO valoracions VALUES (4631, 96, '13/05/2008', 3);
INSERT INTO valoracions VALUES (4632, 72, '24/03/2010', 3);
INSERT INTO valoracions VALUES (4632, 97, '06/02/2006', 10);
INSERT INTO valoracions VALUES (4633, 105, '14/07/2004', 4);
INSERT INTO valoracions VALUES (4634, 84, '28/08/2008', 9);
INSERT INTO valoracions VALUES (4634, 7, '04/09/2007', 8);
INSERT INTO valoracions VALUES (4634, 66, '15/03/2003', 6);
INSERT INTO valoracions VALUES (4635, 36, '15/06/2004', 9);
INSERT INTO valoracions VALUES (4635, 107, '08/12/2003', 9);
INSERT INTO valoracions VALUES (4635, 36, '08/06/2002', 9);
INSERT INTO valoracions VALUES (4635, 19, '21/08/2007', 8);
INSERT INTO valoracions VALUES (4635, 63, '02/06/2003', 8);
INSERT INTO valoracions VALUES (4636, 96, '10/04/2001', 2);
INSERT INTO valoracions VALUES (4636, 12, '12/09/2004', 9);
INSERT INTO valoracions VALUES (4636, 61, '04/07/2001', 6);
INSERT INTO valoracions VALUES (4637, 44, '28/10/2004', 7);
INSERT INTO valoracions VALUES (4637, 19, '16/06/2005', 7);
INSERT INTO valoracions VALUES (4637, 52, '23/06/2005', 6);
INSERT INTO valoracions VALUES (4637, 3, '23/03/2003', 9);
INSERT INTO valoracions VALUES (4637, 53, '31/05/2010', 7);
INSERT INTO valoracions VALUES (4637, 5, '25/06/2004', 6);
INSERT INTO valoracions VALUES (4638, 97, '13/11/2002', 3);
INSERT INTO valoracions VALUES (4638, 25, '08/06/2009', 9);
INSERT INTO valoracions VALUES (4639, 40, '23/06/2004', 10);
INSERT INTO valoracions VALUES (4639, 33, '01/10/2001', 7);
INSERT INTO valoracions VALUES (4639, 115, '28/05/2003', 0);
INSERT INTO valoracions VALUES (4639, 7, '28/03/2005', 7);
INSERT INTO valoracions VALUES (4639, 40, '05/09/2005', 8);
INSERT INTO valoracions VALUES (4640, 109, '01/04/2004', 3);
INSERT INTO valoracions VALUES (4641, 92, '01/03/2009', 6);
INSERT INTO valoracions VALUES (4641, 50, '02/08/2010', 8);
INSERT INTO valoracions VALUES (4641, 37, '11/02/2006', 5);
INSERT INTO valoracions VALUES (4642, 41, '22/01/2005', 6);
INSERT INTO valoracions VALUES (4642, 9, '21/02/2003', 6);
INSERT INTO valoracions VALUES (4643, 23, '28/11/2003', 6);
INSERT INTO valoracions VALUES (4643, 58, '20/11/2001', 4);
INSERT INTO valoracions VALUES (4643, 105, '31/08/2008', 2);
INSERT INTO valoracions VALUES (4644, 20, '04/04/2007', 9);
INSERT INTO valoracions VALUES (4644, 84, '09/05/2009', 1);
INSERT INTO valoracions VALUES (4644, 17, '16/06/2006', 5);
INSERT INTO valoracions VALUES (4644, 61, '21/02/2006', 5);
INSERT INTO valoracions VALUES (4644, 60, '03/05/2007', 3);
INSERT INTO valoracions VALUES (4644, 31, '29/05/2005', 10);
INSERT INTO valoracions VALUES (4644, 60, '27/07/2004', 5);
INSERT INTO valoracions VALUES (4645, 3, '17/03/2004', 9);
INSERT INTO valoracions VALUES (4645, 22, '16/11/2006', 7);
INSERT INTO valoracions VALUES (4645, 26, '17/10/2007', 8);
INSERT INTO valoracions VALUES (4646, 72, '24/03/2008', 2);
INSERT INTO valoracions VALUES (4646, 39, '24/06/2004', 7);
INSERT INTO valoracions VALUES (4646, 26, '31/08/2004', 6);
INSERT INTO valoracions VALUES (4646, 44, '17/07/2005', 9);
INSERT INTO valoracions VALUES (4646, 58, '29/10/2001', 7);
INSERT INTO valoracions VALUES (4646, 44, '27/07/2009', 3);
INSERT INTO valoracions VALUES (4647, 113, '25/09/2002', 4);
INSERT INTO valoracions VALUES (4647, 36, '21/05/2010', 5);
INSERT INTO valoracions VALUES (4647, 61, '30/12/2008', 9);
INSERT INTO valoracions VALUES (4647, 33, '04/01/2007', 7);
INSERT INTO valoracions VALUES (4648, 34, '31/01/2006', 9);
INSERT INTO valoracions VALUES (4648, 113, '10/07/2005', 5);
INSERT INTO valoracions VALUES (4648, 88, '05/08/2004', 7);
INSERT INTO valoracions VALUES (4648, 102, '06/04/2010', 1);
INSERT INTO valoracions VALUES (4648, 67, '20/07/2007', 4);
INSERT INTO valoracions VALUES (4649, 8, '29/07/2001', 6);
INSERT INTO valoracions VALUES (4649, 35, '08/05/2006', 4);
INSERT INTO valoracions VALUES (4649, 6, '06/07/2005', 6);
INSERT INTO valoracions VALUES (4649, 58, '28/09/2009', 4);
INSERT INTO valoracions VALUES (4649, 28, '04/11/2001', 7);
INSERT INTO valoracions VALUES (4650, 27, '05/10/2009', 6);
INSERT INTO valoracions VALUES (4650, 17, '17/08/2010', 9);
INSERT INTO valoracions VALUES (4650, 60, '23/06/2002', 8);
INSERT INTO valoracions VALUES (4650, 70, '06/04/2009', 8);
INSERT INTO valoracions VALUES (4650, 65, '28/05/2010', 7);
INSERT INTO valoracions VALUES (4651, 37, '15/11/2001', 9);
INSERT INTO valoracions VALUES (4651, 38, '26/12/2001', 4);
INSERT INTO valoracions VALUES (4651, 108, '27/02/2003', 1);
INSERT INTO valoracions VALUES (4651, 11, '26/01/2005', 7);
INSERT INTO valoracions VALUES (4652, 116, '26/06/2003', 3);
INSERT INTO valoracions VALUES (4652, 92, '21/02/2003', 9);
INSERT INTO valoracions VALUES (4652, 65, '15/06/2008', 5);
INSERT INTO valoracions VALUES (4652, 67, '11/02/2005', 7);
INSERT INTO valoracions VALUES (4652, 80, '03/02/2004', 9);
INSERT INTO valoracions VALUES (4653, 6, '30/12/2001', 9);
INSERT INTO valoracions VALUES (4653, 56, '08/08/2010', 4);
INSERT INTO valoracions VALUES (4653, 58, '07/11/2003', 4);
INSERT INTO valoracions VALUES (4653, 52, '22/04/2001', 6);
INSERT INTO valoracions VALUES (4653, 43, '20/03/2008', 7);
INSERT INTO valoracions VALUES (4653, 63, '21/01/2007', 8);
INSERT INTO valoracions VALUES (4653, 48, '30/11/2001', 7);
INSERT INTO valoracions VALUES (4653, 74, '10/01/2006', 8);
INSERT INTO valoracions VALUES (4653, 82, '18/06/2002', 7);
INSERT INTO valoracions VALUES (4654, 63, '08/10/2008', 8);
INSERT INTO valoracions VALUES (4654, 54, '23/10/2002', 9);
INSERT INTO valoracions VALUES (4654, 13, '21/06/2009', 9);
INSERT INTO valoracions VALUES (4654, 94, '29/12/2003', 4);
INSERT INTO valoracions VALUES (4654, 7, '05/10/2003', 8);
INSERT INTO valoracions VALUES (4655, 54, '17/03/2007', 3);
INSERT INTO valoracions VALUES (4656, 29, '26/11/2008', 7);
INSERT INTO valoracions VALUES (4657, 107, '16/08/2004', 8);
INSERT INTO valoracions VALUES (4657, 68, '03/06/2006', 6);
INSERT INTO valoracions VALUES (4657, 14, '19/04/2002', 7);
INSERT INTO valoracions VALUES (4658, 36, '07/05/2006', 6);
INSERT INTO valoracions VALUES (4658, 99, '19/08/2003', 3);
INSERT INTO valoracions VALUES (4659, 106, '06/04/2010', 8);
INSERT INTO valoracions VALUES (4659, 28, '03/03/2005', 10);
INSERT INTO valoracions VALUES (4659, 116, '23/02/2005', 2);
INSERT INTO valoracions VALUES (4659, 61, '13/05/2010', 8);
INSERT INTO valoracions VALUES (4659, 106, '25/05/2002', 1);
INSERT INTO valoracions VALUES (4659, 70, '20/11/2004', 2);
INSERT INTO valoracions VALUES (4659, 18, '06/11/2006', 7);
INSERT INTO valoracions VALUES (4659, 55, '23/06/2005', 9);
INSERT INTO valoracions VALUES (4659, 36, '30/10/2008', 9);
INSERT INTO valoracions VALUES (4659, 105, '01/09/2006', 7);
INSERT INTO valoracions VALUES (4660, 61, '01/10/2007', 8);
INSERT INTO valoracions VALUES (4660, 18, '13/02/2009', 6);
INSERT INTO valoracions VALUES (4660, 83, '21/03/2005', 4);
INSERT INTO valoracions VALUES (4660, 6, '25/10/2008', 7);
INSERT INTO valoracions VALUES (4661, 57, '18/08/2006', 6);
INSERT INTO valoracions VALUES (4661, 9, '02/05/2004', 8);
INSERT INTO valoracions VALUES (4661, 75, '02/04/2009', 3);
INSERT INTO valoracions VALUES (4662, 61, '16/03/2004', 6);
INSERT INTO valoracions VALUES (4662, 63, '18/07/2001', 9);
INSERT INTO valoracions VALUES (4662, 80, '20/12/2009', 2);
INSERT INTO valoracions VALUES (4662, 26, '29/04/2010', 6);
INSERT INTO valoracions VALUES (4663, 60, '04/07/2006', 8);
INSERT INTO valoracions VALUES (4663, 43, '27/09/2010', 8);
INSERT INTO valoracions VALUES (4664, 54, '09/11/2001', 9);
INSERT INTO valoracions VALUES (4664, 15, '16/08/2007', 8);
INSERT INTO valoracions VALUES (4664, 35, '08/07/2009', 9);
INSERT INTO valoracions VALUES (4664, 107, '24/07/2001', 1);
INSERT INTO valoracions VALUES (4664, 32, '15/11/2007', 7);
INSERT INTO valoracions VALUES (4665, 48, '14/09/2006', 6);
INSERT INTO valoracions VALUES (4665, 58, '02/12/2001', 6);
INSERT INTO valoracions VALUES (4666, 73, '19/02/2005', 4);
INSERT INTO valoracions VALUES (4666, 78, '21/09/2007', 7);
INSERT INTO valoracions VALUES (4666, 75, '25/08/2003', 8);
INSERT INTO valoracions VALUES (4666, 45, '30/10/2007', 9);
INSERT INTO valoracions VALUES (4666, 109, '26/05/2003', 3);
INSERT INTO valoracions VALUES (4667, 82, '12/12/2004', 5);
INSERT INTO valoracions VALUES (4667, 101, '21/04/2009', 9);
INSERT INTO valoracions VALUES (4667, 57, '16/09/2006', 4);
INSERT INTO valoracions VALUES (4667, 73, '22/06/2010', 4);
INSERT INTO valoracions VALUES (4668, 32, '12/08/2003', 8);
INSERT INTO valoracions VALUES (4668, 93, '05/07/2006', 7);
INSERT INTO valoracions VALUES (4668, 109, '23/05/2008', 6);
INSERT INTO valoracions VALUES (4669, 6, '05/11/2007', 7);
INSERT INTO valoracions VALUES (4669, 4, '03/10/2001', 6);
INSERT INTO valoracions VALUES (4669, 49, '08/08/2003', 5);
INSERT INTO valoracions VALUES (4669, 41, '04/06/2007', 10);
INSERT INTO valoracions VALUES (4670, 55, '14/11/2003', 6);
INSERT INTO valoracions VALUES (4670, 6, '07/06/2004', 9);
INSERT INTO valoracions VALUES (4670, 11, '10/06/2002', 9);
INSERT INTO valoracions VALUES (4671, 43, '07/02/2009', 7);
INSERT INTO valoracions VALUES (4671, 105, '01/09/2001', 2);
INSERT INTO valoracions VALUES (4671, 66, '16/10/2003', 5);
INSERT INTO valoracions VALUES (4672, 6, '25/06/2003', 9);
INSERT INTO valoracions VALUES (4672, 43, '19/10/2007', 7);
INSERT INTO valoracions VALUES (4672, 27, '29/04/2010', 6);
INSERT INTO valoracions VALUES (4673, 77, '22/06/2010', 8);
INSERT INTO valoracions VALUES (4673, 74, '16/10/2003', 5);
INSERT INTO valoracions VALUES (4673, 89, '01/06/2004', 6);
INSERT INTO valoracions VALUES (4673, 22, '02/06/2005', 6);
INSERT INTO valoracions VALUES (4673, 115, '08/12/2009', 7);
INSERT INTO valoracions VALUES (4673, 71, '03/12/2001', 4);
INSERT INTO valoracions VALUES (4673, 99, '04/05/2003', 3);
INSERT INTO valoracions VALUES (4673, 64, '30/09/2005', 8);
INSERT INTO valoracions VALUES (4673, 12, '25/01/2002', 8);
INSERT INTO valoracions VALUES (4674, 49, '23/06/2010', 4);
INSERT INTO valoracions VALUES (4675, 16, '24/08/2005', 8);
INSERT INTO valoracions VALUES (4675, 64, '31/05/2002', 3);
INSERT INTO valoracions VALUES (4675, 60, '10/11/2004', 8);
INSERT INTO valoracions VALUES (4675, 48, '23/11/2002', 5);
INSERT INTO valoracions VALUES (4675, 96, '24/09/2009', 10);
INSERT INTO valoracions VALUES (4676, 105, '22/04/2007', 8);
INSERT INTO valoracions VALUES (4676, 95, '03/08/2007', 9);
INSERT INTO valoracions VALUES (4676, 9, '05/01/2007', 7);
INSERT INTO valoracions VALUES (4676, 50, '06/09/2010', 7);
INSERT INTO valoracions VALUES (4677, 37, '30/11/2008', 9);
INSERT INTO valoracions VALUES (4677, 1, '05/06/2004', 9);
INSERT INTO valoracions VALUES (4677, 69, '21/11/2001', 3);
INSERT INTO valoracions VALUES (4678, 83, '05/11/2008', 3);
INSERT INTO valoracions VALUES (4678, 20, '30/04/2003', 7);
INSERT INTO valoracions VALUES (4678, 54, '05/05/2002', 9);
INSERT INTO valoracions VALUES (4678, 18, '15/06/2009', 8);
INSERT INTO valoracions VALUES (4678, 8, '27/01/2003', 8);
INSERT INTO valoracions VALUES (4679, 75, '27/12/2008', 9);
INSERT INTO valoracions VALUES (4679, 116, '04/07/2005', 5);
INSERT INTO valoracions VALUES (4679, 44, '12/02/2010', 9);
INSERT INTO valoracions VALUES (4680, 91, '08/10/2007', 1);
INSERT INTO valoracions VALUES (4680, 52, '08/10/2004', 4);
INSERT INTO valoracions VALUES (4681, 91, '23/12/2005', 9);
INSERT INTO valoracions VALUES (4681, 38, '29/10/2010', 7);
INSERT INTO valoracions VALUES (4681, 33, '15/10/2007', 4);
INSERT INTO valoracions VALUES (4681, 14, '07/09/2001', 9);
INSERT INTO valoracions VALUES (4681, 75, '02/06/2009', 7);
INSERT INTO valoracions VALUES (4682, 21, '22/12/2004', 7);
INSERT INTO valoracions VALUES (4682, 52, '16/11/2003', 6);
INSERT INTO valoracions VALUES (4682, 14, '17/10/2003', 9);
INSERT INTO valoracions VALUES (4682, 71, '16/05/2005', 7);
INSERT INTO valoracions VALUES (4682, 16, '29/03/2003', 6);
INSERT INTO valoracions VALUES (4683, 103, '05/02/2006', 8);
INSERT INTO valoracions VALUES (4683, 6, '29/04/2007', 9);
INSERT INTO valoracions VALUES (4684, 47, '18/03/2006', 9);
INSERT INTO valoracions VALUES (4684, 84, '12/11/2008', 10);
INSERT INTO valoracions VALUES (4684, 14, '08/03/2002', 8);
INSERT INTO valoracions VALUES (4684, 18, '23/01/2004', 8);
INSERT INTO valoracions VALUES (4684, 20, '28/02/2005', 5);
INSERT INTO valoracions VALUES (4684, 63, '04/12/2002', 5);
INSERT INTO valoracions VALUES (4684, 74, '26/09/2005', 8);
INSERT INTO valoracions VALUES (4684, 34, '23/10/2002', 7);
INSERT INTO valoracions VALUES (4685, 44, '12/02/2002', 5);
INSERT INTO valoracions VALUES (4685, 84, '16/11/2004', 4);
INSERT INTO valoracions VALUES (4685, 107, '16/12/2005', 3);
INSERT INTO valoracions VALUES (4685, 110, '15/12/2005', 1);
INSERT INTO valoracions VALUES (4685, 66, '12/08/2005', 3);
INSERT INTO valoracions VALUES (4685, 115, '18/05/2004', 3);
INSERT INTO valoracions VALUES (4685, 51, '25/10/2005', 5);
INSERT INTO valoracions VALUES (4686, 15, '11/12/2005', 9);
INSERT INTO valoracions VALUES (4686, 79, '08/12/2007', 3);
INSERT INTO valoracions VALUES (4686, 8, '19/10/2003', 8);
INSERT INTO valoracions VALUES (4686, 65, '11/01/2006', 3);
INSERT INTO valoracions VALUES (4686, 107, '07/09/2009', 4);
INSERT INTO valoracions VALUES (4687, 76, '27/01/2010', 5);
INSERT INTO valoracions VALUES (4687, 53, '20/08/2009', 3);
INSERT INTO valoracions VALUES (4687, 2, '15/03/2007', 9);
INSERT INTO valoracions VALUES (4688, 41, '18/06/2005', 7);
INSERT INTO valoracions VALUES (4688, 101, '19/05/2005', 6);
INSERT INTO valoracions VALUES (4688, 28, '24/10/2008', 8);
INSERT INTO valoracions VALUES (4688, 69, '21/09/2004', 7);
INSERT INTO valoracions VALUES (4689, 80, '13/04/2004', 7);
INSERT INTO valoracions VALUES (4689, 78, '05/07/2007', 9);
INSERT INTO valoracions VALUES (4689, 96, '04/12/2005', 2);
INSERT INTO valoracions VALUES (4689, 12, '10/10/2005', 6);
INSERT INTO valoracions VALUES (4690, 65, '07/01/2006', 3);
INSERT INTO valoracions VALUES (4690, 111, '25/01/2009', 5);
INSERT INTO valoracions VALUES (4690, 87, '24/11/2002', 4);
INSERT INTO valoracions VALUES (4690, 27, '03/04/2005', 5);
INSERT INTO valoracions VALUES (4690, 42, '10/03/2005', 9);
INSERT INTO valoracions VALUES (4690, 83, '13/09/2002', 5);
INSERT INTO valoracions VALUES (4690, 79, '27/04/2010', 6);
INSERT INTO valoracions VALUES (4690, 81, '19/10/2006', 7);
INSERT INTO valoracions VALUES (4690, 41, '13/07/2008', 4);
INSERT INTO valoracions VALUES (4690, 78, '02/08/2001', 8);
INSERT INTO valoracions VALUES (4691, 93, '28/10/2001', 5);
INSERT INTO valoracions VALUES (4691, 39, '18/02/2005', 5);
INSERT INTO valoracions VALUES (4692, 84, '28/07/2002', 2);
INSERT INTO valoracions VALUES (4692, 113, '03/11/2003', 7);
INSERT INTO valoracions VALUES (4692, 80, '29/12/2006', 2);
INSERT INTO valoracions VALUES (4692, 57, '05/10/2002', 5);
INSERT INTO valoracions VALUES (4693, 96, '24/06/2010', 3);
INSERT INTO valoracions VALUES (4693, 26, '21/02/2005', 8);
INSERT INTO valoracions VALUES (4693, 62, '04/08/2008', 3);
INSERT INTO valoracions VALUES (4694, 23, '07/04/2008', 5);
INSERT INTO valoracions VALUES (4694, 60, '17/05/2003', 10);
INSERT INTO valoracions VALUES (4694, 49, '13/06/2007', 4);
INSERT INTO valoracions VALUES (4694, 80, '27/07/2010', 6);
INSERT INTO valoracions VALUES (4694, 75, '20/02/2006', 4);
INSERT INTO valoracions VALUES (4694, 81, '19/06/2003', 2);
INSERT INTO valoracions VALUES (4694, 67, '15/02/2002', 5);
INSERT INTO valoracions VALUES (4694, 89, '09/02/2007', 8);
INSERT INTO valoracions VALUES (4694, 25, '08/02/2002', 8);
INSERT INTO valoracions VALUES (4694, 88, '07/03/2002', 8);
INSERT INTO valoracions VALUES (4695, 84, '27/07/2002', 4);
INSERT INTO valoracions VALUES (4695, 82, '23/06/2001', 7);
INSERT INTO valoracions VALUES (4695, 39, '05/10/2008', 8);
INSERT INTO valoracions VALUES (4695, 36, '11/04/2007', 5);
INSERT INTO valoracions VALUES (4696, 103, '12/06/2006', 6);
INSERT INTO valoracions VALUES (4696, 57, '30/06/2005', 4);
INSERT INTO valoracions VALUES (4696, 44, '31/10/2002', 9);
INSERT INTO valoracions VALUES (4696, 81, '25/01/2007', 2);
INSERT INTO valoracions VALUES (4697, 67, '21/09/2004', 6);
INSERT INTO valoracions VALUES (4697, 63, '04/08/2003', 8);
INSERT INTO valoracions VALUES (4698, 21, '21/04/2007', 9);
INSERT INTO valoracions VALUES (4698, 17, '29/03/2004', 5);
INSERT INTO valoracions VALUES (4699, 45, '08/04/2003', 5);
INSERT INTO valoracions VALUES (4699, 114, '17/11/2004', 2);
INSERT INTO valoracions VALUES (4699, 33, '16/04/2010', 6);
INSERT INTO valoracions VALUES (4699, 16, '31/10/2006', 9);
INSERT INTO valoracions VALUES (4699, 85, '22/12/2001', 2);
INSERT INTO valoracions VALUES (4699, 57, '27/02/2007', 5);
INSERT INTO valoracions VALUES (4699, 22, '23/09/2006', 5);
INSERT INTO valoracions VALUES (4700, 63, '23/05/2001', 10);
INSERT INTO valoracions VALUES (4700, 104, '23/05/2007', 6);
INSERT INTO valoracions VALUES (4700, 23, '25/08/2003', 10);
INSERT INTO valoracions VALUES (4700, 94, '17/09/2003', 7);
INSERT INTO valoracions VALUES (4700, 58, '14/04/2005', 9);
INSERT INTO valoracions VALUES (4701, 68, '14/09/2009', 5);
INSERT INTO valoracions VALUES (4701, 34, '18/09/2003', 6);
INSERT INTO valoracions VALUES (4702, 71, '20/02/2007', 10);
INSERT INTO valoracions VALUES (4702, 4, '28/01/2009', 9);
INSERT INTO valoracions VALUES (4702, 40, '27/02/2009', 9);
INSERT INTO valoracions VALUES (4702, 60, '07/10/2001', 5);
INSERT INTO valoracions VALUES (4703, 108, '12/04/2001', 4);
INSERT INTO valoracions VALUES (4703, 110, '04/10/2004', 3);
INSERT INTO valoracions VALUES (4703, 2, '02/12/2002', 7);
INSERT INTO valoracions VALUES (4703, 29, '11/03/2006', 5);
INSERT INTO valoracions VALUES (4703, 62, '09/09/2007', 8);
INSERT INTO valoracions VALUES (4703, 99, '05/12/2002', 6);
INSERT INTO valoracions VALUES (4703, 33, '09/05/2010', 6);
INSERT INTO valoracions VALUES (4703, 52, '28/06/2003', 10);
INSERT INTO valoracions VALUES (4704, 82, '05/09/2008', 5);
INSERT INTO valoracions VALUES (4704, 6, '10/06/2009', 8);
INSERT INTO valoracions VALUES (4704, 78, '10/05/2001', 3);
INSERT INTO valoracions VALUES (4704, 32, '11/02/2006', 10);
INSERT INTO valoracions VALUES (4704, 29, '08/08/2007', 4);
INSERT INTO valoracions VALUES (4705, 52, '22/12/2004', 3);
INSERT INTO valoracions VALUES (4705, 54, '01/04/2010', 5);
INSERT INTO valoracions VALUES (4705, 7, '26/06/2001', 6);
INSERT INTO valoracions VALUES (4705, 25, '28/08/2008', 9);
INSERT INTO valoracions VALUES (4705, 35, '03/12/2006', 7);
INSERT INTO valoracions VALUES (4706, 44, '28/01/2010', 5);
INSERT INTO valoracions VALUES (4706, 46, '07/05/2005', 4);
INSERT INTO valoracions VALUES (4706, 87, '10/01/2005', 2);
INSERT INTO valoracions VALUES (4706, 57, '01/09/2009', 6);
INSERT INTO valoracions VALUES (4707, 89, '11/06/2007', 5);
INSERT INTO valoracions VALUES (4707, 9, '05/10/2007', 7);
INSERT INTO valoracions VALUES (4707, 94, '20/06/2008', 2);
INSERT INTO valoracions VALUES (4707, 71, '15/07/2001', 5);
INSERT INTO valoracions VALUES (4707, 29, '17/04/2005', 4);
INSERT INTO valoracions VALUES (4707, 9, '24/05/2005', 9);
INSERT INTO valoracions VALUES (4707, 101, '01/05/2006', 8);
INSERT INTO valoracions VALUES (4707, 20, '30/08/2004', 5);
INSERT INTO valoracions VALUES (4707, 81, '04/04/2009', 9);
INSERT INTO valoracions VALUES (4708, 39, '04/01/2004', 4);
INSERT INTO valoracions VALUES (4708, 108, '07/04/2002', 7);
INSERT INTO valoracions VALUES (4708, 59, '12/03/2010', 9);
INSERT INTO valoracions VALUES (4708, 75, '14/08/2005', 6);
INSERT INTO valoracions VALUES (4708, 35, '28/01/2004', 5);
INSERT INTO valoracions VALUES (4708, 37, '22/11/2007', 7);
INSERT INTO valoracions VALUES (4709, 19, '11/08/2003', 9);
INSERT INTO valoracions VALUES (4709, 33, '25/06/2004', 6);
INSERT INTO valoracions VALUES (4709, 11, '10/05/2009', 10);
INSERT INTO valoracions VALUES (4709, 106, '02/10/2001', 3);
INSERT INTO valoracions VALUES (4709, 40, '03/08/2004', 9);
INSERT INTO valoracions VALUES (4709, 92, '24/09/2010', 5);
INSERT INTO valoracions VALUES (4709, 86, '27/12/2009', 9);
INSERT INTO valoracions VALUES (4710, 100, '03/05/2006', 4);
INSERT INTO valoracions VALUES (4710, 16, '17/01/2005', 8);
INSERT INTO valoracions VALUES (4710, 39, '03/08/2008', 9);
INSERT INTO valoracions VALUES (4711, 60, '22/03/2005', 4);
INSERT INTO valoracions VALUES (4711, 70, '05/11/2007', 3);
INSERT INTO valoracions VALUES (4712, 55, '30/05/2009', 3);
INSERT INTO valoracions VALUES (4712, 74, '11/11/2005', 8);
INSERT INTO valoracions VALUES (4712, 46, '05/10/2008', 8);
INSERT INTO valoracions VALUES (4712, 91, '31/08/2006', 3);
INSERT INTO valoracions VALUES (4712, 28, '21/02/2006', 4);
INSERT INTO valoracions VALUES (4713, 73, '27/08/2008', 3);
INSERT INTO valoracions VALUES (4713, 105, '23/09/2001', 3);
INSERT INTO valoracions VALUES (4713, 36, '02/01/2010', 7);
INSERT INTO valoracions VALUES (4713, 110, '30/03/2005', 9);
INSERT INTO valoracions VALUES (4713, 2, '02/09/2007', 5);
INSERT INTO valoracions VALUES (4713, 77, '03/10/2002', 8);
INSERT INTO valoracions VALUES (4714, 14, '02/01/2007', 6);
INSERT INTO valoracions VALUES (4714, 52, '25/12/2005', 8);
INSERT INTO valoracions VALUES (4714, 28, '24/08/2005', 9);
INSERT INTO valoracions VALUES (4715, 50, '07/02/2005', 6);
INSERT INTO valoracions VALUES (4715, 57, '18/09/2003', 5);
INSERT INTO valoracions VALUES (4715, 74, '04/07/2006', 7);
INSERT INTO valoracions VALUES (4715, 54, '04/10/2005', 9);
INSERT INTO valoracions VALUES (4715, 109, '02/03/2003', 3);
INSERT INTO valoracions VALUES (4715, 29, '12/07/2007', 10);
INSERT INTO valoracions VALUES (4715, 80, '04/09/2005', 8);
INSERT INTO valoracions VALUES (4715, 20, '16/09/2005', 9);
INSERT INTO valoracions VALUES (4716, 72, '20/09/2007', 8);
INSERT INTO valoracions VALUES (4716, 80, '08/01/2004', 5);
INSERT INTO valoracions VALUES (4716, 56, '08/03/2006', 6);
INSERT INTO valoracions VALUES (4716, 79, '11/05/2009', 2);
INSERT INTO valoracions VALUES (4717, 109, '23/07/2006', 5);
INSERT INTO valoracions VALUES (4717, 110, '27/11/2004', 7);
INSERT INTO valoracions VALUES (4718, 55, '01/04/2001', 9);
INSERT INTO valoracions VALUES (4718, 108, '12/06/2001', 1);
INSERT INTO valoracions VALUES (4718, 37, '06/01/2004', 6);
INSERT INTO valoracions VALUES (4718, 50, '08/04/2002', 7);
INSERT INTO valoracions VALUES (4719, 100, '01/10/2005', 9);
INSERT INTO valoracions VALUES (4719, 18, '03/04/2002', 10);
INSERT INTO valoracions VALUES (4719, 58, '14/06/2006', 7);
INSERT INTO valoracions VALUES (4719, 28, '21/10/2006', 8);
INSERT INTO valoracions VALUES (4720, 76, '09/12/2001', 8);
INSERT INTO valoracions VALUES (4720, 108, '21/03/2010', 5);
INSERT INTO valoracions VALUES (4720, 46, '08/01/2009', 5);
INSERT INTO valoracions VALUES (4720, 17, '21/07/2005', 6);
INSERT INTO valoracions VALUES (4720, 72, '09/01/2007', 4);
INSERT INTO valoracions VALUES (4720, 81, '16/03/2007', 3);
INSERT INTO valoracions VALUES (4720, 70, '29/05/2003', 4);
INSERT INTO valoracions VALUES (4721, 107, '28/09/2001', 2);
INSERT INTO valoracions VALUES (4721, 9, '26/04/2005', 8);
INSERT INTO valoracions VALUES (4721, 112, '29/09/2008', 7);
INSERT INTO valoracions VALUES (4721, 34, '21/08/2001', 7);
INSERT INTO valoracions VALUES (4721, 116, '18/07/2005', 3);
INSERT INTO valoracions VALUES (4721, 12, '04/02/2007', 7);
INSERT INTO valoracions VALUES (4722, 39, '18/07/2010', 9);
INSERT INTO valoracions VALUES (4722, 24, '19/03/2009', 8);
INSERT INTO valoracions VALUES (4723, 91, '08/08/2005', 5);
INSERT INTO valoracions VALUES (4724, 24, '03/06/2004', 6);
INSERT INTO valoracions VALUES (4724, 28, '27/08/2004', 8);
INSERT INTO valoracions VALUES (4724, 105, '11/06/2008', 7);
INSERT INTO valoracions VALUES (4725, 71, '27/09/2006', 4);
INSERT INTO valoracions VALUES (4725, 50, '16/09/2008', 6);
INSERT INTO valoracions VALUES (4725, 91, '08/09/2004', 2);
INSERT INTO valoracions VALUES (4725, 77, '11/02/2006', 4);
INSERT INTO valoracions VALUES (4725, 18, '26/09/2006', 9);
INSERT INTO valoracions VALUES (4726, 96, '07/03/2010', 1);
INSERT INTO valoracions VALUES (4726, 93, '16/04/2008', 2);
INSERT INTO valoracions VALUES (4726, 83, '21/10/2003', 3);
INSERT INTO valoracions VALUES (4726, 82, '14/12/2009', 3);
INSERT INTO valoracions VALUES (4726, 84, '17/07/2009', 6);
INSERT INTO valoracions VALUES (4726, 54, '30/09/2007', 9);
INSERT INTO valoracions VALUES (4726, 32, '27/07/2006', 6);
INSERT INTO valoracions VALUES (4726, 83, '02/04/2006', 4);
INSERT INTO valoracions VALUES (4726, 86, '23/08/2004', 4);
INSERT INTO valoracions VALUES (4727, 46, '23/05/2003', 4);
INSERT INTO valoracions VALUES (4727, 46, '07/11/2006', 8);
INSERT INTO valoracions VALUES (4727, 5, '08/07/2008', 5);
INSERT INTO valoracions VALUES (4727, 22, '27/04/2009', 4);
INSERT INTO valoracions VALUES (4727, 78, '02/01/2009', 8);
INSERT INTO valoracions VALUES (4727, 78, '22/12/2004', 8);
INSERT INTO valoracions VALUES (4728, 43, '15/07/2009', 6);
INSERT INTO valoracions VALUES (4728, 45, '28/05/2010', 5);
INSERT INTO valoracions VALUES (4728, 50, '09/04/2001', 9);
INSERT INTO valoracions VALUES (4728, 57, '27/06/2002', 8);
INSERT INTO valoracions VALUES (4729, 104, '30/09/2008', 5);
INSERT INTO valoracions VALUES (4729, 62, '09/01/2005', 7);
INSERT INTO valoracions VALUES (4729, 1, '18/05/2008', 8);
INSERT INTO valoracions VALUES (4729, 107, '30/12/2006', 4);
INSERT INTO valoracions VALUES (4729, 34, '15/12/2008', 6);
INSERT INTO valoracions VALUES (4730, 58, '27/04/2010', 8);
INSERT INTO valoracions VALUES (4731, 17, '23/09/2003', 6);
INSERT INTO valoracions VALUES (4731, 83, '25/12/2002', 4);
INSERT INTO valoracions VALUES (4731, 28, '26/11/2004', 6);
INSERT INTO valoracions VALUES (4731, 84, '03/10/2003', 9);
INSERT INTO valoracions VALUES (4732, 36, '18/09/2004', 9);
INSERT INTO valoracions VALUES (4732, 34, '13/09/2005', 8);
INSERT INTO valoracions VALUES (4732, 13, '05/09/2010', 9);
INSERT INTO valoracions VALUES (4732, 70, '28/06/2004', 8);
INSERT INTO valoracions VALUES (4733, 48, '24/10/2005', 8);
INSERT INTO valoracions VALUES (4733, 98, '29/05/2008', 9);
INSERT INTO valoracions VALUES (4733, 10, '24/08/2005', 9);
INSERT INTO valoracions VALUES (4733, 80, '06/05/2006', 3);
INSERT INTO valoracions VALUES (4734, 37, '27/10/2002', 8);
INSERT INTO valoracions VALUES (4735, 41, '30/10/2006', 4);
INSERT INTO valoracions VALUES (4735, 64, '10/04/2007', 9);
INSERT INTO valoracions VALUES (4735, 79, '02/04/2004', 10);
INSERT INTO valoracions VALUES (4736, 24, '28/02/2007', 9);
INSERT INTO valoracions VALUES (4736, 59, '21/07/2009', 9);
INSERT INTO valoracions VALUES (4737, 17, '03/09/2002', 7);
INSERT INTO valoracions VALUES (4737, 11, '18/01/2003', 9);
INSERT INTO valoracions VALUES (4737, 89, '30/08/2010', 3);
INSERT INTO valoracions VALUES (4737, 41, '12/01/2010', 9);
INSERT INTO valoracions VALUES (4737, 17, '07/09/2009', 5);
INSERT INTO valoracions VALUES (4738, 92, '11/08/2010', 7);
INSERT INTO valoracions VALUES (4739, 17, '10/07/2004', 6);
INSERT INTO valoracions VALUES (4739, 61, '03/11/2005', 5);
INSERT INTO valoracions VALUES (4739, 21, '21/10/2006', 9);
INSERT INTO valoracions VALUES (4739, 105, '16/12/2006', 3);
INSERT INTO valoracions VALUES (4739, 44, '08/05/2010', 7);
INSERT INTO valoracions VALUES (4739, 91, '05/06/2006', 9);
INSERT INTO valoracions VALUES (4740, 105, '30/06/2005', 4);
INSERT INTO valoracions VALUES (4740, 39, '21/07/2009', 4);
INSERT INTO valoracions VALUES (4740, 24, '23/06/2009', 5);
INSERT INTO valoracions VALUES (4740, 80, '08/01/2004', 7);
INSERT INTO valoracions VALUES (4740, 68, '08/08/2002', 3);
INSERT INTO valoracions VALUES (4740, 4, '19/10/2003', 7);
INSERT INTO valoracions VALUES (4740, 53, '14/04/2001', 8);
INSERT INTO valoracions VALUES (4740, 78, '11/04/2006', 10);
INSERT INTO valoracions VALUES (4741, 39, '31/08/2008', 5);
INSERT INTO valoracions VALUES (4741, 107, '09/11/2001', 1);
INSERT INTO valoracions VALUES (4741, 115, '01/09/2002', 3);
INSERT INTO valoracions VALUES (4741, 79, '28/09/2008', 4);
INSERT INTO valoracions VALUES (4741, 40, '21/01/2005', 7);
INSERT INTO valoracions VALUES (4741, 26, '28/02/2009', 6);
INSERT INTO valoracions VALUES (4741, 111, '25/08/2010', 4);
INSERT INTO valoracions VALUES (4742, 24, '30/12/2009', 6);
INSERT INTO valoracions VALUES (4742, 115, '06/04/2007', 7);
INSERT INTO valoracions VALUES (4743, 82, '12/08/2010', 8);
INSERT INTO valoracions VALUES (4743, 33, '28/03/2006', 9);
INSERT INTO valoracions VALUES (4744, 64, '22/05/2005', 8);
INSERT INTO valoracions VALUES (4744, 110, '18/01/2003', 2);
INSERT INTO valoracions VALUES (4744, 18, '21/05/2006', 6);
INSERT INTO valoracions VALUES (4745, 66, '06/01/2004', 5);
INSERT INTO valoracions VALUES (4745, 114, '15/02/2009', 5);
INSERT INTO valoracions VALUES (4745, 94, '11/06/2004', 4);
INSERT INTO valoracions VALUES (4745, 55, '04/04/2010', 10);
INSERT INTO valoracions VALUES (4745, 22, '19/09/2008', 9);
INSERT INTO valoracions VALUES (4747, 2, '22/03/2009', 9);
INSERT INTO valoracions VALUES (4747, 81, '19/01/2007', 5);
INSERT INTO valoracions VALUES (4748, 37, '10/04/2009', 5);
INSERT INTO valoracions VALUES (4748, 30, '12/10/2002', 7);
INSERT INTO valoracions VALUES (4748, 55, '09/11/2008', 9);
INSERT INTO valoracions VALUES (4749, 67, '30/06/2002', 7);
INSERT INTO valoracions VALUES (4749, 107, '12/03/2009', 3);
INSERT INTO valoracions VALUES (4749, 49, '21/05/2008', 9);
INSERT INTO valoracions VALUES (4749, 82, '29/01/2002', 6);
INSERT INTO valoracions VALUES (4750, 3, '12/11/2003', 9);
INSERT INTO valoracions VALUES (4750, 27, '14/01/2007', 6);
INSERT INTO valoracions VALUES (4751, 74, '18/12/2003', 6);
INSERT INTO valoracions VALUES (4752, 30, '18/07/2006', 6);
INSERT INTO valoracions VALUES (4752, 5, '25/12/2007', 6);
INSERT INTO valoracions VALUES (4752, 18, '05/06/2007', 8);
INSERT INTO valoracions VALUES (4752, 42, '27/07/2004', 4);
INSERT INTO valoracions VALUES (4752, 100, '06/07/2004', 9);
INSERT INTO valoracions VALUES (4753, 6, '17/08/2005', 8);
INSERT INTO valoracions VALUES (4753, 22, '17/04/2009', 5);
INSERT INTO valoracions VALUES (4753, 7, '31/12/2008', 7);
INSERT INTO valoracions VALUES (4753, 100, '07/01/2005', 3);
INSERT INTO valoracions VALUES (4753, 109, '13/10/2001', 2);
INSERT INTO valoracions VALUES (4754, 92, '24/04/2004', 7);
INSERT INTO valoracions VALUES (4754, 94, '16/06/2003', 4);
INSERT INTO valoracions VALUES (4754, 21, '24/05/2001', 5);
INSERT INTO valoracions VALUES (4754, 79, '11/12/2008', 7);
INSERT INTO valoracions VALUES (4754, 67, '07/09/2007', 5);
INSERT INTO valoracions VALUES (4755, 65, '05/12/2006', 5);
INSERT INTO valoracions VALUES (4755, 86, '28/07/2007', 7);
INSERT INTO valoracions VALUES (4755, 49, '16/09/2004', 9);
INSERT INTO valoracions VALUES (4755, 45, '12/01/2010', 8);
INSERT INTO valoracions VALUES (4756, 52, '12/12/2005', 9);
INSERT INTO valoracions VALUES (4756, 62, '15/09/2006', 9);
INSERT INTO valoracions VALUES (4757, 63, '05/09/2008', 5);
INSERT INTO valoracions VALUES (4757, 61, '20/01/2004', 5);
INSERT INTO valoracions VALUES (4757, 92, '17/07/2007', 3);
INSERT INTO valoracions VALUES (4757, 65, '30/01/2004', 4);
INSERT INTO valoracions VALUES (4758, 21, '07/11/2005', 7);
INSERT INTO valoracions VALUES (4758, 85, '01/12/2009', 5);
INSERT INTO valoracions VALUES (4758, 71, '15/12/2006', 7);
INSERT INTO valoracions VALUES (4759, 30, '04/02/2008', 5);
INSERT INTO valoracions VALUES (4759, 103, '07/02/2007', 6);
INSERT INTO valoracions VALUES (4759, 21, '01/11/2009', 5);
INSERT INTO valoracions VALUES (4759, 89, '18/10/2003', 2);
INSERT INTO valoracions VALUES (4759, 55, '12/11/2005', 9);
INSERT INTO valoracions VALUES (4759, 48, '24/08/2008', 9);
INSERT INTO valoracions VALUES (4760, 73, '26/05/2006', 5);
INSERT INTO valoracions VALUES (4760, 92, '07/11/2003', 6);
INSERT INTO valoracions VALUES (4760, 54, '22/12/2005', 10);
INSERT INTO valoracions VALUES (4760, 51, '22/06/2007', 3);
INSERT INTO valoracions VALUES (4760, 90, '27/02/2009', 9);
INSERT INTO valoracions VALUES (4761, 106, '06/01/2008', 8);
INSERT INTO valoracions VALUES (4761, 19, '21/05/2007', 4);
INSERT INTO valoracions VALUES (4761, 83, '28/09/2006', 2);
INSERT INTO valoracions VALUES (4761, 28, '04/02/2004', 8);
INSERT INTO valoracions VALUES (4761, 88, '31/10/2006', 8);
INSERT INTO valoracions VALUES (4762, 64, '27/06/2007', 6);
INSERT INTO valoracions VALUES (4762, 104, '14/01/2010', 2);
INSERT INTO valoracions VALUES (4762, 70, '05/08/2005', 7);
INSERT INTO valoracions VALUES (4762, 26, '12/10/2004', 5);
INSERT INTO valoracions VALUES (4762, 92, '22/04/2001', 7);
INSERT INTO valoracions VALUES (4762, 62, '08/08/2010', 5);
INSERT INTO valoracions VALUES (4763, 29, '29/07/2007', 6);
INSERT INTO valoracions VALUES (4763, 108, '10/04/2003', 7);
INSERT INTO valoracions VALUES (4763, 20, '11/05/2005', 9);
INSERT INTO valoracions VALUES (4763, 109, '28/01/2010', 9);
INSERT INTO valoracions VALUES (4763, 75, '28/06/2009', 8);
INSERT INTO valoracions VALUES (4763, 72, '23/03/2010', 3);
INSERT INTO valoracions VALUES (4764, 78, '28/07/2001', 8);
INSERT INTO valoracions VALUES (4764, 72, '15/07/2002', 5);
INSERT INTO valoracions VALUES (4764, 110, '09/05/2003', 1);
INSERT INTO valoracions VALUES (4764, 74, '18/10/2010', 4);
INSERT INTO valoracions VALUES (4765, 24, '11/12/2006', 9);
INSERT INTO valoracions VALUES (4765, 52, '02/04/2008', 10);
INSERT INTO valoracions VALUES (4765, 46, '09/04/2006', 7);
INSERT INTO valoracions VALUES (4765, 14, '21/10/2008', 5);
INSERT INTO valoracions VALUES (4765, 10, '28/11/2004', 7);
INSERT INTO valoracions VALUES (4765, 89, '14/03/2006', 9);
INSERT INTO valoracions VALUES (4765, 16, '02/08/2009', 7);
INSERT INTO valoracions VALUES (4766, 25, '12/01/2010', 8);
INSERT INTO valoracions VALUES (4766, 51, '06/12/2001', 6);
INSERT INTO valoracions VALUES (4766, 99, '04/09/2006', 3);
INSERT INTO valoracions VALUES (4766, 113, '14/01/2004', 7);
INSERT INTO valoracions VALUES (4766, 27, '14/02/2002', 5);
INSERT INTO valoracions VALUES (4767, 96, '11/09/2008', 6);
INSERT INTO valoracions VALUES (4767, 96, '01/11/2009', 8);
INSERT INTO valoracions VALUES (4767, 89, '18/02/2010', 4);
INSERT INTO valoracions VALUES (4767, 13, '20/05/2001', 8);
INSERT INTO valoracions VALUES (4767, 57, '27/03/2009', 10);
INSERT INTO valoracions VALUES (4768, 36, '01/02/2005', 7);
INSERT INTO valoracions VALUES (4768, 88, '21/04/2004', 3);
INSERT INTO valoracions VALUES (4768, 81, '03/07/2010', 6);
INSERT INTO valoracions VALUES (4768, 27, '07/05/2003', 10);
INSERT INTO valoracions VALUES (4768, 52, '20/01/2004', 8);
INSERT INTO valoracions VALUES (4769, 37, '04/09/2010', 8);
INSERT INTO valoracions VALUES (4769, 31, '05/05/2007', 10);
INSERT INTO valoracions VALUES (4769, 29, '24/10/2001', 4);
INSERT INTO valoracions VALUES (4769, 3, '22/12/2002', 5);
INSERT INTO valoracions VALUES (4769, 36, '06/02/2007', 8);
INSERT INTO valoracions VALUES (4770, 13, '31/01/2002', 5);
INSERT INTO valoracions VALUES (4770, 19, '23/10/2006', 7);
INSERT INTO valoracions VALUES (4770, 58, '02/07/2005', 6);
INSERT INTO valoracions VALUES (4770, 60, '02/03/2005', 8);
INSERT INTO valoracions VALUES (4771, 110, '07/03/2002', 4);
INSERT INTO valoracions VALUES (4771, 99, '14/11/2006', 10);
INSERT INTO valoracions VALUES (4772, 28, '24/08/2010', 5);
INSERT INTO valoracions VALUES (4772, 46, '18/11/2006', 3);
INSERT INTO valoracions VALUES (4772, 25, '05/06/2004', 6);
INSERT INTO valoracions VALUES (4772, 57, '21/12/2008', 7);
INSERT INTO valoracions VALUES (4773, 65, '04/09/2004', 3);
INSERT INTO valoracions VALUES (4773, 103, '20/12/2003', 8);
INSERT INTO valoracions VALUES (4773, 109, '20/10/2010', 7);
INSERT INTO valoracions VALUES (4773, 52, '23/08/2005', 9);
INSERT INTO valoracions VALUES (4774, 59, '09/01/2010', 5);
INSERT INTO valoracions VALUES (4774, 4, '30/05/2004', 6);
INSERT INTO valoracions VALUES (4774, 17, '18/07/2005', 9);
INSERT INTO valoracions VALUES (4774, 79, '26/07/2003', 2);
INSERT INTO valoracions VALUES (4775, 72, '18/08/2008', 8);
INSERT INTO valoracions VALUES (4776, 107, '24/05/2003', 1);
INSERT INTO valoracions VALUES (4776, 1, '05/11/2009', 10);
INSERT INTO valoracions VALUES (4776, 49, '06/11/2004', 8);
INSERT INTO valoracions VALUES (4776, 45, '26/05/2001', 8);
INSERT INTO valoracions VALUES (4776, 49, '29/05/2010', 9);
INSERT INTO valoracions VALUES (4776, 41, '15/02/2003', 9);
INSERT INTO valoracions VALUES (4776, 47, '02/12/2009', 7);
INSERT INTO valoracions VALUES (4777, 103, '09/10/2004', 1);
INSERT INTO valoracions VALUES (4777, 113, '19/11/2001', 0);
INSERT INTO valoracions VALUES (4778, 20, '10/05/2010', 8);
INSERT INTO valoracions VALUES (4778, 67, '20/04/2001', 9);
INSERT INTO valoracions VALUES (4778, 111, '05/10/2006', 4);
INSERT INTO valoracions VALUES (4778, 9, '02/08/2009', 8);
INSERT INTO valoracions VALUES (4779, 6, '07/03/2004', 7);
INSERT INTO valoracions VALUES (4779, 22, '04/04/2002', 9);
INSERT INTO valoracions VALUES (4779, 54, '14/07/2009', 4);
INSERT INTO valoracions VALUES (4779, 5, '22/01/2002', 6);
INSERT INTO valoracions VALUES (4779, 105, '18/10/2003', 1);
INSERT INTO valoracions VALUES (4780, 17, '03/01/2010', 8);
INSERT INTO valoracions VALUES (4780, 15, '09/12/2002', 9);
INSERT INTO valoracions VALUES (4780, 116, '16/11/2004', 9);
INSERT INTO valoracions VALUES (4780, 75, '08/07/2010', 8);
INSERT INTO valoracions VALUES (4780, 2, '18/03/2005', 9);
INSERT INTO valoracions VALUES (4780, 92, '14/10/2004', 4);
INSERT INTO valoracions VALUES (4780, 96, '28/02/2002', 5);
INSERT INTO valoracions VALUES (4781, 67, '18/02/2009', 3);
INSERT INTO valoracions VALUES (4781, 71, '05/07/2010', 10);
INSERT INTO valoracions VALUES (4781, 110, '27/08/2007', 3);
INSERT INTO valoracions VALUES (4781, 109, '17/09/2003', 3);
INSERT INTO valoracions VALUES (4781, 42, '13/12/2009', 4);
INSERT INTO valoracions VALUES (4781, 30, '22/06/2008', 4);
INSERT INTO valoracions VALUES (4782, 51, '27/02/2005', 5);
INSERT INTO valoracions VALUES (4782, 89, '08/05/2003', 4);
INSERT INTO valoracions VALUES (4783, 112, '05/12/2009', 8);
INSERT INTO valoracions VALUES (4783, 70, '01/07/2008', 5);
INSERT INTO valoracions VALUES (4783, 34, '20/11/2006', 6);
INSERT INTO valoracions VALUES (4783, 77, '01/10/2003', 8);
INSERT INTO valoracions VALUES (4783, 79, '11/10/2002', 7);
INSERT INTO valoracions VALUES (4783, 41, '16/08/2006', 4);
INSERT INTO valoracions VALUES (4783, 9, '29/12/2008', 5);
INSERT INTO valoracions VALUES (4783, 13, '06/03/2009', 10);
INSERT INTO valoracions VALUES (4784, 102, '02/08/2005', 10);
INSERT INTO valoracions VALUES (4784, 77, '25/07/2009', 5);
INSERT INTO valoracions VALUES (4784, 107, '08/01/2007', 2);
INSERT INTO valoracions VALUES (4785, 103, '17/07/2003', 3);
INSERT INTO valoracions VALUES (4785, 10, '16/09/2006', 8);
INSERT INTO valoracions VALUES (4786, 66, '07/07/2004', 8);
INSERT INTO valoracions VALUES (4787, 77, '24/05/2006', 8);
INSERT INTO valoracions VALUES (4787, 94, '28/11/2005', 10);
INSERT INTO valoracions VALUES (4788, 40, '02/10/2006', 9);
INSERT INTO valoracions VALUES (4788, 92, '17/05/2007', 9);
INSERT INTO valoracions VALUES (4788, 36, '25/08/2010', 4);
INSERT INTO valoracions VALUES (4789, 60, '12/12/2008', 4);
INSERT INTO valoracions VALUES (4789, 11, '03/05/2009', 7);
INSERT INTO valoracions VALUES (4789, 95, '21/03/2005', 5);
INSERT INTO valoracions VALUES (4789, 1, '14/02/2006', 9);
INSERT INTO valoracions VALUES (4790, 85, '03/12/2008', 7);
INSERT INTO valoracions VALUES (4790, 115, '26/01/2005', 2);
INSERT INTO valoracions VALUES (4790, 36, '17/01/2003', 9);
INSERT INTO valoracions VALUES (4791, 29, '26/09/2002', 7);
INSERT INTO valoracions VALUES (4791, 4, '03/07/2009', 6);
INSERT INTO valoracions VALUES (4791, 25, '17/04/2003', 7);
INSERT INTO valoracions VALUES (4791, 42, '07/09/2004', 6);
INSERT INTO valoracions VALUES (4791, 76, '04/06/2009', 6);
INSERT INTO valoracions VALUES (4792, 47, '25/09/2002', 10);
INSERT INTO valoracions VALUES (4793, 104, '19/08/2003', 6);
INSERT INTO valoracions VALUES (4793, 18, '03/09/2003', 10);
INSERT INTO valoracions VALUES (4793, 72, '19/09/2005', 3);
INSERT INTO valoracions VALUES (4793, 101, '08/12/2005', 10);
INSERT INTO valoracions VALUES (4794, 79, '04/02/2004', 2);
INSERT INTO valoracions VALUES (4794, 47, '15/08/2001', 7);
INSERT INTO valoracions VALUES (4794, 31, '28/06/2005', 8);
INSERT INTO valoracions VALUES (4794, 96, '08/06/2002', 9);
INSERT INTO valoracions VALUES (4794, 103, '08/07/2001', 3);
INSERT INTO valoracions VALUES (4794, 31, '10/05/2007', 7);
INSERT INTO valoracions VALUES (4794, 106, '02/10/2010', 10);
INSERT INTO valoracions VALUES (4794, 111, '10/07/2003', 1);
INSERT INTO valoracions VALUES (4795, 49, '27/12/2007', 8);
INSERT INTO valoracions VALUES (4795, 111, '09/04/2006', 10);
INSERT INTO valoracions VALUES (4795, 84, '05/07/2009', 5);
INSERT INTO valoracions VALUES (4795, 50, '26/06/2009', 4);
INSERT INTO valoracions VALUES (4796, 83, '06/04/2008', 3);
INSERT INTO valoracions VALUES (4796, 83, '13/03/2006', 5);
INSERT INTO valoracions VALUES (4797, 63, '25/01/2002', 4);
INSERT INTO valoracions VALUES (4798, 92, '28/06/2002', 2);
INSERT INTO valoracions VALUES (4798, 59, '07/11/2009', 4);
INSERT INTO valoracions VALUES (4799, 116, '11/04/2008', 3);
INSERT INTO valoracions VALUES (4799, 86, '30/08/2003', 3);
INSERT INTO valoracions VALUES (4799, 17, '20/05/2009', 5);
INSERT INTO valoracions VALUES (4799, 72, '05/03/2004', 3);
INSERT INTO valoracions VALUES (4799, 57, '30/08/2009', 9);
INSERT INTO valoracions VALUES (4799, 109, '17/04/2005', 9);
INSERT INTO valoracions VALUES (4800, 63, '12/06/2010', 6);
INSERT INTO valoracions VALUES (4800, 95, '31/01/2004', 5);
INSERT INTO valoracions VALUES (4800, 11, '06/06/2006', 5);
INSERT INTO valoracions VALUES (4800, 94, '11/05/2002', 4);
INSERT INTO valoracions VALUES (4800, 55, '11/08/2004', 5);
INSERT INTO valoracions VALUES (4800, 11, '14/03/2010', 6);
INSERT INTO valoracions VALUES (4801, 15, '31/12/2007', 8);
INSERT INTO valoracions VALUES (4801, 93, '16/07/2001', 6);
INSERT INTO valoracions VALUES (4801, 33, '15/12/2005', 9);
INSERT INTO valoracions VALUES (4802, 100, '02/05/2003', 1);
INSERT INTO valoracions VALUES (4802, 38, '05/04/2002', 5);
INSERT INTO valoracions VALUES (4802, 105, '07/03/2004', 3);
INSERT INTO valoracions VALUES (4803, 35, '28/01/2009', 4);
INSERT INTO valoracions VALUES (4803, 14, '09/07/2007', 7);
INSERT INTO valoracions VALUES (4803, 13, '08/04/2007', 7);
INSERT INTO valoracions VALUES (4803, 76, '23/04/2006', 4);
INSERT INTO valoracions VALUES (4804, 7, '01/04/2003', 9);
INSERT INTO valoracions VALUES (4804, 101, '18/12/2003', 4);
INSERT INTO valoracions VALUES (4804, 109, '31/07/2009', 5);
INSERT INTO valoracions VALUES (4804, 76, '27/11/2008', 4);
INSERT INTO valoracions VALUES (4805, 115, '01/03/2003', 5);
INSERT INTO valoracions VALUES (4805, 77, '02/03/2006', 8);
INSERT INTO valoracions VALUES (4805, 101, '04/10/2005', 3);
INSERT INTO valoracions VALUES (4806, 89, '05/02/2005', 2);
INSERT INTO valoracions VALUES (4806, 58, '22/11/2008', 7);
INSERT INTO valoracions VALUES (4806, 51, '08/10/2003', 6);
INSERT INTO valoracions VALUES (4807, 91, '04/04/2002', 7);
INSERT INTO valoracions VALUES (4807, 19, '20/10/2001', 7);
INSERT INTO valoracions VALUES (4807, 10, '03/12/2003', 8);
INSERT INTO valoracions VALUES (4807, 59, '02/02/2008', 6);
INSERT INTO valoracions VALUES (4807, 82, '27/12/2008', 5);
INSERT INTO valoracions VALUES (4807, 51, '22/03/2004', 6);
INSERT INTO valoracions VALUES (4807, 69, '11/06/2001', 8);
INSERT INTO valoracions VALUES (4808, 36, '08/06/2009', 6);
INSERT INTO valoracions VALUES (4808, 7, '26/06/2008', 9);
INSERT INTO valoracions VALUES (4808, 59, '09/10/2007', 9);
INSERT INTO valoracions VALUES (4809, 1, '25/12/2005', 7);
INSERT INTO valoracions VALUES (4809, 35, '28/03/2002', 7);
INSERT INTO valoracions VALUES (4809, 113, '09/06/2002', 5);
INSERT INTO valoracions VALUES (4809, 24, '13/08/2004', 7);
INSERT INTO valoracions VALUES (4809, 56, '11/03/2009', 7);
INSERT INTO valoracions VALUES (4810, 67, '17/09/2009', 7);
INSERT INTO valoracions VALUES (4810, 37, '08/04/2004', 4);
INSERT INTO valoracions VALUES (4810, 78, '12/06/2004', 3);
INSERT INTO valoracions VALUES (4810, 92, '31/03/2008', 6);
INSERT INTO valoracions VALUES (4810, 25, '28/04/2006', 4);
INSERT INTO valoracions VALUES (4811, 92, '23/08/2003', 2);
INSERT INTO valoracions VALUES (4811, 68, '01/05/2009', 9);
INSERT INTO valoracions VALUES (4811, 7, '07/12/2007', 9);
INSERT INTO valoracions VALUES (4811, 106, '18/10/2007', 10);
INSERT INTO valoracions VALUES (4812, 42, '25/10/2009', 7);
INSERT INTO valoracions VALUES (4812, 16, '04/01/2005', 8);
INSERT INTO valoracions VALUES (4812, 97, '01/05/2007', 5);
INSERT INTO valoracions VALUES (4812, 14, '09/06/2010', 7);
INSERT INTO valoracions VALUES (4812, 14, '27/07/2010', 9);
INSERT INTO valoracions VALUES (4813, 57, '24/03/2007', 8);
INSERT INTO valoracions VALUES (4813, 112, '28/09/2006', 3);
INSERT INTO valoracions VALUES (4814, 112, '12/02/2003', 10);
INSERT INTO valoracions VALUES (4814, 3, '17/09/2002', 6);
INSERT INTO valoracions VALUES (4814, 93, '19/10/2002', 4);
INSERT INTO valoracions VALUES (4814, 54, '17/03/2010', 7);
INSERT INTO valoracions VALUES (4815, 110, '14/05/2002', 10);
INSERT INTO valoracions VALUES (4815, 9, '25/06/2001', 8);
INSERT INTO valoracions VALUES (4816, 99, '02/07/2005', 3);
INSERT INTO valoracions VALUES (4816, 44, '22/10/2010', 9);
INSERT INTO valoracions VALUES (4816, 16, '21/03/2008', 8);
INSERT INTO valoracions VALUES (4816, 84, '07/08/2008', 8);
INSERT INTO valoracions VALUES (4816, 47, '02/03/2006', 6);
INSERT INTO valoracions VALUES (4816, 21, '28/07/2001', 4);
INSERT INTO valoracions VALUES (4816, 60, '12/01/2003', 3);
INSERT INTO valoracions VALUES (4818, 108, '25/10/2010', 0);
INSERT INTO valoracions VALUES (4818, 85, '30/04/2007', 7);
INSERT INTO valoracions VALUES (4819, 113, '10/03/2003', 6);
INSERT INTO valoracions VALUES (4819, 7, '20/02/2003', 8);
INSERT INTO valoracions VALUES (4819, 33, '05/12/2007', 6);
INSERT INTO valoracions VALUES (4819, 80, '17/10/2002', 3);
INSERT INTO valoracions VALUES (4820, 74, '02/02/2002', 4);
INSERT INTO valoracions VALUES (4820, 43, '17/07/2006', 10);
INSERT INTO valoracions VALUES (4821, 45, '10/11/2001', 9);
INSERT INTO valoracions VALUES (4821, 10, '28/11/2009', 8);
INSERT INTO valoracions VALUES (4822, 60, '16/07/2007', 5);
INSERT INTO valoracions VALUES (4823, 53, '26/07/2010', 5);
INSERT INTO valoracions VALUES (4823, 44, '15/04/2008', 6);
INSERT INTO valoracions VALUES (4823, 77, '29/03/2003', 9);
INSERT INTO valoracions VALUES (4824, 109, '01/05/2002', 2);
INSERT INTO valoracions VALUES (4824, 108, '11/09/2006', 3);
INSERT INTO valoracions VALUES (4824, 86, '17/06/2003', 7);
INSERT INTO valoracions VALUES (4824, 3, '17/05/2001', 8);
INSERT INTO valoracions VALUES (4824, 27, '04/05/2004', 6);
INSERT INTO valoracions VALUES (4824, 93, '14/08/2007', 8);
INSERT INTO valoracions VALUES (4825, 37, '02/11/2009', 10);
INSERT INTO valoracions VALUES (4825, 6, '26/03/2002', 8);
INSERT INTO valoracions VALUES (4826, 89, '06/07/2009', 2);
INSERT INTO valoracions VALUES (4826, 39, '21/09/2004', 5);
INSERT INTO valoracions VALUES (4826, 68, '11/01/2007', 7);
INSERT INTO valoracions VALUES (4827, 21, '23/01/2009', 7);
INSERT INTO valoracions VALUES (4827, 90, '06/08/2003', 6);
INSERT INTO valoracions VALUES (4827, 31, '20/08/2007', 6);
INSERT INTO valoracions VALUES (4828, 80, '01/03/2004', 7);
INSERT INTO valoracions VALUES (4828, 18, '24/07/2007', 7);
INSERT INTO valoracions VALUES (4828, 87, '15/01/2008', 4);
INSERT INTO valoracions VALUES (4828, 116, '19/06/2001', 1);
INSERT INTO valoracions VALUES (4828, 79, '20/12/2003', 7);
INSERT INTO valoracions VALUES (4828, 20, '10/04/2010', 5);
INSERT INTO valoracions VALUES (4828, 20, '30/06/2008', 6);
INSERT INTO valoracions VALUES (4828, 20, '11/03/2005', 5);
INSERT INTO valoracions VALUES (4829, 31, '22/07/2003', 9);
INSERT INTO valoracions VALUES (4829, 91, '13/12/2005', 6);
INSERT INTO valoracions VALUES (4830, 4, '26/09/2002', 9);
INSERT INTO valoracions VALUES (4830, 61, '22/03/2010', 8);
INSERT INTO valoracions VALUES (4830, 71, '10/07/2002', 8);
INSERT INTO valoracions VALUES (4830, 46, '21/01/2007', 7);
INSERT INTO valoracions VALUES (4831, 108, '11/07/2010', 4);
INSERT INTO valoracions VALUES (4831, 91, '27/09/2010', 7);
INSERT INTO valoracions VALUES (4831, 107, '22/12/2006', 10);
INSERT INTO valoracions VALUES (4831, 12, '04/08/2005', 9);
INSERT INTO valoracions VALUES (4831, 79, '11/03/2010', 5);
INSERT INTO valoracions VALUES (4831, 103, '08/09/2010', 3);
INSERT INTO valoracions VALUES (4832, 93, '12/10/2001', 7);
INSERT INTO valoracions VALUES (4832, 110, '16/12/2003', 2);
INSERT INTO valoracions VALUES (4832, 5, '15/12/2004', 8);
INSERT INTO valoracions VALUES (4832, 7, '25/06/2005', 9);
INSERT INTO valoracions VALUES (4832, 78, '07/12/2008', 10);
INSERT INTO valoracions VALUES (4832, 29, '03/03/2009', 4);
INSERT INTO valoracions VALUES (4832, 101, '30/06/2007', 4);
INSERT INTO valoracions VALUES (4833, 38, '11/02/2004', 7);
INSERT INTO valoracions VALUES (4834, 110, '25/09/2001', 9);
INSERT INTO valoracions VALUES (4834, 21, '19/10/2003', 9);
INSERT INTO valoracions VALUES (4834, 108, '23/10/2010', 8);
INSERT INTO valoracions VALUES (4834, 61, '23/07/2006', 6);
INSERT INTO valoracions VALUES (4834, 99, '22/06/2007', 4);
INSERT INTO valoracions VALUES (4835, 93, '02/08/2008', 7);
INSERT INTO valoracions VALUES (4835, 47, '19/10/2007', 5);
INSERT INTO valoracions VALUES (4835, 90, '02/07/2006', 2);
INSERT INTO valoracions VALUES (4835, 39, '29/04/2009', 5);
INSERT INTO valoracions VALUES (4835, 37, '13/10/2001', 9);
INSERT INTO valoracions VALUES (4837, 70, '09/09/2002', 8);
INSERT INTO valoracions VALUES (4837, 79, '18/07/2010', 8);
INSERT INTO valoracions VALUES (4837, 89, '02/06/2009', 9);
INSERT INTO valoracions VALUES (4838, 68, '13/04/2010', 4);
INSERT INTO valoracions VALUES (4838, 22, '06/04/2004', 9);
INSERT INTO valoracions VALUES (4838, 113, '04/02/2002', 5);
INSERT INTO valoracions VALUES (4838, 94, '03/09/2006', 6);
INSERT INTO valoracions VALUES (4839, 52, '01/06/2002', 4);
INSERT INTO valoracions VALUES (4839, 88, '13/02/2009', 2);
INSERT INTO valoracions VALUES (4839, 104, '24/07/2002', 5);
INSERT INTO valoracions VALUES (4839, 54, '03/06/2007', 3);
INSERT INTO valoracions VALUES (4839, 51, '24/07/2001', 7);
INSERT INTO valoracions VALUES (4839, 13, '01/04/2009', 6);
INSERT INTO valoracions VALUES (4840, 107, '04/10/2004', 4);
INSERT INTO valoracions VALUES (4840, 88, '22/08/2001', 7);
INSERT INTO valoracions VALUES (4840, 38, '18/11/2004', 8);
INSERT INTO valoracions VALUES (4840, 42, '16/08/2010', 8);
INSERT INTO valoracions VALUES (4840, 28, '25/12/2004', 8);
INSERT INTO valoracions VALUES (4841, 51, '18/01/2003', 4);
INSERT INTO valoracions VALUES (4841, 38, '11/09/2002', 6);
INSERT INTO valoracions VALUES (4841, 3, '17/07/2009', 8);
INSERT INTO valoracions VALUES (4841, 2, '31/12/2008', 7);
INSERT INTO valoracions VALUES (4841, 114, '03/08/2004', 9);
INSERT INTO valoracions VALUES (4842, 4, '10/03/2002', 8);
INSERT INTO valoracions VALUES (4842, 115, '29/01/2007', 6);
INSERT INTO valoracions VALUES (4842, 105, '21/10/2001', 1);
INSERT INTO valoracions VALUES (4842, 114, '03/05/2004', 4);
INSERT INTO valoracions VALUES (4842, 103, '05/05/2004', 2);
INSERT INTO valoracions VALUES (4843, 91, '27/06/2010', 3);
INSERT INTO valoracions VALUES (4843, 91, '17/05/2005', 10);
INSERT INTO valoracions VALUES (4843, 113, '22/04/2003', 5);
INSERT INTO valoracions VALUES (4843, 43, '20/11/2007', 8);
INSERT INTO valoracions VALUES (4844, 90, '22/02/2007', 6);
INSERT INTO valoracions VALUES (4844, 85, '30/11/2005', 4);
INSERT INTO valoracions VALUES (4844, 91, '19/12/2002', 7);
INSERT INTO valoracions VALUES (4844, 17, '23/02/2009', 6);
INSERT INTO valoracions VALUES (4844, 80, '28/07/2002', 6);
INSERT INTO valoracions VALUES (4844, 103, '05/02/2004', 7);
INSERT INTO valoracions VALUES (4844, 107, '19/09/2008', 10);
INSERT INTO valoracions VALUES (4845, 27, '15/02/2002', 10);
INSERT INTO valoracions VALUES (4845, 36, '07/12/2001', 4);
INSERT INTO valoracions VALUES (4845, 104, '03/04/2002', 2);
INSERT INTO valoracions VALUES (4845, 59, '15/09/2008', 7);
INSERT INTO valoracions VALUES (4845, 1, '14/05/2009', 7);
INSERT INTO valoracions VALUES (4846, 3, '27/05/2009', 5);
INSERT INTO valoracions VALUES (4846, 94, '28/02/2005', 5);
INSERT INTO valoracions VALUES (4846, 3, '07/05/2001', 7);
INSERT INTO valoracions VALUES (4847, 47, '25/10/2008', 6);
INSERT INTO valoracions VALUES (4847, 36, '23/11/2002', 9);
INSERT INTO valoracions VALUES (4847, 53, '09/05/2010', 9);
INSERT INTO valoracions VALUES (4847, 29, '18/05/2007', 8);
INSERT INTO valoracions VALUES (4847, 13, '05/12/2004', 5);
INSERT INTO valoracions VALUES (4847, 30, '24/03/2010', 5);
INSERT INTO valoracions VALUES (4848, 73, '01/11/2005', 4);
INSERT INTO valoracions VALUES (4848, 48, '20/12/2003', 4);
INSERT INTO valoracions VALUES (4848, 105, '31/08/2006', 1);
INSERT INTO valoracions VALUES (4848, 30, '02/06/2001', 7);
INSERT INTO valoracions VALUES (4848, 23, '19/07/2010', 5);
INSERT INTO valoracions VALUES (4848, 23, '02/05/2010', 9);
INSERT INTO valoracions VALUES (4849, 11, '25/05/2009', 5);
INSERT INTO valoracions VALUES (4849, 27, '27/12/2004', 8);
INSERT INTO valoracions VALUES (4850, 27, '28/04/2002', 6);
INSERT INTO valoracions VALUES (4850, 57, '27/12/2005', 5);
INSERT INTO valoracions VALUES (4850, 10, '16/06/2009', 9);
INSERT INTO valoracions VALUES (4851, 37, '26/04/2006', 5);
INSERT INTO valoracions VALUES (4851, 116, '08/10/2006', 5);
INSERT INTO valoracions VALUES (4851, 107, '14/10/2001', 6);
INSERT INTO valoracions VALUES (4851, 63, '06/04/2010', 4);
INSERT INTO valoracions VALUES (4852, 35, '27/04/2004', 6);
INSERT INTO valoracions VALUES (4852, 104, '27/10/2006', 3);
INSERT INTO valoracions VALUES (4852, 56, '06/10/2004', 4);
INSERT INTO valoracions VALUES (4852, 13, '05/10/2001', 5);
INSERT INTO valoracions VALUES (4852, 20, '03/02/2004', 5);
INSERT INTO valoracions VALUES (4853, 58, '17/10/2007', 5);
INSERT INTO valoracions VALUES (4853, 71, '05/07/2008', 2);
INSERT INTO valoracions VALUES (4853, 82, '29/08/2003', 5);
INSERT INTO valoracions VALUES (4853, 105, '22/03/2009', 5);
INSERT INTO valoracions VALUES (4854, 32, '22/07/2010', 9);
INSERT INTO valoracions VALUES (4855, 81, '25/04/2003', 8);
INSERT INTO valoracions VALUES (4855, 29, '28/09/2003', 9);
INSERT INTO valoracions VALUES (4855, 36, '13/10/2008', 5);
INSERT INTO valoracions VALUES (4855, 94, '27/10/2010', 9);
INSERT INTO valoracions VALUES (4855, 100, '14/06/2006', 5);
INSERT INTO valoracions VALUES (4855, 51, '06/10/2008', 6);
INSERT INTO valoracions VALUES (4855, 25, '06/12/2001', 8);
INSERT INTO valoracions VALUES (4855, 106, '20/04/2002', 5);
INSERT INTO valoracions VALUES (4856, 106, '19/06/2005', 8);
INSERT INTO valoracions VALUES (4856, 3, '23/08/2002', 8);
INSERT INTO valoracions VALUES (4856, 94, '25/10/2006', 5);
INSERT INTO valoracions VALUES (4856, 54, '06/02/2006', 7);
INSERT INTO valoracions VALUES (4856, 17, '21/08/2006', 10);
INSERT INTO valoracions VALUES (4857, 3, '21/06/2009', 9);
INSERT INTO valoracions VALUES (4857, 71, '06/06/2003', 6);
INSERT INTO valoracions VALUES (4857, 51, '11/08/2006', 4);
INSERT INTO valoracions VALUES (4858, 5, '30/09/2007', 9);
INSERT INTO valoracions VALUES (4858, 38, '14/04/2003', 3);
INSERT INTO valoracions VALUES (4858, 102, '10/09/2001', 8);
INSERT INTO valoracions VALUES (4859, 102, '05/05/2002', 6);
INSERT INTO valoracions VALUES (4859, 7, '24/05/2001', 7);
INSERT INTO valoracions VALUES (4859, 93, '20/12/2005', 5);
INSERT INTO valoracions VALUES (4859, 53, '11/05/2009', 9);
INSERT INTO valoracions VALUES (4859, 20, '18/06/2004', 10);
INSERT INTO valoracions VALUES (4859, 3, '08/02/2004', 6);
INSERT INTO valoracions VALUES (4859, 7, '16/01/2004', 6);
INSERT INTO valoracions VALUES (4860, 53, '12/01/2008', 6);
INSERT INTO valoracions VALUES (4860, 95, '04/01/2007', 1);
INSERT INTO valoracions VALUES (4860, 108, '13/02/2007', 2);
INSERT INTO valoracions VALUES (4861, 97, '17/01/2004', 2);
INSERT INTO valoracions VALUES (4861, 101, '08/05/2010', 3);
INSERT INTO valoracions VALUES (4861, 13, '09/10/2009', 5);
INSERT INTO valoracions VALUES (4861, 88, '21/12/2002', 7);
INSERT INTO valoracions VALUES (4861, 95, '13/12/2003', 7);
INSERT INTO valoracions VALUES (4862, 14, '06/10/2010', 7);
INSERT INTO valoracions VALUES (4863, 62, '20/02/2003', 6);
INSERT INTO valoracions VALUES (4863, 50, '27/09/2005', 8);
INSERT INTO valoracions VALUES (4863, 88, '07/08/2005', 7);
INSERT INTO valoracions VALUES (4863, 107, '12/10/2009', 5);
INSERT INTO valoracions VALUES (4863, 116, '01/03/2005', 8);
INSERT INTO valoracions VALUES (4864, 83, '06/05/2002', 7);
INSERT INTO valoracions VALUES (4864, 116, '19/08/2010', 2);
INSERT INTO valoracions VALUES (4864, 83, '09/08/2001', 9);
INSERT INTO valoracions VALUES (4864, 2, '18/02/2010', 10);
INSERT INTO valoracions VALUES (4864, 51, '24/02/2005', 9);
INSERT INTO valoracions VALUES (4864, 19, '01/05/2002', 5);
INSERT INTO valoracions VALUES (4864, 1, '14/06/2008', 10);
INSERT INTO valoracions VALUES (4865, 95, '15/11/2008', 1);
INSERT INTO valoracions VALUES (4866, 9, '20/08/2003', 7);
INSERT INTO valoracions VALUES (4866, 71, '13/04/2001', 3);
INSERT INTO valoracions VALUES (4866, 66, '01/10/2010', 4);
INSERT INTO valoracions VALUES (4867, 10, '07/12/2003', 5);
INSERT INTO valoracions VALUES (4867, 58, '22/08/2004', 4);
INSERT INTO valoracions VALUES (4867, 94, '11/10/2001', 7);
INSERT INTO valoracions VALUES (4867, 96, '24/07/2005', 8);
INSERT INTO valoracions VALUES (4868, 53, '07/11/2008', 9);
INSERT INTO valoracions VALUES (4868, 34, '27/12/2006', 5);
INSERT INTO valoracions VALUES (4868, 56, '30/09/2010', 5);
INSERT INTO valoracions VALUES (4869, 47, '23/06/2008', 4);
INSERT INTO valoracions VALUES (4869, 14, '15/12/2007', 7);
INSERT INTO valoracions VALUES (4870, 82, '30/08/2004', 6);
INSERT INTO valoracions VALUES (4870, 7, '26/12/2001', 7);
INSERT INTO valoracions VALUES (4870, 10, '25/04/2003', 6);
INSERT INTO valoracions VALUES (4870, 86, '27/08/2008', 5);
INSERT INTO valoracions VALUES (4871, 64, '31/07/2006', 2);
INSERT INTO valoracions VALUES (4871, 71, '09/04/2005', 8);
INSERT INTO valoracions VALUES (4871, 29, '14/05/2003', 6);
INSERT INTO valoracions VALUES (4871, 38, '02/01/2004', 9);
INSERT INTO valoracions VALUES (4871, 62, '03/02/2008', 3);
INSERT INTO valoracions VALUES (4871, 46, '08/11/2009', 7);
INSERT INTO valoracions VALUES (4871, 62, '14/02/2008', 9);
INSERT INTO valoracions VALUES (4872, 2, '09/09/2005', 9);
INSERT INTO valoracions VALUES (4872, 83, '06/01/2008', 2);
INSERT INTO valoracions VALUES (4872, 19, '06/11/2002', 9);
INSERT INTO valoracions VALUES (4872, 35, '07/05/2007', 4);
INSERT INTO valoracions VALUES (4874, 46, '12/02/2009', 8);
INSERT INTO valoracions VALUES (4874, 41, '26/12/2009', 8);
INSERT INTO valoracions VALUES (4874, 28, '15/10/2005', 8);
INSERT INTO valoracions VALUES (4875, 81, '24/08/2003', 10);
INSERT INTO valoracions VALUES (4875, 53, '12/07/2009', 7);
INSERT INTO valoracions VALUES (4875, 7, '09/07/2001', 5);
INSERT INTO valoracions VALUES (4875, 1, '12/08/2008', 8);
INSERT INTO valoracions VALUES (4875, 105, '21/05/2002', 4);
INSERT INTO valoracions VALUES (4875, 8, '28/09/2005', 7);
INSERT INTO valoracions VALUES (4875, 5, '21/03/2002', 5);
INSERT INTO valoracions VALUES (4875, 27, '12/12/2009', 7);
INSERT INTO valoracions VALUES (4876, 80, '08/01/2008', 10);
INSERT INTO valoracions VALUES (4876, 26, '30/03/2002', 6);
INSERT INTO valoracions VALUES (4876, 59, '26/12/2001', 9);
INSERT INTO valoracions VALUES (4876, 40, '30/04/2001', 7);
INSERT INTO valoracions VALUES (4876, 115, '05/01/2009', 4);
INSERT INTO valoracions VALUES (4877, 44, '27/05/2007', 5);
INSERT INTO valoracions VALUES (4877, 83, '01/04/2003', 5);
INSERT INTO valoracions VALUES (4877, 39, '27/12/2004', 3);
INSERT INTO valoracions VALUES (4877, 10, '16/04/2001', 6);
INSERT INTO valoracions VALUES (4877, 3, '10/08/2007', 6);
INSERT INTO valoracions VALUES (4877, 65, '11/11/2003', 5);
INSERT INTO valoracions VALUES (4877, 55, '22/12/2007', 7);
INSERT INTO valoracions VALUES (4877, 9, '29/08/2009', 6);
INSERT INTO valoracions VALUES (4877, 89, '15/01/2002', 8);
INSERT INTO valoracions VALUES (4877, 70, '11/11/2005', 4);
INSERT INTO valoracions VALUES (4878, 103, '01/10/2002', 4);
INSERT INTO valoracions VALUES (4878, 10, '29/07/2002', 6);
INSERT INTO valoracions VALUES (4878, 109, '05/08/2003', 1);
INSERT INTO valoracions VALUES (4879, 115, '01/10/2010', 2);
INSERT INTO valoracions VALUES (4879, 59, '15/11/2003', 9);
INSERT INTO valoracions VALUES (4879, 60, '20/04/2010', 8);
INSERT INTO valoracions VALUES (4879, 69, '10/03/2007', 4);
INSERT INTO valoracions VALUES (4879, 45, '16/08/2001', 7);
INSERT INTO valoracions VALUES (4880, 69, '08/12/2007', 7);
INSERT INTO valoracions VALUES (4880, 73, '04/04/2010', 8);
INSERT INTO valoracions VALUES (4880, 52, '28/12/2002', 7);
INSERT INTO valoracions VALUES (4880, 23, '24/04/2010', 7);
INSERT INTO valoracions VALUES (4881, 102, '28/01/2009', 6);
INSERT INTO valoracions VALUES (4881, 89, '04/03/2009', 6);
INSERT INTO valoracions VALUES (4881, 9, '28/02/2002', 7);
INSERT INTO valoracions VALUES (4881, 32, '27/07/2003', 4);
INSERT INTO valoracions VALUES (4882, 63, '25/06/2009', 9);
INSERT INTO valoracions VALUES (4882, 53, '06/05/2009', 9);
INSERT INTO valoracions VALUES (4882, 91, '10/11/2001', 4);
INSERT INTO valoracions VALUES (4883, 19, '25/06/2009', 8);
INSERT INTO valoracions VALUES (4883, 19, '31/05/2002', 8);
INSERT INTO valoracions VALUES (4883, 97, '31/08/2007', 3);
INSERT INTO valoracions VALUES (4883, 83, '06/06/2002', 6);
INSERT INTO valoracions VALUES (4883, 95, '14/07/2008', 4);
INSERT INTO valoracions VALUES (4884, 75, '02/05/2006', 8);
INSERT INTO valoracions VALUES (4884, 9, '17/10/2006', 9);
INSERT INTO valoracions VALUES (4884, 39, '16/07/2003', 7);
INSERT INTO valoracions VALUES (4884, 51, '29/11/2006', 5);
INSERT INTO valoracions VALUES (4884, 66, '18/07/2003', 6);
INSERT INTO valoracions VALUES (4884, 13, '16/01/2003', 7);
INSERT INTO valoracions VALUES (4885, 8, '02/09/2007', 7);
INSERT INTO valoracions VALUES (4885, 14, '01/06/2001', 9);
INSERT INTO valoracions VALUES (4885, 33, '18/05/2005', 6);
INSERT INTO valoracions VALUES (4885, 64, '09/08/2005', 10);
INSERT INTO valoracions VALUES (4886, 41, '16/04/2004', 8);
INSERT INTO valoracions VALUES (4886, 115, '29/07/2009', 1);
INSERT INTO valoracions VALUES (4886, 10, '10/09/2008', 8);
INSERT INTO valoracions VALUES (4886, 33, '25/04/2005', 10);
INSERT INTO valoracions VALUES (4886, 110, '05/10/2007', 0);
INSERT INTO valoracions VALUES (4886, 73, '14/09/2008', 2);
INSERT INTO valoracions VALUES (4887, 102, '08/07/2010', 10);
INSERT INTO valoracions VALUES (4887, 35, '21/01/2004', 6);
INSERT INTO valoracions VALUES (4888, 56, '29/08/2010', 8);
INSERT INTO valoracions VALUES (4888, 89, '30/06/2003', 2);
INSERT INTO valoracions VALUES (4889, 36, '20/03/2006', 5);
INSERT INTO valoracions VALUES (4889, 35, '15/07/2006', 4);
INSERT INTO valoracions VALUES (4889, 68, '18/08/2007', 8);
INSERT INTO valoracions VALUES (4889, 92, '28/05/2006', 6);
INSERT INTO valoracions VALUES (4890, 20, '01/05/2004', 5);
INSERT INTO valoracions VALUES (4890, 11, '18/01/2007', 10);
INSERT INTO valoracions VALUES (4890, 75, '16/02/2002', 8);
INSERT INTO valoracions VALUES (4890, 49, '06/06/2002', 6);
INSERT INTO valoracions VALUES (4891, 41, '16/06/2004', 4);
INSERT INTO valoracions VALUES (4892, 79, '18/12/2006', 6);
INSERT INTO valoracions VALUES (4892, 101, '11/10/2008', 10);
INSERT INTO valoracions VALUES (4892, 19, '03/08/2005', 9);
INSERT INTO valoracions VALUES (4892, 14, '23/10/2005', 9);
INSERT INTO valoracions VALUES (4892, 64, '25/10/2010', 10);
INSERT INTO valoracions VALUES (4893, 112, '22/11/2005', 6);
INSERT INTO valoracions VALUES (4893, 108, '04/03/2007', 1);
INSERT INTO valoracions VALUES (4893, 25, '21/05/2002', 5);
INSERT INTO valoracions VALUES (4893, 4, '08/04/2010', 8);
INSERT INTO valoracions VALUES (4894, 103, '25/11/2001', 7);
INSERT INTO valoracions VALUES (4894, 61, '27/07/2008', 6);
INSERT INTO valoracions VALUES (4895, 62, '09/07/2008', 9);
INSERT INTO valoracions VALUES (4895, 74, '17/09/2009', 6);
INSERT INTO valoracions VALUES (4895, 41, '08/10/2007', 7);
INSERT INTO valoracions VALUES (4896, 92, '10/06/2005', 4);
INSERT INTO valoracions VALUES (4896, 97, '17/04/2006', 8);
INSERT INTO valoracions VALUES (4896, 34, '04/08/2006', 5);
INSERT INTO valoracions VALUES (4897, 86, '01/09/2005', 3);
INSERT INTO valoracions VALUES (4897, 46, '22/02/2010', 3);
INSERT INTO valoracions VALUES (4898, 88, '08/12/2004', 8);
INSERT INTO valoracions VALUES (4898, 100, '15/12/2008', 6);
INSERT INTO valoracions VALUES (4898, 32, '03/12/2002', 6);
INSERT INTO valoracions VALUES (4898, 21, '01/07/2002', 5);
INSERT INTO valoracions VALUES (4898, 91, '30/07/2007', 6);
INSERT INTO valoracions VALUES (4899, 61, '05/12/2007', 5);
INSERT INTO valoracions VALUES (4899, 111, '02/12/2006', 5);
INSERT INTO valoracions VALUES (4899, 19, '24/02/2006', 7);
INSERT INTO valoracions VALUES (4899, 92, '06/04/2003', 4);
INSERT INTO valoracions VALUES (4899, 99, '01/07/2008', 8);
INSERT INTO valoracions VALUES (4899, 92, '05/03/2002', 5);
INSERT INTO valoracions VALUES (4900, 77, '14/12/2003', 9);
INSERT INTO valoracions VALUES (4900, 50, '03/09/2010', 6);
INSERT INTO valoracions VALUES (4900, 10, '07/03/2007', 8);
INSERT INTO valoracions VALUES (4900, 76, '06/10/2004', 3);
INSERT INTO valoracions VALUES (4900, 64, '10/01/2008', 9);
INSERT INTO valoracions VALUES (4901, 69, '01/08/2010', 7);
INSERT INTO valoracions VALUES (4901, 81, '15/03/2008', 8);
INSERT INTO valoracions VALUES (4901, 7, '05/07/2008', 9);
INSERT INTO valoracions VALUES (4901, 53, '21/12/2009', 7);
INSERT INTO valoracions VALUES (4901, 89, '29/05/2007', 4);
INSERT INTO valoracions VALUES (4902, 25, '07/05/2005', 5);
INSERT INTO valoracions VALUES (4902, 83, '05/09/2006', 2);
INSERT INTO valoracions VALUES (4902, 43, '21/02/2004', 9);
INSERT INTO valoracions VALUES (4902, 3, '21/07/2010', 8);
INSERT INTO valoracions VALUES (4903, 106, '01/09/2002', 10);
INSERT INTO valoracions VALUES (4904, 69, '16/07/2009', 7);
INSERT INTO valoracions VALUES (4905, 93, '11/03/2003', 8);
INSERT INTO valoracions VALUES (4905, 30, '29/07/2004', 7);
INSERT INTO valoracions VALUES (4905, 100, '22/11/2001', 3);
INSERT INTO valoracions VALUES (4905, 18, '28/06/2001', 9);
INSERT INTO valoracions VALUES (4906, 13, '18/04/2003', 6);
INSERT INTO valoracions VALUES (4906, 15, '14/04/2006', 4);
INSERT INTO valoracions VALUES (4906, 42, '22/09/2001', 9);
INSERT INTO valoracions VALUES (4906, 83, '08/11/2004', 6);
INSERT INTO valoracions VALUES (4906, 77, '24/11/2003', 7);
INSERT INTO valoracions VALUES (4907, 90, '04/06/2005', 10);
INSERT INTO valoracions VALUES (4907, 3, '10/11/2008', 8);
INSERT INTO valoracions VALUES (4907, 31, '26/03/2008', 8);
INSERT INTO valoracions VALUES (4908, 48, '18/06/2003', 4);
INSERT INTO valoracions VALUES (4908, 49, '07/06/2002', 6);
INSERT INTO valoracions VALUES (4908, 36, '14/08/2006', 9);
INSERT INTO valoracions VALUES (4908, 37, '06/02/2004', 4);
INSERT INTO valoracions VALUES (4909, 99, '25/02/2003', 4);
INSERT INTO valoracions VALUES (4909, 37, '30/01/2010', 5);
INSERT INTO valoracions VALUES (4910, 29, '08/08/2006', 8);
INSERT INTO valoracions VALUES (4910, 40, '26/01/2003', 10);
INSERT INTO valoracions VALUES (4910, 21, '30/05/2008', 6);
INSERT INTO valoracions VALUES (4910, 93, '04/12/2001', 9);
INSERT INTO valoracions VALUES (4910, 112, '22/08/2002', 2);
INSERT INTO valoracions VALUES (4911, 66, '25/02/2006', 5);
INSERT INTO valoracions VALUES (4911, 34, '23/11/2006', 6);
INSERT INTO valoracions VALUES (4911, 103, '02/03/2009', 2);
INSERT INTO valoracions VALUES (4911, 107, '10/08/2001', 1);
INSERT INTO valoracions VALUES (4911, 63, '10/04/2008', 5);
INSERT INTO valoracions VALUES (4911, 63, '23/12/2007', 5);
INSERT INTO valoracions VALUES (4912, 10, '20/03/2006', 10);
INSERT INTO valoracions VALUES (4913, 42, '08/07/2004', 5);
INSERT INTO valoracions VALUES (4913, 24, '05/03/2004', 9);
INSERT INTO valoracions VALUES (4913, 112, '02/11/2006', 7);
INSERT INTO valoracions VALUES (4913, 93, '27/09/2002', 2);
INSERT INTO valoracions VALUES (4913, 54, '21/06/2009', 6);
INSERT INTO valoracions VALUES (4913, 31, '06/05/2010', 5);
INSERT INTO valoracions VALUES (4914, 116, '29/03/2009', 10);
INSERT INTO valoracions VALUES (4914, 78, '31/08/2006', 7);
INSERT INTO valoracions VALUES (4914, 83, '30/12/2003', 7);
INSERT INTO valoracions VALUES (4914, 86, '28/11/2002', 4);
INSERT INTO valoracions VALUES (4914, 85, '03/02/2002', 7);
INSERT INTO valoracions VALUES (4914, 105, '02/10/2004', 2);
INSERT INTO valoracions VALUES (4915, 26, '30/10/2004', 8);
INSERT INTO valoracions VALUES (4915, 51, '17/06/2008', 7);
INSERT INTO valoracions VALUES (4916, 22, '10/05/2002', 6);
INSERT INTO valoracions VALUES (4916, 56, '11/01/2008', 6);
INSERT INTO valoracions VALUES (4916, 86, '05/10/2008', 5);
INSERT INTO valoracions VALUES (4916, 95, '08/08/2007', 6);
INSERT INTO valoracions VALUES (4916, 53, '04/03/2008', 4);
INSERT INTO valoracions VALUES (4916, 26, '13/01/2004', 9);
INSERT INTO valoracions VALUES (4916, 92, '18/06/2009', 6);
INSERT INTO valoracions VALUES (4917, 100, '16/10/2007', 10);
INSERT INTO valoracions VALUES (4917, 39, '25/10/2005', 3);
INSERT INTO valoracions VALUES (4917, 14, '03/10/2008', 8);
INSERT INTO valoracions VALUES (4917, 96, '11/03/2010', 6);
INSERT INTO valoracions VALUES (4917, 19, '29/06/2005', 5);
INSERT INTO valoracions VALUES (4918, 81, '31/03/2007', 5);
INSERT INTO valoracions VALUES (4918, 84, '06/10/2009', 8);
INSERT INTO valoracions VALUES (4918, 102, '22/02/2008', 3);
INSERT INTO valoracions VALUES (4919, 79, '29/08/2008', 9);
INSERT INTO valoracions VALUES (4919, 56, '21/07/2007', 3);
INSERT INTO valoracions VALUES (4919, 101, '06/09/2005', 4);
INSERT INTO valoracions VALUES (4919, 67, '29/07/2008', 3);
INSERT INTO valoracions VALUES (4920, 29, '28/09/2002', 8);
INSERT INTO valoracions VALUES (4920, 20, '27/01/2003', 5);
INSERT INTO valoracions VALUES (4920, 4, '05/03/2008', 9);
INSERT INTO valoracions VALUES (4920, 71, '18/01/2010', 8);
INSERT INTO valoracions VALUES (4920, 55, '14/10/2005', 8);
INSERT INTO valoracions VALUES (4920, 96, '08/01/2003', 9);
INSERT INTO valoracions VALUES (4920, 64, '12/04/2008', 2);
INSERT INTO valoracions VALUES (4920, 107, '20/07/2002', 3);
INSERT INTO valoracions VALUES (4920, 75, '15/08/2003', 5);
INSERT INTO valoracions VALUES (4921, 45, '22/01/2002', 9);
INSERT INTO valoracions VALUES (4921, 22, '29/01/2003', 5);
INSERT INTO valoracions VALUES (4921, 55, '11/07/2010', 4);
INSERT INTO valoracions VALUES (4921, 91, '15/04/2001', 3);
INSERT INTO valoracions VALUES (4921, 84, '08/10/2002', 7);
INSERT INTO valoracions VALUES (4922, 107, '04/07/2006', 5);
INSERT INTO valoracions VALUES (4922, 67, '03/02/2009', 3);
INSERT INTO valoracions VALUES (4922, 62, '10/11/2005', 5);
INSERT INTO valoracions VALUES (4922, 6, '30/12/2004', 6);
INSERT INTO valoracions VALUES (4922, 31, '27/10/2006', 9);
INSERT INTO valoracions VALUES (4922, 37, '19/11/2004', 7);
INSERT INTO valoracions VALUES (4923, 25, '31/10/2008', 10);
INSERT INTO valoracions VALUES (4923, 87, '27/03/2002', 1);
INSERT INTO valoracions VALUES (4923, 87, '04/01/2008', 6);
INSERT INTO valoracions VALUES (4923, 63, '05/10/2001', 6);
INSERT INTO valoracions VALUES (4923, 67, '11/09/2007', 7);
INSERT INTO valoracions VALUES (4923, 31, '08/04/2003', 9);
INSERT INTO valoracions VALUES (4923, 3, '06/04/2002', 8);
INSERT INTO valoracions VALUES (4924, 39, '14/02/2007', 10);
INSERT INTO valoracions VALUES (4924, 113, '21/11/2003', 5);
INSERT INTO valoracions VALUES (4924, 12, '20/04/2006', 9);
INSERT INTO valoracions VALUES (4924, 95, '16/05/2002', 8);
INSERT INTO valoracions VALUES (4925, 103, '14/09/2006', 5);
INSERT INTO valoracions VALUES (4925, 116, '11/01/2008', 2);
INSERT INTO valoracions VALUES (4925, 30, '25/10/2001', 9);
INSERT INTO valoracions VALUES (4925, 79, '06/05/2009', 5);
INSERT INTO valoracions VALUES (4925, 109, '23/06/2004', 2);
INSERT INTO valoracions VALUES (4926, 113, '06/10/2002', 9);
INSERT INTO valoracions VALUES (4926, 31, '06/12/2008', 5);
INSERT INTO valoracions VALUES (4926, 12, '12/05/2006', 8);
INSERT INTO valoracions VALUES (4926, 70, '23/07/2004', 5);
INSERT INTO valoracions VALUES (4927, 50, '06/05/2001', 4);
INSERT INTO valoracions VALUES (4927, 17, '31/07/2009', 8);
INSERT INTO valoracions VALUES (4927, 89, '10/08/2010', 9);
INSERT INTO valoracions VALUES (4927, 78, '03/09/2009', 10);
INSERT INTO valoracions VALUES (4928, 42, '31/05/2008', 6);
INSERT INTO valoracions VALUES (4928, 102, '11/11/2002', 2);
INSERT INTO valoracions VALUES (4928, 46, '17/08/2005', 10);
INSERT INTO valoracions VALUES (4929, 112, '10/09/2008', 5);
INSERT INTO valoracions VALUES (4929, 41, '17/12/2007', 4);
INSERT INTO valoracions VALUES (4929, 3, '11/10/2010', 8);
INSERT INTO valoracions VALUES (4929, 87, '25/08/2008', 1);
INSERT INTO valoracions VALUES (4930, 41, '23/09/2001', 7);
INSERT INTO valoracions VALUES (4930, 23, '02/03/2006', 5);
INSERT INTO valoracions VALUES (4930, 27, '18/06/2010', 5);
INSERT INTO valoracions VALUES (4930, 15, '16/08/2008', 6);
INSERT INTO valoracions VALUES (4930, 64, '30/06/2003', 9);
INSERT INTO valoracions VALUES (4931, 86, '24/09/2006', 9);
INSERT INTO valoracions VALUES (4931, 102, '04/07/2003', 2);
INSERT INTO valoracions VALUES (4931, 97, '14/02/2007', 2);
INSERT INTO valoracions VALUES (4931, 51, '29/10/2007', 5);
INSERT INTO valoracions VALUES (4931, 31, '01/11/2008', 6);
INSERT INTO valoracions VALUES (4931, 68, '14/01/2005', 7);
INSERT INTO valoracions VALUES (4931, 39, '11/10/2003', 9);
INSERT INTO valoracions VALUES (4932, 21, '16/06/2003', 4);
INSERT INTO valoracions VALUES (4932, 22, '01/07/2009', 9);
INSERT INTO valoracions VALUES (4932, 24, '04/07/2001', 8);
INSERT INTO valoracions VALUES (4932, 6, '08/08/2005', 6);
INSERT INTO valoracions VALUES (4933, 60, '01/01/2004', 5);
INSERT INTO valoracions VALUES (4933, 62, '05/12/2004', 7);
INSERT INTO valoracions VALUES (4933, 31, '29/10/2005', 9);
INSERT INTO valoracions VALUES (4934, 100, '26/09/2002', 3);
INSERT INTO valoracions VALUES (4934, 4, '19/06/2001', 8);
INSERT INTO valoracions VALUES (4934, 30, '13/08/2005', 6);
INSERT INTO valoracions VALUES (4934, 50, '15/07/2009', 4);
INSERT INTO valoracions VALUES (4935, 80, '13/08/2004', 6);
INSERT INTO valoracions VALUES (4935, 61, '24/09/2009', 5);
INSERT INTO valoracions VALUES (4935, 37, '20/03/2002', 7);
INSERT INTO valoracions VALUES (4935, 97, '24/06/2003', 8);
INSERT INTO valoracions VALUES (4936, 44, '09/10/2006', 9);
INSERT INTO valoracions VALUES (4936, 55, '03/08/2004', 6);
INSERT INTO valoracions VALUES (4936, 60, '13/12/2004', 8);
INSERT INTO valoracions VALUES (4936, 89, '16/12/2003', 4);
INSERT INTO valoracions VALUES (4936, 77, '10/06/2003', 9);
INSERT INTO valoracions VALUES (4936, 107, '12/12/2008', 3);
INSERT INTO valoracions VALUES (4936, 113, '05/03/2009', 5);
INSERT INTO valoracions VALUES (4937, 61, '02/07/2008', 10);
INSERT INTO valoracions VALUES (4937, 65, '10/10/2001', 7);
INSERT INTO valoracions VALUES (4937, 85, '21/02/2002', 2);
INSERT INTO valoracions VALUES (4937, 113, '26/12/2005', 4);
INSERT INTO valoracions VALUES (4937, 81, '12/06/2009', 3);
INSERT INTO valoracions VALUES (4938, 51, '06/01/2008', 7);
INSERT INTO valoracions VALUES (4938, 12, '09/10/2002', 10);
INSERT INTO valoracions VALUES (4939, 88, '06/12/2002', 8);
INSERT INTO valoracions VALUES (4939, 41, '27/02/2005', 5);
INSERT INTO valoracions VALUES (4939, 40, '02/01/2007', 9);
INSERT INTO valoracions VALUES (4939, 74, '05/12/2003', 2);
INSERT INTO valoracions VALUES (4939, 50, '02/10/2006', 5);
INSERT INTO valoracions VALUES (4939, 108, '01/01/2004', 3);
INSERT INTO valoracions VALUES (4939, 20, '24/07/2008', 7);
INSERT INTO valoracions VALUES (4939, 8, '04/08/2007', 9);
INSERT INTO valoracions VALUES (4939, 29, '03/11/2007', 4);
INSERT INTO valoracions VALUES (4940, 76, '31/12/2006', 3);
INSERT INTO valoracions VALUES (4940, 112, '18/03/2003', 7);
INSERT INTO valoracions VALUES (4940, 57, '16/05/2006', 7);
INSERT INTO valoracions VALUES (4940, 35, '02/07/2010', 7);
INSERT INTO valoracions VALUES (4941, 59, '30/03/2002', 3);
INSERT INTO valoracions VALUES (4941, 104, '05/03/2007', 5);
INSERT INTO valoracions VALUES (4942, 59, '19/01/2003', 6);
INSERT INTO valoracions VALUES (4942, 28, '08/08/2008', 7);
INSERT INTO valoracions VALUES (4942, 105, '31/05/2008', 2);
INSERT INTO valoracions VALUES (4942, 104, '05/04/2001', 2);
INSERT INTO valoracions VALUES (4943, 2, '02/02/2005', 6);
INSERT INTO valoracions VALUES (4943, 113, '08/11/2004', 3);
INSERT INTO valoracions VALUES (4943, 65, '19/05/2009', 9);
INSERT INTO valoracions VALUES (4944, 56, '14/12/2002', 6);
INSERT INTO valoracions VALUES (4944, 51, '05/03/2005', 6);
INSERT INTO valoracions VALUES (4944, 78, '16/01/2002', 4);
INSERT INTO valoracions VALUES (4944, 40, '01/10/2004', 6);
INSERT INTO valoracions VALUES (4944, 91, '25/08/2006', 5);
INSERT INTO valoracions VALUES (4944, 61, '20/03/2007', 9);
INSERT INTO valoracions VALUES (4945, 99, '14/07/2004', 4);
INSERT INTO valoracions VALUES (4945, 113, '30/04/2005', 4);
INSERT INTO valoracions VALUES (4945, 1, '07/06/2004', 8);
INSERT INTO valoracions VALUES (4945, 91, '28/12/2003', 6);
INSERT INTO valoracions VALUES (4945, 37, '27/03/2010', 9);
INSERT INTO valoracions VALUES (4945, 7, '18/01/2004', 6);
INSERT INTO valoracions VALUES (4946, 4, '21/12/2004', 6);
INSERT INTO valoracions VALUES (4946, 38, '25/11/2008', 8);
INSERT INTO valoracions VALUES (4946, 81, '13/01/2002', 10);
INSERT INTO valoracions VALUES (4947, 100, '28/01/2003', 8);
INSERT INTO valoracions VALUES (4947, 9, '27/03/2006', 8);
INSERT INTO valoracions VALUES (4947, 5, '01/10/2005', 9);
INSERT INTO valoracions VALUES (4947, 113, '03/07/2003', 4);
INSERT INTO valoracions VALUES (4947, 74, '12/06/2004', 8);
INSERT INTO valoracions VALUES (4947, 54, '09/06/2003', 9);
INSERT INTO valoracions VALUES (4947, 57, '28/12/2006', 9);
INSERT INTO valoracions VALUES (4947, 69, '12/10/2008', 9);
INSERT INTO valoracions VALUES (4947, 96, '22/05/2006', 9);
INSERT INTO valoracions VALUES (4948, 15, '20/02/2006', 8);
INSERT INTO valoracions VALUES (4948, 33, '26/08/2009', 5);
INSERT INTO valoracions VALUES (4948, 20, '30/07/2003', 6);
INSERT INTO valoracions VALUES (4949, 96, '14/12/2007', 5);
INSERT INTO valoracions VALUES (4949, 16, '27/07/2007', 9);
INSERT INTO valoracions VALUES (4949, 27, '28/04/2003', 9);
INSERT INTO valoracions VALUES (4949, 107, '26/08/2007', 9);
INSERT INTO valoracions VALUES (4949, 96, '27/05/2005', 9);
INSERT INTO valoracions VALUES (4949, 23, '23/02/2009', 9);
INSERT INTO valoracions VALUES (4949, 20, '30/04/2004', 5);
INSERT INTO valoracions VALUES (4949, 20, '20/11/2008', 8);
INSERT INTO valoracions VALUES (4949, 69, '04/12/2005', 4);
INSERT INTO valoracions VALUES (4949, 28, '26/01/2006', 4);
INSERT INTO valoracions VALUES (4949, 91, '15/02/2002', 4);
INSERT INTO valoracions VALUES (4950, 47, '09/08/2002', 9);
INSERT INTO valoracions VALUES (4950, 19, '27/08/2005', 6);
INSERT INTO valoracions VALUES (4951, 36, '31/10/2006', 9);
INSERT INTO valoracions VALUES (4951, 111, '19/08/2003', 7);
INSERT INTO valoracions VALUES (4952, 80, '21/01/2008', 9);
INSERT INTO valoracions VALUES (4952, 34, '17/03/2004', 4);
INSERT INTO valoracions VALUES (4952, 62, '26/09/2008', 4);
INSERT INTO valoracions VALUES (4952, 65, '27/03/2010', 7);
INSERT INTO valoracions VALUES (4952, 115, '29/05/2007', 1);
INSERT INTO valoracions VALUES (4952, 11, '06/01/2009', 8);
INSERT INTO valoracions VALUES (4952, 70, '14/05/2009', 2);
INSERT INTO valoracions VALUES (4953, 11, '16/12/2003', 6);
INSERT INTO valoracions VALUES (4953, 34, '29/05/2006', 6);
INSERT INTO valoracions VALUES (4953, 1, '05/10/2008', 10);
INSERT INTO valoracions VALUES (4954, 32, '24/10/2009', 9);
INSERT INTO valoracions VALUES (4954, 58, '28/04/2009', 3);
INSERT INTO valoracions VALUES (4955, 116, '21/03/2007', 4);
INSERT INTO valoracions VALUES (4955, 28, '10/04/2009', 6);
INSERT INTO valoracions VALUES (4955, 94, '28/09/2008', 8);
INSERT INTO valoracions VALUES (4956, 21, '15/01/2002', 9);
INSERT INTO valoracions VALUES (4956, 53, '17/06/2002', 8);
INSERT INTO valoracions VALUES (4956, 5, '08/05/2005', 7);
INSERT INTO valoracions VALUES (4956, 17, '23/07/2001', 6);
INSERT INTO valoracions VALUES (4956, 5, '23/01/2003', 8);
INSERT INTO valoracions VALUES (4956, 10, '12/05/2004', 8);
INSERT INTO valoracions VALUES (4956, 104, '08/05/2001', 8);
INSERT INTO valoracions VALUES (4956, 21, '20/04/2009', 5);
INSERT INTO valoracions VALUES (4957, 86, '30/09/2006', 7);
INSERT INTO valoracions VALUES (4957, 75, '08/01/2003', 3);
INSERT INTO valoracions VALUES (4957, 104, '25/02/2009', 8);
INSERT INTO valoracions VALUES (4957, 77, '29/01/2003', 3);
INSERT INTO valoracions VALUES (4957, 74, '06/01/2002', 4);
INSERT INTO valoracions VALUES (4958, 110, '04/11/2006', 4);
INSERT INTO valoracions VALUES (4959, 13, '03/10/2010', 6);
INSERT INTO valoracions VALUES (4959, 68, '31/05/2008', 10);
INSERT INTO valoracions VALUES (4960, 44, '20/09/2009', 7);
INSERT INTO valoracions VALUES (4961, 72, '07/11/2008', 7);
INSERT INTO valoracions VALUES (4961, 50, '02/04/2008', 4);
INSERT INTO valoracions VALUES (4962, 96, '05/01/2003', 5);
INSERT INTO valoracions VALUES (4962, 107, '28/02/2009', 5);
INSERT INTO valoracions VALUES (4962, 16, '10/04/2002', 7);
INSERT INTO valoracions VALUES (4962, 63, '17/05/2007', 5);
INSERT INTO valoracions VALUES (4962, 40, '06/09/2005', 9);
INSERT INTO valoracions VALUES (4962, 101, '26/09/2002', 3);
INSERT INTO valoracions VALUES (4963, 60, '22/01/2007', 4);
INSERT INTO valoracions VALUES (4963, 67, '31/07/2007', 2);
INSERT INTO valoracions VALUES (4963, 80, '30/12/2005', 3);
INSERT INTO valoracions VALUES (4963, 52, '28/06/2004', 3);
INSERT INTO valoracions VALUES (4963, 44, '27/11/2003', 6);
INSERT INTO valoracions VALUES (4963, 45, '31/12/2005', 10);
INSERT INTO valoracions VALUES (4964, 33, '15/12/2003', 6);
INSERT INTO valoracions VALUES (4964, 102, '18/09/2003', 9);
INSERT INTO valoracions VALUES (4964, 5, '15/11/2009', 8);
INSERT INTO valoracions VALUES (4965, 43, '02/11/2007', 9);
INSERT INTO valoracions VALUES (4965, 101, '25/01/2008', 3);
INSERT INTO valoracions VALUES (4965, 108, '24/09/2001', 3);
INSERT INTO valoracions VALUES (4965, 94, '14/07/2003', 2);
INSERT INTO valoracions VALUES (4965, 54, '24/12/2007', 3);
INSERT INTO valoracions VALUES (4965, 1, '20/04/2003', 10);
INSERT INTO valoracions VALUES (4966, 6, '09/08/2007', 5);
INSERT INTO valoracions VALUES (4966, 66, '15/03/2006', 5);
INSERT INTO valoracions VALUES (4966, 50, '07/01/2002', 5);
INSERT INTO valoracions VALUES (4966, 91, '19/06/2005', 2);
INSERT INTO valoracions VALUES (4967, 26, '18/11/2006', 8);
INSERT INTO valoracions VALUES (4967, 60, '19/06/2002', 6);
INSERT INTO valoracions VALUES (4967, 11, '16/01/2003', 8);
INSERT INTO valoracions VALUES (4968, 113, '17/10/2005', 3);
INSERT INTO valoracions VALUES (4968, 63, '10/05/2001', 3);
INSERT INTO valoracions VALUES (4968, 2, '19/01/2004', 7);
INSERT INTO valoracions VALUES (4969, 67, '07/01/2002', 8);
INSERT INTO valoracions VALUES (4969, 13, '10/06/2006', 5);
INSERT INTO valoracions VALUES (4969, 87, '13/04/2001', 5);
INSERT INTO valoracions VALUES (4969, 35, '16/09/2009', 7);
INSERT INTO valoracions VALUES (4969, 44, '08/02/2009', 9);
INSERT INTO valoracions VALUES (4969, 5, '03/04/2003', 9);
INSERT INTO valoracions VALUES (4969, 112, '23/11/2009', 10);
INSERT INTO valoracions VALUES (4970, 95, '03/03/2005', 3);
INSERT INTO valoracions VALUES (4970, 9, '12/09/2003', 6);
INSERT INTO valoracions VALUES (4970, 28, '31/10/2003', 6);
INSERT INTO valoracions VALUES (4970, 7, '28/10/2007', 9);
INSERT INTO valoracions VALUES (4970, 34, '20/06/2003', 4);
INSERT INTO valoracions VALUES (4971, 20, '04/02/2007', 5);
INSERT INTO valoracions VALUES (4971, 106, '23/04/2007', 3);
INSERT INTO valoracions VALUES (4971, 26, '05/10/2003', 6);
INSERT INTO valoracions VALUES (4971, 4, '30/07/2005', 6);
INSERT INTO valoracions VALUES (4971, 82, '18/06/2002', 4);
INSERT INTO valoracions VALUES (4971, 93, '13/10/2003', 6);
INSERT INTO valoracions VALUES (4972, 99, '29/06/2006', 8);
INSERT INTO valoracions VALUES (4972, 58, '28/06/2002', 6);
INSERT INTO valoracions VALUES (4972, 32, '09/03/2004', 6);
INSERT INTO valoracions VALUES (4972, 9, '01/02/2002', 6);
INSERT INTO valoracions VALUES (4972, 46, '28/01/2009', 5);
INSERT INTO valoracions VALUES (4972, 13, '23/12/2003', 9);
INSERT INTO valoracions VALUES (4973, 105, '15/06/2002', 3);
INSERT INTO valoracions VALUES (4973, 48, '09/04/2010', 9);
INSERT INTO valoracions VALUES (4973, 74, '09/03/2002', 9);
INSERT INTO valoracions VALUES (4973, 95, '01/09/2007', 5);
INSERT INTO valoracions VALUES (4973, 20, '23/07/2001', 9);
INSERT INTO valoracions VALUES (4973, 87, '25/05/2007', 9);
INSERT INTO valoracions VALUES (4974, 59, '09/06/2007', 8);
INSERT INTO valoracions VALUES (4974, 43, '07/04/2007', 9);
INSERT INTO valoracions VALUES (4974, 74, '21/12/2008', 8);
INSERT INTO valoracions VALUES (4975, 65, '25/06/2002', 4);
INSERT INTO valoracions VALUES (4975, 86, '25/02/2004', 6);
INSERT INTO valoracions VALUES (4975, 14, '01/08/2007', 5);
INSERT INTO valoracions VALUES (4976, 54, '21/07/2007', 4);
INSERT INTO valoracions VALUES (4977, 63, '18/10/2006', 3);
INSERT INTO valoracions VALUES (4977, 86, '14/03/2008', 5);
INSERT INTO valoracions VALUES (4977, 13, '08/05/2005', 6);
INSERT INTO valoracions VALUES (4977, 47, '02/06/2001', 6);
INSERT INTO valoracions VALUES (4977, 6, '21/06/2006', 10);
INSERT INTO valoracions VALUES (4978, 65, '25/06/2002', 4);
INSERT INTO valoracions VALUES (4978, 113, '02/04/2007', 4);
INSERT INTO valoracions VALUES (4978, 22, '10/01/2007', 9);
INSERT INTO valoracions VALUES (4978, 100, '31/12/2005', 3);
INSERT INTO valoracions VALUES (4978, 71, '26/07/2009', 7);
INSERT INTO valoracions VALUES (4979, 89, '09/07/2008', 4);
INSERT INTO valoracions VALUES (4979, 25, '14/01/2003', 8);
INSERT INTO valoracions VALUES (4979, 37, '19/11/2009', 3);
INSERT INTO valoracions VALUES (4979, 62, '02/02/2006', 7);
INSERT INTO valoracions VALUES (4980, 58, '04/04/2009', 8);
INSERT INTO valoracions VALUES (4981, 8, '11/12/2003', 8);
INSERT INTO valoracions VALUES (4981, 17, '09/09/2001', 8);
INSERT INTO valoracions VALUES (4981, 85, '13/03/2010', 2);
INSERT INTO valoracions VALUES (4981, 69, '23/03/2009', 4);
INSERT INTO valoracions VALUES (4982, 55, '27/07/2002', 3);
INSERT INTO valoracions VALUES (4982, 105, '27/05/2001', 9);
INSERT INTO valoracions VALUES (4982, 107, '13/12/2009', 5);
INSERT INTO valoracions VALUES (4982, 85, '30/09/2010', 6);
INSERT INTO valoracions VALUES (4982, 82, '26/04/2006', 4);
INSERT INTO valoracions VALUES (4983, 14, '26/04/2005', 9);
INSERT INTO valoracions VALUES (4983, 16, '03/07/2008', 5);
INSERT INTO valoracions VALUES (4983, 22, '07/10/2002', 9);
INSERT INTO valoracions VALUES (4983, 52, '22/12/2005', 6);
INSERT INTO valoracions VALUES (4984, 32, '29/07/2010', 4);
INSERT INTO valoracions VALUES (4984, 112, '13/10/2002', 1);
INSERT INTO valoracions VALUES (4984, 102, '23/12/2002', 6);
INSERT INTO valoracions VALUES (4984, 115, '19/10/2001', 8);
INSERT INTO valoracions VALUES (4984, 84, '23/03/2002', 7);
INSERT INTO valoracions VALUES (4985, 71, '29/09/2003', 4);
INSERT INTO valoracions VALUES (4985, 24, '01/01/2007', 9);
INSERT INTO valoracions VALUES (4985, 46, '23/03/2010', 3);
INSERT INTO valoracions VALUES (4986, 52, '05/10/2010', 9);
INSERT INTO valoracions VALUES (4986, 109, '09/04/2003', 6);
INSERT INTO valoracions VALUES (4986, 18, '14/02/2005', 9);
INSERT INTO valoracions VALUES (4986, 3, '16/08/2007', 10);
INSERT INTO valoracions VALUES (4986, 23, '18/05/2006', 9);
INSERT INTO valoracions VALUES (4986, 94, '09/01/2007', 10);
INSERT INTO valoracions VALUES (4986, 34, '08/02/2005', 6);
INSERT INTO valoracions VALUES (4987, 30, '04/02/2003', 6);
INSERT INTO valoracions VALUES (4987, 63, '06/06/2008', 8);
INSERT INTO valoracions VALUES (4987, 66, '01/05/2007', 7);
INSERT INTO valoracions VALUES (4987, 31, '05/04/2002', 10);
INSERT INTO valoracions VALUES (4987, 54, '22/12/2003', 10);
INSERT INTO valoracions VALUES (4988, 72, '07/09/2006', 8);
INSERT INTO valoracions VALUES (4988, 88, '26/11/2008', 7);
INSERT INTO valoracions VALUES (4989, 48, '08/02/2005', 9);
INSERT INTO valoracions VALUES (4989, 106, '26/01/2003', 2);
INSERT INTO valoracions VALUES (4989, 71, '26/09/2002', 4);
INSERT INTO valoracions VALUES (4990, 68, '16/02/2007', 8);
INSERT INTO valoracions VALUES (4990, 72, '26/02/2003', 8);
INSERT INTO valoracions VALUES (4990, 106, '18/05/2010', 6);
INSERT INTO valoracions VALUES (4990, 25, '17/01/2006', 10);
INSERT INTO valoracions VALUES (4990, 79, '11/10/2001', 8);
INSERT INTO valoracions VALUES (4990, 69, '19/07/2003', 3);
INSERT INTO valoracions VALUES (4990, 60, '18/07/2009', 5);
INSERT INTO valoracions VALUES (4990, 86, '27/10/2005', 4);
INSERT INTO valoracions VALUES (4990, 99, '19/09/2003', 10);
INSERT INTO valoracions VALUES (4990, 104, '21/11/2004', 9);
INSERT INTO valoracions VALUES (4991, 63, '02/01/2007', 7);
INSERT INTO valoracions VALUES (4992, 100, '12/12/2007', 8);
INSERT INTO valoracions VALUES (4992, 37, '27/08/2003', 7);
INSERT INTO valoracions VALUES (4992, 69, '06/05/2002', 5);
INSERT INTO valoracions VALUES (4992, 59, '25/02/2002', 6);
INSERT INTO valoracions VALUES (4992, 87, '03/02/2006', 5);
INSERT INTO valoracions VALUES (4992, 3, '05/03/2002', 7);
INSERT INTO valoracions VALUES (4992, 32, '23/04/2002', 8);
INSERT INTO valoracions VALUES (4993, 48, '01/06/2002', 9);
INSERT INTO valoracions VALUES (4993, 93, '13/08/2003', 3);
INSERT INTO valoracions VALUES (4993, 69, '14/11/2005', 7);
INSERT INTO valoracions VALUES (4993, 112, '08/06/2006', 7);
INSERT INTO valoracions VALUES (4993, 100, '04/07/2002', 9);
INSERT INTO valoracions VALUES (4994, 88, '04/03/2006', 7);
INSERT INTO valoracions VALUES (4994, 4, '16/12/2003', 6);
INSERT INTO valoracions VALUES (4994, 37, '19/08/2006', 9);
INSERT INTO valoracions VALUES (4994, 51, '24/06/2007', 6);
INSERT INTO valoracions VALUES (4995, 96, '12/09/2008', 7);
INSERT INTO valoracions VALUES (4995, 13, '25/12/2003', 7);
INSERT INTO valoracions VALUES (4995, 111, '23/07/2004', 8);
INSERT INTO valoracions VALUES (4995, 41, '24/12/2004', 7);
INSERT INTO valoracions VALUES (4995, 3, '24/03/2008', 9);
INSERT INTO valoracions VALUES (4995, 9, '29/10/2007', 8);
INSERT INTO valoracions VALUES (4995, 47, '20/02/2008', 4);
INSERT INTO valoracions VALUES (4996, 63, '20/01/2006', 4);
INSERT INTO valoracions VALUES (4996, 76, '31/05/2006', 8);
INSERT INTO valoracions VALUES (4996, 67, '28/04/2007', 8);
INSERT INTO valoracions VALUES (4996, 36, '22/06/2010', 5);
INSERT INTO valoracions VALUES (4996, 16, '30/05/2003', 8);
INSERT INTO valoracions VALUES (4997, 8, '24/02/2008', 8);
INSERT INTO valoracions VALUES (4997, 85, '28/06/2005', 9);
INSERT INTO valoracions VALUES (4997, 71, '29/07/2004', 4);
INSERT INTO valoracions VALUES (4997, 29, '06/07/2003', 4);
INSERT INTO valoracions VALUES (4997, 4, '05/02/2005', 5);
INSERT INTO valoracions VALUES (4998, 51, '08/03/2006', 7);
INSERT INTO valoracions VALUES (4998, 5, '15/04/2003', 9);
INSERT INTO valoracions VALUES (4999, 114, '19/11/2005', 7);
INSERT INTO valoracions VALUES (4999, 52, '31/08/2005', 4);
INSERT INTO valoracions VALUES (4999, 33, '24/01/2008', 9);
INSERT INTO valoracions VALUES (4999, 26, '05/12/2002', 9);
INSERT INTO valoracions VALUES (5000, 55, '28/03/2009', 5);
INSERT INTO valoracions VALUES (5000, 77, '28/02/2003', 4);
                                                                                                                                         


INSERT INTO favorites VALUES (1, 8, 1);
INSERT INTO favorites VALUES (1, 23, 2);
INSERT INTO favorites VALUES (2, 26, 1);
INSERT INTO favorites VALUES (3, 105, 3);
INSERT INTO favorites VALUES (3, 73, 2);
INSERT INTO favorites VALUES (3, 39, 1);
INSERT INTO favorites VALUES (4, 95, 1);
INSERT INTO favorites VALUES (4, 13, 2);
INSERT INTO favorites VALUES (5, 27, 1);
INSERT INTO favorites VALUES (6, 26, 4);
INSERT INTO favorites VALUES (6, 1, 1);
INSERT INTO favorites VALUES (6, 42, 2);
INSERT INTO favorites VALUES (6, 45, 3);
INSERT INTO favorites VALUES (7, 80, 2);
INSERT INTO favorites VALUES (7, 36, 1);
INSERT INTO favorites VALUES (7, 10, 3);
INSERT INTO favorites VALUES (10, 99, 3);
INSERT INTO favorites VALUES (10, 36, 1);
INSERT INTO favorites VALUES (10, 34, 2);
INSERT INTO favorites VALUES (10, 54, 4);
INSERT INTO favorites VALUES (11, 70, 1);
INSERT INTO favorites VALUES (12, 47, 3);
INSERT INTO favorites VALUES (12, 44, 4);
INSERT INTO favorites VALUES (12, 103, 2);
INSERT INTO favorites VALUES (12, 106, 1);
INSERT INTO favorites VALUES (13, 31, 2);
INSERT INTO favorites VALUES (13, 18, 1);
INSERT INTO favorites VALUES (14, 9, 1);
INSERT INTO favorites VALUES (14, 41, 2);
INSERT INTO favorites VALUES (15, 59, 1);
INSERT INTO favorites VALUES (16, 7, 4);
INSERT INTO favorites VALUES (16, 87, 3);
INSERT INTO favorites VALUES (16, 113, 2);
INSERT INTO favorites VALUES (16, 4, 1);
INSERT INTO favorites VALUES (18, 20, 1);
INSERT INTO favorites VALUES (18, 25, 2);
INSERT INTO favorites VALUES (19, 111, 1);
INSERT INTO favorites VALUES (20, 92, 1);
INSERT INTO favorites VALUES (21, 54, 2);
INSERT INTO favorites VALUES (21, 75, 1);
INSERT INTO favorites VALUES (22, 62, 2);
INSERT INTO favorites VALUES (22, 71, 1);
INSERT INTO favorites VALUES (22, 83, 4);
INSERT INTO favorites VALUES (22, 61, 3);
INSERT INTO favorites VALUES (23, 107, 3);
INSERT INTO favorites VALUES (23, 29, 4);
INSERT INTO favorites VALUES (23, 115, 6);
INSERT INTO favorites VALUES (23, 53, 1);
INSERT INTO favorites VALUES (23, 57, 2);
INSERT INTO favorites VALUES (23, 29, 5);
INSERT INTO favorites VALUES (24, 16, 3);
INSERT INTO favorites VALUES (24, 42, 1);
INSERT INTO favorites VALUES (24, 78, 2);
INSERT INTO favorites VALUES (25, 42, 4);
INSERT INTO favorites VALUES (25, 22, 3);
INSERT INTO favorites VALUES (25, 27, 1);
INSERT INTO favorites VALUES (25, 10, 2);
INSERT INTO favorites VALUES (26, 78, 1);
INSERT INTO favorites VALUES (27, 38, 2);
INSERT INTO favorites VALUES (27, 9, 3);
INSERT INTO favorites VALUES (27, 90, 1);
INSERT INTO favorites VALUES (28, 11, 1);
INSERT INTO favorites VALUES (29, 4, 3);
INSERT INTO favorites VALUES (29, 7, 1);
INSERT INTO favorites VALUES (29, 45, 2);
INSERT INTO favorites VALUES (29, 10, 4);
INSERT INTO favorites VALUES (30, 4, 3);
INSERT INTO favorites VALUES (30, 68, 2);
INSERT INTO favorites VALUES (30, 88, 1);
INSERT INTO favorites VALUES (31, 40, 3);
INSERT INTO favorites VALUES (31, 15, 1);
INSERT INTO favorites VALUES (31, 75, 2);
INSERT INTO favorites VALUES (32, 54, 3);
INSERT INTO favorites VALUES (32, 29, 1);
INSERT INTO favorites VALUES (32, 48, 2);
INSERT INTO favorites VALUES (33, 21, 3);
INSERT INTO favorites VALUES (33, 18, 1);
INSERT INTO favorites VALUES (33, 61, 2);
INSERT INTO favorites VALUES (34, 106, 2);
INSERT INTO favorites VALUES (34, 79, 1);
INSERT INTO favorites VALUES (35, 1, 1);
INSERT INTO favorites VALUES (35, 56, 3);
INSERT INTO favorites VALUES (35, 17, 2);
INSERT INTO favorites VALUES (36, 102, 3);
INSERT INTO favorites VALUES (36, 49, 2);
INSERT INTO favorites VALUES (36, 85, 1);
INSERT INTO favorites VALUES (37, 44, 3);
INSERT INTO favorites VALUES (37, 97, 2);
INSERT INTO favorites VALUES (37, 32, 1);
INSERT INTO favorites VALUES (38, 78, 3);
INSERT INTO favorites VALUES (38, 31, 1);
INSERT INTO favorites VALUES (38, 88, 2);
INSERT INTO favorites VALUES (39, 114, 3);
INSERT INTO favorites VALUES (39, 102, 1);
INSERT INTO favorites VALUES (39, 85, 2);
INSERT INTO favorites VALUES (40, 48, 3);
INSERT INTO favorites VALUES (40, 83, 2);
INSERT INTO favorites VALUES (40, 71, 1);
INSERT INTO favorites VALUES (42, 8, 3);
INSERT INTO favorites VALUES (42, 80, 1);
INSERT INTO favorites VALUES (42, 24, 2);
INSERT INTO favorites VALUES (42, 4, 4);
INSERT INTO favorites VALUES (43, 14, 1);
INSERT INTO favorites VALUES (44, 71, 1);
INSERT INTO favorites VALUES (44, 100, 2);
INSERT INTO favorites VALUES (46, 99, 3);
INSERT INTO favorites VALUES (46, 1, 1);
INSERT INTO favorites VALUES (46, 115, 2);
INSERT INTO favorites VALUES (47, 94, 1);
INSERT INTO favorites VALUES (48, 88, 1);
INSERT INTO favorites VALUES (49, 116, 1);
INSERT INTO favorites VALUES (49, 11, 2);
INSERT INTO favorites VALUES (51, 105, 3);
INSERT INTO favorites VALUES (51, 13, 1);
INSERT INTO favorites VALUES (51, 62, 2);
INSERT INTO favorites VALUES (51, 25, 4);
INSERT INTO favorites VALUES (52, 35, 1);
INSERT INTO favorites VALUES (53, 3, 4);
INSERT INTO favorites VALUES (53, 5, 1);
INSERT INTO favorites VALUES (53, 29, 3);
INSERT INTO favorites VALUES (53, 75, 2);
INSERT INTO favorites VALUES (55, 82, 3);
INSERT INTO favorites VALUES (55, 34, 2);
INSERT INTO favorites VALUES (55, 115, 1);
INSERT INTO favorites VALUES (56, 14, 1);
INSERT INTO favorites VALUES (56, 76, 2);
INSERT INTO favorites VALUES (58, 48, 1);
INSERT INTO favorites VALUES (58, 33, 2);
INSERT INTO favorites VALUES (61, 21, 3);
INSERT INTO favorites VALUES (61, 36, 2);
INSERT INTO favorites VALUES (61, 18, 1);
INSERT INTO favorites VALUES (61, 110, 4);
INSERT INTO favorites VALUES (63, 106, 6);
INSERT INTO favorites VALUES (63, 19, 4);
INSERT INTO favorites VALUES (63, 37, 3);
INSERT INTO favorites VALUES (63, 21, 1);
INSERT INTO favorites VALUES (63, 24, 2);
INSERT INTO favorites VALUES (63, 22, 5);
INSERT INTO favorites VALUES (64, 46, 5);
INSERT INTO favorites VALUES (64, 60, 3);
INSERT INTO favorites VALUES (64, 30, 1);
INSERT INTO favorites VALUES (64, 10, 4);
INSERT INTO favorites VALUES (64, 88, 2);
INSERT INTO favorites VALUES (65, 109, 5);
INSERT INTO favorites VALUES (65, 13, 3);
INSERT INTO favorites VALUES (65, 22, 2);
INSERT INTO favorites VALUES (65, 48, 1);
INSERT INTO favorites VALUES (65, 38, 4);
INSERT INTO favorites VALUES (66, 9, 5);
INSERT INTO favorites VALUES (66, 30, 3);
INSERT INTO favorites VALUES (66, 12, 2);
INSERT INTO favorites VALUES (66, 14, 1);
INSERT INTO favorites VALUES (66, 106, 4);
INSERT INTO favorites VALUES (67, 66, 1);
INSERT INTO favorites VALUES (68, 29, 2);
INSERT INTO favorites VALUES (68, 34, 1);
INSERT INTO favorites VALUES (68, 95, 3);
INSERT INTO favorites VALUES (69, 9, 2);
INSERT INTO favorites VALUES (69, 108, 1);
INSERT INTO favorites VALUES (70, 1, 3);
INSERT INTO favorites VALUES (70, 84, 1);
INSERT INTO favorites VALUES (70, 50, 2);
INSERT INTO favorites VALUES (71, 99, 1);
INSERT INTO favorites VALUES (72, 34, 2);
INSERT INTO favorites VALUES (72, 70, 4);
INSERT INTO favorites VALUES (72, 100, 1);
INSERT INTO favorites VALUES (72, 94, 3);
INSERT INTO favorites VALUES (74, 20, 3);
INSERT INTO favorites VALUES (74, 10, 2);
INSERT INTO favorites VALUES (74, 65, 1);
INSERT INTO favorites VALUES (75, 36, 2);
INSERT INTO favorites VALUES (75, 49, 1);
INSERT INTO favorites VALUES (75, 12, 3);
INSERT INTO favorites VALUES (76, 43, 1);
INSERT INTO favorites VALUES (77, 111, 2);
INSERT INTO favorites VALUES (77, 78, 1);
INSERT INTO favorites VALUES (77, 41, 4);
INSERT INTO favorites VALUES (77, 100, 3);
INSERT INTO favorites VALUES (78, 77, 1);
INSERT INTO favorites VALUES (78, 57, 2);
INSERT INTO favorites VALUES (79, 20, 1);
INSERT INTO favorites VALUES (80, 101, 1);
INSERT INTO favorites VALUES (80, 91, 3);
INSERT INTO favorites VALUES (80, 29, 2);
INSERT INTO favorites VALUES (82, 64, 2);
INSERT INTO favorites VALUES (82, 67, 1);
INSERT INTO favorites VALUES (82, 12, 3);
INSERT INTO favorites VALUES (83, 18, 4);
INSERT INTO favorites VALUES (83, 73, 1);
INSERT INTO favorites VALUES (83, 2, 2);
INSERT INTO favorites VALUES (83, 35, 3);
INSERT INTO favorites VALUES (84, 67, 4);
INSERT INTO favorites VALUES (84, 2, 3);
INSERT INTO favorites VALUES (84, 114, 2);
INSERT INTO favorites VALUES (84, 16, 1);
INSERT INTO favorites VALUES (85, 35, 4);
INSERT INTO favorites VALUES (85, 93, 3);
INSERT INTO favorites VALUES (85, 7, 2);
INSERT INTO favorites VALUES (85, 36, 1);
INSERT INTO favorites VALUES (86, 61, 5);
INSERT INTO favorites VALUES (86, 95, 6);
INSERT INTO favorites VALUES (86, 23, 2);
INSERT INTO favorites VALUES (86, 89, 4);
INSERT INTO favorites VALUES (86, 40, 1);
INSERT INTO favorites VALUES (86, 33, 3);
INSERT INTO favorites VALUES (87, 73, 2);
INSERT INTO favorites VALUES (87, 95, 1);
INSERT INTO favorites VALUES (87, 5, 3);
INSERT INTO favorites VALUES (88, 47, 1);
INSERT INTO favorites VALUES (88, 99, 2);
INSERT INTO favorites VALUES (89, 18, 1);
INSERT INTO favorites VALUES (89, 26, 2);
INSERT INTO favorites VALUES (90, 39, 3);
INSERT INTO favorites VALUES (90, 90, 1);
INSERT INTO favorites VALUES (90, 31, 2);
INSERT INTO favorites VALUES (91, 86, 1);
INSERT INTO favorites VALUES (91, 28, 2);
INSERT INTO favorites VALUES (93, 116, 6);
INSERT INTO favorites VALUES (93, 53, 5);
INSERT INTO favorites VALUES (93, 71, 1);
INSERT INTO favorites VALUES (93, 45, 3);
INSERT INTO favorites VALUES (93, 78, 2);
INSERT INTO favorites VALUES (93, 109, 4);
INSERT INTO favorites VALUES (94, 41, 2);
INSERT INTO favorites VALUES (94, 61, 1);
INSERT INTO favorites VALUES (94, 8, 3);
INSERT INTO favorites VALUES (95, 73, 1);
INSERT INTO favorites VALUES (95, 20, 2);
INSERT INTO favorites VALUES (96, 5, 1);
INSERT INTO favorites VALUES (96, 27, 2);
INSERT INTO favorites VALUES (97, 53, 3);
INSERT INTO favorites VALUES (97, 46, 1);
INSERT INTO favorites VALUES (97, 41, 2);
INSERT INTO favorites VALUES (98, 9, 5);
INSERT INTO favorites VALUES (98, 115, 4);
INSERT INTO favorites VALUES (98, 108, 1);
INSERT INTO favorites VALUES (98, 50, 2);
INSERT INTO favorites VALUES (98, 83, 3);
INSERT INTO favorites VALUES (99, 1, 4);
INSERT INTO favorites VALUES (99, 38, 3);
INSERT INTO favorites VALUES (99, 52, 1);
INSERT INTO favorites VALUES (99, 10, 2);
INSERT INTO favorites VALUES (100, 53, 1);
INSERT INTO favorites VALUES (100, 38, 2);
INSERT INTO favorites VALUES (101, 74, 2);
INSERT INTO favorites VALUES (101, 18, 1);
INSERT INTO favorites VALUES (103, 34, 1);
INSERT INTO favorites VALUES (104, 59, 2);
INSERT INTO favorites VALUES (104, 75, 1);
INSERT INTO favorites VALUES (104, 114, 3);
INSERT INTO favorites VALUES (105, 23, 2);
INSERT INTO favorites VALUES (105, 68, 1);
INSERT INTO favorites VALUES (106, 26, 1);
INSERT INTO favorites VALUES (106, 7, 4);
INSERT INTO favorites VALUES (106, 35, 3);
INSERT INTO favorites VALUES (106, 110, 2);
INSERT INTO favorites VALUES (108, 71, 2);
INSERT INTO favorites VALUES (108, 42, 1);
INSERT INTO favorites VALUES (108, 87, 3);
INSERT INTO favorites VALUES (109, 26, 1);
INSERT INTO favorites VALUES (109, 38, 3);
INSERT INTO favorites VALUES (109, 28, 2);
INSERT INTO favorites VALUES (110, 22, 1);
INSERT INTO favorites VALUES (110, 66, 2);
INSERT INTO favorites VALUES (110, 13, 3);
INSERT INTO favorites VALUES (110, 12, 4);
INSERT INTO favorites VALUES (111, 7, 1);
INSERT INTO favorites VALUES (112, 111, 1);
INSERT INTO favorites VALUES (112, 31, 2);
INSERT INTO favorites VALUES (113, 63, 1);
INSERT INTO favorites VALUES (113, 26, 2);
INSERT INTO favorites VALUES (113, 116, 3);
INSERT INTO favorites VALUES (114, 42, 1);
INSERT INTO favorites VALUES (114, 17, 2);
INSERT INTO favorites VALUES (116, 3, 2);
INSERT INTO favorites VALUES (116, 14, 1);
INSERT INTO favorites VALUES (116, 76, 3);
INSERT INTO favorites VALUES (116, 7, 4);
INSERT INTO favorites VALUES (117, 25, 1);
INSERT INTO favorites VALUES (118, 4, 1);
INSERT INTO favorites VALUES (118, 76, 2);
INSERT INTO favorites VALUES (119, 62, 1);
INSERT INTO favorites VALUES (120, 106, 1);
INSERT INTO favorites VALUES (120, 51, 2);
INSERT INTO favorites VALUES (120, 61, 3);
INSERT INTO favorites VALUES (121, 16, 1);
INSERT INTO favorites VALUES (121, 17, 2);
INSERT INTO favorites VALUES (122, 50, 1);
INSERT INTO favorites VALUES (123, 82, 2);
INSERT INTO favorites VALUES (123, 56, 1);
INSERT INTO favorites VALUES (123, 86, 3);
INSERT INTO favorites VALUES (123, 93, 4);
INSERT INTO favorites VALUES (124, 53, 2);
INSERT INTO favorites VALUES (124, 104, 1);
INSERT INTO favorites VALUES (125, 22, 1);
INSERT INTO favorites VALUES (126, 77, 3);
INSERT INTO favorites VALUES (126, 69, 5);
INSERT INTO favorites VALUES (126, 2, 1);
INSERT INTO favorites VALUES (126, 100, 2);
INSERT INTO favorites VALUES (126, 16, 4);
INSERT INTO favorites VALUES (126, 70, 6);
INSERT INTO favorites VALUES (127, 14, 1);
INSERT INTO favorites VALUES (127, 103, 2);
INSERT INTO favorites VALUES (129, 60, 1);
INSERT INTO favorites VALUES (130, 40, 1);
INSERT INTO favorites VALUES (130, 88, 2);
INSERT INTO favorites VALUES (131, 56, 2);
INSERT INTO favorites VALUES (131, 84, 1);
INSERT INTO favorites VALUES (131, 29, 3);
INSERT INTO favorites VALUES (131, 32, 4);
INSERT INTO favorites VALUES (132, 114, 2);
INSERT INTO favorites VALUES (132, 116, 1);
INSERT INTO favorites VALUES (133, 30, 1);
INSERT INTO favorites VALUES (133, 32, 2);
INSERT INTO favorites VALUES (133, 48, 4);
INSERT INTO favorites VALUES (133, 84, 3);
INSERT INTO favorites VALUES (134, 59, 1);
INSERT INTO favorites VALUES (134, 61, 2);
INSERT INTO favorites VALUES (135, 23, 1);
INSERT INTO favorites VALUES (135, 113, 2);
INSERT INTO favorites VALUES (135, 44, 4);
INSERT INTO favorites VALUES (135, 44, 3);
INSERT INTO favorites VALUES (136, 22, 1);
INSERT INTO favorites VALUES (137, 2, 1);
INSERT INTO favorites VALUES (137, 39, 2);
INSERT INTO favorites VALUES (137, 59, 3);
INSERT INTO favorites VALUES (137, 5, 4);
INSERT INTO favorites VALUES (138, 48, 1);
INSERT INTO favorites VALUES (138, 16, 2);
INSERT INTO favorites VALUES (140, 16, 1);
INSERT INTO favorites VALUES (140, 103, 2);
INSERT INTO favorites VALUES (140, 42, 3);
INSERT INTO favorites VALUES (141, 39, 1);
INSERT INTO favorites VALUES (141, 11, 2);
INSERT INTO favorites VALUES (142, 93, 1);
INSERT INTO favorites VALUES (142, 37, 3);
INSERT INTO favorites VALUES (142, 44, 2);
INSERT INTO favorites VALUES (142, 26, 4);
INSERT INTO favorites VALUES (142, 8, 5);
INSERT INTO favorites VALUES (143, 97, 1);
INSERT INTO favorites VALUES (145, 39, 1);
INSERT INTO favorites VALUES (145, 62, 2);
INSERT INTO favorites VALUES (146, 98, 2);
INSERT INTO favorites VALUES (146, 90, 1);
INSERT INTO favorites VALUES (146, 92, 3);
INSERT INTO favorites VALUES (146, 4, 4);
INSERT INTO favorites VALUES (148, 6, 3);
INSERT INTO favorites VALUES (148, 18, 2);
INSERT INTO favorites VALUES (148, 99, 1);
INSERT INTO favorites VALUES (148, 53, 5);
INSERT INTO favorites VALUES (148, 60, 4);
INSERT INTO favorites VALUES (149, 73, 1);
INSERT INTO favorites VALUES (151, 107, 1);
INSERT INTO favorites VALUES (151, 61, 2);
INSERT INTO favorites VALUES (151, 1, 3);
INSERT INTO favorites VALUES (152, 8, 1);
INSERT INTO favorites VALUES (152, 7, 2);
INSERT INTO favorites VALUES (152, 29, 3);
INSERT INTO favorites VALUES (152, 57, 4);
INSERT INTO favorites VALUES (152, 58, 6);
INSERT INTO favorites VALUES (152, 65, 5);
INSERT INTO favorites VALUES (153, 5, 1);
INSERT INTO favorites VALUES (153, 34, 4);
INSERT INTO favorites VALUES (153, 16, 3);
INSERT INTO favorites VALUES (153, 94, 2);
INSERT INTO favorites VALUES (153, 4, 5);
INSERT INTO favorites VALUES (154, 59, 1);
INSERT INTO favorites VALUES (154, 21, 2);
INSERT INTO favorites VALUES (154, 94, 3);
INSERT INTO favorites VALUES (154, 33, 5);
INSERT INTO favorites VALUES (154, 13, 4);
INSERT INTO favorites VALUES (154, 67, 6);
INSERT INTO favorites VALUES (155, 52, 2);
INSERT INTO favorites VALUES (155, 63, 1);
INSERT INTO favorites VALUES (155, 103, 3);
INSERT INTO favorites VALUES (155, 102, 4);
INSERT INTO favorites VALUES (156, 66, 3);
INSERT INTO favorites VALUES (156, 80, 1);
INSERT INTO favorites VALUES (156, 45, 2);
INSERT INTO favorites VALUES (156, 115, 4);
INSERT INTO favorites VALUES (156, 75, 5);
INSERT INTO favorites VALUES (157, 109, 1);
INSERT INTO favorites VALUES (158, 55, 3);
INSERT INTO favorites VALUES (158, 92, 2);
INSERT INTO favorites VALUES (158, 45, 1);
INSERT INTO favorites VALUES (158, 102, 4);
INSERT INTO favorites VALUES (158, 105, 5);
INSERT INTO favorites VALUES (159, 34, 1);
INSERT INTO favorites VALUES (160, 9, 2);
INSERT INTO favorites VALUES (160, 26, 1);
INSERT INTO favorites VALUES (160, 22, 3);
INSERT INTO favorites VALUES (160, 91, 4);
INSERT INTO favorites VALUES (161, 8, 1);
INSERT INTO favorites VALUES (161, 52, 2);
INSERT INTO favorites VALUES (161, 35, 3);
INSERT INTO favorites VALUES (161, 37, 4);
INSERT INTO favorites VALUES (162, 67, 2);
INSERT INTO favorites VALUES (162, 80, 1);
INSERT INTO favorites VALUES (162, 31, 3);
INSERT INTO favorites VALUES (162, 95, 4);
INSERT INTO favorites VALUES (163, 65, 1);
INSERT INTO favorites VALUES (163, 67, 2);
INSERT INTO favorites VALUES (164, 3, 3);
INSERT INTO favorites VALUES (164, 3, 4);
INSERT INTO favorites VALUES (164, 30, 1);
INSERT INTO favorites VALUES (164, 92, 2);
INSERT INTO favorites VALUES (164, 21, 5);
INSERT INTO favorites VALUES (165, 17, 1);
INSERT INTO favorites VALUES (166, 64, 2);
INSERT INTO favorites VALUES (166, 64, 1);
INSERT INTO favorites VALUES (166, 48, 3);
INSERT INTO favorites VALUES (167, 63, 1);
INSERT INTO favorites VALUES (168, 39, 2);
INSERT INTO favorites VALUES (168, 50, 1);
INSERT INTO favorites VALUES (169, 90, 1);
INSERT INTO favorites VALUES (169, 5, 2);
INSERT INTO favorites VALUES (169, 103, 3);
INSERT INTO favorites VALUES (170, 103, 2);
INSERT INTO favorites VALUES (170, 27, 1);
INSERT INTO favorites VALUES (170, 105, 3);
INSERT INTO favorites VALUES (173, 105, 1);
INSERT INTO favorites VALUES (173, 43, 2);
INSERT INTO favorites VALUES (173, 57, 3);
INSERT INTO favorites VALUES (173, 107, 6);
INSERT INTO favorites VALUES (173, 5, 4);
INSERT INTO favorites VALUES (173, 42, 5);
INSERT INTO favorites VALUES (174, 68, 1);
INSERT INTO favorites VALUES (174, 66, 3);
INSERT INTO favorites VALUES (174, 30, 2);
INSERT INTO favorites VALUES (174, 9, 4);
INSERT INTO favorites VALUES (175, 28, 1);
INSERT INTO favorites VALUES (175, 112, 2);
INSERT INTO favorites VALUES (175, 5, 5);
INSERT INTO favorites VALUES (175, 22, 3);
INSERT INTO favorites VALUES (175, 22, 6);
INSERT INTO favorites VALUES (175, 62, 4);
INSERT INTO favorites VALUES (178, 14, 1);
INSERT INTO favorites VALUES (178, 87, 2);
INSERT INTO favorites VALUES (178, 56, 3);
INSERT INTO favorites VALUES (178, 17, 4);
INSERT INTO favorites VALUES (179, 31, 1);
INSERT INTO favorites VALUES (179, 13, 2);
INSERT INTO favorites VALUES (181, 12, 1);
INSERT INTO favorites VALUES (181, 114, 2);
INSERT INTO favorites VALUES (181, 60, 3);
INSERT INTO favorites VALUES (182, 12, 1);
INSERT INTO favorites VALUES (182, 19, 2);
INSERT INTO favorites VALUES (182, 4, 3);
INSERT INTO favorites VALUES (183, 87, 2);
INSERT INTO favorites VALUES (183, 110, 1);
INSERT INTO favorites VALUES (184, 18, 1);
INSERT INTO favorites VALUES (185, 77, 2);
INSERT INTO favorites VALUES (185, 30, 1);
INSERT INTO favorites VALUES (185, 65, 3);
INSERT INTO favorites VALUES (185, 96, 4);
INSERT INTO favorites VALUES (185, 44, 5);
INSERT INTO favorites VALUES (186, 92, 1);
INSERT INTO favorites VALUES (186, 32, 2);
INSERT INTO favorites VALUES (187, 60, 2);
INSERT INTO favorites VALUES (187, 58, 1);
INSERT INTO favorites VALUES (187, 40, 4);
INSERT INTO favorites VALUES (187, 55, 3);
INSERT INTO favorites VALUES (187, 24, 5);
INSERT INTO favorites VALUES (188, 30, 3);
INSERT INTO favorites VALUES (188, 59, 2);
INSERT INTO favorites VALUES (188, 104, 1);
INSERT INTO favorites VALUES (189, 15, 1);
INSERT INTO favorites VALUES (189, 89, 3);
INSERT INTO favorites VALUES (189, 34, 2);
INSERT INTO favorites VALUES (190, 71, 2);
INSERT INTO favorites VALUES (190, 2, 1);
INSERT INTO favorites VALUES (190, 7, 3);
INSERT INTO favorites VALUES (191, 56, 1);
INSERT INTO favorites VALUES (191, 66, 2);
INSERT INTO favorites VALUES (192, 81, 1);
INSERT INTO favorites VALUES (192, 68, 3);
INSERT INTO favorites VALUES (192, 112, 2);
INSERT INTO favorites VALUES (193, 41, 1);
INSERT INTO favorites VALUES (193, 4, 2);
INSERT INTO favorites VALUES (193, 70, 3);
INSERT INTO favorites VALUES (194, 110, 2);
INSERT INTO favorites VALUES (194, 66, 1);
INSERT INTO favorites VALUES (194, 100, 3);
INSERT INTO favorites VALUES (195, 34, 1);
INSERT INTO favorites VALUES (195, 54, 2);
INSERT INTO favorites VALUES (196, 15, 1);
INSERT INTO favorites VALUES (197, 15, 1);
INSERT INTO favorites VALUES (197, 17, 2);
INSERT INTO favorites VALUES (198, 77, 2);
INSERT INTO favorites VALUES (198, 74, 1);
INSERT INTO favorites VALUES (198, 15, 4);
INSERT INTO favorites VALUES (198, 30, 3);
INSERT INTO favorites VALUES (199, 48, 1);
INSERT INTO favorites VALUES (199, 70, 3);
INSERT INTO favorites VALUES (199, 31, 2);
INSERT INTO favorites VALUES (200, 106, 2);
INSERT INTO favorites VALUES (200, 49, 1);
INSERT INTO favorites VALUES (200, 82, 3);
INSERT INTO favorites VALUES (200, 89, 4);
INSERT INTO favorites VALUES (201, 29, 3);
INSERT INTO favorites VALUES (201, 9, 2);
INSERT INTO favorites VALUES (201, 64, 1);
INSERT INTO favorites VALUES (201, 37, 4);
INSERT INTO favorites VALUES (201, 25, 5);
INSERT INTO favorites VALUES (202, 39, 1);
INSERT INTO favorites VALUES (203, 40, 2);
INSERT INTO favorites VALUES (203, 5, 1);
INSERT INTO favorites VALUES (203, 8, 3);
INSERT INTO favorites VALUES (203, 56, 4);
INSERT INTO favorites VALUES (205, 50, 1);
INSERT INTO favorites VALUES (205, 97, 3);
INSERT INTO favorites VALUES (205, 82, 4);
INSERT INTO favorites VALUES (205, 30, 2);
INSERT INTO favorites VALUES (206, 55, 2);
INSERT INTO favorites VALUES (206, 91, 1);
INSERT INTO favorites VALUES (206, 33, 3);
INSERT INTO favorites VALUES (207, 57, 1);
INSERT INTO favorites VALUES (207, 38, 2);
INSERT INTO favorites VALUES (207, 105, 3);
INSERT INTO favorites VALUES (208, 87, 1);
INSERT INTO favorites VALUES (208, 22, 3);
INSERT INTO favorites VALUES (208, 91, 2);
INSERT INTO favorites VALUES (208, 45, 4);
INSERT INTO favorites VALUES (209, 36, 2);
INSERT INTO favorites VALUES (209, 32, 1);
INSERT INTO favorites VALUES (209, 78, 3);
INSERT INTO favorites VALUES (209, 36, 4);
INSERT INTO favorites VALUES (211, 105, 1);
INSERT INTO favorites VALUES (211, 67, 7);
INSERT INTO favorites VALUES (211, 47, 3);
INSERT INTO favorites VALUES (211, 46, 4);
INSERT INTO favorites VALUES (211, 104, 2);
INSERT INTO favorites VALUES (211, 51, 6);
INSERT INTO favorites VALUES (211, 12, 5);
INSERT INTO favorites VALUES (212, 10, 1);
INSERT INTO favorites VALUES (212, 2, 3);
INSERT INTO favorites VALUES (212, 33, 4);
INSERT INTO favorites VALUES (212, 84, 2);
INSERT INTO favorites VALUES (212, 10, 6);
INSERT INTO favorites VALUES (212, 20, 7);
INSERT INTO favorites VALUES (212, 91, 5);
INSERT INTO favorites VALUES (213, 17, 1);
INSERT INTO favorites VALUES (213, 109, 2);
INSERT INTO favorites VALUES (214, 90, 1);
INSERT INTO favorites VALUES (214, 90, 2);
INSERT INTO favorites VALUES (215, 8, 1);
INSERT INTO favorites VALUES (218, 106, 1);
INSERT INTO favorites VALUES (218, 19, 2);
INSERT INTO favorites VALUES (219, 32, 2);
INSERT INTO favorites VALUES (219, 108, 1);
INSERT INTO favorites VALUES (219, 114, 4);
INSERT INTO favorites VALUES (219, 1, 3);
INSERT INTO favorites VALUES (220, 76, 2);
INSERT INTO favorites VALUES (220, 24, 1);
INSERT INTO favorites VALUES (221, 109, 1);
INSERT INTO favorites VALUES (222, 42, 1);
INSERT INTO favorites VALUES (222, 19, 2);
INSERT INTO favorites VALUES (222, 42, 3);
INSERT INTO favorites VALUES (222, 31, 4);
INSERT INTO favorites VALUES (222, 15, 6);
INSERT INTO favorites VALUES (222, 43, 5);
INSERT INTO favorites VALUES (222, 75, 7);
INSERT INTO favorites VALUES (223, 50, 1);
INSERT INTO favorites VALUES (224, 63, 1);
INSERT INTO favorites VALUES (224, 59, 2);
INSERT INTO favorites VALUES (224, 24, 3);
INSERT INTO favorites VALUES (225, 39, 2);
INSERT INTO favorites VALUES (225, 63, 1);
INSERT INTO favorites VALUES (225, 33, 3);
INSERT INTO favorites VALUES (225, 7, 4);
INSERT INTO favorites VALUES (226, 2, 1);
INSERT INTO favorites VALUES (227, 105, 1);
INSERT INTO favorites VALUES (227, 9, 2);
INSERT INTO favorites VALUES (228, 75, 2);
INSERT INTO favorites VALUES (228, 22, 1);
INSERT INTO favorites VALUES (229, 17, 2);
INSERT INTO favorites VALUES (229, 33, 3);
INSERT INTO favorites VALUES (229, 52, 1);
INSERT INTO favorites VALUES (229, 61, 4);
INSERT INTO favorites VALUES (229, 67, 5);
INSERT INTO favorites VALUES (230, 113, 1);
INSERT INTO favorites VALUES (231, 42, 1);
INSERT INTO favorites VALUES (231, 42, 2);
INSERT INTO favorites VALUES (231, 68, 3);
INSERT INTO favorites VALUES (231, 29, 4);
INSERT INTO favorites VALUES (232, 43, 2);
INSERT INTO favorites VALUES (232, 24, 1);
INSERT INTO favorites VALUES (232, 83, 3);
INSERT INTO favorites VALUES (233, 76, 1);
INSERT INTO favorites VALUES (234, 74, 1);
INSERT INTO favorites VALUES (234, 50, 2);
INSERT INTO favorites VALUES (234, 38, 3);
INSERT INTO favorites VALUES (235, 99, 1);
INSERT INTO favorites VALUES (235, 35, 3);
INSERT INTO favorites VALUES (235, 40, 2);
INSERT INTO favorites VALUES (236, 35, 1);
INSERT INTO favorites VALUES (237, 50, 1);
INSERT INTO favorites VALUES (237, 49, 3);
INSERT INTO favorites VALUES (237, 80, 2);
INSERT INTO favorites VALUES (238, 26, 1);
INSERT INTO favorites VALUES (238, 29, 3);
INSERT INTO favorites VALUES (238, 2, 4);
INSERT INTO favorites VALUES (238, 3, 2);
INSERT INTO favorites VALUES (239, 47, 1);
INSERT INTO favorites VALUES (239, 67, 2);
INSERT INTO favorites VALUES (239, 74, 3);
INSERT INTO favorites VALUES (240, 62, 2);
INSERT INTO favorites VALUES (240, 26, 1);
INSERT INTO favorites VALUES (240, 91, 4);
INSERT INTO favorites VALUES (240, 14, 3);
INSERT INTO favorites VALUES (241, 86, 1);
INSERT INTO favorites VALUES (241, 89, 2);
INSERT INTO favorites VALUES (242, 34, 1);
INSERT INTO favorites VALUES (243, 8, 1);
INSERT INTO favorites VALUES (244, 16, 3);
INSERT INTO favorites VALUES (244, 71, 2);
INSERT INTO favorites VALUES (244, 47, 1);
INSERT INTO favorites VALUES (245, 18, 1);
INSERT INTO favorites VALUES (245, 33, 2);
INSERT INTO favorites VALUES (246, 2, 1);
INSERT INTO favorites VALUES (246, 88, 2);
INSERT INTO favorites VALUES (246, 45, 3);
INSERT INTO favorites VALUES (246, 40, 4);
INSERT INTO favorites VALUES (247, 62, 2);
INSERT INTO favorites VALUES (247, 17, 1);
INSERT INTO favorites VALUES (248, 27, 3);
INSERT INTO favorites VALUES (248, 32, 2);
INSERT INTO favorites VALUES (248, 25, 1);
INSERT INTO favorites VALUES (249, 52, 1);
INSERT INTO favorites VALUES (250, 67, 1);
INSERT INTO favorites VALUES (250, 69, 2);
INSERT INTO favorites VALUES (250, 78, 4);
INSERT INTO favorites VALUES (250, 50, 3);
INSERT INTO favorites VALUES (250, 33, 5);
INSERT INTO favorites VALUES (250, 30, 6);
INSERT INTO favorites VALUES (251, 23, 1);
INSERT INTO favorites VALUES (251, 99, 2);
INSERT INTO favorites VALUES (251, 55, 4);
INSERT INTO favorites VALUES (251, 83, 3);
INSERT INTO favorites VALUES (251, 70, 6);
INSERT INTO favorites VALUES (251, 1, 5);
INSERT INTO favorites VALUES (252, 116, 2);
INSERT INTO favorites VALUES (252, 29, 4);
INSERT INTO favorites VALUES (252, 66, 1);
INSERT INTO favorites VALUES (252, 11, 3);
INSERT INTO favorites VALUES (252, 51, 7);
INSERT INTO favorites VALUES (252, 84, 6);
INSERT INTO favorites VALUES (252, 114, 5);
INSERT INTO favorites VALUES (252, 27, 8);
INSERT INTO favorites VALUES (253, 57, 1);
INSERT INTO favorites VALUES (253, 31, 2);
INSERT INTO favorites VALUES (253, 20, 7);
INSERT INTO favorites VALUES (253, 77, 4);
INSERT INTO favorites VALUES (253, 27, 3);
INSERT INTO favorites VALUES (253, 45, 5);
INSERT INTO favorites VALUES (253, 64, 6);
INSERT INTO favorites VALUES (254, 108, 1);
INSERT INTO favorites VALUES (255, 29, 2);
INSERT INTO favorites VALUES (255, 26, 4);
INSERT INTO favorites VALUES (255, 29, 3);
INSERT INTO favorites VALUES (255, 45, 1);
INSERT INTO favorites VALUES (255, 29, 5);
INSERT INTO favorites VALUES (256, 40, 1);
INSERT INTO favorites VALUES (257, 59, 1);
INSERT INTO favorites VALUES (257, 74, 2);
INSERT INTO favorites VALUES (257, 61, 3);
INSERT INTO favorites VALUES (257, 40, 4);
INSERT INTO favorites VALUES (258, 36, 1);
INSERT INTO favorites VALUES (259, 50, 1);
INSERT INTO favorites VALUES (259, 71, 4);
INSERT INTO favorites VALUES (259, 26, 5);
INSERT INTO favorites VALUES (259, 69, 2);
INSERT INTO favorites VALUES (259, 92, 3);
INSERT INTO favorites VALUES (260, 23, 2);
INSERT INTO favorites VALUES (260, 104, 1);
INSERT INTO favorites VALUES (261, 114, 2);
INSERT INTO favorites VALUES (261, 21, 1);
INSERT INTO favorites VALUES (262, 83, 1);
INSERT INTO favorites VALUES (262, 13, 3);
INSERT INTO favorites VALUES (262, 38, 2);
INSERT INTO favorites VALUES (263, 39, 2);
INSERT INTO favorites VALUES (263, 28, 1);
INSERT INTO favorites VALUES (264, 73, 1);
INSERT INTO favorites VALUES (264, 36, 3);
INSERT INTO favorites VALUES (264, 31, 2);
INSERT INTO favorites VALUES (264, 38, 4);
INSERT INTO favorites VALUES (265, 8, 1);
INSERT INTO favorites VALUES (266, 76, 1);
INSERT INTO favorites VALUES (267, 41, 1);
INSERT INTO favorites VALUES (267, 108, 4);
INSERT INTO favorites VALUES (267, 1, 3);
INSERT INTO favorites VALUES (267, 6, 2);
INSERT INTO favorites VALUES (268, 70, 1);
INSERT INTO favorites VALUES (269, 12, 2);
INSERT INTO favorites VALUES (269, 23, 3);
INSERT INTO favorites VALUES (269, 86, 1);
INSERT INTO favorites VALUES (269, 91, 4);
INSERT INTO favorites VALUES (271, 82, 1);
INSERT INTO favorites VALUES (271, 31, 2);
INSERT INTO favorites VALUES (271, 26, 4);
INSERT INTO favorites VALUES (271, 30, 3);
INSERT INTO favorites VALUES (271, 12, 5);
INSERT INTO favorites VALUES (271, 36, 7);
INSERT INTO favorites VALUES (271, 37, 6);
INSERT INTO favorites VALUES (272, 82, 1);
INSERT INTO favorites VALUES (272, 27, 2);
INSERT INTO favorites VALUES (272, 36, 3);
INSERT INTO favorites VALUES (272, 43, 4);
INSERT INTO favorites VALUES (272, 47, 5);
INSERT INTO favorites VALUES (273, 94, 1);
INSERT INTO favorites VALUES (274, 28, 1);
INSERT INTO favorites VALUES (274, 14, 3);
INSERT INTO favorites VALUES (274, 68, 2);
INSERT INTO favorites VALUES (275, 73, 1);
INSERT INTO favorites VALUES (276, 22, 1);
INSERT INTO favorites VALUES (276, 8, 2);
INSERT INTO favorites VALUES (276, 23, 5);
INSERT INTO favorites VALUES (276, 39, 3);
INSERT INTO favorites VALUES (276, 89, 4);
INSERT INTO favorites VALUES (277, 53, 1);
INSERT INTO favorites VALUES (277, 78, 2);
INSERT INTO favorites VALUES (277, 97, 3);
INSERT INTO favorites VALUES (278, 12, 1);
INSERT INTO favorites VALUES (279, 111, 1);
INSERT INTO favorites VALUES (279, 85, 2);
INSERT INTO favorites VALUES (280, 31, 1);
INSERT INTO favorites VALUES (280, 18, 2);
INSERT INTO favorites VALUES (280, 33, 3);
INSERT INTO favorites VALUES (281, 109, 1);
INSERT INTO favorites VALUES (281, 99, 2);
INSERT INTO favorites VALUES (282, 26, 2);
INSERT INTO favorites VALUES (282, 39, 1);
INSERT INTO favorites VALUES (282, 26, 3);
INSERT INTO favorites VALUES (284, 86, 2);
INSERT INTO favorites VALUES (284, 70, 1);
INSERT INTO favorites VALUES (284, 64, 3);
INSERT INTO favorites VALUES (284, 65, 4);
INSERT INTO favorites VALUES (285, 110, 2);
INSERT INTO favorites VALUES (285, 63, 1);
INSERT INTO favorites VALUES (286, 101, 1);
INSERT INTO favorites VALUES (287, 26, 1);
INSERT INTO favorites VALUES (287, 12, 2);
INSERT INTO favorites VALUES (288, 2, 1);
INSERT INTO favorites VALUES (288, 25, 2);
INSERT INTO favorites VALUES (288, 29, 3);
INSERT INTO favorites VALUES (288, 80, 4);
INSERT INTO favorites VALUES (289, 13, 1);
INSERT INTO favorites VALUES (289, 85, 2);
INSERT INTO favorites VALUES (289, 16, 5);
INSERT INTO favorites VALUES (289, 14, 3);
INSERT INTO favorites VALUES (289, 92, 4);
INSERT INTO favorites VALUES (290, 66, 1);
INSERT INTO favorites VALUES (290, 46, 3);
INSERT INTO favorites VALUES (290, 18, 2);
INSERT INTO favorites VALUES (290, 56, 6);
INSERT INTO favorites VALUES (290, 20, 4);
INSERT INTO favorites VALUES (290, 111, 5);
INSERT INTO favorites VALUES (291, 63, 1);
INSERT INTO favorites VALUES (292, 93, 2);
INSERT INTO favorites VALUES (292, 71, 1);
INSERT INTO favorites VALUES (292, 96, 3);
INSERT INTO favorites VALUES (293, 46, 3);
INSERT INTO favorites VALUES (293, 10, 1);
INSERT INTO favorites VALUES (293, 13, 5);
INSERT INTO favorites VALUES (293, 19, 4);
INSERT INTO favorites VALUES (293, 52, 2);
INSERT INTO favorites VALUES (295, 82, 1);
INSERT INTO favorites VALUES (295, 113, 2);
INSERT INTO favorites VALUES (296, 22, 1);
INSERT INTO favorites VALUES (297, 7, 1);
INSERT INTO favorites VALUES (297, 92, 2);
INSERT INTO favorites VALUES (298, 111, 2);
INSERT INTO favorites VALUES (298, 47, 1);
INSERT INTO favorites VALUES (299, 30, 1);
INSERT INTO favorites VALUES (299, 22, 4);
INSERT INTO favorites VALUES (299, 96, 2);
INSERT INTO favorites VALUES (299, 40, 3);
INSERT INTO favorites VALUES (300, 14, 1);
INSERT INTO favorites VALUES (300, 56, 2);
INSERT INTO favorites VALUES (300, 16, 3);
INSERT INTO favorites VALUES (301, 41, 1);
INSERT INTO favorites VALUES (301, 43, 2);
INSERT INTO favorites VALUES (302, 6, 1);
INSERT INTO favorites VALUES (302, 32, 2);
INSERT INTO favorites VALUES (302, 106, 4);
INSERT INTO favorites VALUES (302, 6, 3);
INSERT INTO favorites VALUES (302, 72, 5);
INSERT INTO favorites VALUES (302, 47, 6);
INSERT INTO favorites VALUES (303, 56, 1);
INSERT INTO favorites VALUES (303, 91, 3);
INSERT INTO favorites VALUES (303, 24, 2);
INSERT INTO favorites VALUES (304, 98, 1);
INSERT INTO favorites VALUES (304, 29, 2);
INSERT INTO favorites VALUES (304, 25, 4);
INSERT INTO favorites VALUES (304, 53, 5);
INSERT INTO favorites VALUES (304, 53, 3);
INSERT INTO favorites VALUES (305, 84, 1);
INSERT INTO favorites VALUES (305, 3, 2);
INSERT INTO favorites VALUES (305, 51, 3);
INSERT INTO favorites VALUES (305, 85, 5);
INSERT INTO favorites VALUES (305, 49, 4);
INSERT INTO favorites VALUES (306, 58, 1);
INSERT INTO favorites VALUES (306, 88, 2);
INSERT INTO favorites VALUES (307, 35, 2);
INSERT INTO favorites VALUES (307, 31, 1);
INSERT INTO favorites VALUES (307, 32, 3);
INSERT INTO favorites VALUES (307, 26, 4);
INSERT INTO favorites VALUES (307, 53, 5);
INSERT INTO favorites VALUES (308, 35, 1);
INSERT INTO favorites VALUES (308, 106, 2);
INSERT INTO favorites VALUES (308, 93, 4);
INSERT INTO favorites VALUES (308, 55, 3);
INSERT INTO favorites VALUES (309, 59, 1);
INSERT INTO favorites VALUES (309, 55, 3);
INSERT INTO favorites VALUES (309, 85, 2);
INSERT INTO favorites VALUES (309, 16, 4);
INSERT INTO favorites VALUES (311, 103, 1);
INSERT INTO favorites VALUES (311, 38, 2);
INSERT INTO favorites VALUES (313, 47, 1);
INSERT INTO favorites VALUES (314, 113, 1);
INSERT INTO favorites VALUES (315, 18, 2);
INSERT INTO favorites VALUES (315, 88, 1);
INSERT INTO favorites VALUES (315, 10, 3);
INSERT INTO favorites VALUES (316, 103, 1);
INSERT INTO favorites VALUES (316, 36, 2);
INSERT INTO favorites VALUES (316, 109, 3);
INSERT INTO favorites VALUES (316, 83, 4);
INSERT INTO favorites VALUES (317, 45, 3);
INSERT INTO favorites VALUES (317, 62, 1);
INSERT INTO favorites VALUES (317, 74, 5);
INSERT INTO favorites VALUES (317, 44, 2);
INSERT INTO favorites VALUES (317, 77, 4);
INSERT INTO favorites VALUES (317, 107, 6);
INSERT INTO favorites VALUES (318, 38, 1);
INSERT INTO favorites VALUES (318, 77, 2);
INSERT INTO favorites VALUES (319, 83, 2);
INSERT INTO favorites VALUES (319, 21, 1);
INSERT INTO favorites VALUES (319, 47, 3);
INSERT INTO favorites VALUES (320, 3, 1);
INSERT INTO favorites VALUES (321, 99, 1);
INSERT INTO favorites VALUES (321, 44, 2);
INSERT INTO favorites VALUES (322, 78, 1);
INSERT INTO favorites VALUES (322, 94, 2);
INSERT INTO favorites VALUES (322, 107, 3);
INSERT INTO favorites VALUES (323, 74, 2);
INSERT INTO favorites VALUES (323, 5, 1);
INSERT INTO favorites VALUES (323, 2, 4);
INSERT INTO favorites VALUES (323, 26, 3);
INSERT INTO favorites VALUES (324, 36, 1);
INSERT INTO favorites VALUES (324, 90, 2);
INSERT INTO favorites VALUES (324, 9, 3);
INSERT INTO favorites VALUES (326, 115, 1);
INSERT INTO favorites VALUES (327, 51, 2);
INSERT INTO favorites VALUES (327, 37, 1);
INSERT INTO favorites VALUES (327, 20, 3);
INSERT INTO favorites VALUES (328, 78, 1);
INSERT INTO favorites VALUES (329, 57, 1);
INSERT INTO favorites VALUES (329, 104, 2);
INSERT INTO favorites VALUES (330, 24, 1);
INSERT INTO favorites VALUES (331, 49, 2);
INSERT INTO favorites VALUES (331, 33, 1);
INSERT INTO favorites VALUES (332, 72, 1);
INSERT INTO favorites VALUES (332, 87, 3);
INSERT INTO favorites VALUES (332, 65, 2);
INSERT INTO favorites VALUES (332, 9, 4);
INSERT INTO favorites VALUES (332, 87, 6);
INSERT INTO favorites VALUES (332, 114, 5);
INSERT INTO favorites VALUES (334, 45, 1);
INSERT INTO favorites VALUES (336, 38, 1);
INSERT INTO favorites VALUES (337, 3, 2);
INSERT INTO favorites VALUES (337, 98, 1);
INSERT INTO favorites VALUES (337, 15, 3);
INSERT INTO favorites VALUES (337, 4, 4);
INSERT INTO favorites VALUES (339, 114, 2);
INSERT INTO favorites VALUES (339, 62, 1);
INSERT INTO favorites VALUES (339, 74, 3);
INSERT INTO favorites VALUES (339, 19, 4);
INSERT INTO favorites VALUES (340, 20, 1);
INSERT INTO favorites VALUES (340, 57, 4);
INSERT INTO favorites VALUES (340, 3, 2);
INSERT INTO favorites VALUES (340, 111, 3);
INSERT INTO favorites VALUES (341, 8, 1);
INSERT INTO favorites VALUES (341, 5, 2);
INSERT INTO favorites VALUES (342, 32, 1);
INSERT INTO favorites VALUES (343, 90, 4);
INSERT INTO favorites VALUES (343, 15, 3);
INSERT INTO favorites VALUES (343, 21, 2);
INSERT INTO favorites VALUES (343, 17, 1);
INSERT INTO favorites VALUES (343, 39, 5);
INSERT INTO favorites VALUES (343, 25, 6);
INSERT INTO favorites VALUES (344, 26, 1);
INSERT INTO favorites VALUES (345, 78, 1);
INSERT INTO favorites VALUES (346, 22, 1);
INSERT INTO favorites VALUES (346, 30, 2);
INSERT INTO favorites VALUES (347, 109, 1);
INSERT INTO favorites VALUES (349, 85, 2);
INSERT INTO favorites VALUES (349, 55, 1);
INSERT INTO favorites VALUES (349, 7, 3);
INSERT INTO favorites VALUES (350, 26, 1);
INSERT INTO favorites VALUES (351, 2, 1);
INSERT INTO favorites VALUES (351, 69, 3);
INSERT INTO favorites VALUES (351, 20, 4);
INSERT INTO favorites VALUES (351, 59, 2);
INSERT INTO favorites VALUES (352, 89, 1);
INSERT INTO favorites VALUES (354, 26, 1);
INSERT INTO favorites VALUES (354, 61, 3);
INSERT INTO favorites VALUES (354, 46, 2);
INSERT INTO favorites VALUES (355, 25, 1);
INSERT INTO favorites VALUES (355, 102, 2);
INSERT INTO favorites VALUES (356, 61, 2);
INSERT INTO favorites VALUES (356, 85, 1);
INSERT INTO favorites VALUES (357, 31, 2);
INSERT INTO favorites VALUES (357, 18, 1);
INSERT INTO favorites VALUES (357, 47, 3);
INSERT INTO favorites VALUES (358, 3, 2);
INSERT INTO favorites VALUES (358, 92, 1);
INSERT INTO favorites VALUES (358, 74, 3);
INSERT INTO favorites VALUES (358, 34, 4);
INSERT INTO favorites VALUES (358, 60, 5);
INSERT INTO favorites VALUES (359, 100, 1);
INSERT INTO favorites VALUES (359, 100, 2);
INSERT INTO favorites VALUES (360, 104, 1);
INSERT INTO favorites VALUES (360, 72, 2);
INSERT INTO favorites VALUES (360, 38, 3);
INSERT INTO favorites VALUES (361, 15, 1);
INSERT INTO favorites VALUES (361, 108, 2);
INSERT INTO favorites VALUES (361, 100, 3);
INSERT INTO favorites VALUES (361, 9, 4);
INSERT INTO favorites VALUES (362, 62, 2);
INSERT INTO favorites VALUES (362, 52, 1);
INSERT INTO favorites VALUES (362, 44, 3);
INSERT INTO favorites VALUES (363, 11, 1);
INSERT INTO favorites VALUES (363, 110, 2);
INSERT INTO favorites VALUES (364, 7, 1);
INSERT INTO favorites VALUES (365, 41, 1);
INSERT INTO favorites VALUES (365, 25, 2);
INSERT INTO favorites VALUES (366, 108, 1);
INSERT INTO favorites VALUES (366, 62, 2);
INSERT INTO favorites VALUES (366, 72, 3);
INSERT INTO favorites VALUES (367, 65, 1);
INSERT INTO favorites VALUES (367, 40, 3);
INSERT INTO favorites VALUES (367, 34, 2);
INSERT INTO favorites VALUES (368, 71, 1);
INSERT INTO favorites VALUES (368, 22, 3);
INSERT INTO favorites VALUES (368, 65, 2);
INSERT INTO favorites VALUES (369, 99, 1);
INSERT INTO favorites VALUES (371, 45, 1);
INSERT INTO favorites VALUES (371, 20, 2);
INSERT INTO favorites VALUES (373, 31, 1);
INSERT INTO favorites VALUES (373, 94, 2);
INSERT INTO favorites VALUES (373, 27, 3);
INSERT INTO favorites VALUES (374, 2, 1);
INSERT INTO favorites VALUES (374, 63, 3);
INSERT INTO favorites VALUES (374, 85, 2);
INSERT INTO favorites VALUES (375, 67, 1);
INSERT INTO favorites VALUES (376, 100, 1);
INSERT INTO favorites VALUES (377, 62, 1);
INSERT INTO favorites VALUES (377, 99, 2);
INSERT INTO favorites VALUES (379, 28, 2);
INSERT INTO favorites VALUES (379, 6, 1);
INSERT INTO favorites VALUES (379, 84, 3);
INSERT INTO favorites VALUES (380, 10, 1);
INSERT INTO favorites VALUES (380, 66, 3);
INSERT INTO favorites VALUES (380, 51, 2);
INSERT INTO favorites VALUES (380, 58, 5);
INSERT INTO favorites VALUES (380, 109, 4);
INSERT INTO favorites VALUES (381, 2, 1);
INSERT INTO favorites VALUES (381, 77, 2);
INSERT INTO favorites VALUES (381, 43, 3);
INSERT INTO favorites VALUES (382, 23, 1);
INSERT INTO favorites VALUES (382, 15, 3);
INSERT INTO favorites VALUES (382, 59, 4);
INSERT INTO favorites VALUES (382, 40, 2);
INSERT INTO favorites VALUES (383, 15, 2);
INSERT INTO favorites VALUES (383, 76, 1);
INSERT INTO favorites VALUES (384, 4, 1);
INSERT INTO favorites VALUES (384, 26, 2);
INSERT INTO favorites VALUES (384, 13, 3);
INSERT INTO favorites VALUES (385, 46, 1);
INSERT INTO favorites VALUES (385, 56, 2);
INSERT INTO favorites VALUES (385, 97, 4);
INSERT INTO favorites VALUES (385, 20, 3);
INSERT INTO favorites VALUES (386, 66, 1);
INSERT INTO favorites VALUES (387, 22, 1);
INSERT INTO favorites VALUES (388, 81, 2);
INSERT INTO favorites VALUES (388, 76, 1);
INSERT INTO favorites VALUES (388, 65, 3);
INSERT INTO favorites VALUES (389, 94, 1);
INSERT INTO favorites VALUES (389, 56, 2);
INSERT INTO favorites VALUES (390, 5, 1);
INSERT INTO favorites VALUES (390, 78, 2);
INSERT INTO favorites VALUES (391, 98, 1);
INSERT INTO favorites VALUES (391, 27, 2);
INSERT INTO favorites VALUES (392, 19, 1);
INSERT INTO favorites VALUES (392, 27, 2);
INSERT INTO favorites VALUES (392, 63, 3);
INSERT INTO favorites VALUES (392, 1, 4);
INSERT INTO favorites VALUES (394, 111, 1);
INSERT INTO favorites VALUES (394, 60, 2);
INSERT INTO favorites VALUES (394, 108, 3);
INSERT INTO favorites VALUES (395, 100, 1);
INSERT INTO favorites VALUES (395, 68, 2);
INSERT INTO favorites VALUES (395, 18, 4);
INSERT INTO favorites VALUES (395, 23, 3);
INSERT INTO favorites VALUES (396, 25, 1);
INSERT INTO favorites VALUES (396, 24, 2);
INSERT INTO favorites VALUES (397, 25, 1);
INSERT INTO favorites VALUES (397, 5, 2);
INSERT INTO favorites VALUES (398, 16, 2);
INSERT INTO favorites VALUES (398, 61, 1);
INSERT INTO favorites VALUES (398, 113, 3);
INSERT INTO favorites VALUES (398, 76, 4);
INSERT INTO favorites VALUES (398, 7, 5);
INSERT INTO favorites VALUES (399, 11, 1);
INSERT INTO favorites VALUES (399, 18, 2);
INSERT INTO favorites VALUES (399, 31, 3);
INSERT INTO favorites VALUES (400, 15, 1);
INSERT INTO favorites VALUES (400, 32, 2);
INSERT INTO favorites VALUES (402, 16, 1);
INSERT INTO favorites VALUES (403, 85, 1);
INSERT INTO favorites VALUES (404, 55, 1);
INSERT INTO favorites VALUES (405, 25, 1);
INSERT INTO favorites VALUES (405, 71, 2);
INSERT INTO favorites VALUES (406, 53, 2);
INSERT INTO favorites VALUES (406, 97, 1);
INSERT INTO favorites VALUES (406, 64, 3);
INSERT INTO favorites VALUES (408, 116, 1);
INSERT INTO favorites VALUES (408, 111, 2);
INSERT INTO favorites VALUES (408, 12, 3);
INSERT INTO favorites VALUES (409, 14, 1);
INSERT INTO favorites VALUES (410, 20, 1);
INSERT INTO favorites VALUES (410, 73, 2);
INSERT INTO favorites VALUES (410, 106, 3);
INSERT INTO favorites VALUES (410, 58, 5);
INSERT INTO favorites VALUES (410, 7, 4);
INSERT INTO favorites VALUES (412, 31, 2);
INSERT INTO favorites VALUES (412, 14, 1);
INSERT INTO favorites VALUES (412, 23, 3);
INSERT INTO favorites VALUES (412, 14, 5);
INSERT INTO favorites VALUES (412, 87, 4);
INSERT INTO favorites VALUES (413, 66, 1);
INSERT INTO favorites VALUES (413, 28, 2);
INSERT INTO favorites VALUES (413, 70, 4);
INSERT INTO favorites VALUES (413, 95, 3);
INSERT INTO favorites VALUES (414, 60, 2);
INSERT INTO favorites VALUES (414, 34, 4);
INSERT INTO favorites VALUES (414, 8, 1);
INSERT INTO favorites VALUES (414, 97, 3);
INSERT INTO favorites VALUES (415, 49, 1);
INSERT INTO favorites VALUES (415, 59, 3);
INSERT INTO favorites VALUES (415, 13, 2);
INSERT INTO favorites VALUES (415, 74, 4);
INSERT INTO favorites VALUES (416, 31, 2);
INSERT INTO favorites VALUES (416, 29, 1);
INSERT INTO favorites VALUES (417, 39, 1);
INSERT INTO favorites VALUES (417, 25, 3);
INSERT INTO favorites VALUES (417, 12, 2);
INSERT INTO favorites VALUES (418, 52, 1);
INSERT INTO favorites VALUES (419, 45, 1);
INSERT INTO favorites VALUES (419, 6, 3);
INSERT INTO favorites VALUES (419, 66, 2);
INSERT INTO favorites VALUES (419, 92, 5);
INSERT INTO favorites VALUES (419, 32, 4);
INSERT INTO favorites VALUES (419, 10, 7);
INSERT INTO favorites VALUES (419, 71, 6);
INSERT INTO favorites VALUES (420, 81, 2);
INSERT INTO favorites VALUES (420, 51, 1);
INSERT INTO favorites VALUES (420, 46, 3);
INSERT INTO favorites VALUES (421, 64, 1);
INSERT INTO favorites VALUES (421, 86, 2);
INSERT INTO favorites VALUES (422, 28, 2);
INSERT INTO favorites VALUES (422, 5, 1);
INSERT INTO favorites VALUES (422, 103, 3);
INSERT INTO favorites VALUES (423, 28, 2);
INSERT INTO favorites VALUES (423, 70, 1);
INSERT INTO favorites VALUES (423, 48, 5);
INSERT INTO favorites VALUES (423, 31, 4);
INSERT INTO favorites VALUES (423, 7, 3);
INSERT INTO favorites VALUES (424, 90, 2);
INSERT INTO favorites VALUES (424, 96, 1);
INSERT INTO favorites VALUES (425, 1, 3);
INSERT INTO favorites VALUES (425, 72, 1);
INSERT INTO favorites VALUES (425, 5, 2);
INSERT INTO favorites VALUES (425, 22, 4);
INSERT INTO favorites VALUES (426, 24, 2);
INSERT INTO favorites VALUES (426, 10, 1);
INSERT INTO favorites VALUES (426, 16, 4);
INSERT INTO favorites VALUES (426, 98, 3);
INSERT INTO favorites VALUES (427, 3, 1);
INSERT INTO favorites VALUES (427, 95, 2);
INSERT INTO favorites VALUES (428, 61, 1);
INSERT INTO favorites VALUES (428, 5, 2);
INSERT INTO favorites VALUES (429, 64, 1);
INSERT INTO favorites VALUES (429, 80, 2);
INSERT INTO favorites VALUES (431, 74, 1);
INSERT INTO favorites VALUES (431, 29, 3);
INSERT INTO favorites VALUES (431, 77, 2);
INSERT INTO favorites VALUES (432, 38, 1);
INSERT INTO favorites VALUES (432, 1, 3);
INSERT INTO favorites VALUES (432, 32, 2);
INSERT INTO favorites VALUES (432, 19, 5);
INSERT INTO favorites VALUES (432, 24, 4);
INSERT INTO favorites VALUES (433, 112, 2);
INSERT INTO favorites VALUES (433, 50, 1);
INSERT INTO favorites VALUES (433, 84, 3);
INSERT INTO favorites VALUES (434, 31, 1);
INSERT INTO favorites VALUES (434, 61, 2);
INSERT INTO favorites VALUES (434, 72, 3);
INSERT INTO favorites VALUES (435, 79, 1);
INSERT INTO favorites VALUES (435, 81, 2);
INSERT INTO favorites VALUES (435, 29, 3);
INSERT INTO favorites VALUES (435, 51, 4);
INSERT INTO favorites VALUES (435, 47, 5);
INSERT INTO favorites VALUES (436, 104, 2);
INSERT INTO favorites VALUES (436, 16, 1);
INSERT INTO favorites VALUES (436, 87, 3);
INSERT INTO favorites VALUES (437, 8, 3);
INSERT INTO favorites VALUES (437, 62, 4);
INSERT INTO favorites VALUES (437, 90, 2);
INSERT INTO favorites VALUES (437, 37, 1);
INSERT INTO favorites VALUES (438, 48, 2);
INSERT INTO favorites VALUES (438, 34, 1);
INSERT INTO favorites VALUES (438, 11, 3);
INSERT INTO favorites VALUES (438, 2, 5);
INSERT INTO favorites VALUES (438, 100, 4);
INSERT INTO favorites VALUES (438, 69, 7);
INSERT INTO favorites VALUES (438, 44, 6);
INSERT INTO favorites VALUES (439, 28, 1);
INSERT INTO favorites VALUES (439, 14, 2);
INSERT INTO favorites VALUES (440, 113, 1);
INSERT INTO favorites VALUES (440, 71, 3);
INSERT INTO favorites VALUES (440, 109, 2);
INSERT INTO favorites VALUES (440, 9, 4);
INSERT INTO favorites VALUES (440, 101, 8);
INSERT INTO favorites VALUES (440, 31, 7);
INSERT INTO favorites VALUES (440, 48, 6);
INSERT INTO favorites VALUES (440, 14, 5);
INSERT INTO favorites VALUES (441, 61, 1);
INSERT INTO favorites VALUES (441, 2, 2);
INSERT INTO favorites VALUES (441, 65, 3);
INSERT INTO favorites VALUES (442, 98, 3);
INSERT INTO favorites VALUES (442, 80, 2);
INSERT INTO favorites VALUES (442, 39, 1);
INSERT INTO favorites VALUES (442, 83, 6);
INSERT INTO favorites VALUES (442, 19, 5);
INSERT INTO favorites VALUES (442, 91, 4);
INSERT INTO favorites VALUES (443, 41, 1);
INSERT INTO favorites VALUES (443, 44, 3);
INSERT INTO favorites VALUES (443, 83, 2);
INSERT INTO favorites VALUES (444, 76, 1);
INSERT INTO favorites VALUES (444, 66, 2);
INSERT INTO favorites VALUES (445, 32, 1);
INSERT INTO favorites VALUES (445, 6, 3);
INSERT INTO favorites VALUES (445, 47, 2);
INSERT INTO favorites VALUES (445, 57, 4);
INSERT INTO favorites VALUES (446, 69, 2);
INSERT INTO favorites VALUES (446, 107, 1);
INSERT INTO favorites VALUES (446, 103, 3);
INSERT INTO favorites VALUES (447, 45, 1);
INSERT INTO favorites VALUES (447, 37, 2);
INSERT INTO favorites VALUES (448, 45, 1);
INSERT INTO favorites VALUES (448, 33, 2);
INSERT INTO favorites VALUES (449, 115, 1);
INSERT INTO favorites VALUES (450, 40, 1);
INSERT INTO favorites VALUES (450, 29, 2);
INSERT INTO favorites VALUES (450, 41, 3);
INSERT INTO favorites VALUES (451, 71, 1);
INSERT INTO favorites VALUES (452, 12, 2);
INSERT INTO favorites VALUES (452, 59, 1);
INSERT INTO favorites VALUES (452, 38, 3);
INSERT INTO favorites VALUES (453, 16, 1);
INSERT INTO favorites VALUES (453, 72, 2);
INSERT INTO favorites VALUES (453, 94, 4);
INSERT INTO favorites VALUES (453, 75, 3);
INSERT INTO favorites VALUES (454, 104, 1);
INSERT INTO favorites VALUES (454, 20, 2);
INSERT INTO favorites VALUES (454, 35, 3);
INSERT INTO favorites VALUES (455, 75, 1);
INSERT INTO favorites VALUES (456, 60, 1);
INSERT INTO favorites VALUES (456, 58, 3);
INSERT INTO favorites VALUES (456, 54, 2);
INSERT INTO favorites VALUES (458, 81, 1);
INSERT INTO favorites VALUES (459, 93, 1);
INSERT INTO favorites VALUES (459, 84, 2);
INSERT INTO favorites VALUES (459, 47, 3);
INSERT INTO favorites VALUES (460, 105, 1);
INSERT INTO favorites VALUES (460, 20, 2);
INSERT INTO favorites VALUES (461, 27, 1);
INSERT INTO favorites VALUES (461, 5, 2);
INSERT INTO favorites VALUES (462, 5, 2);
INSERT INTO favorites VALUES (462, 107, 1);
INSERT INTO favorites VALUES (462, 32, 4);
INSERT INTO favorites VALUES (462, 100, 3);
INSERT INTO favorites VALUES (462, 108, 5);
INSERT INTO favorites VALUES (463, 75, 1);
INSERT INTO favorites VALUES (464, 20, 1);
INSERT INTO favorites VALUES (464, 33, 2);
INSERT INTO favorites VALUES (465, 13, 1);
INSERT INTO favorites VALUES (465, 24, 2);
INSERT INTO favorites VALUES (465, 74, 4);
INSERT INTO favorites VALUES (465, 52, 3);
INSERT INTO favorites VALUES (466, 35, 1);
INSERT INTO favorites VALUES (466, 91, 2);
INSERT INTO favorites VALUES (466, 81, 3);
INSERT INTO favorites VALUES (467, 22, 2);
INSERT INTO favorites VALUES (467, 22, 1);
INSERT INTO favorites VALUES (467, 22, 3);
INSERT INTO favorites VALUES (468, 24, 3);
INSERT INTO favorites VALUES (468, 31, 1);
INSERT INTO favorites VALUES (468, 16, 4);
INSERT INTO favorites VALUES (468, 34, 2);
INSERT INTO favorites VALUES (468, 20, 5);
INSERT INTO favorites VALUES (471, 108, 1);
INSERT INTO favorites VALUES (471, 5, 2);
INSERT INTO favorites VALUES (471, 18, 3);
INSERT INTO favorites VALUES (472, 36, 1);
INSERT INTO favorites VALUES (472, 57, 4);
INSERT INTO favorites VALUES (472, 100, 3);
INSERT INTO favorites VALUES (472, 7, 2);
INSERT INTO favorites VALUES (472, 79, 5);
INSERT INTO favorites VALUES (472, 115, 6);
INSERT INTO favorites VALUES (473, 16, 1);
INSERT INTO favorites VALUES (473, 19, 2);
INSERT INTO favorites VALUES (474, 102, 2);
INSERT INTO favorites VALUES (474, 67, 1);
INSERT INTO favorites VALUES (474, 8, 3);
INSERT INTO favorites VALUES (474, 49, 5);
INSERT INTO favorites VALUES (474, 108, 4);
INSERT INTO favorites VALUES (475, 46, 1);
INSERT INTO favorites VALUES (476, 8, 1);
INSERT INTO favorites VALUES (476, 40, 2);
INSERT INTO favorites VALUES (477, 27, 1);
INSERT INTO favorites VALUES (477, 9, 2);
INSERT INTO favorites VALUES (478, 32, 2);
INSERT INTO favorites VALUES (478, 54, 1);
INSERT INTO favorites VALUES (478, 93, 3);
INSERT INTO favorites VALUES (478, 36, 4);
INSERT INTO favorites VALUES (479, 24, 2);
INSERT INTO favorites VALUES (479, 92, 1);
INSERT INTO favorites VALUES (480, 110, 1);
INSERT INTO favorites VALUES (481, 11, 1);
INSERT INTO favorites VALUES (481, 1, 2);
INSERT INTO favorites VALUES (481, 5, 3);
INSERT INTO favorites VALUES (481, 17, 4);
INSERT INTO favorites VALUES (482, 59, 1);
INSERT INTO favorites VALUES (482, 37, 3);
INSERT INTO favorites VALUES (482, 39, 2);
INSERT INTO favorites VALUES (482, 35, 5);
INSERT INTO favorites VALUES (482, 71, 4);
INSERT INTO favorites VALUES (482, 25, 6);
INSERT INTO favorites VALUES (483, 30, 1);
INSERT INTO favorites VALUES (483, 5, 2);
INSERT INTO favorites VALUES (483, 76, 3);
INSERT INTO favorites VALUES (484, 2, 1);
INSERT INTO favorites VALUES (484, 13, 2);
INSERT INTO favorites VALUES (485, 115, 1);
INSERT INTO favorites VALUES (486, 15, 2);
INSERT INTO favorites VALUES (486, 36, 1);
INSERT INTO favorites VALUES (487, 63, 1);
INSERT INTO favorites VALUES (487, 76, 2);
INSERT INTO favorites VALUES (487, 17, 3);
INSERT INTO favorites VALUES (488, 4, 1);
INSERT INTO favorites VALUES (488, 47, 2);
INSERT INTO favorites VALUES (488, 67, 4);
INSERT INTO favorites VALUES (488, 60, 3);
INSERT INTO favorites VALUES (490, 56, 1);
INSERT INTO favorites VALUES (491, 26, 1);
INSERT INTO favorites VALUES (491, 113, 4);
INSERT INTO favorites VALUES (491, 42, 3);
INSERT INTO favorites VALUES (491, 90, 2);
INSERT INTO favorites VALUES (491, 96, 5);
INSERT INTO favorites VALUES (492, 88, 1);
INSERT INTO favorites VALUES (492, 91, 2);
INSERT INTO favorites VALUES (493, 88, 1);
INSERT INTO favorites VALUES (494, 56, 2);
INSERT INTO favorites VALUES (494, 67, 1);
INSERT INTO favorites VALUES (494, 68, 3);
INSERT INTO favorites VALUES (494, 24, 6);
INSERT INTO favorites VALUES (494, 51, 4);
INSERT INTO favorites VALUES (494, 96, 5);
INSERT INTO favorites VALUES (495, 53, 2);
INSERT INTO favorites VALUES (495, 41, 1);
INSERT INTO favorites VALUES (495, 103, 3);
INSERT INTO favorites VALUES (496, 97, 1);
INSERT INTO favorites VALUES (497, 33, 1);
INSERT INTO favorites VALUES (497, 65, 2);
INSERT INTO favorites VALUES (498, 34, 1);
INSERT INTO favorites VALUES (498, 84, 3);
INSERT INTO favorites VALUES (498, 83, 2);
INSERT INTO favorites VALUES (498, 104, 4);
INSERT INTO favorites VALUES (498, 47, 5);
INSERT INTO favorites VALUES (499, 40, 2);
INSERT INTO favorites VALUES (499, 42, 1);
INSERT INTO favorites VALUES (500, 12, 1);
INSERT INTO favorites VALUES (500, 55, 2);
INSERT INTO favorites VALUES (500, 92, 3);
INSERT INTO favorites VALUES (500, 22, 4);
INSERT INTO favorites VALUES (500, 105, 5);
INSERT INTO favorites VALUES (501, 61, 3);
INSERT INTO favorites VALUES (501, 45, 2);
INSERT INTO favorites VALUES (501, 1, 1);
INSERT INTO favorites VALUES (501, 20, 4);
INSERT INTO favorites VALUES (501, 2, 5);
INSERT INTO favorites VALUES (502, 62, 2);
INSERT INTO favorites VALUES (502, 71, 1);
INSERT INTO favorites VALUES (502, 8, 3);
INSERT INTO favorites VALUES (502, 48, 4);
INSERT INTO favorites VALUES (504, 68, 2);
INSERT INTO favorites VALUES (504, 24, 1);
INSERT INTO favorites VALUES (504, 97, 3);
INSERT INTO favorites VALUES (504, 34, 4);
INSERT INTO favorites VALUES (505, 4, 1);
INSERT INTO favorites VALUES (505, 79, 2);
INSERT INTO favorites VALUES (505, 55, 3);
INSERT INTO favorites VALUES (506, 27, 1);
INSERT INTO favorites VALUES (506, 3, 2);
INSERT INTO favorites VALUES (506, 23, 3);
INSERT INTO favorites VALUES (507, 88, 2);
INSERT INTO favorites VALUES (507, 4, 1);
INSERT INTO favorites VALUES (508, 21, 2);
INSERT INTO favorites VALUES (508, 73, 1);
INSERT INTO favorites VALUES (509, 76, 1);
INSERT INTO favorites VALUES (509, 8, 2);
INSERT INTO favorites VALUES (509, 115, 3);
INSERT INTO favorites VALUES (509, 4, 4);
INSERT INTO favorites VALUES (510, 73, 1);
INSERT INTO favorites VALUES (510, 36, 3);
INSERT INTO favorites VALUES (510, 71, 2);
INSERT INTO favorites VALUES (511, 35, 1);
INSERT INTO favorites VALUES (511, 9, 3);
INSERT INTO favorites VALUES (511, 49, 2);
INSERT INTO favorites VALUES (512, 44, 2);
INSERT INTO favorites VALUES (512, 24, 4);
INSERT INTO favorites VALUES (512, 29, 1);
INSERT INTO favorites VALUES (512, 59, 3);
INSERT INTO favorites VALUES (512, 24, 8);
INSERT INTO favorites VALUES (512, 79, 5);
INSERT INTO favorites VALUES (512, 73, 7);
INSERT INTO favorites VALUES (512, 40, 6);
INSERT INTO favorites VALUES (512, 46, 9);
INSERT INTO favorites VALUES (513, 22, 1);
INSERT INTO favorites VALUES (514, 24, 5);
INSERT INTO favorites VALUES (514, 45, 1);
INSERT INTO favorites VALUES (514, 80, 4);
INSERT INTO favorites VALUES (514, 25, 3);
INSERT INTO favorites VALUES (514, 20, 2);
INSERT INTO favorites VALUES (515, 59, 1);
INSERT INTO favorites VALUES (515, 98, 2);
INSERT INTO favorites VALUES (516, 88, 1);
INSERT INTO favorites VALUES (516, 2, 2);
INSERT INTO favorites VALUES (517, 35, 1);
INSERT INTO favorites VALUES (518, 64, 1);
INSERT INTO favorites VALUES (518, 67, 2);
INSERT INTO favorites VALUES (519, 97, 2);
INSERT INTO favorites VALUES (519, 104, 1);
INSERT INTO favorites VALUES (520, 66, 3);
INSERT INTO favorites VALUES (520, 8, 1);
INSERT INTO favorites VALUES (520, 49, 2);
INSERT INTO favorites VALUES (520, 19, 4);
INSERT INTO favorites VALUES (521, 7, 1);
INSERT INTO favorites VALUES (521, 62, 2);
INSERT INTO favorites VALUES (522, 4, 1);
INSERT INTO favorites VALUES (522, 107, 2);
INSERT INTO favorites VALUES (522, 35, 3);
INSERT INTO favorites VALUES (523, 104, 2);
INSERT INTO favorites VALUES (523, 14, 1);
INSERT INTO favorites VALUES (523, 106, 3);
INSERT INTO favorites VALUES (523, 19, 4);
INSERT INTO favorites VALUES (524, 111, 2);
INSERT INTO favorites VALUES (524, 112, 1);
INSERT INTO favorites VALUES (524, 7, 3);
INSERT INTO favorites VALUES (525, 73, 1);
INSERT INTO favorites VALUES (526, 1, 1);
INSERT INTO favorites VALUES (526, 84, 2);
INSERT INTO favorites VALUES (527, 40, 2);
INSERT INTO favorites VALUES (527, 14, 1);
INSERT INTO favorites VALUES (527, 55, 3);
INSERT INTO favorites VALUES (527, 2, 4);
INSERT INTO favorites VALUES (528, 88, 1);
INSERT INTO favorites VALUES (528, 27, 2);
INSERT INTO favorites VALUES (529, 5, 1);
INSERT INTO favorites VALUES (529, 30, 2);
INSERT INTO favorites VALUES (531, 78, 1);
INSERT INTO favorites VALUES (531, 104, 3);
INSERT INTO favorites VALUES (531, 76, 2);
INSERT INTO favorites VALUES (531, 61, 4);
INSERT INTO favorites VALUES (532, 66, 3);
INSERT INTO favorites VALUES (532, 43, 2);
INSERT INTO favorites VALUES (532, 79, 1);
INSERT INTO favorites VALUES (533, 14, 1);
INSERT INTO favorites VALUES (533, 7, 2);
INSERT INTO favorites VALUES (534, 5, 1);
INSERT INTO favorites VALUES (534, 31, 2);
INSERT INTO favorites VALUES (534, 66, 3);
INSERT INTO favorites VALUES (535, 74, 1);
INSERT INTO favorites VALUES (536, 54, 1);
INSERT INTO favorites VALUES (537, 59, 1);
INSERT INTO favorites VALUES (537, 93, 2);
INSERT INTO favorites VALUES (538, 22, 1);
INSERT INTO favorites VALUES (539, 38, 2);
INSERT INTO favorites VALUES (539, 68, 1);
INSERT INTO favorites VALUES (539, 35, 3);
INSERT INTO favorites VALUES (540, 40, 2);
INSERT INTO favorites VALUES (540, 69, 1);
INSERT INTO favorites VALUES (540, 104, 3);
INSERT INTO favorites VALUES (541, 26, 2);
INSERT INTO favorites VALUES (541, 89, 1);
INSERT INTO favorites VALUES (541, 110, 3);
INSERT INTO favorites VALUES (541, 106, 4);
INSERT INTO favorites VALUES (542, 55, 1);
INSERT INTO favorites VALUES (542, 52, 2);
INSERT INTO favorites VALUES (543, 31, 1);
INSERT INTO favorites VALUES (544, 92, 2);
INSERT INTO favorites VALUES (544, 34, 4);
INSERT INTO favorites VALUES (544, 39, 1);
INSERT INTO favorites VALUES (544, 21, 3);
INSERT INTO favorites VALUES (545, 68, 3);
INSERT INTO favorites VALUES (545, 66, 2);
INSERT INTO favorites VALUES (545, 1, 1);
INSERT INTO favorites VALUES (545, 66, 4);
INSERT INTO favorites VALUES (545, 29, 5);
INSERT INTO favorites VALUES (545, 7, 6);
INSERT INTO favorites VALUES (546, 116, 1);
INSERT INTO favorites VALUES (546, 71, 2);
INSERT INTO favorites VALUES (546, 42, 3);
INSERT INTO favorites VALUES (547, 28, 2);
INSERT INTO favorites VALUES (547, 107, 3);
INSERT INTO favorites VALUES (547, 38, 1);
INSERT INTO favorites VALUES (547, 62, 4);
INSERT INTO favorites VALUES (548, 3, 2);
INSERT INTO favorites VALUES (548, 79, 1);
INSERT INTO favorites VALUES (548, 16, 5);
INSERT INTO favorites VALUES (548, 66, 4);
INSERT INTO favorites VALUES (548, 15, 3);
INSERT INTO favorites VALUES (548, 64, 6);
INSERT INTO favorites VALUES (550, 61, 1);
INSERT INTO favorites VALUES (551, 37, 2);
INSERT INTO favorites VALUES (551, 1, 1);
INSERT INTO favorites VALUES (551, 77, 3);
INSERT INTO favorites VALUES (552, 110, 1);
INSERT INTO favorites VALUES (552, 29, 2);
INSERT INTO favorites VALUES (552, 9, 3);
INSERT INTO favorites VALUES (554, 38, 1);
INSERT INTO favorites VALUES (554, 53, 2);
INSERT INTO favorites VALUES (555, 28, 1);
INSERT INTO favorites VALUES (556, 77, 2);
INSERT INTO favorites VALUES (556, 52, 1);
INSERT INTO favorites VALUES (556, 60, 4);
INSERT INTO favorites VALUES (556, 113, 3);
INSERT INTO favorites VALUES (556, 64, 6);
INSERT INTO favorites VALUES (556, 90, 5);
INSERT INTO favorites VALUES (557, 5, 2);
INSERT INTO favorites VALUES (557, 28, 1);
INSERT INTO favorites VALUES (558, 102, 2);
INSERT INTO favorites VALUES (558, 14, 1);
INSERT INTO favorites VALUES (559, 15, 1);
INSERT INTO favorites VALUES (559, 56, 2);
INSERT INTO favorites VALUES (559, 71, 3);
INSERT INTO favorites VALUES (560, 111, 2);
INSERT INTO favorites VALUES (560, 67, 1);
INSERT INTO favorites VALUES (560, 1, 3);
INSERT INTO favorites VALUES (560, 64, 4);
INSERT INTO favorites VALUES (561, 92, 1);
INSERT INTO favorites VALUES (561, 99, 2);
INSERT INTO favorites VALUES (562, 2, 1);
INSERT INTO favorites VALUES (564, 94, 1);
INSERT INTO favorites VALUES (564, 104, 2);
INSERT INTO favorites VALUES (564, 52, 4);
INSERT INTO favorites VALUES (564, 4, 3);
INSERT INTO favorites VALUES (565, 15, 1);
INSERT INTO favorites VALUES (567, 59, 1);
INSERT INTO favorites VALUES (567, 28, 2);
INSERT INTO favorites VALUES (568, 51, 3);
INSERT INTO favorites VALUES (568, 15, 1);
INSERT INTO favorites VALUES (568, 9, 2);
INSERT INTO favorites VALUES (568, 107, 4);
INSERT INTO favorites VALUES (569, 114, 1);
INSERT INTO favorites VALUES (570, 76, 1);
INSERT INTO favorites VALUES (570, 13, 2);
INSERT INTO favorites VALUES (571, 55, 2);
INSERT INTO favorites VALUES (571, 71, 1);
INSERT INTO favorites VALUES (573, 9, 1);
INSERT INTO favorites VALUES (573, 113, 2);
INSERT INTO favorites VALUES (574, 40, 1);
INSERT INTO favorites VALUES (574, 27, 3);
INSERT INTO favorites VALUES (574, 23, 4);
INSERT INTO favorites VALUES (574, 113, 2);
INSERT INTO favorites VALUES (575, 40, 3);
INSERT INTO favorites VALUES (575, 21, 2);
INSERT INTO favorites VALUES (575, 42, 1);
INSERT INTO favorites VALUES (575, 10, 4);
INSERT INTO favorites VALUES (576, 88, 2);
INSERT INTO favorites VALUES (576, 108, 1);
INSERT INTO favorites VALUES (576, 48, 3);
INSERT INTO favorites VALUES (576, 73, 5);
INSERT INTO favorites VALUES (576, 59, 4);
INSERT INTO favorites VALUES (576, 63, 6);
INSERT INTO favorites VALUES (577, 2, 1);
INSERT INTO favorites VALUES (577, 42, 2);
INSERT INTO favorites VALUES (578, 33, 1);
INSERT INTO favorites VALUES (579, 13, 1);
INSERT INTO favorites VALUES (579, 96, 4);
INSERT INTO favorites VALUES (579, 70, 2);
INSERT INTO favorites VALUES (579, 66, 3);
INSERT INTO favorites VALUES (579, 115, 5);
INSERT INTO favorites VALUES (579, 41, 6);
INSERT INTO favorites VALUES (580, 1, 1);
INSERT INTO favorites VALUES (580, 50, 2);
INSERT INTO favorites VALUES (581, 45, 1);
INSERT INTO favorites VALUES (581, 90, 2);
INSERT INTO favorites VALUES (581, 12, 3);
INSERT INTO favorites VALUES (582, 110, 5);
INSERT INTO favorites VALUES (582, 56, 4);
INSERT INTO favorites VALUES (582, 100, 2);
INSERT INTO favorites VALUES (582, 84, 3);
INSERT INTO favorites VALUES (582, 95, 1);
INSERT INTO favorites VALUES (583, 33, 2);
INSERT INTO favorites VALUES (583, 38, 1);
INSERT INTO favorites VALUES (583, 9, 3);
INSERT INTO favorites VALUES (584, 23, 1);
INSERT INTO favorites VALUES (585, 72, 4);
INSERT INTO favorites VALUES (585, 7, 1);
INSERT INTO favorites VALUES (585, 37, 3);
INSERT INTO favorites VALUES (585, 39, 2);
INSERT INTO favorites VALUES (586, 11, 1);
INSERT INTO favorites VALUES (586, 28, 2);
INSERT INTO favorites VALUES (586, 88, 3);
INSERT INTO favorites VALUES (586, 102, 4);
INSERT INTO favorites VALUES (587, 113, 2);
INSERT INTO favorites VALUES (587, 20, 1);
INSERT INTO favorites VALUES (588, 75, 2);
INSERT INTO favorites VALUES (588, 20, 3);
INSERT INTO favorites VALUES (588, 21, 1);
INSERT INTO favorites VALUES (589, 53, 2);
INSERT INTO favorites VALUES (589, 112, 1);
INSERT INTO favorites VALUES (589, 76, 3);
INSERT INTO favorites VALUES (590, 57, 2);
INSERT INTO favorites VALUES (590, 70, 1);
INSERT INTO favorites VALUES (591, 40, 1);
INSERT INTO favorites VALUES (591, 18, 2);
INSERT INTO favorites VALUES (592, 3, 1);
INSERT INTO favorites VALUES (593, 4, 3);
INSERT INTO favorites VALUES (593, 27, 1);
INSERT INTO favorites VALUES (593, 41, 4);
INSERT INTO favorites VALUES (593, 80, 2);
INSERT INTO favorites VALUES (593, 115, 5);
INSERT INTO favorites VALUES (594, 23, 2);
INSERT INTO favorites VALUES (594, 22, 1);
INSERT INTO favorites VALUES (595, 60, 1);
INSERT INTO favorites VALUES (596, 22, 2);
INSERT INTO favorites VALUES (596, 11, 1);
INSERT INTO favorites VALUES (596, 40, 3);
INSERT INTO favorites VALUES (596, 60, 4);
INSERT INTO favorites VALUES (597, 6, 1);
INSERT INTO favorites VALUES (598, 85, 1);
INSERT INTO favorites VALUES (598, 13, 3);
INSERT INTO favorites VALUES (598, 1, 2);
INSERT INTO favorites VALUES (598, 84, 4);
INSERT INTO favorites VALUES (599, 107, 1);
INSERT INTO favorites VALUES (599, 61, 2);
INSERT INTO favorites VALUES (599, 11, 3);
INSERT INTO favorites VALUES (599, 78, 4);
INSERT INTO favorites VALUES (600, 1, 1);
INSERT INTO favorites VALUES (601, 6, 1);
INSERT INTO favorites VALUES (601, 43, 2);
INSERT INTO favorites VALUES (601, 12, 3);
INSERT INTO favorites VALUES (602, 62, 1);
INSERT INTO favorites VALUES (602, 106, 2);
INSERT INTO favorites VALUES (602, 99, 3);
INSERT INTO favorites VALUES (602, 65, 5);
INSERT INTO favorites VALUES (602, 60, 4);
INSERT INTO favorites VALUES (603, 1, 2);
INSERT INTO favorites VALUES (603, 27, 1);
INSERT INTO favorites VALUES (604, 56, 1);
INSERT INTO favorites VALUES (604, 7, 2);
INSERT INTO favorites VALUES (604, 84, 3);
INSERT INTO favorites VALUES (605, 25, 1);
INSERT INTO favorites VALUES (605, 112, 2);
INSERT INTO favorites VALUES (606, 13, 2);
INSERT INTO favorites VALUES (606, 32, 1);
INSERT INTO favorites VALUES (606, 116, 3);
INSERT INTO favorites VALUES (607, 77, 3);
INSERT INTO favorites VALUES (607, 60, 2);
INSERT INTO favorites VALUES (607, 9, 1);
INSERT INTO favorites VALUES (607, 14, 4);
INSERT INTO favorites VALUES (608, 83, 1);
INSERT INTO favorites VALUES (608, 28, 2);
INSERT INTO favorites VALUES (608, 36, 3);
INSERT INTO favorites VALUES (609, 79, 2);
INSERT INTO favorites VALUES (609, 32, 1);
INSERT INTO favorites VALUES (609, 80, 3);
INSERT INTO favorites VALUES (610, 19, 1);
INSERT INTO favorites VALUES (611, 99, 2);
INSERT INTO favorites VALUES (611, 81, 1);
INSERT INTO favorites VALUES (611, 20, 3);
INSERT INTO favorites VALUES (611, 4, 4);
INSERT INTO favorites VALUES (611, 33, 6);
INSERT INTO favorites VALUES (611, 27, 5);
INSERT INTO favorites VALUES (612, 75, 1);
INSERT INTO favorites VALUES (613, 48, 1);
INSERT INTO favorites VALUES (614, 10, 2);
INSERT INTO favorites VALUES (614, 41, 1);
INSERT INTO favorites VALUES (615, 77, 1);
INSERT INTO favorites VALUES (615, 30, 2);
INSERT INTO favorites VALUES (616, 32, 2);
INSERT INTO favorites VALUES (616, 2, 1);
INSERT INTO favorites VALUES (616, 79, 3);
INSERT INTO favorites VALUES (616, 18, 4);
INSERT INTO favorites VALUES (617, 61, 1);
INSERT INTO favorites VALUES (617, 2, 2);
INSERT INTO favorites VALUES (617, 44, 3);
INSERT INTO favorites VALUES (617, 86, 4);
INSERT INTO favorites VALUES (618, 69, 1);
INSERT INTO favorites VALUES (618, 37, 2);
INSERT INTO favorites VALUES (619, 34, 1);
INSERT INTO favorites VALUES (619, 50, 2);
INSERT INTO favorites VALUES (621, 67, 1);
INSERT INTO favorites VALUES (621, 28, 2);
INSERT INTO favorites VALUES (622, 91, 1);
INSERT INTO favorites VALUES (622, 3, 2);
INSERT INTO favorites VALUES (623, 21, 1);
INSERT INTO favorites VALUES (623, 109, 4);
INSERT INTO favorites VALUES (623, 69, 3);
INSERT INTO favorites VALUES (623, 104, 2);
INSERT INTO favorites VALUES (623, 97, 5);
INSERT INTO favorites VALUES (624, 22, 1);
INSERT INTO favorites VALUES (624, 24, 2);
INSERT INTO favorites VALUES (625, 52, 1);
INSERT INTO favorites VALUES (625, 18, 2);
INSERT INTO favorites VALUES (625, 95, 3);
INSERT INTO favorites VALUES (625, 2, 4);
INSERT INTO favorites VALUES (626, 1, 1);
INSERT INTO favorites VALUES (626, 39, 3);
INSERT INTO favorites VALUES (626, 43, 4);
INSERT INTO favorites VALUES (626, 75, 2);
INSERT INTO favorites VALUES (627, 32, 2);
INSERT INTO favorites VALUES (627, 71, 3);
INSERT INTO favorites VALUES (627, 111, 1);
INSERT INTO favorites VALUES (627, 42, 4);
INSERT INTO favorites VALUES (627, 68, 6);
INSERT INTO favorites VALUES (627, 12, 5);
INSERT INTO favorites VALUES (628, 11, 2);
INSERT INTO favorites VALUES (628, 78, 1);
INSERT INTO favorites VALUES (628, 90, 5);
INSERT INTO favorites VALUES (628, 58, 4);
INSERT INTO favorites VALUES (628, 44, 3);
INSERT INTO favorites VALUES (630, 55, 2);
INSERT INTO favorites VALUES (630, 23, 1);
INSERT INTO favorites VALUES (630, 114, 3);
INSERT INTO favorites VALUES (630, 24, 4);
INSERT INTO favorites VALUES (630, 59, 5);
INSERT INTO favorites VALUES (631, 71, 1);
INSERT INTO favorites VALUES (631, 95, 3);
INSERT INTO favorites VALUES (631, 30, 2);
INSERT INTO favorites VALUES (631, 64, 6);
INSERT INTO favorites VALUES (631, 25, 5);
INSERT INTO favorites VALUES (631, 3, 4);
INSERT INTO favorites VALUES (632, 34, 1);
INSERT INTO favorites VALUES (633, 6, 1);
INSERT INTO favorites VALUES (633, 9, 2);
INSERT INTO favorites VALUES (634, 56, 1);
INSERT INTO favorites VALUES (634, 37, 2);
INSERT INTO favorites VALUES (635, 15, 1);
INSERT INTO favorites VALUES (635, 49, 5);
INSERT INTO favorites VALUES (635, 45, 3);
INSERT INTO favorites VALUES (635, 7, 2);
INSERT INTO favorites VALUES (635, 94, 4);
INSERT INTO favorites VALUES (635, 63, 6);
INSERT INTO favorites VALUES (636, 8, 1);
INSERT INTO favorites VALUES (636, 13, 2);
INSERT INTO favorites VALUES (637, 94, 1);
INSERT INTO favorites VALUES (637, 104, 3);
INSERT INTO favorites VALUES (637, 54, 4);
INSERT INTO favorites VALUES (637, 42, 2);
INSERT INTO favorites VALUES (638, 18, 1);
INSERT INTO favorites VALUES (639, 54, 1);
INSERT INTO favorites VALUES (639, 7, 3);
INSERT INTO favorites VALUES (639, 11, 2);
INSERT INTO favorites VALUES (640, 60, 1);
INSERT INTO favorites VALUES (640, 30, 2);
INSERT INTO favorites VALUES (640, 50, 3);
INSERT INTO favorites VALUES (641, 11, 2);
INSERT INTO favorites VALUES (641, 77, 1);
INSERT INTO favorites VALUES (643, 26, 2);
INSERT INTO favorites VALUES (643, 15, 1);
INSERT INTO favorites VALUES (644, 48, 1);
INSERT INTO favorites VALUES (644, 23, 2);
INSERT INTO favorites VALUES (646, 87, 2);
INSERT INTO favorites VALUES (646, 104, 3);
INSERT INTO favorites VALUES (646, 77, 1);
INSERT INTO favorites VALUES (646, 30, 4);
INSERT INTO favorites VALUES (647, 54, 1);
INSERT INTO favorites VALUES (648, 76, 1);
INSERT INTO favorites VALUES (648, 45, 2);
INSERT INTO favorites VALUES (652, 88, 1);
INSERT INTO favorites VALUES (652, 58, 2);
INSERT INTO favorites VALUES (652, 15, 3);
INSERT INTO favorites VALUES (652, 112, 4);
INSERT INTO favorites VALUES (653, 49, 3);
INSERT INTO favorites VALUES (653, 20, 1);
INSERT INTO favorites VALUES (653, 27, 2);
INSERT INTO favorites VALUES (654, 7, 1);
INSERT INTO favorites VALUES (654, 66, 3);
INSERT INTO favorites VALUES (654, 115, 2);
INSERT INTO favorites VALUES (654, 46, 4);
INSERT INTO favorites VALUES (655, 27, 1);
INSERT INTO favorites VALUES (655, 11, 4);
INSERT INTO favorites VALUES (655, 26, 3);
INSERT INTO favorites VALUES (655, 92, 2);
INSERT INTO favorites VALUES (655, 3, 6);
INSERT INTO favorites VALUES (655, 44, 5);
INSERT INTO favorites VALUES (655, 76, 7);
INSERT INTO favorites VALUES (656, 95, 2);
INSERT INTO favorites VALUES (656, 25, 1);
INSERT INTO favorites VALUES (656, 73, 3);
INSERT INTO favorites VALUES (657, 100, 1);
INSERT INTO favorites VALUES (657, 51, 2);
INSERT INTO favorites VALUES (658, 43, 1);
INSERT INTO favorites VALUES (658, 59, 2);
INSERT INTO favorites VALUES (658, 112, 3);
INSERT INTO favorites VALUES (659, 92, 1);
INSERT INTO favorites VALUES (660, 90, 3);
INSERT INTO favorites VALUES (660, 21, 2);
INSERT INTO favorites VALUES (660, 90, 1);
INSERT INTO favorites VALUES (660, 94, 4);
INSERT INTO favorites VALUES (660, 55, 5);
INSERT INTO favorites VALUES (661, 34, 1);
INSERT INTO favorites VALUES (661, 79, 5);
INSERT INTO favorites VALUES (661, 2, 6);
INSERT INTO favorites VALUES (661, 30, 4);
INSERT INTO favorites VALUES (661, 66, 3);
INSERT INTO favorites VALUES (661, 11, 2);
INSERT INTO favorites VALUES (662, 17, 1);
INSERT INTO favorites VALUES (662, 44, 3);
INSERT INTO favorites VALUES (662, 102, 4);
INSERT INTO favorites VALUES (662, 84, 2);
INSERT INTO favorites VALUES (663, 94, 1);
INSERT INTO favorites VALUES (663, 35, 2);
INSERT INTO favorites VALUES (664, 34, 1);
INSERT INTO favorites VALUES (664, 29, 2);
INSERT INTO favorites VALUES (664, 68, 3);
INSERT INTO favorites VALUES (665, 91, 1);
INSERT INTO favorites VALUES (665, 58, 2);
INSERT INTO favorites VALUES (665, 107, 3);
INSERT INTO favorites VALUES (665, 5, 4);
INSERT INTO favorites VALUES (666, 66, 2);
INSERT INTO favorites VALUES (666, 108, 1);
INSERT INTO favorites VALUES (666, 98, 9);
INSERT INTO favorites VALUES (666, 11, 4);
INSERT INTO favorites VALUES (666, 18, 3);
INSERT INTO favorites VALUES (666, 25, 7);
INSERT INTO favorites VALUES (666, 32, 6);
INSERT INTO favorites VALUES (666, 4, 5);
INSERT INTO favorites VALUES (666, 106, 8);
INSERT INTO favorites VALUES (668, 94, 2);
INSERT INTO favorites VALUES (668, 49, 1);
INSERT INTO favorites VALUES (669, 70, 1);
INSERT INTO favorites VALUES (669, 3, 2);
INSERT INTO favorites VALUES (669, 52, 3);
INSERT INTO favorites VALUES (670, 26, 2);
INSERT INTO favorites VALUES (670, 32, 1);
INSERT INTO favorites VALUES (671, 53, 2);
INSERT INTO favorites VALUES (671, 70, 1);
INSERT INTO favorites VALUES (672, 32, 2);
INSERT INTO favorites VALUES (672, 35, 1);
INSERT INTO favorites VALUES (672, 92, 3);
INSERT INTO favorites VALUES (673, 95, 1);
INSERT INTO favorites VALUES (674, 96, 3);
INSERT INTO favorites VALUES (674, 27, 2);
INSERT INTO favorites VALUES (674, 7, 1);
INSERT INTO favorites VALUES (674, 54, 4);
INSERT INTO favorites VALUES (675, 1, 1);
INSERT INTO favorites VALUES (675, 91, 2);
INSERT INTO favorites VALUES (676, 41, 1);
INSERT INTO favorites VALUES (677, 45, 1);
INSERT INTO favorites VALUES (678, 9, 1);
INSERT INTO favorites VALUES (679, 88, 3);
INSERT INTO favorites VALUES (679, 35, 2);
INSERT INTO favorites VALUES (679, 6, 1);
INSERT INTO favorites VALUES (679, 67, 4);
INSERT INTO favorites VALUES (680, 42, 3);
INSERT INTO favorites VALUES (680, 92, 1);
INSERT INTO favorites VALUES (680, 107, 2);
INSERT INTO favorites VALUES (680, 32, 4);
INSERT INTO favorites VALUES (681, 60, 2);
INSERT INTO favorites VALUES (681, 103, 1);
INSERT INTO favorites VALUES (681, 87, 3);
INSERT INTO favorites VALUES (681, 3, 5);
INSERT INTO favorites VALUES (681, 91, 4);
INSERT INTO favorites VALUES (682, 80, 2);
INSERT INTO favorites VALUES (682, 81, 1);
INSERT INTO favorites VALUES (682, 8, 4);
INSERT INTO favorites VALUES (682, 80, 3);
INSERT INTO favorites VALUES (682, 49, 5);
INSERT INTO favorites VALUES (682, 19, 6);
INSERT INTO favorites VALUES (683, 111, 2);
INSERT INTO favorites VALUES (683, 37, 1);
INSERT INTO favorites VALUES (684, 55, 2);
INSERT INTO favorites VALUES (684, 111, 1);
INSERT INTO favorites VALUES (684, 22, 5);
INSERT INTO favorites VALUES (684, 23, 3);
INSERT INTO favorites VALUES (684, 31, 4);
INSERT INTO favorites VALUES (685, 34, 1);
INSERT INTO favorites VALUES (685, 71, 2);
INSERT INTO favorites VALUES (686, 101, 2);
INSERT INTO favorites VALUES (686, 89, 3);
INSERT INTO favorites VALUES (686, 90, 1);
INSERT INTO favorites VALUES (686, 24, 6);
INSERT INTO favorites VALUES (686, 12, 5);
INSERT INTO favorites VALUES (686, 10, 4);
INSERT INTO favorites VALUES (687, 110, 1);
INSERT INTO favorites VALUES (687, 10, 2);
INSERT INTO favorites VALUES (687, 88, 3);
INSERT INTO favorites VALUES (687, 39, 4);
INSERT INTO favorites VALUES (687, 63, 5);
INSERT INTO favorites VALUES (688, 21, 1);
INSERT INTO favorites VALUES (689, 93, 1);
INSERT INTO favorites VALUES (689, 66, 3);
INSERT INTO favorites VALUES (689, 26, 2);
INSERT INTO favorites VALUES (690, 52, 4);
INSERT INTO favorites VALUES (690, 89, 3);
INSERT INTO favorites VALUES (690, 10, 2);
INSERT INTO favorites VALUES (690, 58, 1);
INSERT INTO favorites VALUES (692, 1, 1);
INSERT INTO favorites VALUES (692, 106, 3);
INSERT INTO favorites VALUES (692, 14, 2);
INSERT INTO favorites VALUES (692, 20, 4);
INSERT INTO favorites VALUES (693, 102, 1);
INSERT INTO favorites VALUES (693, 104, 3);
INSERT INTO favorites VALUES (693, 45, 2);
INSERT INTO favorites VALUES (694, 115, 1);
INSERT INTO favorites VALUES (694, 82, 2);
INSERT INTO favorites VALUES (694, 49, 5);
INSERT INTO favorites VALUES (694, 81, 4);
INSERT INTO favorites VALUES (694, 43, 3);
INSERT INTO favorites VALUES (694, 42, 6);
INSERT INTO favorites VALUES (695, 54, 2);
INSERT INTO favorites VALUES (695, 11, 1);
INSERT INTO favorites VALUES (695, 22, 3);
INSERT INTO favorites VALUES (695, 96, 4);
INSERT INTO favorites VALUES (695, 37, 5);
INSERT INTO favorites VALUES (696, 66, 1);
INSERT INTO favorites VALUES (698, 59, 2);
INSERT INTO favorites VALUES (698, 80, 1);
INSERT INTO favorites VALUES (698, 59, 3);
INSERT INTO favorites VALUES (698, 50, 4);
INSERT INTO favorites VALUES (699, 45, 2);
INSERT INTO favorites VALUES (699, 38, 4);
INSERT INTO favorites VALUES (699, 53, 1);
INSERT INTO favorites VALUES (699, 40, 3);
INSERT INTO favorites VALUES (699, 18, 5);
INSERT INTO favorites VALUES (700, 11, 1);
INSERT INTO favorites VALUES (700, 9, 2);
INSERT INTO favorites VALUES (700, 99, 3);
INSERT INTO favorites VALUES (700, 98, 4);
INSERT INTO favorites VALUES (701, 42, 1);
INSERT INTO favorites VALUES (702, 60, 3);
INSERT INTO favorites VALUES (702, 23, 1);
INSERT INTO favorites VALUES (702, 5, 2);
INSERT INTO favorites VALUES (703, 65, 1);
INSERT INTO favorites VALUES (703, 3, 2);
INSERT INTO favorites VALUES (705, 57, 2);
INSERT INTO favorites VALUES (705, 71, 1);
INSERT INTO favorites VALUES (705, 80, 5);
INSERT INTO favorites VALUES (705, 15, 4);
INSERT INTO favorites VALUES (705, 50, 3);
INSERT INTO favorites VALUES (706, 9, 1);
INSERT INTO favorites VALUES (706, 50, 2);
INSERT INTO favorites VALUES (707, 9, 1);
INSERT INTO favorites VALUES (707, 97, 3);
INSERT INTO favorites VALUES (707, 80, 2);
INSERT INTO favorites VALUES (707, 60, 5);
INSERT INTO favorites VALUES (707, 113, 4);
INSERT INTO favorites VALUES (708, 53, 1);
INSERT INTO favorites VALUES (708, 103, 2);
INSERT INTO favorites VALUES (709, 7, 1);
INSERT INTO favorites VALUES (709, 77, 2);
INSERT INTO favorites VALUES (711, 12, 1);
INSERT INTO favorites VALUES (712, 44, 2);
INSERT INTO favorites VALUES (712, 115, 1);
INSERT INTO favorites VALUES (713, 28, 1);
INSERT INTO favorites VALUES (713, 21, 3);
INSERT INTO favorites VALUES (713, 109, 2);
INSERT INTO favorites VALUES (714, 10, 2);
INSERT INTO favorites VALUES (714, 110, 1);
INSERT INTO favorites VALUES (715, 31, 2);
INSERT INTO favorites VALUES (715, 54, 1);
INSERT INTO favorites VALUES (715, 17, 3);
INSERT INTO favorites VALUES (716, 36, 1);
INSERT INTO favorites VALUES (716, 16, 2);
INSERT INTO favorites VALUES (716, 51, 3);
INSERT INTO favorites VALUES (717, 1, 1);
INSERT INTO favorites VALUES (717, 85, 2);
INSERT INTO favorites VALUES (718, 66, 1);
INSERT INTO favorites VALUES (719, 28, 1);
INSERT INTO favorites VALUES (719, 103, 2);
INSERT INTO favorites VALUES (720, 69, 1);
INSERT INTO favorites VALUES (720, 46, 2);
INSERT INTO favorites VALUES (720, 47, 3);
INSERT INTO favorites VALUES (721, 23, 1);
INSERT INTO favorites VALUES (721, 45, 2);
INSERT INTO favorites VALUES (722, 96, 1);
INSERT INTO favorites VALUES (723, 69, 1);
INSERT INTO favorites VALUES (723, 107, 2);
INSERT INTO favorites VALUES (724, 65, 2);
INSERT INTO favorites VALUES (724, 45, 1);
INSERT INTO favorites VALUES (724, 111, 3);
INSERT INTO favorites VALUES (724, 92, 4);
INSERT INTO favorites VALUES (725, 116, 1);
INSERT INTO favorites VALUES (725, 115, 2);
INSERT INTO favorites VALUES (726, 68, 1);
INSERT INTO favorites VALUES (727, 70, 1);
INSERT INTO favorites VALUES (727, 90, 3);
INSERT INTO favorites VALUES (727, 85, 2);
INSERT INTO favorites VALUES (727, 12, 4);
INSERT INTO favorites VALUES (728, 2, 1);
INSERT INTO favorites VALUES (728, 79, 2);
INSERT INTO favorites VALUES (729, 105, 1);
INSERT INTO favorites VALUES (729, 85, 6);
INSERT INTO favorites VALUES (729, 21, 5);
INSERT INTO favorites VALUES (729, 17, 3);
INSERT INTO favorites VALUES (729, 71, 4);
INSERT INTO favorites VALUES (729, 12, 2);
INSERT INTO favorites VALUES (729, 88, 7);
INSERT INTO favorites VALUES (729, 96, 8);
INSERT INTO favorites VALUES (730, 49, 1);
INSERT INTO favorites VALUES (730, 77, 3);
INSERT INTO favorites VALUES (730, 68, 2);
INSERT INTO favorites VALUES (730, 116, 7);
INSERT INTO favorites VALUES (730, 12, 5);
INSERT INTO favorites VALUES (730, 60, 4);
INSERT INTO favorites VALUES (730, 68, 6);
INSERT INTO favorites VALUES (731, 17, 1);
INSERT INTO favorites VALUES (731, 116, 4);
INSERT INTO favorites VALUES (731, 111, 3);
INSERT INTO favorites VALUES (731, 35, 2);
INSERT INTO favorites VALUES (732, 29, 1);
INSERT INTO favorites VALUES (732, 12, 2);
INSERT INTO favorites VALUES (732, 69, 3);
INSERT INTO favorites VALUES (733, 14, 2);
INSERT INTO favorites VALUES (733, 25, 1);
INSERT INTO favorites VALUES (733, 48, 3);
INSERT INTO favorites VALUES (735, 37, 1);
INSERT INTO favorites VALUES (735, 62, 2);
INSERT INTO favorites VALUES (736, 61, 1);
INSERT INTO favorites VALUES (736, 2, 2);
INSERT INTO favorites VALUES (736, 59, 3);
INSERT INTO favorites VALUES (737, 18, 1);
INSERT INTO favorites VALUES (739, 43, 1);
INSERT INTO favorites VALUES (739, 24, 2);
INSERT INTO favorites VALUES (739, 27, 4);
INSERT INTO favorites VALUES (739, 41, 3);
INSERT INTO favorites VALUES (739, 36, 6);
INSERT INTO favorites VALUES (739, 86, 5);
INSERT INTO favorites VALUES (740, 35, 1);
INSERT INTO favorites VALUES (740, 66, 2);
INSERT INTO favorites VALUES (740, 13, 3);
INSERT INTO favorites VALUES (741, 41, 1);
INSERT INTO favorites VALUES (741, 40, 2);
INSERT INTO favorites VALUES (742, 60, 1);
INSERT INTO favorites VALUES (742, 88, 2);
INSERT INTO favorites VALUES (742, 65, 3);
INSERT INTO favorites VALUES (743, 39, 1);
INSERT INTO favorites VALUES (743, 81, 2);
INSERT INTO favorites VALUES (743, 93, 3);
INSERT INTO favorites VALUES (744, 25, 2);
INSERT INTO favorites VALUES (744, 13, 3);
INSERT INTO favorites VALUES (744, 48, 1);
INSERT INTO favorites VALUES (744, 19, 4);
INSERT INTO favorites VALUES (745, 2, 1);
INSERT INTO favorites VALUES (745, 96, 2);
INSERT INTO favorites VALUES (746, 24, 2);
INSERT INTO favorites VALUES (746, 24, 1);
INSERT INTO favorites VALUES (747, 55, 1);
INSERT INTO favorites VALUES (747, 37, 2);
INSERT INTO favorites VALUES (748, 23, 2);
INSERT INTO favorites VALUES (748, 56, 1);
INSERT INTO favorites VALUES (748, 80, 4);
INSERT INTO favorites VALUES (748, 43, 3);
INSERT INTO favorites VALUES (749, 54, 1);
INSERT INTO favorites VALUES (749, 16, 4);
INSERT INTO favorites VALUES (749, 44, 3);
INSERT INTO favorites VALUES (749, 8, 2);
INSERT INTO favorites VALUES (749, 26, 5);
INSERT INTO favorites VALUES (750, 26, 1);
INSERT INTO favorites VALUES (750, 94, 2);
INSERT INTO favorites VALUES (751, 57, 1);
INSERT INTO favorites VALUES (752, 29, 2);
INSERT INTO favorites VALUES (752, 80, 1);
INSERT INTO favorites VALUES (752, 73, 3);
INSERT INTO favorites VALUES (753, 45, 1);
INSERT INTO favorites VALUES (754, 37, 1);
INSERT INTO favorites VALUES (754, 2, 2);
INSERT INTO favorites VALUES (755, 68, 1);
INSERT INTO favorites VALUES (755, 29, 2);
INSERT INTO favorites VALUES (757, 111, 1);
INSERT INTO favorites VALUES (759, 23, 4);
INSERT INTO favorites VALUES (759, 29, 3);
INSERT INTO favorites VALUES (759, 93, 1);
INSERT INTO favorites VALUES (759, 49, 2);
INSERT INTO favorites VALUES (759, 39, 7);
INSERT INTO favorites VALUES (759, 58, 5);
INSERT INTO favorites VALUES (759, 24, 6);
INSERT INTO favorites VALUES (761, 51, 2);
INSERT INTO favorites VALUES (761, 97, 1);
INSERT INTO favorites VALUES (761, 3, 3);
INSERT INTO favorites VALUES (762, 116, 2);
INSERT INTO favorites VALUES (762, 24, 1);
INSERT INTO favorites VALUES (763, 54, 2);
INSERT INTO favorites VALUES (763, 19, 1);
INSERT INTO favorites VALUES (763, 34, 3);
INSERT INTO favorites VALUES (764, 20, 1);
INSERT INTO favorites VALUES (765, 42, 1);
INSERT INTO favorites VALUES (766, 47, 1);
INSERT INTO favorites VALUES (766, 102, 2);
INSERT INTO favorites VALUES (766, 77, 3);
INSERT INTO favorites VALUES (766, 65, 4);
INSERT INTO favorites VALUES (767, 100, 1);
INSERT INTO favorites VALUES (768, 55, 2);
INSERT INTO favorites VALUES (768, 66, 1);
INSERT INTO favorites VALUES (769, 93, 1);
INSERT INTO favorites VALUES (769, 93, 2);
INSERT INTO favorites VALUES (769, 45, 4);
INSERT INTO favorites VALUES (769, 41, 3);
INSERT INTO favorites VALUES (769, 101, 6);
INSERT INTO favorites VALUES (769, 51, 5);
INSERT INTO favorites VALUES (770, 5, 1);
INSERT INTO favorites VALUES (770, 13, 3);
INSERT INTO favorites VALUES (770, 10, 2);
INSERT INTO favorites VALUES (771, 26, 1);
INSERT INTO favorites VALUES (771, 106, 2);
INSERT INTO favorites VALUES (771, 111, 3);
INSERT INTO favorites VALUES (771, 45, 4);
INSERT INTO favorites VALUES (771, 33, 5);
INSERT INTO favorites VALUES (772, 19, 1);
INSERT INTO favorites VALUES (773, 39, 1);
INSERT INTO favorites VALUES (773, 11, 2);
INSERT INTO favorites VALUES (774, 55, 1);
INSERT INTO favorites VALUES (775, 44, 1);
INSERT INTO favorites VALUES (776, 14, 1);
INSERT INTO favorites VALUES (777, 69, 4);
INSERT INTO favorites VALUES (777, 51, 1);
INSERT INTO favorites VALUES (777, 47, 6);
INSERT INTO favorites VALUES (777, 22, 5);
INSERT INTO favorites VALUES (777, 19, 3);
INSERT INTO favorites VALUES (777, 8, 2);
INSERT INTO favorites VALUES (777, 24, 8);
INSERT INTO favorites VALUES (777, 94, 7);
INSERT INTO favorites VALUES (778, 89, 3);
INSERT INTO favorites VALUES (778, 36, 1);
INSERT INTO favorites VALUES (778, 25, 2);
INSERT INTO favorites VALUES (779, 11, 1);
INSERT INTO favorites VALUES (779, 10, 2);
INSERT INTO favorites VALUES (780, 66, 1);
INSERT INTO favorites VALUES (780, 11, 2);
INSERT INTO favorites VALUES (780, 36, 3);
INSERT INTO favorites VALUES (780, 9, 4);
INSERT INTO favorites VALUES (780, 48, 5);
INSERT INTO favorites VALUES (781, 114, 1);
INSERT INTO favorites VALUES (781, 107, 2);
INSERT INTO favorites VALUES (781, 53, 3);
INSERT INTO favorites VALUES (781, 67, 4);
INSERT INTO favorites VALUES (782, 16, 1);
INSERT INTO favorites VALUES (782, 7, 2);
INSERT INTO favorites VALUES (782, 106, 3);
INSERT INTO favorites VALUES (783, 7, 3);
INSERT INTO favorites VALUES (783, 38, 1);
INSERT INTO favorites VALUES (783, 60, 2);
INSERT INTO favorites VALUES (783, 50, 4);
INSERT INTO favorites VALUES (785, 1, 1);
INSERT INTO favorites VALUES (787, 17, 1);
INSERT INTO favorites VALUES (789, 91, 2);
INSERT INTO favorites VALUES (789, 27, 1);
INSERT INTO favorites VALUES (789, 67, 3);
INSERT INTO favorites VALUES (789, 67, 4);
INSERT INTO favorites VALUES (790, 77, 2);
INSERT INTO favorites VALUES (790, 30, 1);
INSERT INTO favorites VALUES (790, 31, 3);
INSERT INTO favorites VALUES (790, 55, 4);
INSERT INTO favorites VALUES (790, 37, 5);
INSERT INTO favorites VALUES (791, 66, 3);
INSERT INTO favorites VALUES (791, 77, 2);
INSERT INTO favorites VALUES (791, 58, 1);
INSERT INTO favorites VALUES (792, 62, 1);
INSERT INTO favorites VALUES (793, 88, 1);
INSERT INTO favorites VALUES (794, 80, 1);
INSERT INTO favorites VALUES (794, 54, 2);
INSERT INTO favorites VALUES (795, 115, 1);
INSERT INTO favorites VALUES (796, 21, 3);
INSERT INTO favorites VALUES (796, 30, 1);
INSERT INTO favorites VALUES (796, 35, 2);
INSERT INTO favorites VALUES (796, 31, 4);
INSERT INTO favorites VALUES (797, 15, 1);
INSERT INTO favorites VALUES (798, 65, 1);
INSERT INTO favorites VALUES (798, 65, 2);
INSERT INTO favorites VALUES (798, 8, 3);
INSERT INTO favorites VALUES (799, 113, 1);
INSERT INTO favorites VALUES (799, 9, 3);
INSERT INTO favorites VALUES (799, 9, 2);
INSERT INTO favorites VALUES (800, 95, 1);
INSERT INTO favorites VALUES (800, 80, 2);
INSERT INTO favorites VALUES (800, 99, 3);
INSERT INTO favorites VALUES (801, 64, 2);
INSERT INTO favorites VALUES (801, 91, 1);
INSERT INTO favorites VALUES (801, 91, 3);
INSERT INTO favorites VALUES (802, 46, 1);
INSERT INTO favorites VALUES (802, 73, 2);
INSERT INTO favorites VALUES (802, 44, 3);
INSERT INTO favorites VALUES (803, 21, 2);
INSERT INTO favorites VALUES (803, 114, 1);
INSERT INTO favorites VALUES (803, 12, 3);
INSERT INTO favorites VALUES (804, 22, 1);
INSERT INTO favorites VALUES (805, 17, 1);
INSERT INTO favorites VALUES (805, 55, 3);
INSERT INTO favorites VALUES (805, 26, 2);
INSERT INTO favorites VALUES (806, 8, 1);
INSERT INTO favorites VALUES (806, 81, 2);
INSERT INTO favorites VALUES (806, 97, 3);
INSERT INTO favorites VALUES (808, 72, 1);
INSERT INTO favorites VALUES (808, 49, 2);
INSERT INTO favorites VALUES (808, 44, 3);
INSERT INTO favorites VALUES (810, 56, 1);
INSERT INTO favorites VALUES (810, 45, 2);
INSERT INTO favorites VALUES (810, 24, 4);
INSERT INTO favorites VALUES (810, 84, 3);
INSERT INTO favorites VALUES (811, 108, 1);
INSERT INTO favorites VALUES (811, 18, 2);
INSERT INTO favorites VALUES (812, 46, 2);
INSERT INTO favorites VALUES (812, 90, 1);
INSERT INTO favorites VALUES (812, 28, 4);
INSERT INTO favorites VALUES (812, 46, 3);
INSERT INTO favorites VALUES (813, 8, 2);
INSERT INTO favorites VALUES (813, 5, 1);
INSERT INTO favorites VALUES (813, 42, 3);
INSERT INTO favorites VALUES (813, 103, 4);
INSERT INTO favorites VALUES (813, 3, 5);
INSERT INTO favorites VALUES (814, 22, 1);
INSERT INTO favorites VALUES (815, 70, 1);
INSERT INTO favorites VALUES (816, 25, 1);
INSERT INTO favorites VALUES (817, 72, 1);
INSERT INTO favorites VALUES (818, 52, 2);
INSERT INTO favorites VALUES (818, 71, 1);
INSERT INTO favorites VALUES (819, 88, 1);
INSERT INTO favorites VALUES (820, 11, 2);
INSERT INTO favorites VALUES (820, 7, 1);
INSERT INTO favorites VALUES (821, 65, 1);
INSERT INTO favorites VALUES (821, 43, 2);
INSERT INTO favorites VALUES (821, 45, 3);
INSERT INTO favorites VALUES (821, 113, 5);
INSERT INTO favorites VALUES (821, 67, 4);
INSERT INTO favorites VALUES (822, 82, 1);
INSERT INTO favorites VALUES (822, 35, 3);
INSERT INTO favorites VALUES (822, 13, 2);
INSERT INTO favorites VALUES (823, 64, 1);
INSERT INTO favorites VALUES (824, 18, 2);
INSERT INTO favorites VALUES (824, 89, 1);
INSERT INTO favorites VALUES (824, 76, 3);
INSERT INTO favorites VALUES (824, 28, 4);
INSERT INTO favorites VALUES (825, 108, 2);
INSERT INTO favorites VALUES (825, 56, 1);
INSERT INTO favorites VALUES (825, 63, 3);
INSERT INTO favorites VALUES (826, 32, 1);
INSERT INTO favorites VALUES (826, 113, 2);
INSERT INTO favorites VALUES (827, 104, 3);
INSERT INTO favorites VALUES (827, 14, 1);
INSERT INTO favorites VALUES (827, 13, 2);
INSERT INTO favorites VALUES (827, 15, 4);
INSERT INTO favorites VALUES (828, 80, 2);
INSERT INTO favorites VALUES (828, 50, 1);
INSERT INTO favorites VALUES (828, 69, 3);
INSERT INTO favorites VALUES (829, 65, 1);
INSERT INTO favorites VALUES (829, 22, 2);
INSERT INTO favorites VALUES (829, 5, 7);
INSERT INTO favorites VALUES (829, 51, 6);
INSERT INTO favorites VALUES (829, 108, 4);
INSERT INTO favorites VALUES (829, 7, 3);
INSERT INTO favorites VALUES (829, 54, 5);
INSERT INTO favorites VALUES (830, 6, 1);
INSERT INTO favorites VALUES (831, 16, 1);
INSERT INTO favorites VALUES (831, 1, 5);
INSERT INTO favorites VALUES (831, 12, 3);
INSERT INTO favorites VALUES (831, 30, 2);
INSERT INTO favorites VALUES (831, 66, 4);
INSERT INTO favorites VALUES (832, 45, 2);
INSERT INTO favorites VALUES (832, 67, 3);
INSERT INTO favorites VALUES (832, 101, 1);
INSERT INTO favorites VALUES (832, 92, 5);
INSERT INTO favorites VALUES (832, 64, 6);
INSERT INTO favorites VALUES (832, 35, 4);
INSERT INTO favorites VALUES (833, 78, 2);
INSERT INTO favorites VALUES (833, 62, 3);
INSERT INTO favorites VALUES (833, 83, 1);
INSERT INTO favorites VALUES (833, 93, 4);
INSERT INTO favorites VALUES (833, 59, 8);
INSERT INTO favorites VALUES (833, 19, 6);
INSERT INTO favorites VALUES (833, 35, 5);
INSERT INTO favorites VALUES (833, 65, 7);
INSERT INTO favorites VALUES (834, 90, 1);
INSERT INTO favorites VALUES (834, 78, 2);
INSERT INTO favorites VALUES (835, 72, 1);
INSERT INTO favorites VALUES (835, 28, 2);
INSERT INTO favorites VALUES (836, 89, 1);
INSERT INTO favorites VALUES (837, 8, 1);
INSERT INTO favorites VALUES (837, 98, 3);
INSERT INTO favorites VALUES (837, 23, 2);
INSERT INTO favorites VALUES (838, 13, 1);
INSERT INTO favorites VALUES (838, 53, 2);
INSERT INTO favorites VALUES (838, 90, 3);
INSERT INTO favorites VALUES (839, 115, 1);
INSERT INTO favorites VALUES (839, 23, 2);
INSERT INTO favorites VALUES (840, 104, 1);
INSERT INTO favorites VALUES (840, 37, 2);
INSERT INTO favorites VALUES (841, 73, 1);
INSERT INTO favorites VALUES (841, 71, 2);
INSERT INTO favorites VALUES (841, 28, 3);
INSERT INTO favorites VALUES (842, 91, 2);
INSERT INTO favorites VALUES (842, 55, 1);
INSERT INTO favorites VALUES (842, 28, 3);
INSERT INTO favorites VALUES (842, 63, 4);
INSERT INTO favorites VALUES (843, 52, 1);
INSERT INTO favorites VALUES (844, 46, 1);
INSERT INTO favorites VALUES (845, 2, 1);
INSERT INTO favorites VALUES (845, 74, 2);
INSERT INTO favorites VALUES (846, 114, 1);
INSERT INTO favorites VALUES (846, 49, 2);
INSERT INTO favorites VALUES (846, 50, 3);
INSERT INTO favorites VALUES (847, 90, 1);
INSERT INTO favorites VALUES (847, 98, 2);
INSERT INTO favorites VALUES (848, 103, 1);
INSERT INTO favorites VALUES (848, 75, 4);
INSERT INTO favorites VALUES (848, 88, 2);
INSERT INTO favorites VALUES (848, 48, 3);
INSERT INTO favorites VALUES (849, 29, 2);
INSERT INTO favorites VALUES (849, 56, 3);
INSERT INTO favorites VALUES (849, 98, 1);
INSERT INTO favorites VALUES (849, 82, 4);
INSERT INTO favorites VALUES (849, 48, 5);
INSERT INTO favorites VALUES (851, 28, 1);
INSERT INTO favorites VALUES (851, 95, 2);
INSERT INTO favorites VALUES (852, 115, 1);
INSERT INTO favorites VALUES (852, 48, 2);
INSERT INTO favorites VALUES (852, 62, 3);
INSERT INTO favorites VALUES (853, 8, 2);
INSERT INTO favorites VALUES (853, 80, 1);
INSERT INTO favorites VALUES (853, 9, 3);
INSERT INTO favorites VALUES (853, 35, 4);
INSERT INTO favorites VALUES (853, 90, 5);
INSERT INTO favorites VALUES (855, 61, 2);
INSERT INTO favorites VALUES (855, 113, 1);
INSERT INTO favorites VALUES (855, 67, 3);
INSERT INTO favorites VALUES (856, 72, 1);
INSERT INTO favorites VALUES (856, 18, 2);
INSERT INTO favorites VALUES (856, 52, 3);
INSERT INTO favorites VALUES (857, 14, 1);
INSERT INTO favorites VALUES (858, 111, 1);
INSERT INTO favorites VALUES (858, 107, 2);
INSERT INTO favorites VALUES (859, 46, 1);
INSERT INTO favorites VALUES (859, 3, 2);
INSERT INTO favorites VALUES (860, 26, 2);
INSERT INTO favorites VALUES (860, 113, 1);
INSERT INTO favorites VALUES (860, 35, 3);
INSERT INTO favorites VALUES (862, 71, 1);
INSERT INTO favorites VALUES (862, 26, 2);
INSERT INTO favorites VALUES (863, 8, 1);
INSERT INTO favorites VALUES (863, 38, 2);
INSERT INTO favorites VALUES (863, 81, 3);
INSERT INTO favorites VALUES (864, 59, 1);
INSERT INTO favorites VALUES (865, 88, 1);
INSERT INTO favorites VALUES (865, 9, 3);
INSERT INTO favorites VALUES (865, 81, 2);
INSERT INTO favorites VALUES (866, 51, 1);
INSERT INTO favorites VALUES (866, 67, 2);
INSERT INTO favorites VALUES (867, 82, 1);
INSERT INTO favorites VALUES (867, 65, 2);
INSERT INTO favorites VALUES (867, 116, 3);
INSERT INTO favorites VALUES (868, 99, 2);
INSERT INTO favorites VALUES (868, 102, 1);
INSERT INTO favorites VALUES (869, 67, 1);
INSERT INTO favorites VALUES (870, 2, 1);
INSERT INTO favorites VALUES (871, 21, 1);
INSERT INTO favorites VALUES (871, 54, 2);
INSERT INTO favorites VALUES (871, 24, 3);
INSERT INTO favorites VALUES (871, 8, 4);
INSERT INTO favorites VALUES (872, 63, 1);
INSERT INTO favorites VALUES (872, 65, 2);
INSERT INTO favorites VALUES (873, 52, 3);
INSERT INTO favorites VALUES (873, 75, 5);
INSERT INTO favorites VALUES (873, 74, 4);
INSERT INTO favorites VALUES (873, 9, 2);
INSERT INTO favorites VALUES (873, 41, 1);
INSERT INTO favorites VALUES (873, 81, 6);
INSERT INTO favorites VALUES (873, 89, 7);
INSERT INTO favorites VALUES (874, 17, 1);
INSERT INTO favorites VALUES (874, 111, 2);
INSERT INTO favorites VALUES (874, 110, 4);
INSERT INTO favorites VALUES (874, 50, 3);
INSERT INTO favorites VALUES (875, 72, 3);
INSERT INTO favorites VALUES (875, 106, 1);
INSERT INTO favorites VALUES (875, 102, 2);
INSERT INTO favorites VALUES (876, 107, 1);
INSERT INTO favorites VALUES (876, 96, 6);
INSERT INTO favorites VALUES (876, 57, 5);
INSERT INTO favorites VALUES (876, 114, 4);
INSERT INTO favorites VALUES (876, 8, 3);
INSERT INTO favorites VALUES (876, 80, 2);
INSERT INTO favorites VALUES (876, 94, 7);
INSERT INTO favorites VALUES (877, 9, 3);
INSERT INTO favorites VALUES (877, 78, 2);
INSERT INTO favorites VALUES (877, 27, 1);
INSERT INTO favorites VALUES (877, 14, 4);
INSERT INTO favorites VALUES (878, 2, 3);
INSERT INTO favorites VALUES (878, 26, 1);
INSERT INTO favorites VALUES (878, 6, 2);
INSERT INTO favorites VALUES (878, 107, 4);
INSERT INTO favorites VALUES (880, 76, 2);
INSERT INTO favorites VALUES (880, 98, 1);
INSERT INTO favorites VALUES (880, 7, 3);
INSERT INTO favorites VALUES (880, 93, 5);
INSERT INTO favorites VALUES (880, 4, 4);
INSERT INTO favorites VALUES (880, 35, 6);
INSERT INTO favorites VALUES (882, 112, 1);
INSERT INTO favorites VALUES (882, 4, 2);
INSERT INTO favorites VALUES (882, 102, 3);
INSERT INTO favorites VALUES (882, 80, 4);
INSERT INTO favorites VALUES (882, 40, 5);
INSERT INTO favorites VALUES (883, 94, 1);
INSERT INTO favorites VALUES (884, 100, 1);
INSERT INTO favorites VALUES (884, 78, 2);
INSERT INTO favorites VALUES (884, 89, 3);
INSERT INTO favorites VALUES (884, 95, 4);
INSERT INTO favorites VALUES (886, 73, 3);
INSERT INTO favorites VALUES (886, 15, 2);
INSERT INTO favorites VALUES (886, 24, 1);
INSERT INTO favorites VALUES (886, 17, 4);
INSERT INTO favorites VALUES (886, 87, 5);
INSERT INTO favorites VALUES (888, 1, 1);
INSERT INTO favorites VALUES (890, 111, 1);
INSERT INTO favorites VALUES (890, 4, 2);
INSERT INTO favorites VALUES (890, 22, 4);
INSERT INTO favorites VALUES (890, 98, 3);
INSERT INTO favorites VALUES (890, 91, 6);
INSERT INTO favorites VALUES (890, 8, 5);
INSERT INTO favorites VALUES (892, 77, 2);
INSERT INTO favorites VALUES (892, 102, 1);
INSERT INTO favorites VALUES (892, 97, 3);
INSERT INTO favorites VALUES (893, 83, 1);
INSERT INTO favorites VALUES (893, 107, 2);
INSERT INTO favorites VALUES (893, 102, 3);
INSERT INTO favorites VALUES (894, 99, 1);
INSERT INTO favorites VALUES (894, 32, 2);
INSERT INTO favorites VALUES (895, 94, 1);
INSERT INTO favorites VALUES (895, 22, 2);
INSERT INTO favorites VALUES (895, 97, 4);
INSERT INTO favorites VALUES (895, 90, 3);
INSERT INTO favorites VALUES (896, 78, 1);
INSERT INTO favorites VALUES (896, 114, 3);
INSERT INTO favorites VALUES (896, 45, 2);
INSERT INTO favorites VALUES (897, 65, 1);
INSERT INTO favorites VALUES (898, 71, 1);
INSERT INTO favorites VALUES (898, 45, 4);
INSERT INTO favorites VALUES (898, 24, 3);
INSERT INTO favorites VALUES (898, 24, 2);
INSERT INTO favorites VALUES (899, 106, 1);
INSERT INTO favorites VALUES (899, 13, 2);
INSERT INTO favorites VALUES (899, 72, 4);
INSERT INTO favorites VALUES (899, 73, 3);
INSERT INTO favorites VALUES (899, 39, 5);
INSERT INTO favorites VALUES (900, 43, 2);
INSERT INTO favorites VALUES (900, 35, 1);
INSERT INTO favorites VALUES (900, 59, 3);
INSERT INTO favorites VALUES (900, 83, 4);
INSERT INTO favorites VALUES (902, 4, 1);
INSERT INTO favorites VALUES (902, 32, 5);
INSERT INTO favorites VALUES (902, 90, 3);
INSERT INTO favorites VALUES (902, 32, 4);
INSERT INTO favorites VALUES (902, 96, 2);
INSERT INTO favorites VALUES (902, 5, 6);
INSERT INTO favorites VALUES (903, 39, 1);
INSERT INTO favorites VALUES (903, 74, 2);
INSERT INTO favorites VALUES (903, 112, 3);
INSERT INTO favorites VALUES (903, 40, 4);
INSERT INTO favorites VALUES (904, 46, 1);
INSERT INTO favorites VALUES (904, 50, 2);
INSERT INTO favorites VALUES (904, 22, 3);
INSERT INTO favorites VALUES (905, 114, 1);
INSERT INTO favorites VALUES (905, 59, 3);
INSERT INTO favorites VALUES (905, 16, 2);
INSERT INTO favorites VALUES (906, 31, 1);
INSERT INTO favorites VALUES (907, 64, 1);
INSERT INTO favorites VALUES (908, 65, 2);
INSERT INTO favorites VALUES (908, 46, 1);
INSERT INTO favorites VALUES (908, 61, 3);
INSERT INTO favorites VALUES (909, 28, 1);
INSERT INTO favorites VALUES (910, 95, 1);
INSERT INTO favorites VALUES (910, 91, 2);
INSERT INTO favorites VALUES (911, 37, 1);
INSERT INTO favorites VALUES (911, 8, 2);
INSERT INTO favorites VALUES (911, 114, 3);
INSERT INTO favorites VALUES (912, 63, 2);
INSERT INTO favorites VALUES (912, 41, 1);
INSERT INTO favorites VALUES (912, 22, 3);
INSERT INTO favorites VALUES (912, 88, 4);
INSERT INTO favorites VALUES (912, 37, 5);
INSERT INTO favorites VALUES (912, 11, 6);
INSERT INTO favorites VALUES (913, 98, 2);
INSERT INTO favorites VALUES (913, 75, 1);
INSERT INTO favorites VALUES (913, 63, 4);
INSERT INTO favorites VALUES (913, 38, 3);
INSERT INTO favorites VALUES (914, 27, 1);
INSERT INTO favorites VALUES (914, 13, 2);
INSERT INTO favorites VALUES (914, 80, 3);
INSERT INTO favorites VALUES (915, 55, 1);
INSERT INTO favorites VALUES (916, 93, 1);
INSERT INTO favorites VALUES (916, 38, 2);
INSERT INTO favorites VALUES (918, 31, 2);
INSERT INTO favorites VALUES (918, 28, 1);
INSERT INTO favorites VALUES (918, 20, 3);
INSERT INTO favorites VALUES (919, 98, 2);
INSERT INTO favorites VALUES (919, 25, 1);
INSERT INTO favorites VALUES (919, 39, 4);
INSERT INTO favorites VALUES (919, 87, 3);
INSERT INTO favorites VALUES (920, 72, 3);
INSERT INTO favorites VALUES (920, 2, 2);
INSERT INTO favorites VALUES (920, 3, 1);
INSERT INTO favorites VALUES (920, 71, 4);
INSERT INTO favorites VALUES (920, 97, 5);
INSERT INTO favorites VALUES (921, 23, 1);
INSERT INTO favorites VALUES (921, 115, 2);
INSERT INTO favorites VALUES (921, 25, 3);
INSERT INTO favorites VALUES (921, 116, 4);
INSERT INTO favorites VALUES (922, 79, 1);
INSERT INTO favorites VALUES (922, 61, 2);
INSERT INTO favorites VALUES (922, 29, 3);
INSERT INTO favorites VALUES (922, 116, 4);
INSERT INTO favorites VALUES (923, 32, 1);
INSERT INTO favorites VALUES (923, 99, 2);
INSERT INTO favorites VALUES (923, 20, 3);
INSERT INTO favorites VALUES (923, 115, 4);
INSERT INTO favorites VALUES (924, 36, 2);
INSERT INTO favorites VALUES (924, 22, 1);
INSERT INTO favorites VALUES (924, 81, 3);
INSERT INTO favorites VALUES (924, 9, 4);
INSERT INTO favorites VALUES (925, 68, 2);
INSERT INTO favorites VALUES (925, 62, 3);
INSERT INTO favorites VALUES (925, 18, 1);
INSERT INTO favorites VALUES (925, 24, 4);
INSERT INTO favorites VALUES (925, 105, 5);
INSERT INTO favorites VALUES (926, 32, 1);
INSERT INTO favorites VALUES (926, 48, 4);
INSERT INTO favorites VALUES (926, 13, 3);
INSERT INTO favorites VALUES (926, 96, 2);
INSERT INTO favorites VALUES (927, 85, 1);
INSERT INTO favorites VALUES (927, 40, 3);
INSERT INTO favorites VALUES (927, 69, 2);
INSERT INTO favorites VALUES (928, 16, 1);
INSERT INTO favorites VALUES (928, 113, 2);
INSERT INTO favorites VALUES (929, 21, 1);
INSERT INTO favorites VALUES (929, 92, 2);
INSERT INTO favorites VALUES (930, 44, 2);
INSERT INTO favorites VALUES (930, 13, 1);
INSERT INTO favorites VALUES (930, 27, 3);
INSERT INTO favorites VALUES (931, 15, 1);
INSERT INTO favorites VALUES (932, 71, 1);
INSERT INTO favorites VALUES (933, 16, 1);
INSERT INTO favorites VALUES (933, 62, 3);
INSERT INTO favorites VALUES (933, 81, 2);
INSERT INTO favorites VALUES (935, 115, 1);
INSERT INTO favorites VALUES (936, 87, 2);
INSERT INTO favorites VALUES (936, 37, 1);
INSERT INTO favorites VALUES (936, 82, 4);
INSERT INTO favorites VALUES (936, 5, 3);
INSERT INTO favorites VALUES (937, 56, 1);
INSERT INTO favorites VALUES (937, 73, 3);
INSERT INTO favorites VALUES (937, 62, 2);
INSERT INTO favorites VALUES (938, 60, 1);
INSERT INTO favorites VALUES (938, 20, 2);
INSERT INTO favorites VALUES (938, 2, 3);
INSERT INTO favorites VALUES (938, 41, 4);
INSERT INTO favorites VALUES (939, 2, 1);
INSERT INTO favorites VALUES (939, 10, 2);
INSERT INTO favorites VALUES (939, 39, 3);
INSERT INTO favorites VALUES (940, 82, 1);
INSERT INTO favorites VALUES (941, 28, 2);
INSERT INTO favorites VALUES (941, 12, 1);
INSERT INTO favorites VALUES (941, 43, 4);
INSERT INTO favorites VALUES (941, 29, 3);
INSERT INTO favorites VALUES (941, 97, 5);
INSERT INTO favorites VALUES (942, 28, 1);
INSERT INTO favorites VALUES (942, 60, 2);
INSERT INTO favorites VALUES (942, 92, 3);
INSERT INTO favorites VALUES (943, 60, 1);
INSERT INTO favorites VALUES (943, 2, 2);
INSERT INTO favorites VALUES (943, 94, 3);
INSERT INTO favorites VALUES (944, 57, 1);
INSERT INTO favorites VALUES (945, 61, 1);
INSERT INTO favorites VALUES (945, 62, 2);
INSERT INTO favorites VALUES (946, 35, 3);
INSERT INTO favorites VALUES (946, 5, 4);
INSERT INTO favorites VALUES (946, 60, 1);
INSERT INTO favorites VALUES (946, 18, 2);
INSERT INTO favorites VALUES (947, 30, 1);
INSERT INTO favorites VALUES (949, 98, 1);
INSERT INTO favorites VALUES (950, 76, 2);
INSERT INTO favorites VALUES (950, 37, 1);
INSERT INTO favorites VALUES (950, 71, 3);
INSERT INTO favorites VALUES (950, 53, 4);
INSERT INTO favorites VALUES (952, 110, 1);
INSERT INTO favorites VALUES (952, 52, 2);
INSERT INTO favorites VALUES (954, 3, 1);
INSERT INTO favorites VALUES (955, 115, 2);
INSERT INTO favorites VALUES (955, 32, 1);
INSERT INTO favorites VALUES (955, 64, 3);
INSERT INTO favorites VALUES (956, 9, 3);
INSERT INTO favorites VALUES (956, 68, 1);
INSERT INTO favorites VALUES (956, 82, 2);
INSERT INTO favorites VALUES (956, 17, 4);
INSERT INTO favorites VALUES (957, 60, 1);
INSERT INTO favorites VALUES (957, 22, 2);
INSERT INTO favorites VALUES (958, 18, 1);
INSERT INTO favorites VALUES (958, 74, 2);
INSERT INTO favorites VALUES (958, 80, 3);
INSERT INTO favorites VALUES (959, 2, 1);
INSERT INTO favorites VALUES (959, 5, 3);
INSERT INTO favorites VALUES (959, 51, 2);
INSERT INTO favorites VALUES (960, 1, 1);
INSERT INTO favorites VALUES (960, 1, 2);
INSERT INTO favorites VALUES (960, 74, 3);
INSERT INTO favorites VALUES (961, 12, 1);
INSERT INTO favorites VALUES (961, 79, 4);
INSERT INTO favorites VALUES (961, 46, 2);
INSERT INTO favorites VALUES (961, 91, 3);
INSERT INTO favorites VALUES (961, 105, 5);
INSERT INTO favorites VALUES (962, 111, 2);
INSERT INTO favorites VALUES (962, 6, 1);
INSERT INTO favorites VALUES (962, 87, 3);
INSERT INTO favorites VALUES (962, 48, 4);
INSERT INTO favorites VALUES (963, 34, 1);
INSERT INTO favorites VALUES (963, 5, 2);
INSERT INTO favorites VALUES (963, 115, 3);
INSERT INTO favorites VALUES (964, 71, 2);
INSERT INTO favorites VALUES (964, 3, 1);
INSERT INTO favorites VALUES (964, 95, 3);
INSERT INTO favorites VALUES (965, 6, 1);
INSERT INTO favorites VALUES (965, 69, 2);
INSERT INTO favorites VALUES (966, 114, 1);
INSERT INTO favorites VALUES (966, 115, 2);
INSERT INTO favorites VALUES (967, 12, 2);
INSERT INTO favorites VALUES (967, 44, 1);
INSERT INTO favorites VALUES (967, 8, 3);
INSERT INTO favorites VALUES (969, 54, 1);
INSERT INTO favorites VALUES (970, 46, 2);
INSERT INTO favorites VALUES (970, 99, 1);
INSERT INTO favorites VALUES (971, 50, 2);
INSERT INTO favorites VALUES (971, 77, 1);
INSERT INTO favorites VALUES (972, 88, 1);
INSERT INTO favorites VALUES (972, 57, 2);
INSERT INTO favorites VALUES (972, 15, 3);
INSERT INTO favorites VALUES (973, 87, 1);
INSERT INTO favorites VALUES (974, 7, 1);
INSERT INTO favorites VALUES (974, 28, 2);
INSERT INTO favorites VALUES (975, 49, 2);
INSERT INTO favorites VALUES (975, 23, 1);
INSERT INTO favorites VALUES (975, 28, 3);
INSERT INTO favorites VALUES (975, 115, 6);
INSERT INTO favorites VALUES (975, 37, 5);
INSERT INTO favorites VALUES (975, 78, 4);
INSERT INTO favorites VALUES (977, 52, 1);
INSERT INTO favorites VALUES (977, 97, 2);
INSERT INTO favorites VALUES (978, 38, 1);
INSERT INTO favorites VALUES (978, 56, 3);
INSERT INTO favorites VALUES (978, 9, 2);
INSERT INTO favorites VALUES (978, 15, 5);
INSERT INTO favorites VALUES (978, 13, 4);
INSERT INTO favorites VALUES (979, 17, 1);
INSERT INTO favorites VALUES (979, 7, 2);
INSERT INTO favorites VALUES (979, 97, 3);
INSERT INTO favorites VALUES (980, 26, 1);
INSERT INTO favorites VALUES (980, 18, 2);
INSERT INTO favorites VALUES (981, 96, 2);
INSERT INTO favorites VALUES (981, 4, 1);
INSERT INTO favorites VALUES (981, 11, 3);
INSERT INTO favorites VALUES (981, 80, 4);
INSERT INTO favorites VALUES (982, 53, 2);
INSERT INTO favorites VALUES (982, 20, 1);
INSERT INTO favorites VALUES (982, 27, 4);
INSERT INTO favorites VALUES (982, 63, 3);
INSERT INTO favorites VALUES (982, 48, 5);
INSERT INTO favorites VALUES (983, 81, 1);
INSERT INTO favorites VALUES (984, 86, 1);
INSERT INTO favorites VALUES (984, 63, 2);
INSERT INTO favorites VALUES (985, 9, 2);
INSERT INTO favorites VALUES (985, 22, 1);
INSERT INTO favorites VALUES (986, 41, 1);
INSERT INTO favorites VALUES (986, 24, 2);
INSERT INTO favorites VALUES (987, 6, 3);
INSERT INTO favorites VALUES (987, 46, 2);
INSERT INTO favorites VALUES (987, 30, 1);
INSERT INTO favorites VALUES (988, 12, 1);
INSERT INTO favorites VALUES (988, 36, 2);
INSERT INTO favorites VALUES (988, 97, 4);
INSERT INTO favorites VALUES (988, 56, 3);
INSERT INTO favorites VALUES (989, 63, 1);
INSERT INTO favorites VALUES (989, 26, 3);
INSERT INTO favorites VALUES (989, 47, 2);
INSERT INTO favorites VALUES (990, 21, 1);
INSERT INTO favorites VALUES (991, 102, 1);
INSERT INTO favorites VALUES (991, 39, 2);
INSERT INTO favorites VALUES (992, 9, 2);
INSERT INTO favorites VALUES (992, 36, 1);
INSERT INTO favorites VALUES (992, 27, 3);
INSERT INTO favorites VALUES (994, 9, 2);
INSERT INTO favorites VALUES (994, 59, 1);
INSERT INTO favorites VALUES (995, 65, 2);
INSERT INTO favorites VALUES (995, 85, 1);
INSERT INTO favorites VALUES (996, 7, 2);
INSERT INTO favorites VALUES (996, 63, 1);
INSERT INTO favorites VALUES (997, 101, 1);
INSERT INTO favorites VALUES (997, 103, 4);
INSERT INTO favorites VALUES (997, 103, 2);
INSERT INTO favorites VALUES (997, 106, 3);
INSERT INTO favorites VALUES (998, 111, 1);
INSERT INTO favorites VALUES (998, 107, 4);
INSERT INTO favorites VALUES (998, 102, 5);
INSERT INTO favorites VALUES (998, 73, 2);
INSERT INTO favorites VALUES (998, 5, 3);
INSERT INTO favorites VALUES (999, 22, 1);
INSERT INTO favorites VALUES (999, 10, 3);
INSERT INTO favorites VALUES (999, 94, 2);
INSERT INTO favorites VALUES (1000, 23, 3);
INSERT INTO favorites VALUES (1000, 2, 2);
INSERT INTO favorites VALUES (1000, 61, 1);
INSERT INTO favorites VALUES (1000, 49, 5);
INSERT INTO favorites VALUES (1000, 33, 4);
INSERT INTO favorites VALUES (1001, 16, 1);
INSERT INTO favorites VALUES (1002, 43, 1);
INSERT INTO favorites VALUES (1002, 102, 2);
INSERT INTO favorites VALUES (1003, 65, 1);
INSERT INTO favorites VALUES (1003, 43, 2);
INSERT INTO favorites VALUES (1003, 74, 3);
INSERT INTO favorites VALUES (1004, 1, 2);
INSERT INTO favorites VALUES (1004, 100, 1);
INSERT INTO favorites VALUES (1004, 16, 3);
INSERT INTO favorites VALUES (1006, 68, 2);
INSERT INTO favorites VALUES (1006, 54, 1);
INSERT INTO favorites VALUES (1006, 111, 3);
INSERT INTO favorites VALUES (1006, 116, 4);
INSERT INTO favorites VALUES (1007, 66, 1);
INSERT INTO favorites VALUES (1008, 110, 2);
INSERT INTO favorites VALUES (1008, 41, 1);
INSERT INTO favorites VALUES (1008, 93, 3);
INSERT INTO favorites VALUES (1009, 28, 1);
INSERT INTO favorites VALUES (1010, 75, 1);
INSERT INTO favorites VALUES (1010, 82, 2);
INSERT INTO favorites VALUES (1010, 24, 3);
INSERT INTO favorites VALUES (1011, 32, 1);
INSERT INTO favorites VALUES (1011, 84, 2);
INSERT INTO favorites VALUES (1011, 30, 3);
INSERT INTO favorites VALUES (1012, 31, 3);
INSERT INTO favorites VALUES (1012, 5, 1);
INSERT INTO favorites VALUES (1012, 72, 2);
INSERT INTO favorites VALUES (1012, 68, 4);
INSERT INTO favorites VALUES (1013, 21, 3);
INSERT INTO favorites VALUES (1013, 5, 2);
INSERT INTO favorites VALUES (1013, 71, 1);
INSERT INTO favorites VALUES (1013, 16, 4);
INSERT INTO favorites VALUES (1013, 41, 5);
INSERT INTO favorites VALUES (1014, 111, 1);
INSERT INTO favorites VALUES (1014, 6, 2);
INSERT INTO favorites VALUES (1015, 1, 1);
INSERT INTO favorites VALUES (1015, 43, 2);
INSERT INTO favorites VALUES (1017, 19, 1);
INSERT INTO favorites VALUES (1017, 76, 2);
INSERT INTO favorites VALUES (1018, 31, 1);
INSERT INTO favorites VALUES (1018, 89, 2);
INSERT INTO favorites VALUES (1019, 96, 1);
INSERT INTO favorites VALUES (1019, 114, 4);
INSERT INTO favorites VALUES (1019, 21, 3);
INSERT INTO favorites VALUES (1019, 46, 2);
INSERT INTO favorites VALUES (1020, 19, 2);
INSERT INTO favorites VALUES (1020, 48, 1);
INSERT INTO favorites VALUES (1021, 26, 2);
INSERT INTO favorites VALUES (1021, 49, 1);
INSERT INTO favorites VALUES (1022, 65, 1);
INSERT INTO favorites VALUES (1023, 55, 1);
INSERT INTO favorites VALUES (1023, 68, 2);
INSERT INTO favorites VALUES (1024, 87, 2);
INSERT INTO favorites VALUES (1024, 65, 1);
INSERT INTO favorites VALUES (1024, 11, 3);
INSERT INTO favorites VALUES (1025, 96, 2);
INSERT INTO favorites VALUES (1025, 25, 1);
INSERT INTO favorites VALUES (1025, 78, 3);
INSERT INTO favorites VALUES (1025, 19, 5);
INSERT INTO favorites VALUES (1025, 8, 4);
INSERT INTO favorites VALUES (1026, 88, 2);
INSERT INTO favorites VALUES (1026, 71, 1);
INSERT INTO favorites VALUES (1026, 53, 5);
INSERT INTO favorites VALUES (1026, 65, 4);
INSERT INTO favorites VALUES (1026, 79, 3);
INSERT INTO favorites VALUES (1029, 53, 2);
INSERT INTO favorites VALUES (1029, 19, 1);
INSERT INTO favorites VALUES (1029, 20, 4);
INSERT INTO favorites VALUES (1029, 47, 3);
INSERT INTO favorites VALUES (1030, 60, 1);
INSERT INTO favorites VALUES (1030, 70, 2);
INSERT INTO favorites VALUES (1030, 84, 4);
INSERT INTO favorites VALUES (1030, 97, 3);
INSERT INTO favorites VALUES (1030, 11, 6);
INSERT INTO favorites VALUES (1030, 62, 5);
INSERT INTO favorites VALUES (1031, 38, 1);
INSERT INTO favorites VALUES (1032, 51, 1);
INSERT INTO favorites VALUES (1032, 87, 2);
INSERT INTO favorites VALUES (1032, 87, 4);
INSERT INTO favorites VALUES (1032, 9, 3);
INSERT INTO favorites VALUES (1033, 49, 1);
INSERT INTO favorites VALUES (1033, 90, 2);
INSERT INTO favorites VALUES (1034, 66, 1);
INSERT INTO favorites VALUES (1035, 33, 1);
INSERT INTO favorites VALUES (1036, 13, 1);
INSERT INTO favorites VALUES (1036, 32, 3);
INSERT INTO favorites VALUES (1036, 70, 2);
INSERT INTO favorites VALUES (1038, 20, 1);
INSERT INTO favorites VALUES (1038, 89, 2);
INSERT INTO favorites VALUES (1039, 61, 2);
INSERT INTO favorites VALUES (1039, 73, 1);
INSERT INTO favorites VALUES (1041, 68, 2);
INSERT INTO favorites VALUES (1041, 88, 1);
INSERT INTO favorites VALUES (1042, 9, 1);
INSERT INTO favorites VALUES (1042, 20, 2);
INSERT INTO favorites VALUES (1042, 17, 4);
INSERT INTO favorites VALUES (1042, 77, 3);
INSERT INTO favorites VALUES (1043, 22, 1);
INSERT INTO favorites VALUES (1044, 51, 1);
INSERT INTO favorites VALUES (1044, 97, 2);
INSERT INTO favorites VALUES (1045, 56, 3);
INSERT INTO favorites VALUES (1045, 15, 2);
INSERT INTO favorites VALUES (1045, 37, 1);
INSERT INTO favorites VALUES (1045, 6, 6);
INSERT INTO favorites VALUES (1045, 2, 5);
INSERT INTO favorites VALUES (1045, 33, 4);
INSERT INTO favorites VALUES (1046, 59, 1);
INSERT INTO favorites VALUES (1046, 34, 3);
INSERT INTO favorites VALUES (1046, 28, 2);
INSERT INTO favorites VALUES (1046, 45, 5);
INSERT INTO favorites VALUES (1046, 43, 4);
INSERT INTO favorites VALUES (1046, 23, 6);
INSERT INTO favorites VALUES (1047, 85, 1);
INSERT INTO favorites VALUES (1047, 98, 5);
INSERT INTO favorites VALUES (1047, 13, 4);
INSERT INTO favorites VALUES (1047, 42, 3);
INSERT INTO favorites VALUES (1047, 54, 2);
INSERT INTO favorites VALUES (1048, 97, 1);
INSERT INTO favorites VALUES (1048, 38, 2);
INSERT INTO favorites VALUES (1048, 38, 3);
INSERT INTO favorites VALUES (1049, 102, 1);
INSERT INTO favorites VALUES (1049, 96, 2);
INSERT INTO favorites VALUES (1049, 98, 3);
INSERT INTO favorites VALUES (1050, 19, 1);
INSERT INTO favorites VALUES (1050, 35, 2);
INSERT INTO favorites VALUES (1051, 10, 1);
INSERT INTO favorites VALUES (1051, 26, 3);
INSERT INTO favorites VALUES (1051, 1, 2);
INSERT INTO favorites VALUES (1052, 43, 2);
INSERT INTO favorites VALUES (1052, 97, 1);
INSERT INTO favorites VALUES (1053, 52, 1);
INSERT INTO favorites VALUES (1055, 15, 1);
INSERT INTO favorites VALUES (1056, 92, 1);
INSERT INTO favorites VALUES (1056, 110, 2);
INSERT INTO favorites VALUES (1056, 82, 3);
INSERT INTO favorites VALUES (1057, 108, 1);
INSERT INTO favorites VALUES (1057, 32, 2);
INSERT INTO favorites VALUES (1058, 97, 1);
INSERT INTO favorites VALUES (1058, 9, 2);
INSERT INTO favorites VALUES (1058, 13, 4);
INSERT INTO favorites VALUES (1058, 11, 5);
INSERT INTO favorites VALUES (1058, 76, 3);
INSERT INTO favorites VALUES (1059, 18, 2);
INSERT INTO favorites VALUES (1059, 79, 3);
INSERT INTO favorites VALUES (1059, 45, 1);
INSERT INTO favorites VALUES (1059, 67, 4);
INSERT INTO favorites VALUES (1060, 14, 1);
INSERT INTO favorites VALUES (1060, 31, 5);
INSERT INTO favorites VALUES (1060, 44, 4);
INSERT INTO favorites VALUES (1060, 58, 3);
INSERT INTO favorites VALUES (1060, 92, 2);
INSERT INTO favorites VALUES (1061, 6, 1);
INSERT INTO favorites VALUES (1061, 105, 3);
INSERT INTO favorites VALUES (1061, 15, 2);
INSERT INTO favorites VALUES (1061, 48, 5);
INSERT INTO favorites VALUES (1061, 114, 4);
INSERT INTO favorites VALUES (1062, 16, 1);
INSERT INTO favorites VALUES (1062, 38, 2);
INSERT INTO favorites VALUES (1063, 48, 1);
INSERT INTO favorites VALUES (1063, 81, 2);
INSERT INTO favorites VALUES (1064, 15, 1);
INSERT INTO favorites VALUES (1064, 107, 2);
INSERT INTO favorites VALUES (1064, 28, 3);
INSERT INTO favorites VALUES (1065, 26, 1);
INSERT INTO favorites VALUES (1065, 42, 3);
INSERT INTO favorites VALUES (1065, 63, 2);
INSERT INTO favorites VALUES (1065, 28, 4);
INSERT INTO favorites VALUES (1066, 93, 4);
INSERT INTO favorites VALUES (1066, 110, 3);
INSERT INTO favorites VALUES (1066, 100, 5);
INSERT INTO favorites VALUES (1066, 98, 1);
INSERT INTO favorites VALUES (1066, 19, 2);
INSERT INTO favorites VALUES (1067, 14, 3);
INSERT INTO favorites VALUES (1067, 78, 1);
INSERT INTO favorites VALUES (1067, 111, 2);
INSERT INTO favorites VALUES (1068, 24, 1);
INSERT INTO favorites VALUES (1068, 113, 4);
INSERT INTO favorites VALUES (1068, 96, 2);
INSERT INTO favorites VALUES (1068, 64, 3);
INSERT INTO favorites VALUES (1069, 65, 2);
INSERT INTO favorites VALUES (1069, 22, 1);
INSERT INTO favorites VALUES (1070, 20, 1);
INSERT INTO favorites VALUES (1070, 76, 2);
INSERT INTO favorites VALUES (1070, 82, 3);
INSERT INTO favorites VALUES (1071, 14, 1);
INSERT INTO favorites VALUES (1071, 20, 2);
INSERT INTO favorites VALUES (1072, 33, 1);
INSERT INTO favorites VALUES (1073, 23, 1);
INSERT INTO favorites VALUES (1073, 24, 4);
INSERT INTO favorites VALUES (1073, 16, 2);
INSERT INTO favorites VALUES (1073, 25, 3);
INSERT INTO favorites VALUES (1074, 1, 2);
INSERT INTO favorites VALUES (1074, 51, 1);
INSERT INTO favorites VALUES (1075, 69, 1);
INSERT INTO favorites VALUES (1076, 67, 1);
INSERT INTO favorites VALUES (1077, 73, 5);
INSERT INTO favorites VALUES (1077, 101, 1);
INSERT INTO favorites VALUES (1077, 54, 2);
INSERT INTO favorites VALUES (1077, 6, 3);
INSERT INTO favorites VALUES (1077, 75, 4);
INSERT INTO favorites VALUES (1078, 104, 2);
INSERT INTO favorites VALUES (1078, 8, 1);
INSERT INTO favorites VALUES (1079, 25, 2);
INSERT INTO favorites VALUES (1079, 94, 1);
INSERT INTO favorites VALUES (1079, 3, 4);
INSERT INTO favorites VALUES (1079, 67, 5);
INSERT INTO favorites VALUES (1079, 44, 3);
INSERT INTO favorites VALUES (1079, 23, 6);
INSERT INTO favorites VALUES (1080, 110, 2);
INSERT INTO favorites VALUES (1080, 58, 1);
INSERT INTO favorites VALUES (1080, 53, 3);
INSERT INTO favorites VALUES (1081, 22, 1);
INSERT INTO favorites VALUES (1081, 37, 2);
INSERT INTO favorites VALUES (1082, 20, 1);
INSERT INTO favorites VALUES (1082, 114, 4);
INSERT INTO favorites VALUES (1082, 30, 3);
INSERT INTO favorites VALUES (1082, 55, 2);
INSERT INTO favorites VALUES (1083, 1, 5);
INSERT INTO favorites VALUES (1083, 10, 1);
INSERT INTO favorites VALUES (1083, 12, 2);
INSERT INTO favorites VALUES (1083, 5, 4);
INSERT INTO favorites VALUES (1083, 7, 3);
INSERT INTO favorites VALUES (1084, 101, 2);
INSERT INTO favorites VALUES (1084, 87, 1);
INSERT INTO favorites VALUES (1084, 28, 3);
INSERT INTO favorites VALUES (1086, 3, 4);
INSERT INTO favorites VALUES (1086, 74, 1);
INSERT INTO favorites VALUES (1086, 74, 3);
INSERT INTO favorites VALUES (1086, 13, 2);
INSERT INTO favorites VALUES (1087, 32, 5);
INSERT INTO favorites VALUES (1087, 49, 3);
INSERT INTO favorites VALUES (1087, 89, 4);
INSERT INTO favorites VALUES (1087, 5, 2);
INSERT INTO favorites VALUES (1087, 96, 10);
INSERT INTO favorites VALUES (1087, 25, 8);
INSERT INTO favorites VALUES (1087, 6, 9);
INSERT INTO favorites VALUES (1087, 2, 7);
INSERT INTO favorites VALUES (1087, 112, 6);
INSERT INTO favorites VALUES (1087, 2, 1);
INSERT INTO favorites VALUES (1088, 35, 3);
INSERT INTO favorites VALUES (1088, 112, 1);
INSERT INTO favorites VALUES (1088, 53, 5);
INSERT INTO favorites VALUES (1088, 84, 4);
INSERT INTO favorites VALUES (1088, 110, 2);
INSERT INTO favorites VALUES (1089, 23, 2);
INSERT INTO favorites VALUES (1089, 111, 1);
INSERT INTO favorites VALUES (1089, 69, 3);
INSERT INTO favorites VALUES (1090, 43, 1);
INSERT INTO favorites VALUES (1090, 22, 4);
INSERT INTO favorites VALUES (1090, 5, 2);
INSERT INTO favorites VALUES (1090, 15, 3);
INSERT INTO favorites VALUES (1091, 63, 4);
INSERT INTO favorites VALUES (1091, 74, 1);
INSERT INTO favorites VALUES (1091, 32, 2);
INSERT INTO favorites VALUES (1091, 94, 3);
INSERT INTO favorites VALUES (1092, 51, 1);
INSERT INTO favorites VALUES (1093, 71, 1);
INSERT INTO favorites VALUES (1093, 88, 4);
INSERT INTO favorites VALUES (1093, 68, 3);
INSERT INTO favorites VALUES (1093, 56, 2);
INSERT INTO favorites VALUES (1094, 6, 1);
INSERT INTO favorites VALUES (1094, 58, 2);
INSERT INTO favorites VALUES (1094, 97, 3);
INSERT INTO favorites VALUES (1095, 91, 1);
INSERT INTO favorites VALUES (1095, 48, 2);
INSERT INTO favorites VALUES (1095, 73, 3);
INSERT INTO favorites VALUES (1096, 8, 1);
INSERT INTO favorites VALUES (1097, 74, 1);
INSERT INTO favorites VALUES (1098, 48, 2);
INSERT INTO favorites VALUES (1098, 102, 1);
INSERT INTO favorites VALUES (1098, 10, 4);
INSERT INTO favorites VALUES (1098, 66, 3);
INSERT INTO favorites VALUES (1099, 38, 1);
INSERT INTO favorites VALUES (1099, 26, 2);
INSERT INTO favorites VALUES (1099, 84, 3);
INSERT INTO favorites VALUES (1100, 10, 1);
INSERT INTO favorites VALUES (1100, 28, 2);
INSERT INTO favorites VALUES (1101, 57, 1);
INSERT INTO favorites VALUES (1101, 70, 2);
INSERT INTO favorites VALUES (1101, 96, 3);
INSERT INTO favorites VALUES (1102, 57, 3);
INSERT INTO favorites VALUES (1102, 86, 2);
INSERT INTO favorites VALUES (1102, 27, 1);
INSERT INTO favorites VALUES (1103, 72, 1);
INSERT INTO favorites VALUES (1104, 1, 1);
INSERT INTO favorites VALUES (1104, 13, 3);
INSERT INTO favorites VALUES (1104, 13, 4);
INSERT INTO favorites VALUES (1104, 53, 2);
INSERT INTO favorites VALUES (1104, 84, 5);
INSERT INTO favorites VALUES (1104, 20, 6);
INSERT INTO favorites VALUES (1104, 22, 7);
INSERT INTO favorites VALUES (1105, 26, 1);
INSERT INTO favorites VALUES (1105, 101, 2);
INSERT INTO favorites VALUES (1106, 4, 1);
INSERT INTO favorites VALUES (1106, 83, 2);
INSERT INTO favorites VALUES (1107, 68, 1);
INSERT INTO favorites VALUES (1107, 58, 2);
INSERT INTO favorites VALUES (1107, 57, 3);
INSERT INTO favorites VALUES (1108, 42, 3);
INSERT INTO favorites VALUES (1108, 34, 2);
INSERT INTO favorites VALUES (1108, 25, 1);
INSERT INTO favorites VALUES (1108, 8, 4);
INSERT INTO favorites VALUES (1109, 39, 2);
INSERT INTO favorites VALUES (1109, 77, 1);
INSERT INTO favorites VALUES (1109, 43, 4);
INSERT INTO favorites VALUES (1109, 73, 5);
INSERT INTO favorites VALUES (1109, 14, 3);
INSERT INTO favorites VALUES (1109, 5, 7);
INSERT INTO favorites VALUES (1109, 22, 6);
INSERT INTO favorites VALUES (1109, 82, 9);
INSERT INTO favorites VALUES (1109, 35, 8);
INSERT INTO favorites VALUES (1110, 112, 1);
INSERT INTO favorites VALUES (1110, 72, 2);
INSERT INTO favorites VALUES (1110, 100, 3);
INSERT INTO favorites VALUES (1111, 112, 1);
INSERT INTO favorites VALUES (1111, 24, 3);
INSERT INTO favorites VALUES (1111, 22, 4);
INSERT INTO favorites VALUES (1111, 24, 2);
INSERT INTO favorites VALUES (1112, 84, 1);
INSERT INTO favorites VALUES (1113, 66, 1);
INSERT INTO favorites VALUES (1114, 97, 1);
INSERT INTO favorites VALUES (1115, 108, 1);
INSERT INTO favorites VALUES (1116, 86, 2);
INSERT INTO favorites VALUES (1116, 38, 1);
INSERT INTO favorites VALUES (1116, 57, 3);
INSERT INTO favorites VALUES (1117, 79, 1);
INSERT INTO favorites VALUES (1117, 68, 2);
INSERT INTO favorites VALUES (1117, 113, 3);
INSERT INTO favorites VALUES (1117, 77, 4);
INSERT INTO favorites VALUES (1117, 20, 6);
INSERT INTO favorites VALUES (1117, 71, 5);
INSERT INTO favorites VALUES (1118, 8, 1);
INSERT INTO favorites VALUES (1119, 20, 1);
INSERT INTO favorites VALUES (1120, 19, 2);
INSERT INTO favorites VALUES (1120, 70, 3);
INSERT INTO favorites VALUES (1120, 35, 1);
INSERT INTO favorites VALUES (1120, 80, 5);
INSERT INTO favorites VALUES (1120, 78, 4);
INSERT INTO favorites VALUES (1120, 76, 6);
INSERT INTO favorites VALUES (1122, 19, 1);
INSERT INTO favorites VALUES (1123, 49, 1);
INSERT INTO favorites VALUES (1123, 114, 3);
INSERT INTO favorites VALUES (1123, 20, 2);
INSERT INTO favorites VALUES (1123, 24, 4);
INSERT INTO favorites VALUES (1123, 51, 5);
INSERT INTO favorites VALUES (1124, 88, 2);
INSERT INTO favorites VALUES (1124, 42, 1);
INSERT INTO favorites VALUES (1124, 5, 4);
INSERT INTO favorites VALUES (1124, 94, 3);
INSERT INTO favorites VALUES (1125, 103, 1);
INSERT INTO favorites VALUES (1125, 47, 2);
INSERT INTO favorites VALUES (1125, 18, 3);
INSERT INTO favorites VALUES (1126, 25, 3);
INSERT INTO favorites VALUES (1126, 57, 1);
INSERT INTO favorites VALUES (1126, 46, 2);
INSERT INTO favorites VALUES (1126, 39, 4);
INSERT INTO favorites VALUES (1127, 4, 1);
INSERT INTO favorites VALUES (1127, 32, 2);
INSERT INTO favorites VALUES (1127, 38, 3);
INSERT INTO favorites VALUES (1128, 32, 1);
INSERT INTO favorites VALUES (1129, 4, 3);
INSERT INTO favorites VALUES (1129, 85, 2);
INSERT INTO favorites VALUES (1129, 26, 1);
INSERT INTO favorites VALUES (1129, 110, 5);
INSERT INTO favorites VALUES (1129, 32, 4);
INSERT INTO favorites VALUES (1130, 80, 1);
INSERT INTO favorites VALUES (1130, 60, 2);
INSERT INTO favorites VALUES (1131, 1, 1);
INSERT INTO favorites VALUES (1131, 56, 3);
INSERT INTO favorites VALUES (1131, 36, 2);
INSERT INTO favorites VALUES (1132, 59, 2);
INSERT INTO favorites VALUES (1132, 102, 1);
INSERT INTO favorites VALUES (1132, 50, 4);
INSERT INTO favorites VALUES (1132, 14, 3);
INSERT INTO favorites VALUES (1132, 104, 5);
INSERT INTO favorites VALUES (1132, 35, 6);
INSERT INTO favorites VALUES (1134, 3, 1);
INSERT INTO favorites VALUES (1134, 35, 2);
INSERT INTO favorites VALUES (1134, 11, 4);
INSERT INTO favorites VALUES (1134, 53, 3);
INSERT INTO favorites VALUES (1134, 35, 5);
INSERT INTO favorites VALUES (1135, 12, 1);
INSERT INTO favorites VALUES (1135, 21, 2);
INSERT INTO favorites VALUES (1136, 1, 1);
INSERT INTO favorites VALUES (1136, 43, 3);
INSERT INTO favorites VALUES (1136, 19, 2);
INSERT INTO favorites VALUES (1136, 62, 5);
INSERT INTO favorites VALUES (1136, 99, 4);
INSERT INTO favorites VALUES (1136, 12, 7);
INSERT INTO favorites VALUES (1136, 45, 6);
INSERT INTO favorites VALUES (1136, 15, 8);
INSERT INTO favorites VALUES (1137, 79, 2);
INSERT INTO favorites VALUES (1137, 95, 1);
INSERT INTO favorites VALUES (1137, 86, 4);
INSERT INTO favorites VALUES (1137, 67, 3);
INSERT INTO favorites VALUES (1138, 39, 1);
INSERT INTO favorites VALUES (1138, 9, 2);
INSERT INTO favorites VALUES (1139, 23, 1);
INSERT INTO favorites VALUES (1140, 6, 1);
INSERT INTO favorites VALUES (1141, 52, 1);
INSERT INTO favorites VALUES (1142, 14, 1);
INSERT INTO favorites VALUES (1142, 31, 2);
INSERT INTO favorites VALUES (1143, 110, 1);
INSERT INTO favorites VALUES (1143, 43, 2);
INSERT INTO favorites VALUES (1143, 30, 4);
INSERT INTO favorites VALUES (1143, 76, 3);
INSERT INTO favorites VALUES (1144, 73, 1);
INSERT INTO favorites VALUES (1144, 65, 2);
INSERT INTO favorites VALUES (1144, 15, 4);
INSERT INTO favorites VALUES (1144, 81, 3);
INSERT INTO favorites VALUES (1145, 28, 3);
INSERT INTO favorites VALUES (1145, 15, 1);
INSERT INTO favorites VALUES (1145, 105, 2);
INSERT INTO favorites VALUES (1146, 10, 1);
INSERT INTO favorites VALUES (1146, 29, 2);
INSERT INTO favorites VALUES (1147, 67, 2);
INSERT INTO favorites VALUES (1147, 107, 1);
INSERT INTO favorites VALUES (1147, 98, 4);
INSERT INTO favorites VALUES (1147, 80, 3);
INSERT INTO favorites VALUES (1147, 98, 5);
INSERT INTO favorites VALUES (1148, 19, 2);
INSERT INTO favorites VALUES (1148, 111, 1);
INSERT INTO favorites VALUES (1149, 5, 1);
INSERT INTO favorites VALUES (1150, 105, 1);
INSERT INTO favorites VALUES (1150, 11, 2);
INSERT INTO favorites VALUES (1150, 81, 3);
INSERT INTO favorites VALUES (1151, 82, 1);
INSERT INTO favorites VALUES (1151, 40, 2);
INSERT INTO favorites VALUES (1151, 31, 3);
INSERT INTO favorites VALUES (1151, 39, 4);
INSERT INTO favorites VALUES (1151, 21, 5);
INSERT INTO favorites VALUES (1152, 18, 1);
INSERT INTO favorites VALUES (1153, 45, 1);
INSERT INTO favorites VALUES (1153, 47, 2);
INSERT INTO favorites VALUES (1153, 116, 3);
INSERT INTO favorites VALUES (1154, 12, 1);
INSERT INTO favorites VALUES (1154, 114, 2);
INSERT INTO favorites VALUES (1154, 84, 3);
INSERT INTO favorites VALUES (1155, 48, 1);
INSERT INTO favorites VALUES (1155, 13, 2);
INSERT INTO favorites VALUES (1155, 90, 4);
INSERT INTO favorites VALUES (1155, 12, 3);
INSERT INTO favorites VALUES (1156, 23, 2);
INSERT INTO favorites VALUES (1156, 18, 1);
INSERT INTO favorites VALUES (1156, 30, 3);
INSERT INTO favorites VALUES (1156, 55, 5);
INSERT INTO favorites VALUES (1156, 33, 4);
INSERT INTO favorites VALUES (1157, 92, 1);
INSERT INTO favorites VALUES (1157, 26, 2);
INSERT INTO favorites VALUES (1158, 23, 1);
INSERT INTO favorites VALUES (1158, 87, 3);
INSERT INTO favorites VALUES (1158, 52, 2);
INSERT INTO favorites VALUES (1159, 112, 1);
INSERT INTO favorites VALUES (1160, 102, 1);
INSERT INTO favorites VALUES (1160, 91, 5);
INSERT INTO favorites VALUES (1160, 29, 4);
INSERT INTO favorites VALUES (1160, 116, 3);
INSERT INTO favorites VALUES (1160, 80, 2);
INSERT INTO favorites VALUES (1160, 7, 6);
INSERT INTO favorites VALUES (1161, 94, 2);
INSERT INTO favorites VALUES (1161, 112, 1);
INSERT INTO favorites VALUES (1162, 23, 1);
INSERT INTO favorites VALUES (1162, 10, 4);
INSERT INTO favorites VALUES (1162, 29, 3);
INSERT INTO favorites VALUES (1162, 46, 2);
INSERT INTO favorites VALUES (1163, 11, 1);
INSERT INTO favorites VALUES (1164, 69, 1);
INSERT INTO favorites VALUES (1164, 103, 2);
INSERT INTO favorites VALUES (1165, 99, 1);
INSERT INTO favorites VALUES (1165, 80, 3);
INSERT INTO favorites VALUES (1165, 14, 2);
INSERT INTO favorites VALUES (1165, 16, 4);
INSERT INTO favorites VALUES (1166, 111, 1);
INSERT INTO favorites VALUES (1166, 59, 2);
INSERT INTO favorites VALUES (1167, 103, 1);
INSERT INTO favorites VALUES (1168, 54, 1);
INSERT INTO favorites VALUES (1168, 6, 2);
INSERT INTO favorites VALUES (1168, 62, 3);
INSERT INTO favorites VALUES (1169, 46, 1);
INSERT INTO favorites VALUES (1169, 11, 2);
INSERT INTO favorites VALUES (1170, 49, 1);
INSERT INTO favorites VALUES (1170, 9, 2);
INSERT INTO favorites VALUES (1171, 13, 1);
INSERT INTO favorites VALUES (1172, 87, 2);
INSERT INTO favorites VALUES (1172, 85, 1);
INSERT INTO favorites VALUES (1174, 19, 1);
INSERT INTO favorites VALUES (1174, 51, 2);
INSERT INTO favorites VALUES (1174, 48, 3);
INSERT INTO favorites VALUES (1174, 19, 5);
INSERT INTO favorites VALUES (1174, 72, 4);
INSERT INTO favorites VALUES (1175, 38, 1);
INSERT INTO favorites VALUES (1175, 67, 2);
INSERT INTO favorites VALUES (1177, 1, 3);
INSERT INTO favorites VALUES (1177, 88, 5);
INSERT INTO favorites VALUES (1177, 30, 2);
INSERT INTO favorites VALUES (1177, 79, 1);
INSERT INTO favorites VALUES (1177, 70, 4);
INSERT INTO favorites VALUES (1177, 39, 6);
INSERT INTO favorites VALUES (1178, 4, 1);
INSERT INTO favorites VALUES (1178, 7, 3);
INSERT INTO favorites VALUES (1178, 48, 2);
INSERT INTO favorites VALUES (1179, 63, 2);
INSERT INTO favorites VALUES (1179, 69, 4);
INSERT INTO favorites VALUES (1179, 114, 1);
INSERT INTO favorites VALUES (1179, 51, 3);
INSERT INTO favorites VALUES (1179, 73, 5);
INSERT INTO favorites VALUES (1179, 84, 6);
INSERT INTO favorites VALUES (1180, 36, 1);
INSERT INTO favorites VALUES (1180, 41, 2);
INSERT INTO favorites VALUES (1181, 51, 1);
INSERT INTO favorites VALUES (1181, 88, 2);
INSERT INTO favorites VALUES (1183, 46, 1);
INSERT INTO favorites VALUES (1183, 15, 2);
INSERT INTO favorites VALUES (1183, 31, 3);
INSERT INTO favorites VALUES (1184, 65, 1);
INSERT INTO favorites VALUES (1184, 26, 2);
INSERT INTO favorites VALUES (1184, 19, 4);
INSERT INTO favorites VALUES (1184, 43, 3);
INSERT INTO favorites VALUES (1185, 98, 1);
INSERT INTO favorites VALUES (1185, 105, 2);
INSERT INTO favorites VALUES (1185, 85, 3);
INSERT INTO favorites VALUES (1185, 22, 5);
INSERT INTO favorites VALUES (1185, 35, 4);
INSERT INTO favorites VALUES (1186, 19, 1);
INSERT INTO favorites VALUES (1186, 69, 2);
INSERT INTO favorites VALUES (1186, 89, 3);
INSERT INTO favorites VALUES (1188, 115, 1);
INSERT INTO favorites VALUES (1188, 24, 3);
INSERT INTO favorites VALUES (1188, 60, 2);
INSERT INTO favorites VALUES (1189, 81, 1);
INSERT INTO favorites VALUES (1189, 73, 2);
INSERT INTO favorites VALUES (1189, 100, 3);
INSERT INTO favorites VALUES (1189, 22, 4);
INSERT INTO favorites VALUES (1190, 44, 1);
INSERT INTO favorites VALUES (1190, 85, 2);
INSERT INTO favorites VALUES (1191, 61, 2);
INSERT INTO favorites VALUES (1191, 77, 1);
INSERT INTO favorites VALUES (1191, 63, 4);
INSERT INTO favorites VALUES (1191, 88, 3);
INSERT INTO favorites VALUES (1191, 33, 5);
INSERT INTO favorites VALUES (1192, 62, 3);
INSERT INTO favorites VALUES (1192, 53, 2);
INSERT INTO favorites VALUES (1192, 57, 1);
INSERT INTO favorites VALUES (1192, 114, 5);
INSERT INTO favorites VALUES (1192, 44, 4);
INSERT INTO favorites VALUES (1192, 8, 6);
INSERT INTO favorites VALUES (1194, 98, 2);
INSERT INTO favorites VALUES (1194, 28, 3);
INSERT INTO favorites VALUES (1194, 48, 5);
INSERT INTO favorites VALUES (1194, 13, 1);
INSERT INTO favorites VALUES (1194, 98, 4);
INSERT INTO favorites VALUES (1194, 96, 6);
INSERT INTO favorites VALUES (1195, 2, 1);
INSERT INTO favorites VALUES (1195, 26, 6);
INSERT INTO favorites VALUES (1195, 9, 5);
INSERT INTO favorites VALUES (1195, 54, 4);
INSERT INTO favorites VALUES (1195, 8, 3);
INSERT INTO favorites VALUES (1195, 52, 2);
INSERT INTO favorites VALUES (1195, 29, 7);
INSERT INTO favorites VALUES (1196, 2, 2);
INSERT INTO favorites VALUES (1196, 78, 3);
INSERT INTO favorites VALUES (1196, 39, 1);
INSERT INTO favorites VALUES (1197, 70, 3);
INSERT INTO favorites VALUES (1197, 48, 2);
INSERT INTO favorites VALUES (1197, 12, 1);
INSERT INTO favorites VALUES (1197, 37, 7);
INSERT INTO favorites VALUES (1197, 71, 6);
INSERT INTO favorites VALUES (1197, 70, 5);
INSERT INTO favorites VALUES (1197, 8, 4);
INSERT INTO favorites VALUES (1199, 72, 1);
INSERT INTO favorites VALUES (1199, 45, 2);
INSERT INTO favorites VALUES (1200, 105, 2);
INSERT INTO favorites VALUES (1200, 32, 3);
INSERT INTO favorites VALUES (1200, 55, 1);
INSERT INTO favorites VALUES (1200, 58, 4);
INSERT INTO favorites VALUES (1201, 43, 2);
INSERT INTO favorites VALUES (1201, 95, 1);
INSERT INTO favorites VALUES (1202, 11, 1);
INSERT INTO favorites VALUES (1202, 54, 2);
INSERT INTO favorites VALUES (1204, 82, 1);
INSERT INTO favorites VALUES (1204, 51, 2);
INSERT INTO favorites VALUES (1204, 67, 3);
INSERT INTO favorites VALUES (1205, 85, 1);
INSERT INTO favorites VALUES (1206, 56, 1);
INSERT INTO favorites VALUES (1207, 107, 1);
INSERT INTO favorites VALUES (1207, 64, 2);
INSERT INTO favorites VALUES (1207, 65, 3);
INSERT INTO favorites VALUES (1208, 30, 1);
INSERT INTO favorites VALUES (1209, 79, 1);
INSERT INTO favorites VALUES (1210, 26, 1);
INSERT INTO favorites VALUES (1210, 12, 3);
INSERT INTO favorites VALUES (1210, 98, 2);
INSERT INTO favorites VALUES (1211, 50, 2);
INSERT INTO favorites VALUES (1211, 90, 1);
INSERT INTO favorites VALUES (1211, 16, 3);
INSERT INTO favorites VALUES (1212, 60, 1);
INSERT INTO favorites VALUES (1212, 68, 2);
INSERT INTO favorites VALUES (1212, 15, 7);
INSERT INTO favorites VALUES (1212, 76, 6);
INSERT INTO favorites VALUES (1212, 14, 5);
INSERT INTO favorites VALUES (1212, 54, 4);
INSERT INTO favorites VALUES (1212, 59, 3);
INSERT INTO favorites VALUES (1213, 24, 2);
INSERT INTO favorites VALUES (1213, 78, 1);
INSERT INTO favorites VALUES (1213, 32, 5);
INSERT INTO favorites VALUES (1213, 93, 4);
INSERT INTO favorites VALUES (1213, 72, 3);
INSERT INTO favorites VALUES (1213, 41, 6);
INSERT INTO favorites VALUES (1214, 79, 1);
INSERT INTO favorites VALUES (1214, 114, 2);
INSERT INTO favorites VALUES (1214, 65, 3);
INSERT INTO favorites VALUES (1215, 115, 1);
INSERT INTO favorites VALUES (1215, 77, 3);
INSERT INTO favorites VALUES (1215, 38, 2);
INSERT INTO favorites VALUES (1215, 93, 4);
INSERT INTO favorites VALUES (1216, 97, 1);
INSERT INTO favorites VALUES (1216, 62, 5);
INSERT INTO favorites VALUES (1216, 5, 2);
INSERT INTO favorites VALUES (1216, 23, 3);
INSERT INTO favorites VALUES (1216, 96, 4);
INSERT INTO favorites VALUES (1217, 46, 1);
INSERT INTO favorites VALUES (1218, 37, 1);
INSERT INTO favorites VALUES (1219, 46, 1);
INSERT INTO favorites VALUES (1219, 31, 2);
INSERT INTO favorites VALUES (1220, 47, 1);
INSERT INTO favorites VALUES (1220, 20, 2);
INSERT INTO favorites VALUES (1220, 35, 4);
INSERT INTO favorites VALUES (1220, 62, 3);
INSERT INTO favorites VALUES (1221, 11, 3);
INSERT INTO favorites VALUES (1221, 63, 2);
INSERT INTO favorites VALUES (1221, 72, 1);
INSERT INTO favorites VALUES (1221, 75, 4);
INSERT INTO favorites VALUES (1221, 18, 6);
INSERT INTO favorites VALUES (1221, 66, 5);
INSERT INTO favorites VALUES (1222, 79, 1);
INSERT INTO favorites VALUES (1222, 41, 3);
INSERT INTO favorites VALUES (1222, 94, 2);
INSERT INTO favorites VALUES (1223, 69, 2);
INSERT INTO favorites VALUES (1223, 73, 1);
INSERT INTO favorites VALUES (1223, 49, 3);
INSERT INTO favorites VALUES (1224, 95, 1);
INSERT INTO favorites VALUES (1224, 32, 3);
INSERT INTO favorites VALUES (1224, 101, 2);
INSERT INTO favorites VALUES (1225, 34, 1);
INSERT INTO favorites VALUES (1225, 41, 2);
INSERT INTO favorites VALUES (1226, 53, 2);
INSERT INTO favorites VALUES (1226, 24, 1);
INSERT INTO favorites VALUES (1226, 88, 5);
INSERT INTO favorites VALUES (1226, 68, 3);
INSERT INTO favorites VALUES (1226, 3, 4);
INSERT INTO favorites VALUES (1227, 5, 3);
INSERT INTO favorites VALUES (1227, 64, 2);
INSERT INTO favorites VALUES (1227, 39, 1);
INSERT INTO favorites VALUES (1227, 16, 4);
INSERT INTO favorites VALUES (1227, 53, 5);
INSERT INTO favorites VALUES (1227, 101, 6);
INSERT INTO favorites VALUES (1228, 27, 1);
INSERT INTO favorites VALUES (1228, 63, 2);
INSERT INTO favorites VALUES (1228, 28, 4);
INSERT INTO favorites VALUES (1228, 59, 3);
INSERT INTO favorites VALUES (1229, 46, 2);
INSERT INTO favorites VALUES (1229, 45, 1);
INSERT INTO favorites VALUES (1229, 74, 3);
INSERT INTO favorites VALUES (1230, 45, 2);
INSERT INTO favorites VALUES (1230, 17, 1);
INSERT INTO favorites VALUES (1230, 86, 3);
INSERT INTO favorites VALUES (1231, 64, 1);
INSERT INTO favorites VALUES (1231, 36, 3);
INSERT INTO favorites VALUES (1231, 43, 2);
INSERT INTO favorites VALUES (1233, 102, 1);
INSERT INTO favorites VALUES (1233, 39, 3);
INSERT INTO favorites VALUES (1233, 56, 2);
INSERT INTO favorites VALUES (1233, 31, 4);
INSERT INTO favorites VALUES (1234, 79, 1);
INSERT INTO favorites VALUES (1235, 108, 2);
INSERT INTO favorites VALUES (1235, 100, 1);
INSERT INTO favorites VALUES (1235, 30, 3);
INSERT INTO favorites VALUES (1237, 44, 1);
INSERT INTO favorites VALUES (1238, 38, 1);
INSERT INTO favorites VALUES (1238, 49, 2);
INSERT INTO favorites VALUES (1238, 55, 3);
INSERT INTO favorites VALUES (1238, 48, 4);
INSERT INTO favorites VALUES (1239, 26, 1);
INSERT INTO favorites VALUES (1239, 101, 2);
INSERT INTO favorites VALUES (1240, 39, 1);
INSERT INTO favorites VALUES (1240, 6, 2);
INSERT INTO favorites VALUES (1240, 71, 3);
INSERT INTO favorites VALUES (1241, 55, 1);
INSERT INTO favorites VALUES (1242, 58, 1);
INSERT INTO favorites VALUES (1242, 36, 3);
INSERT INTO favorites VALUES (1242, 99, 2);
INSERT INTO favorites VALUES (1243, 31, 2);
INSERT INTO favorites VALUES (1243, 55, 1);
INSERT INTO favorites VALUES (1244, 90, 2);
INSERT INTO favorites VALUES (1244, 44, 1);
INSERT INTO favorites VALUES (1244, 31, 5);
INSERT INTO favorites VALUES (1244, 94, 4);
INSERT INTO favorites VALUES (1244, 92, 3);
INSERT INTO favorites VALUES (1244, 108, 6);
INSERT INTO favorites VALUES (1245, 70, 1);
INSERT INTO favorites VALUES (1245, 2, 2);
INSERT INTO favorites VALUES (1246, 36, 3);
INSERT INTO favorites VALUES (1246, 87, 2);
INSERT INTO favorites VALUES (1246, 54, 4);
INSERT INTO favorites VALUES (1246, 32, 1);
INSERT INTO favorites VALUES (1246, 99, 5);
INSERT INTO favorites VALUES (1247, 52, 1);
INSERT INTO favorites VALUES (1247, 82, 2);
INSERT INTO favorites VALUES (1248, 102, 1);
INSERT INTO favorites VALUES (1248, 100, 2);
INSERT INTO favorites VALUES (1249, 18, 2);
INSERT INTO favorites VALUES (1249, 100, 1);
INSERT INTO favorites VALUES (1251, 34, 1);
INSERT INTO favorites VALUES (1251, 50, 2);
INSERT INTO favorites VALUES (1251, 7, 3);
INSERT INTO favorites VALUES (1252, 10, 2);
INSERT INTO favorites VALUES (1252, 2, 1);
INSERT INTO favorites VALUES (1252, 17, 5);
INSERT INTO favorites VALUES (1252, 8, 4);
INSERT INTO favorites VALUES (1252, 82, 3);
INSERT INTO favorites VALUES (1252, 95, 6);
INSERT INTO favorites VALUES (1253, 100, 1);
INSERT INTO favorites VALUES (1253, 36, 3);
INSERT INTO favorites VALUES (1253, 116, 2);
INSERT INTO favorites VALUES (1254, 42, 1);
INSERT INTO favorites VALUES (1254, 60, 2);
INSERT INTO favorites VALUES (1255, 16, 1);
INSERT INTO favorites VALUES (1256, 26, 1);
INSERT INTO favorites VALUES (1256, 76, 2);
INSERT INTO favorites VALUES (1256, 72, 3);
INSERT INTO favorites VALUES (1256, 7, 5);
INSERT INTO favorites VALUES (1256, 51, 4);
INSERT INTO favorites VALUES (1256, 110, 8);
INSERT INTO favorites VALUES (1256, 53, 7);
INSERT INTO favorites VALUES (1256, 82, 9);
INSERT INTO favorites VALUES (1256, 94, 6);
INSERT INTO favorites VALUES (1257, 61, 1);
INSERT INTO favorites VALUES (1258, 82, 3);
INSERT INTO favorites VALUES (1258, 79, 2);
INSERT INTO favorites VALUES (1258, 113, 1);
INSERT INTO favorites VALUES (1258, 38, 4);
INSERT INTO favorites VALUES (1259, 72, 1);
INSERT INTO favorites VALUES (1259, 106, 2);
INSERT INTO favorites VALUES (1260, 71, 2);
INSERT INTO favorites VALUES (1260, 69, 3);
INSERT INTO favorites VALUES (1260, 71, 1);
INSERT INTO favorites VALUES (1260, 5, 6);
INSERT INTO favorites VALUES (1260, 49, 4);
INSERT INTO favorites VALUES (1260, 71, 5);
INSERT INTO favorites VALUES (1261, 75, 1);
INSERT INTO favorites VALUES (1262, 8, 1);
INSERT INTO favorites VALUES (1263, 61, 2);
INSERT INTO favorites VALUES (1263, 78, 1);
INSERT INTO favorites VALUES (1263, 15, 3);
INSERT INTO favorites VALUES (1264, 51, 1);
INSERT INTO favorites VALUES (1264, 61, 3);
INSERT INTO favorites VALUES (1264, 3, 4);
INSERT INTO favorites VALUES (1264, 44, 2);
INSERT INTO favorites VALUES (1264, 2, 5);
INSERT INTO favorites VALUES (1264, 22, 6);
INSERT INTO favorites VALUES (1265, 96, 1);
INSERT INTO favorites VALUES (1266, 88, 1);
INSERT INTO favorites VALUES (1266, 111, 2);
INSERT INTO favorites VALUES (1266, 53, 5);
INSERT INTO favorites VALUES (1266, 11, 4);
INSERT INTO favorites VALUES (1266, 2, 3);
INSERT INTO favorites VALUES (1267, 41, 2);
INSERT INTO favorites VALUES (1267, 101, 1);
INSERT INTO favorites VALUES (1268, 7, 1);
INSERT INTO favorites VALUES (1268, 67, 2);
INSERT INTO favorites VALUES (1268, 74, 3);
INSERT INTO favorites VALUES (1270, 52, 2);
INSERT INTO favorites VALUES (1270, 27, 1);
INSERT INTO favorites VALUES (1270, 32, 4);
INSERT INTO favorites VALUES (1270, 104, 3);
INSERT INTO favorites VALUES (1271, 50, 1);
INSERT INTO favorites VALUES (1271, 63, 2);
INSERT INTO favorites VALUES (1272, 72, 1);
INSERT INTO favorites VALUES (1272, 101, 4);
INSERT INTO favorites VALUES (1272, 88, 2);
INSERT INTO favorites VALUES (1272, 68, 3);
INSERT INTO favorites VALUES (1272, 15, 6);
INSERT INTO favorites VALUES (1272, 69, 5);
INSERT INTO favorites VALUES (1272, 42, 8);
INSERT INTO favorites VALUES (1272, 28, 7);
INSERT INTO favorites VALUES (1273, 14, 1);
INSERT INTO favorites VALUES (1273, 14, 2);
INSERT INTO favorites VALUES (1274, 20, 1);
INSERT INTO favorites VALUES (1275, 69, 3);
INSERT INTO favorites VALUES (1275, 78, 5);
INSERT INTO favorites VALUES (1275, 10, 2);
INSERT INTO favorites VALUES (1275, 95, 1);
INSERT INTO favorites VALUES (1275, 83, 4);
INSERT INTO favorites VALUES (1276, 8, 1);
INSERT INTO favorites VALUES (1277, 62, 1);
INSERT INTO favorites VALUES (1277, 105, 3);
INSERT INTO favorites VALUES (1277, 26, 2);
INSERT INTO favorites VALUES (1277, 26, 4);
INSERT INTO favorites VALUES (1278, 84, 1);
INSERT INTO favorites VALUES (1278, 116, 3);
INSERT INTO favorites VALUES (1278, 41, 2);
INSERT INTO favorites VALUES (1280, 85, 2);
INSERT INTO favorites VALUES (1280, 6, 1);
INSERT INTO favorites VALUES (1281, 74, 2);
INSERT INTO favorites VALUES (1281, 95, 1);
INSERT INTO favorites VALUES (1281, 14, 4);
INSERT INTO favorites VALUES (1281, 115, 3);
INSERT INTO favorites VALUES (1282, 78, 2);
INSERT INTO favorites VALUES (1282, 23, 1);
INSERT INTO favorites VALUES (1282, 55, 3);
INSERT INTO favorites VALUES (1283, 21, 1);
INSERT INTO favorites VALUES (1283, 63, 2);
INSERT INTO favorites VALUES (1283, 68, 3);
INSERT INTO favorites VALUES (1285, 58, 1);
INSERT INTO favorites VALUES (1288, 3, 1);
INSERT INTO favorites VALUES (1288, 6, 2);
INSERT INTO favorites VALUES (1288, 29, 3);
INSERT INTO favorites VALUES (1289, 36, 2);
INSERT INTO favorites VALUES (1289, 60, 1);
INSERT INTO favorites VALUES (1289, 108, 6);
INSERT INTO favorites VALUES (1289, 91, 5);
INSERT INTO favorites VALUES (1289, 27, 3);
INSERT INTO favorites VALUES (1289, 15, 4);
INSERT INTO favorites VALUES (1290, 28, 1);
INSERT INTO favorites VALUES (1290, 96, 2);
INSERT INTO favorites VALUES (1291, 36, 1);
INSERT INTO favorites VALUES (1291, 33, 2);
INSERT INTO favorites VALUES (1291, 74, 3);
INSERT INTO favorites VALUES (1292, 50, 1);
INSERT INTO favorites VALUES (1292, 63, 5);
INSERT INTO favorites VALUES (1292, 47, 2);
INSERT INTO favorites VALUES (1292, 53, 4);
INSERT INTO favorites VALUES (1292, 3, 6);
INSERT INTO favorites VALUES (1292, 46, 3);
INSERT INTO favorites VALUES (1293, 58, 1);
INSERT INTO favorites VALUES (1293, 81, 3);
INSERT INTO favorites VALUES (1293, 116, 2);
INSERT INTO favorites VALUES (1293, 3, 7);
INSERT INTO favorites VALUES (1293, 8, 4);
INSERT INTO favorites VALUES (1293, 37, 6);
INSERT INTO favorites VALUES (1293, 29, 5);
INSERT INTO favorites VALUES (1293, 98, 8);
INSERT INTO favorites VALUES (1294, 71, 1);
INSERT INTO favorites VALUES (1295, 8, 1);
INSERT INTO favorites VALUES (1295, 61, 2);
INSERT INTO favorites VALUES (1296, 78, 1);
INSERT INTO favorites VALUES (1296, 3, 2);
INSERT INTO favorites VALUES (1297, 88, 1);
INSERT INTO favorites VALUES (1298, 10, 1);
INSERT INTO favorites VALUES (1298, 49, 2);
INSERT INTO favorites VALUES (1299, 23, 1);
INSERT INTO favorites VALUES (1299, 22, 2);
INSERT INTO favorites VALUES (1299, 6, 3);
INSERT INTO favorites VALUES (1300, 13, 1);
INSERT INTO favorites VALUES (1300, 5, 2);
INSERT INTO favorites VALUES (1301, 8, 1);
INSERT INTO favorites VALUES (1301, 13, 2);
INSERT INTO favorites VALUES (1301, 62, 3);
INSERT INTO favorites VALUES (1301, 101, 4);
INSERT INTO favorites VALUES (1301, 7, 6);
INSERT INTO favorites VALUES (1301, 16, 5);
INSERT INTO favorites VALUES (1302, 74, 2);
INSERT INTO favorites VALUES (1302, 64, 1);
INSERT INTO favorites VALUES (1303, 76, 1);
INSERT INTO favorites VALUES (1303, 116, 2);
INSERT INTO favorites VALUES (1303, 4, 4);
INSERT INTO favorites VALUES (1303, 36, 3);
INSERT INTO favorites VALUES (1303, 4, 6);
INSERT INTO favorites VALUES (1303, 99, 5);
INSERT INTO favorites VALUES (1304, 20, 2);
INSERT INTO favorites VALUES (1304, 27, 3);
INSERT INTO favorites VALUES (1304, 43, 1);
INSERT INTO favorites VALUES (1304, 62, 4);
INSERT INTO favorites VALUES (1304, 85, 5);
INSERT INTO favorites VALUES (1305, 61, 2);
INSERT INTO favorites VALUES (1305, 24, 1);
INSERT INTO favorites VALUES (1306, 5, 2);
INSERT INTO favorites VALUES (1306, 85, 1);
INSERT INTO favorites VALUES (1307, 102, 3);
INSERT INTO favorites VALUES (1307, 33, 2);
INSERT INTO favorites VALUES (1307, 56, 1);
INSERT INTO favorites VALUES (1307, 112, 6);
INSERT INTO favorites VALUES (1307, 109, 4);
INSERT INTO favorites VALUES (1307, 5, 5);
INSERT INTO favorites VALUES (1308, 54, 1);
INSERT INTO favorites VALUES (1308, 113, 2);
INSERT INTO favorites VALUES (1309, 113, 2);
INSERT INTO favorites VALUES (1309, 68, 1);
INSERT INTO favorites VALUES (1309, 14, 3);
INSERT INTO favorites VALUES (1310, 12, 1);
INSERT INTO favorites VALUES (1310, 104, 2);
INSERT INTO favorites VALUES (1311, 56, 1);
INSERT INTO favorites VALUES (1311, 5, 2);
INSERT INTO favorites VALUES (1311, 7, 3);
INSERT INTO favorites VALUES (1313, 37, 1);
INSERT INTO favorites VALUES (1314, 10, 1);
INSERT INTO favorites VALUES (1314, 9, 2);
INSERT INTO favorites VALUES (1315, 9, 1);
INSERT INTO favorites VALUES (1315, 86, 3);
INSERT INTO favorites VALUES (1315, 3, 2);
INSERT INTO favorites VALUES (1316, 54, 2);
INSERT INTO favorites VALUES (1316, 56, 1);
INSERT INTO favorites VALUES (1317, 75, 1);
INSERT INTO favorites VALUES (1317, 93, 3);
INSERT INTO favorites VALUES (1317, 94, 2);
INSERT INTO favorites VALUES (1318, 8, 4);
INSERT INTO favorites VALUES (1318, 50, 3);
INSERT INTO favorites VALUES (1318, 41, 1);
INSERT INTO favorites VALUES (1318, 53, 2);
INSERT INTO favorites VALUES (1318, 19, 5);
INSERT INTO favorites VALUES (1318, 29, 8);
INSERT INTO favorites VALUES (1318, 78, 7);
INSERT INTO favorites VALUES (1318, 30, 6);
INSERT INTO favorites VALUES (1319, 83, 1);
INSERT INTO favorites VALUES (1320, 38, 1);
INSERT INTO favorites VALUES (1320, 21, 2);
INSERT INTO favorites VALUES (1320, 61, 3);
INSERT INTO favorites VALUES (1321, 19, 2);
INSERT INTO favorites VALUES (1321, 76, 1);
INSERT INTO favorites VALUES (1321, 17, 3);
INSERT INTO favorites VALUES (1321, 80, 4);
INSERT INTO favorites VALUES (1322, 2, 1);
INSERT INTO favorites VALUES (1322, 89, 2);
INSERT INTO favorites VALUES (1323, 27, 2);
INSERT INTO favorites VALUES (1323, 57, 1);
INSERT INTO favorites VALUES (1324, 70, 1);
INSERT INTO favorites VALUES (1324, 13, 2);
INSERT INTO favorites VALUES (1324, 44, 3);
INSERT INTO favorites VALUES (1325, 7, 3);
INSERT INTO favorites VALUES (1325, 5, 2);
INSERT INTO favorites VALUES (1325, 112, 6);
INSERT INTO favorites VALUES (1325, 89, 1);
INSERT INTO favorites VALUES (1325, 100, 7);
INSERT INTO favorites VALUES (1325, 92, 5);
INSERT INTO favorites VALUES (1325, 116, 4);
INSERT INTO favorites VALUES (1325, 23, 8);
INSERT INTO favorites VALUES (1326, 19, 3);
INSERT INTO favorites VALUES (1326, 114, 1);
INSERT INTO favorites VALUES (1326, 55, 2);
INSERT INTO favorites VALUES (1326, 107, 5);
INSERT INTO favorites VALUES (1326, 21, 4);
INSERT INTO favorites VALUES (1327, 2, 1);
INSERT INTO favorites VALUES (1328, 114, 1);
INSERT INTO favorites VALUES (1328, 83, 4);
INSERT INTO favorites VALUES (1328, 24, 3);
INSERT INTO favorites VALUES (1328, 15, 2);
INSERT INTO favorites VALUES (1328, 82, 5);
INSERT INTO favorites VALUES (1329, 91, 1);
INSERT INTO favorites VALUES (1329, 51, 2);
INSERT INTO favorites VALUES (1329, 50, 3);
INSERT INTO favorites VALUES (1330, 34, 1);
INSERT INTO favorites VALUES (1330, 112, 2);
INSERT INTO favorites VALUES (1330, 11, 3);
INSERT INTO favorites VALUES (1330, 67, 5);
INSERT INTO favorites VALUES (1330, 69, 4);
INSERT INTO favorites VALUES (1332, 34, 1);
INSERT INTO favorites VALUES (1332, 114, 2);
INSERT INTO favorites VALUES (1332, 100, 3);
INSERT INTO favorites VALUES (1333, 68, 1);
INSERT INTO favorites VALUES (1333, 49, 2);
INSERT INTO favorites VALUES (1334, 4, 2);
INSERT INTO favorites VALUES (1334, 103, 1);
INSERT INTO favorites VALUES (1334, 72, 3);
INSERT INTO favorites VALUES (1335, 25, 1);
INSERT INTO favorites VALUES (1335, 60, 2);
INSERT INTO favorites VALUES (1335, 86, 3);
INSERT INTO favorites VALUES (1335, 84, 4);
INSERT INTO favorites VALUES (1335, 112, 5);
INSERT INTO favorites VALUES (1337, 66, 1);
INSERT INTO favorites VALUES (1337, 4, 3);
INSERT INTO favorites VALUES (1337, 35, 2);
INSERT INTO favorites VALUES (1337, 111, 5);
INSERT INTO favorites VALUES (1337, 88, 4);
INSERT INTO favorites VALUES (1339, 51, 1);
INSERT INTO favorites VALUES (1340, 62, 4);
INSERT INTO favorites VALUES (1340, 87, 2);
INSERT INTO favorites VALUES (1340, 70, 1);
INSERT INTO favorites VALUES (1340, 65, 5);
INSERT INTO favorites VALUES (1340, 95, 3);
INSERT INTO favorites VALUES (1341, 22, 2);
INSERT INTO favorites VALUES (1341, 43, 1);
INSERT INTO favorites VALUES (1341, 91, 3);
INSERT INTO favorites VALUES (1341, 101, 4);
INSERT INTO favorites VALUES (1342, 91, 2);
INSERT INTO favorites VALUES (1342, 38, 1);
INSERT INTO favorites VALUES (1342, 19, 3);
INSERT INTO favorites VALUES (1343, 26, 1);
INSERT INTO favorites VALUES (1343, 32, 2);
INSERT INTO favorites VALUES (1343, 30, 3);
INSERT INTO favorites VALUES (1344, 53, 2);
INSERT INTO favorites VALUES (1344, 97, 1);
INSERT INTO favorites VALUES (1344, 83, 3);
INSERT INTO favorites VALUES (1345, 27, 4);
INSERT INTO favorites VALUES (1345, 66, 3);
INSERT INTO favorites VALUES (1345, 86, 1);
INSERT INTO favorites VALUES (1345, 28, 2);
INSERT INTO favorites VALUES (1346, 41, 1);
INSERT INTO favorites VALUES (1346, 9, 2);
INSERT INTO favorites VALUES (1346, 47, 3);
INSERT INTO favorites VALUES (1347, 100, 1);
INSERT INTO favorites VALUES (1348, 79, 3);
INSERT INTO favorites VALUES (1348, 64, 2);
INSERT INTO favorites VALUES (1348, 42, 1);
INSERT INTO favorites VALUES (1349, 85, 2);
INSERT INTO favorites VALUES (1349, 50, 1);
INSERT INTO favorites VALUES (1349, 33, 4);
INSERT INTO favorites VALUES (1349, 41, 5);
INSERT INTO favorites VALUES (1349, 21, 3);
INSERT INTO favorites VALUES (1350, 95, 3);
INSERT INTO favorites VALUES (1350, 99, 1);
INSERT INTO favorites VALUES (1350, 29, 2);
INSERT INTO favorites VALUES (1350, 91, 4);
INSERT INTO favorites VALUES (1352, 64, 1);
INSERT INTO favorites VALUES (1352, 35, 2);
INSERT INTO favorites VALUES (1352, 25, 3);
INSERT INTO favorites VALUES (1353, 92, 1);
INSERT INTO favorites VALUES (1354, 29, 2);
INSERT INTO favorites VALUES (1354, 85, 1);
INSERT INTO favorites VALUES (1355, 92, 1);
INSERT INTO favorites VALUES (1357, 23, 3);
INSERT INTO favorites VALUES (1357, 36, 2);
INSERT INTO favorites VALUES (1357, 107, 1);
INSERT INTO favorites VALUES (1358, 108, 1);
INSERT INTO favorites VALUES (1358, 97, 2);
INSERT INTO favorites VALUES (1358, 109, 3);
INSERT INTO favorites VALUES (1359, 59, 1);
INSERT INTO favorites VALUES (1359, 47, 2);
INSERT INTO favorites VALUES (1360, 83, 1);
INSERT INTO favorites VALUES (1361, 45, 1);
INSERT INTO favorites VALUES (1363, 55, 3);
INSERT INTO favorites VALUES (1363, 55, 2);
INSERT INTO favorites VALUES (1363, 82, 1);
INSERT INTO favorites VALUES (1363, 19, 4);
INSERT INTO favorites VALUES (1364, 64, 2);
INSERT INTO favorites VALUES (1364, 28, 1);
INSERT INTO favorites VALUES (1364, 27, 3);
INSERT INTO favorites VALUES (1365, 23, 1);
INSERT INTO favorites VALUES (1365, 9, 2);
INSERT INTO favorites VALUES (1366, 4, 1);
INSERT INTO favorites VALUES (1367, 14, 1);
INSERT INTO favorites VALUES (1367, 52, 2);
INSERT INTO favorites VALUES (1367, 4, 3);
INSERT INTO favorites VALUES (1369, 84, 1);
INSERT INTO favorites VALUES (1371, 108, 1);
INSERT INTO favorites VALUES (1371, 62, 2);
INSERT INTO favorites VALUES (1371, 2, 3);
INSERT INTO favorites VALUES (1371, 32, 4);
INSERT INTO favorites VALUES (1372, 59, 4);
INSERT INTO favorites VALUES (1372, 19, 2);
INSERT INTO favorites VALUES (1372, 96, 1);
INSERT INTO favorites VALUES (1372, 6, 3);
INSERT INTO favorites VALUES (1373, 9, 1);
INSERT INTO favorites VALUES (1373, 87, 2);
INSERT INTO favorites VALUES (1374, 88, 1);
INSERT INTO favorites VALUES (1374, 6, 2);
INSERT INTO favorites VALUES (1375, 55, 2);
INSERT INTO favorites VALUES (1375, 108, 1);
INSERT INTO favorites VALUES (1375, 31, 3);
INSERT INTO favorites VALUES (1375, 80, 4);
INSERT INTO favorites VALUES (1376, 53, 1);
INSERT INTO favorites VALUES (1376, 79, 2);
INSERT INTO favorites VALUES (1377, 93, 1);
INSERT INTO favorites VALUES (1377, 26, 3);
INSERT INTO favorites VALUES (1377, 5, 2);
INSERT INTO favorites VALUES (1378, 114, 2);
INSERT INTO favorites VALUES (1378, 11, 1);
INSERT INTO favorites VALUES (1379, 95, 1);
INSERT INTO favorites VALUES (1379, 22, 2);
INSERT INTO favorites VALUES (1380, 55, 2);
INSERT INTO favorites VALUES (1380, 39, 1);
INSERT INTO favorites VALUES (1381, 45, 1);
INSERT INTO favorites VALUES (1381, 68, 2);
INSERT INTO favorites VALUES (1382, 20, 2);
INSERT INTO favorites VALUES (1382, 109, 1);
INSERT INTO favorites VALUES (1382, 11, 3);
INSERT INTO favorites VALUES (1383, 116, 1);
INSERT INTO favorites VALUES (1383, 110, 2);
INSERT INTO favorites VALUES (1383, 72, 3);
INSERT INTO favorites VALUES (1384, 74, 3);
INSERT INTO favorites VALUES (1384, 21, 1);
INSERT INTO favorites VALUES (1384, 90, 2);
INSERT INTO favorites VALUES (1384, 6, 5);
INSERT INTO favorites VALUES (1384, 58, 4);
INSERT INTO favorites VALUES (1385, 45, 1);
INSERT INTO favorites VALUES (1385, 64, 2);
INSERT INTO favorites VALUES (1385, 69, 4);
INSERT INTO favorites VALUES (1385, 10, 3);
INSERT INTO favorites VALUES (1385, 65, 5);
INSERT INTO favorites VALUES (1385, 20, 6);
INSERT INTO favorites VALUES (1386, 18, 1);
INSERT INTO favorites VALUES (1386, 15, 2);
INSERT INTO favorites VALUES (1387, 55, 1);
INSERT INTO favorites VALUES (1387, 31, 2);
INSERT INTO favorites VALUES (1387, 92, 3);
INSERT INTO favorites VALUES (1388, 49, 1);
INSERT INTO favorites VALUES (1388, 42, 3);
INSERT INTO favorites VALUES (1388, 35, 2);
INSERT INTO favorites VALUES (1389, 7, 1);
INSERT INTO favorites VALUES (1389, 10, 2);
INSERT INTO favorites VALUES (1390, 73, 1);
INSERT INTO favorites VALUES (1390, 39, 3);
INSERT INTO favorites VALUES (1390, 59, 2);
INSERT INTO favorites VALUES (1390, 36, 4);
INSERT INTO favorites VALUES (1390, 75, 5);
INSERT INTO favorites VALUES (1391, 69, 1);
INSERT INTO favorites VALUES (1391, 71, 2);
INSERT INTO favorites VALUES (1391, 65, 5);
INSERT INTO favorites VALUES (1391, 46, 3);
INSERT INTO favorites VALUES (1391, 95, 4);
INSERT INTO favorites VALUES (1392, 43, 2);
INSERT INTO favorites VALUES (1392, 44, 1);
INSERT INTO favorites VALUES (1393, 88, 2);
INSERT INTO favorites VALUES (1393, 10, 1);
INSERT INTO favorites VALUES (1393, 10, 4);
INSERT INTO favorites VALUES (1393, 55, 3);
INSERT INTO favorites VALUES (1394, 75, 3);
INSERT INTO favorites VALUES (1394, 58, 1);
INSERT INTO favorites VALUES (1394, 74, 2);
INSERT INTO favorites VALUES (1394, 106, 4);
INSERT INTO favorites VALUES (1395, 91, 1);
INSERT INTO favorites VALUES (1395, 82, 2);
INSERT INTO favorites VALUES (1395, 86, 3);
INSERT INTO favorites VALUES (1396, 36, 1);
INSERT INTO favorites VALUES (1397, 2, 1);
INSERT INTO favorites VALUES (1398, 104, 1);
INSERT INTO favorites VALUES (1398, 31, 2);
INSERT INTO favorites VALUES (1399, 9, 2);
INSERT INTO favorites VALUES (1399, 30, 1);
INSERT INTO favorites VALUES (1400, 110, 2);
INSERT INTO favorites VALUES (1400, 21, 1);
INSERT INTO favorites VALUES (1400, 15, 3);
INSERT INTO favorites VALUES (1401, 90, 1);
INSERT INTO favorites VALUES (1401, 4, 3);
INSERT INTO favorites VALUES (1401, 59, 2);
INSERT INTO favorites VALUES (1401, 46, 5);
INSERT INTO favorites VALUES (1401, 33, 4);
INSERT INTO favorites VALUES (1402, 98, 1);
INSERT INTO favorites VALUES (1403, 15, 1);
INSERT INTO favorites VALUES (1404, 98, 1);
INSERT INTO favorites VALUES (1404, 73, 4);
INSERT INTO favorites VALUES (1404, 9, 3);
INSERT INTO favorites VALUES (1404, 40, 2);
INSERT INTO favorites VALUES (1405, 8, 2);
INSERT INTO favorites VALUES (1405, 33, 1);
INSERT INTO favorites VALUES (1405, 28, 4);
INSERT INTO favorites VALUES (1405, 10, 3);
INSERT INTO favorites VALUES (1405, 80, 6);
INSERT INTO favorites VALUES (1405, 63, 5);
INSERT INTO favorites VALUES (1406, 69, 1);
INSERT INTO favorites VALUES (1406, 4, 2);
INSERT INTO favorites VALUES (1407, 28, 1);
INSERT INTO favorites VALUES (1407, 3, 4);
INSERT INTO favorites VALUES (1407, 82, 2);
INSERT INTO favorites VALUES (1407, 30, 3);
INSERT INTO favorites VALUES (1408, 103, 1);
INSERT INTO favorites VALUES (1408, 16, 4);
INSERT INTO favorites VALUES (1408, 50, 2);
INSERT INTO favorites VALUES (1408, 55, 3);
INSERT INTO favorites VALUES (1409, 2, 1);
INSERT INTO favorites VALUES (1409, 31, 2);
INSERT INTO favorites VALUES (1409, 9, 3);
INSERT INTO favorites VALUES (1410, 55, 1);
INSERT INTO favorites VALUES (1410, 15, 2);
INSERT INTO favorites VALUES (1410, 20, 5);
INSERT INTO favorites VALUES (1410, 50, 3);
INSERT INTO favorites VALUES (1410, 66, 4);
INSERT INTO favorites VALUES (1411, 7, 1);
INSERT INTO favorites VALUES (1411, 109, 3);
INSERT INTO favorites VALUES (1411, 24, 2);
INSERT INTO favorites VALUES (1412, 28, 1);
INSERT INTO favorites VALUES (1412, 48, 2);
INSERT INTO favorites VALUES (1413, 58, 1);
INSERT INTO favorites VALUES (1413, 20, 2);
INSERT INTO favorites VALUES (1413, 78, 3);
INSERT INTO favorites VALUES (1414, 66, 1);
INSERT INTO favorites VALUES (1414, 11, 2);
INSERT INTO favorites VALUES (1415, 6, 1);
INSERT INTO favorites VALUES (1415, 33, 2);
INSERT INTO favorites VALUES (1416, 13, 1);
INSERT INTO favorites VALUES (1417, 112, 1);
INSERT INTO favorites VALUES (1418, 109, 3);
INSERT INTO favorites VALUES (1418, 16, 2);
INSERT INTO favorites VALUES (1418, 28, 1);
INSERT INTO favorites VALUES (1418, 21, 4);
INSERT INTO favorites VALUES (1419, 55, 1);
INSERT INTO favorites VALUES (1419, 105, 2);
INSERT INTO favorites VALUES (1420, 46, 1);
INSERT INTO favorites VALUES (1421, 11, 2);
INSERT INTO favorites VALUES (1421, 20, 1);
INSERT INTO favorites VALUES (1422, 3, 1);
INSERT INTO favorites VALUES (1422, 98, 2);
INSERT INTO favorites VALUES (1422, 33, 3);
INSERT INTO favorites VALUES (1422, 32, 4);
INSERT INTO favorites VALUES (1424, 13, 2);
INSERT INTO favorites VALUES (1424, 104, 1);
INSERT INTO favorites VALUES (1424, 82, 3);
INSERT INTO favorites VALUES (1425, 35, 1);
INSERT INTO favorites VALUES (1426, 14, 1);
INSERT INTO favorites VALUES (1427, 31, 1);
INSERT INTO favorites VALUES (1427, 48, 2);
INSERT INTO favorites VALUES (1427, 51, 4);
INSERT INTO favorites VALUES (1427, 84, 3);
INSERT INTO favorites VALUES (1428, 1, 1);
INSERT INTO favorites VALUES (1429, 61, 3);
INSERT INTO favorites VALUES (1429, 38, 2);
INSERT INTO favorites VALUES (1429, 91, 1);
INSERT INTO favorites VALUES (1429, 4, 4);
INSERT INTO favorites VALUES (1430, 3, 1);
INSERT INTO favorites VALUES (1430, 75, 2);
INSERT INTO favorites VALUES (1430, 65, 3);
INSERT INTO favorites VALUES (1430, 29, 4);
INSERT INTO favorites VALUES (1430, 106, 5);
INSERT INTO favorites VALUES (1431, 66, 3);
INSERT INTO favorites VALUES (1431, 3, 2);
INSERT INTO favorites VALUES (1431, 3, 1);
INSERT INTO favorites VALUES (1431, 107, 4);
INSERT INTO favorites VALUES (1433, 42, 3);
INSERT INTO favorites VALUES (1433, 109, 2);
INSERT INTO favorites VALUES (1433, 45, 1);
INSERT INTO favorites VALUES (1433, 10, 4);
INSERT INTO favorites VALUES (1433, 19, 5);
INSERT INTO favorites VALUES (1434, 66, 1);
INSERT INTO favorites VALUES (1434, 20, 3);
INSERT INTO favorites VALUES (1434, 10, 2);
INSERT INTO favorites VALUES (1435, 30, 1);
INSERT INTO favorites VALUES (1435, 81, 2);
INSERT INTO favorites VALUES (1436, 30, 1);
INSERT INTO favorites VALUES (1437, 59, 1);
INSERT INTO favorites VALUES (1438, 14, 1);
INSERT INTO favorites VALUES (1438, 31, 2);
INSERT INTO favorites VALUES (1438, 12, 3);
INSERT INTO favorites VALUES (1439, 50, 1);
INSERT INTO favorites VALUES (1439, 29, 2);
INSERT INTO favorites VALUES (1441, 1, 1);
INSERT INTO favorites VALUES (1442, 22, 1);
INSERT INTO favorites VALUES (1442, 61, 2);
INSERT INTO favorites VALUES (1443, 2, 1);
INSERT INTO favorites VALUES (1443, 108, 2);
INSERT INTO favorites VALUES (1443, 69, 3);
INSERT INTO favorites VALUES (1444, 60, 2);
INSERT INTO favorites VALUES (1444, 21, 1);
INSERT INTO favorites VALUES (1445, 4, 1);
INSERT INTO favorites VALUES (1446, 95, 2);
INSERT INTO favorites VALUES (1446, 80, 1);
INSERT INTO favorites VALUES (1448, 52, 1);
INSERT INTO favorites VALUES (1449, 73, 1);
INSERT INTO favorites VALUES (1449, 93, 5);
INSERT INTO favorites VALUES (1449, 33, 3);
INSERT INTO favorites VALUES (1449, 42, 2);
INSERT INTO favorites VALUES (1449, 49, 4);
INSERT INTO favorites VALUES (1450, 82, 2);
INSERT INTO favorites VALUES (1450, 73, 1);
INSERT INTO favorites VALUES (1450, 88, 3);
INSERT INTO favorites VALUES (1451, 14, 1);
INSERT INTO favorites VALUES (1451, 9, 2);
INSERT INTO favorites VALUES (1453, 56, 1);
INSERT INTO favorites VALUES (1454, 64, 1);
INSERT INTO favorites VALUES (1454, 103, 2);
INSERT INTO favorites VALUES (1454, 3, 3);
INSERT INTO favorites VALUES (1454, 63, 4);
INSERT INTO favorites VALUES (1455, 88, 1);
INSERT INTO favorites VALUES (1455, 65, 2);
INSERT INTO favorites VALUES (1455, 100, 3);
INSERT INTO favorites VALUES (1456, 58, 1);
INSERT INTO favorites VALUES (1456, 81, 3);
INSERT INTO favorites VALUES (1456, 91, 4);
INSERT INTO favorites VALUES (1456, 44, 2);
INSERT INTO favorites VALUES (1456, 9, 6);
INSERT INTO favorites VALUES (1456, 114, 5);
INSERT INTO favorites VALUES (1457, 98, 2);
INSERT INTO favorites VALUES (1457, 42, 1);
INSERT INTO favorites VALUES (1457, 79, 3);
INSERT INTO favorites VALUES (1458, 99, 3);
INSERT INTO favorites VALUES (1458, 22, 2);
INSERT INTO favorites VALUES (1458, 39, 1);
INSERT INTO favorites VALUES (1458, 43, 4);
INSERT INTO favorites VALUES (1459, 8, 1);
INSERT INTO favorites VALUES (1459, 61, 2);
INSERT INTO favorites VALUES (1459, 4, 3);
INSERT INTO favorites VALUES (1460, 58, 4);
INSERT INTO favorites VALUES (1460, 68, 1);
INSERT INTO favorites VALUES (1460, 36, 2);
INSERT INTO favorites VALUES (1460, 101, 3);
INSERT INTO favorites VALUES (1463, 47, 2);
INSERT INTO favorites VALUES (1463, 102, 1);
INSERT INTO favorites VALUES (1463, 73, 3);
INSERT INTO favorites VALUES (1463, 83, 4);
INSERT INTO favorites VALUES (1463, 17, 7);
INSERT INTO favorites VALUES (1463, 11, 5);
INSERT INTO favorites VALUES (1463, 54, 6);
INSERT INTO favorites VALUES (1464, 42, 1);
INSERT INTO favorites VALUES (1464, 15, 2);
INSERT INTO favorites VALUES (1465, 94, 2);
INSERT INTO favorites VALUES (1465, 67, 1);
INSERT INTO favorites VALUES (1465, 1, 3);
INSERT INTO favorites VALUES (1466, 91, 4);
INSERT INTO favorites VALUES (1466, 30, 3);
INSERT INTO favorites VALUES (1466, 66, 2);
INSERT INTO favorites VALUES (1466, 72, 1);
INSERT INTO favorites VALUES (1466, 11, 6);
INSERT INTO favorites VALUES (1466, 7, 5);
INSERT INTO favorites VALUES (1466, 55, 7);
INSERT INTO favorites VALUES (1467, 69, 1);
INSERT INTO favorites VALUES (1467, 7, 2);
INSERT INTO favorites VALUES (1467, 70, 4);
INSERT INTO favorites VALUES (1467, 93, 3);
INSERT INTO favorites VALUES (1468, 20, 1);
INSERT INTO favorites VALUES (1468, 16, 2);
INSERT INTO favorites VALUES (1469, 97, 2);
INSERT INTO favorites VALUES (1469, 49, 1);
INSERT INTO favorites VALUES (1470, 87, 1);
INSERT INTO favorites VALUES (1470, 15, 2);
INSERT INTO favorites VALUES (1470, 12, 3);
INSERT INTO favorites VALUES (1471, 91, 1);
INSERT INTO favorites VALUES (1472, 30, 1);
INSERT INTO favorites VALUES (1472, 33, 2);
INSERT INTO favorites VALUES (1473, 13, 1);
INSERT INTO favorites VALUES (1473, 24, 3);
INSERT INTO favorites VALUES (1473, 63, 2);
INSERT INTO favorites VALUES (1474, 1, 1);
INSERT INTO favorites VALUES (1474, 55, 2);
INSERT INTO favorites VALUES (1475, 8, 2);
INSERT INTO favorites VALUES (1475, 90, 1);
INSERT INTO favorites VALUES (1476, 2, 1);
INSERT INTO favorites VALUES (1476, 35, 2);
INSERT INTO favorites VALUES (1477, 59, 2);
INSERT INTO favorites VALUES (1477, 13, 3);
INSERT INTO favorites VALUES (1477, 59, 4);
INSERT INTO favorites VALUES (1477, 101, 1);
INSERT INTO favorites VALUES (1478, 48, 1);
INSERT INTO favorites VALUES (1478, 94, 2);
INSERT INTO favorites VALUES (1479, 32, 1);
INSERT INTO favorites VALUES (1480, 47, 1);
INSERT INTO favorites VALUES (1481, 32, 1);
INSERT INTO favorites VALUES (1481, 90, 2);
INSERT INTO favorites VALUES (1481, 92, 4);
INSERT INTO favorites VALUES (1481, 71, 3);
INSERT INTO favorites VALUES (1482, 12, 2);
INSERT INTO favorites VALUES (1482, 20, 1);
INSERT INTO favorites VALUES (1483, 65, 4);
INSERT INTO favorites VALUES (1483, 41, 2);
INSERT INTO favorites VALUES (1483, 107, 1);
INSERT INTO favorites VALUES (1483, 7, 3);
INSERT INTO favorites VALUES (1484, 5, 1);
INSERT INTO favorites VALUES (1485, 116, 2);
INSERT INTO favorites VALUES (1485, 114, 1);
INSERT INTO favorites VALUES (1486, 63, 3);
INSERT INTO favorites VALUES (1486, 52, 2);
INSERT INTO favorites VALUES (1486, 43, 1);
INSERT INTO favorites VALUES (1487, 64, 2);
INSERT INTO favorites VALUES (1487, 61, 5);
INSERT INTO favorites VALUES (1487, 79, 3);
INSERT INTO favorites VALUES (1487, 15, 4);
INSERT INTO favorites VALUES (1487, 67, 1);
INSERT INTO favorites VALUES (1488, 60, 3);
INSERT INTO favorites VALUES (1488, 101, 2);
INSERT INTO favorites VALUES (1488, 27, 1);
INSERT INTO favorites VALUES (1490, 81, 1);
INSERT INTO favorites VALUES (1490, 36, 2);
INSERT INTO favorites VALUES (1491, 21, 1);
INSERT INTO favorites VALUES (1491, 106, 2);
INSERT INTO favorites VALUES (1492, 110, 5);
INSERT INTO favorites VALUES (1492, 32, 3);
INSERT INTO favorites VALUES (1492, 1, 4);
INSERT INTO favorites VALUES (1492, 69, 1);
INSERT INTO favorites VALUES (1492, 35, 2);
INSERT INTO favorites VALUES (1492, 3, 7);
INSERT INTO favorites VALUES (1492, 49, 6);
INSERT INTO favorites VALUES (1493, 24, 4);
INSERT INTO favorites VALUES (1493, 42, 1);
INSERT INTO favorites VALUES (1493, 21, 2);
INSERT INTO favorites VALUES (1493, 42, 3);
INSERT INTO favorites VALUES (1493, 47, 5);
INSERT INTO favorites VALUES (1494, 13, 2);
INSERT INTO favorites VALUES (1494, 114, 1);
INSERT INTO favorites VALUES (1495, 69, 1);
INSERT INTO favorites VALUES (1496, 109, 2);
INSERT INTO favorites VALUES (1496, 111, 1);
INSERT INTO favorites VALUES (1496, 101, 3);
INSERT INTO favorites VALUES (1497, 32, 1);
INSERT INTO favorites VALUES (1497, 96, 3);
INSERT INTO favorites VALUES (1497, 115, 2);
INSERT INTO favorites VALUES (1498, 63, 1);
INSERT INTO favorites VALUES (1500, 106, 1);
INSERT INTO favorites VALUES (1501, 66, 1);
INSERT INTO favorites VALUES (1501, 60, 2);
INSERT INTO favorites VALUES (1502, 30, 1);
INSERT INTO favorites VALUES (1503, 5, 2);
INSERT INTO favorites VALUES (1503, 105, 1);
INSERT INTO favorites VALUES (1503, 55, 3);
INSERT INTO favorites VALUES (1503, 70, 4);
INSERT INTO favorites VALUES (1504, 37, 1);
INSERT INTO favorites VALUES (1504, 42, 4);
INSERT INTO favorites VALUES (1504, 28, 3);
INSERT INTO favorites VALUES (1504, 8, 2);
INSERT INTO favorites VALUES (1504, 30, 5);
INSERT INTO favorites VALUES (1504, 35, 6);
INSERT INTO favorites VALUES (1505, 72, 1);
INSERT INTO favorites VALUES (1505, 43, 5);
INSERT INTO favorites VALUES (1505, 83, 4);
INSERT INTO favorites VALUES (1505, 51, 6);
INSERT INTO favorites VALUES (1505, 4, 2);
INSERT INTO favorites VALUES (1505, 94, 3);
INSERT INTO favorites VALUES (1507, 41, 1);
INSERT INTO favorites VALUES (1507, 72, 2);
INSERT INTO favorites VALUES (1508, 102, 1);
INSERT INTO favorites VALUES (1509, 114, 3);
INSERT INTO favorites VALUES (1509, 89, 1);
INSERT INTO favorites VALUES (1509, 36, 2);
INSERT INTO favorites VALUES (1510, 106, 1);
INSERT INTO favorites VALUES (1510, 48, 2);
INSERT INTO favorites VALUES (1510, 57, 3);
INSERT INTO favorites VALUES (1510, 84, 4);
INSERT INTO favorites VALUES (1511, 78, 2);
INSERT INTO favorites VALUES (1511, 33, 1);
INSERT INTO favorites VALUES (1511, 10, 4);
INSERT INTO favorites VALUES (1511, 9, 3);
INSERT INTO favorites VALUES (1512, 71, 2);
INSERT INTO favorites VALUES (1512, 85, 1);
INSERT INTO favorites VALUES (1512, 13, 5);
INSERT INTO favorites VALUES (1512, 25, 3);
INSERT INTO favorites VALUES (1512, 10, 4);
INSERT INTO favorites VALUES (1512, 45, 6);
INSERT INTO favorites VALUES (1513, 71, 1);
INSERT INTO favorites VALUES (1514, 51, 1);
INSERT INTO favorites VALUES (1514, 13, 2);
INSERT INTO favorites VALUES (1514, 59, 3);
INSERT INTO favorites VALUES (1515, 77, 2);
INSERT INTO favorites VALUES (1515, 61, 1);
INSERT INTO favorites VALUES (1516, 45, 1);
INSERT INTO favorites VALUES (1516, 5, 2);
INSERT INTO favorites VALUES (1516, 32, 3);
INSERT INTO favorites VALUES (1517, 94, 2);
INSERT INTO favorites VALUES (1517, 9, 1);
INSERT INTO favorites VALUES (1518, 105, 1);
INSERT INTO favorites VALUES (1518, 14, 2);
INSERT INTO favorites VALUES (1518, 44, 3);
INSERT INTO favorites VALUES (1519, 116, 2);
INSERT INTO favorites VALUES (1519, 25, 1);
INSERT INTO favorites VALUES (1520, 55, 2);
INSERT INTO favorites VALUES (1520, 21, 1);
INSERT INTO favorites VALUES (1520, 11, 3);
INSERT INTO favorites VALUES (1520, 45, 4);
INSERT INTO favorites VALUES (1521, 81, 1);
INSERT INTO favorites VALUES (1521, 56, 2);
INSERT INTO favorites VALUES (1522, 69, 1);
INSERT INTO favorites VALUES (1523, 109, 1);
INSERT INTO favorites VALUES (1523, 62, 2);
INSERT INTO favorites VALUES (1524, 42, 2);
INSERT INTO favorites VALUES (1524, 26, 1);
INSERT INTO favorites VALUES (1524, 24, 3);
INSERT INTO favorites VALUES (1525, 47, 1);
INSERT INTO favorites VALUES (1525, 30, 3);
INSERT INTO favorites VALUES (1525, 12, 2);
INSERT INTO favorites VALUES (1526, 6, 1);
INSERT INTO favorites VALUES (1526, 59, 2);
INSERT INTO favorites VALUES (1527, 69, 1);
INSERT INTO favorites VALUES (1527, 108, 2);
INSERT INTO favorites VALUES (1527, 101, 3);
INSERT INTO favorites VALUES (1528, 106, 1);
INSERT INTO favorites VALUES (1528, 53, 2);
INSERT INTO favorites VALUES (1528, 19, 3);
INSERT INTO favorites VALUES (1529, 43, 1);
INSERT INTO favorites VALUES (1529, 50, 3);
INSERT INTO favorites VALUES (1529, 40, 2);
INSERT INTO favorites VALUES (1529, 46, 4);
INSERT INTO favorites VALUES (1529, 3, 5);
INSERT INTO favorites VALUES (1530, 3, 1);
INSERT INTO favorites VALUES (1531, 47, 1);
INSERT INTO favorites VALUES (1531, 45, 2);
INSERT INTO favorites VALUES (1533, 53, 2);
INSERT INTO favorites VALUES (1533, 64, 1);
INSERT INTO favorites VALUES (1533, 111, 3);
INSERT INTO favorites VALUES (1533, 90, 5);
INSERT INTO favorites VALUES (1533, 46, 4);
INSERT INTO favorites VALUES (1535, 47, 1);
INSERT INTO favorites VALUES (1536, 57, 1);
INSERT INTO favorites VALUES (1536, 20, 3);
INSERT INTO favorites VALUES (1536, 112, 2);
INSERT INTO favorites VALUES (1536, 42, 4);
INSERT INTO favorites VALUES (1537, 29, 2);
INSERT INTO favorites VALUES (1537, 99, 1);
INSERT INTO favorites VALUES (1537, 66, 4);
INSERT INTO favorites VALUES (1537, 89, 3);
INSERT INTO favorites VALUES (1538, 9, 1);
INSERT INTO favorites VALUES (1538, 73, 2);
INSERT INTO favorites VALUES (1539, 66, 2);
INSERT INTO favorites VALUES (1539, 1, 1);
INSERT INTO favorites VALUES (1540, 39, 1);
INSERT INTO favorites VALUES (1540, 54, 2);
INSERT INTO favorites VALUES (1540, 18, 3);
INSERT INTO favorites VALUES (1541, 98, 1);
INSERT INTO favorites VALUES (1541, 79, 2);
INSERT INTO favorites VALUES (1541, 26, 3);
INSERT INTO favorites VALUES (1542, 110, 1);
INSERT INTO favorites VALUES (1542, 45, 3);
INSERT INTO favorites VALUES (1542, 10, 2);
INSERT INTO favorites VALUES (1544, 17, 2);
INSERT INTO favorites VALUES (1544, 94, 1);
INSERT INTO favorites VALUES (1544, 99, 5);
INSERT INTO favorites VALUES (1544, 18, 3);
INSERT INTO favorites VALUES (1544, 24, 4);
INSERT INTO favorites VALUES (1545, 86, 1);
INSERT INTO favorites VALUES (1545, 14, 2);
INSERT INTO favorites VALUES (1545, 5, 3);
INSERT INTO favorites VALUES (1546, 112, 1);
INSERT INTO favorites VALUES (1546, 97, 4);
INSERT INTO favorites VALUES (1546, 111, 2);
INSERT INTO favorites VALUES (1546, 74, 3);
INSERT INTO favorites VALUES (1546, 115, 6);
INSERT INTO favorites VALUES (1546, 104, 5);
INSERT INTO favorites VALUES (1547, 67, 1);
INSERT INTO favorites VALUES (1547, 59, 2);
INSERT INTO favorites VALUES (1547, 13, 4);
INSERT INTO favorites VALUES (1547, 39, 3);
INSERT INTO favorites VALUES (1548, 8, 2);
INSERT INTO favorites VALUES (1548, 14, 1);
INSERT INTO favorites VALUES (1549, 91, 1);
INSERT INTO favorites VALUES (1550, 32, 1);
INSERT INTO favorites VALUES (1550, 35, 4);
INSERT INTO favorites VALUES (1550, 9, 2);
INSERT INTO favorites VALUES (1550, 87, 3);
INSERT INTO favorites VALUES (1552, 28, 2);
INSERT INTO favorites VALUES (1552, 3, 1);
INSERT INTO favorites VALUES (1552, 97, 4);
INSERT INTO favorites VALUES (1552, 25, 3);
INSERT INTO favorites VALUES (1553, 56, 1);
INSERT INTO favorites VALUES (1553, 83, 3);
INSERT INTO favorites VALUES (1553, 48, 2);
INSERT INTO favorites VALUES (1553, 24, 4);
INSERT INTO favorites VALUES (1555, 43, 1);
INSERT INTO favorites VALUES (1555, 113, 2);
INSERT INTO favorites VALUES (1556, 54, 1);
INSERT INTO favorites VALUES (1556, 28, 3);
INSERT INTO favorites VALUES (1556, 9, 2);
INSERT INTO favorites VALUES (1558, 44, 2);
INSERT INTO favorites VALUES (1558, 98, 1);
INSERT INTO favorites VALUES (1558, 22, 5);
INSERT INTO favorites VALUES (1558, 26, 3);
INSERT INTO favorites VALUES (1558, 39, 4);
INSERT INTO favorites VALUES (1558, 17, 6);
INSERT INTO favorites VALUES (1558, 29, 7);
INSERT INTO favorites VALUES (1559, 1, 1);
INSERT INTO favorites VALUES (1559, 57, 2);
INSERT INTO favorites VALUES (1559, 105, 3);
INSERT INTO favorites VALUES (1560, 32, 1);
INSERT INTO favorites VALUES (1560, 92, 2);
INSERT INTO favorites VALUES (1560, 3, 3);
INSERT INTO favorites VALUES (1561, 49, 2);
INSERT INTO favorites VALUES (1561, 56, 1);
INSERT INTO favorites VALUES (1561, 76, 4);
INSERT INTO favorites VALUES (1561, 2, 3);
INSERT INTO favorites VALUES (1562, 114, 1);
INSERT INTO favorites VALUES (1562, 46, 3);
INSERT INTO favorites VALUES (1562, 110, 2);
INSERT INTO favorites VALUES (1562, 31, 5);
INSERT INTO favorites VALUES (1562, 42, 4);
INSERT INTO favorites VALUES (1563, 51, 1);
INSERT INTO favorites VALUES (1563, 107, 2);
INSERT INTO favorites VALUES (1563, 4, 3);
INSERT INTO favorites VALUES (1563, 62, 4);
INSERT INTO favorites VALUES (1564, 53, 1);
INSERT INTO favorites VALUES (1564, 13, 3);
INSERT INTO favorites VALUES (1564, 88, 4);
INSERT INTO favorites VALUES (1564, 90, 2);
INSERT INTO favorites VALUES (1565, 42, 1);
INSERT INTO favorites VALUES (1565, 52, 2);
INSERT INTO favorites VALUES (1565, 38, 3);
INSERT INTO favorites VALUES (1565, 67, 4);
INSERT INTO favorites VALUES (1566, 34, 1);
INSERT INTO favorites VALUES (1566, 13, 2);
INSERT INTO favorites VALUES (1566, 76, 3);
INSERT INTO favorites VALUES (1566, 18, 4);
INSERT INTO favorites VALUES (1567, 84, 1);
INSERT INTO favorites VALUES (1567, 59, 2);
INSERT INTO favorites VALUES (1568, 1, 3);
INSERT INTO favorites VALUES (1568, 17, 4);
INSERT INTO favorites VALUES (1568, 90, 2);
INSERT INTO favorites VALUES (1568, 11, 1);
INSERT INTO favorites VALUES (1568, 97, 5);
INSERT INTO favorites VALUES (1568, 19, 6);
INSERT INTO favorites VALUES (1568, 45, 7);
INSERT INTO favorites VALUES (1569, 82, 2);
INSERT INTO favorites VALUES (1569, 32, 1);
INSERT INTO favorites VALUES (1569, 69, 3);
INSERT INTO favorites VALUES (1570, 24, 1);
INSERT INTO favorites VALUES (1570, 39, 2);
INSERT INTO favorites VALUES (1570, 111, 4);
INSERT INTO favorites VALUES (1570, 13, 3);
INSERT INTO favorites VALUES (1570, 22, 5);
INSERT INTO favorites VALUES (1571, 20, 1);
INSERT INTO favorites VALUES (1571, 24, 2);
INSERT INTO favorites VALUES (1572, 94, 1);
INSERT INTO favorites VALUES (1572, 1, 2);
INSERT INTO favorites VALUES (1572, 82, 3);
INSERT INTO favorites VALUES (1572, 62, 5);
INSERT INTO favorites VALUES (1572, 76, 4);
INSERT INTO favorites VALUES (1573, 4, 2);
INSERT INTO favorites VALUES (1573, 37, 1);
INSERT INTO favorites VALUES (1573, 79, 4);
INSERT INTO favorites VALUES (1573, 104, 3);
INSERT INTO favorites VALUES (1574, 113, 1);
INSERT INTO favorites VALUES (1575, 90, 1);
INSERT INTO favorites VALUES (1575, 15, 2);
INSERT INTO favorites VALUES (1576, 19, 1);
INSERT INTO favorites VALUES (1576, 55, 4);
INSERT INTO favorites VALUES (1576, 11, 3);
INSERT INTO favorites VALUES (1576, 112, 2);
INSERT INTO favorites VALUES (1576, 98, 5);
INSERT INTO favorites VALUES (1577, 102, 1);
INSERT INTO favorites VALUES (1577, 101, 3);
INSERT INTO favorites VALUES (1577, 107, 2);
INSERT INTO favorites VALUES (1577, 30, 5);
INSERT INTO favorites VALUES (1577, 105, 4);
INSERT INTO favorites VALUES (1578, 23, 2);
INSERT INTO favorites VALUES (1578, 56, 1);
INSERT INTO favorites VALUES (1578, 64, 3);
INSERT INTO favorites VALUES (1579, 92, 1);
INSERT INTO favorites VALUES (1579, 39, 3);
INSERT INTO favorites VALUES (1579, 16, 2);
INSERT INTO favorites VALUES (1580, 82, 1);
INSERT INTO favorites VALUES (1580, 13, 2);
INSERT INTO favorites VALUES (1580, 20, 3);
INSERT INTO favorites VALUES (1580, 55, 4);
INSERT INTO favorites VALUES (1580, 12, 5);
INSERT INTO favorites VALUES (1581, 70, 1);
INSERT INTO favorites VALUES (1581, 105, 2);
INSERT INTO favorites VALUES (1581, 2, 3);
INSERT INTO favorites VALUES (1583, 12, 1);
INSERT INTO favorites VALUES (1583, 63, 2);
INSERT INTO favorites VALUES (1583, 53, 3);
INSERT INTO favorites VALUES (1584, 24, 1);
INSERT INTO favorites VALUES (1584, 64, 2);
INSERT INTO favorites VALUES (1585, 78, 1);
INSERT INTO favorites VALUES (1585, 41, 2);
INSERT INTO favorites VALUES (1586, 70, 2);
INSERT INTO favorites VALUES (1586, 25, 1);
INSERT INTO favorites VALUES (1586, 46, 3);
INSERT INTO favorites VALUES (1587, 50, 1);
INSERT INTO favorites VALUES (1588, 74, 1);
INSERT INTO favorites VALUES (1588, 14, 3);
INSERT INTO favorites VALUES (1588, 107, 2);
INSERT INTO favorites VALUES (1589, 92, 1);
INSERT INTO favorites VALUES (1589, 12, 2);
INSERT INTO favorites VALUES (1589, 113, 3);
INSERT INTO favorites VALUES (1590, 54, 1);
INSERT INTO favorites VALUES (1591, 6, 1);
INSERT INTO favorites VALUES (1591, 51, 2);
INSERT INTO favorites VALUES (1591, 66, 3);
INSERT INTO favorites VALUES (1592, 104, 1);
INSERT INTO favorites VALUES (1592, 56, 2);
INSERT INTO favorites VALUES (1593, 9, 1);
INSERT INTO favorites VALUES (1593, 2, 2);
INSERT INTO favorites VALUES (1595, 101, 1);
INSERT INTO favorites VALUES (1597, 61, 1);
INSERT INTO favorites VALUES (1597, 2, 4);
INSERT INTO favorites VALUES (1597, 13, 3);
INSERT INTO favorites VALUES (1597, 26, 2);
INSERT INTO favorites VALUES (1598, 92, 2);
INSERT INTO favorites VALUES (1598, 111, 1);
INSERT INTO favorites VALUES (1600, 114, 1);
INSERT INTO favorites VALUES (1600, 75, 2);
INSERT INTO favorites VALUES (1601, 15, 2);
INSERT INTO favorites VALUES (1601, 19, 1);
INSERT INTO favorites VALUES (1601, 45, 5);
INSERT INTO favorites VALUES (1601, 114, 6);
INSERT INTO favorites VALUES (1601, 76, 4);
INSERT INTO favorites VALUES (1601, 100, 3);
INSERT INTO favorites VALUES (1602, 5, 2);
INSERT INTO favorites VALUES (1602, 88, 1);
INSERT INTO favorites VALUES (1602, 94, 3);
INSERT INTO favorites VALUES (1603, 76, 3);
INSERT INTO favorites VALUES (1603, 91, 2);
INSERT INTO favorites VALUES (1603, 28, 1);
INSERT INTO favorites VALUES (1603, 44, 4);
INSERT INTO favorites VALUES (1604, 77, 1);
INSERT INTO favorites VALUES (1604, 94, 2);
INSERT INTO favorites VALUES (1605, 43, 1);
INSERT INTO favorites VALUES (1605, 3, 2);
INSERT INTO favorites VALUES (1605, 41, 4);
INSERT INTO favorites VALUES (1605, 39, 3);
INSERT INTO favorites VALUES (1605, 85, 5);
INSERT INTO favorites VALUES (1605, 40, 6);
INSERT INTO favorites VALUES (1606, 55, 1);
INSERT INTO favorites VALUES (1606, 88, 3);
INSERT INTO favorites VALUES (1606, 14, 2);
INSERT INTO favorites VALUES (1606, 104, 4);
INSERT INTO favorites VALUES (1607, 47, 2);
INSERT INTO favorites VALUES (1607, 98, 1);
INSERT INTO favorites VALUES (1607, 36, 3);
INSERT INTO favorites VALUES (1608, 89, 1);
INSERT INTO favorites VALUES (1608, 54, 2);
INSERT INTO favorites VALUES (1609, 35, 1);
INSERT INTO favorites VALUES (1609, 111, 2);
INSERT INTO favorites VALUES (1609, 109, 3);
INSERT INTO favorites VALUES (1611, 14, 1);
INSERT INTO favorites VALUES (1611, 18, 2);
INSERT INTO favorites VALUES (1612, 40, 1);
INSERT INTO favorites VALUES (1612, 26, 2);
INSERT INTO favorites VALUES (1614, 31, 1);
INSERT INTO favorites VALUES (1614, 73, 2);
INSERT INTO favorites VALUES (1614, 50, 3);
INSERT INTO favorites VALUES (1615, 36, 1);
INSERT INTO favorites VALUES (1615, 32, 2);
INSERT INTO favorites VALUES (1616, 57, 1);
INSERT INTO favorites VALUES (1616, 13, 2);
INSERT INTO favorites VALUES (1616, 34, 3);
INSERT INTO favorites VALUES (1617, 103, 1);
INSERT INTO favorites VALUES (1618, 16, 1);
INSERT INTO favorites VALUES (1618, 112, 2);
INSERT INTO favorites VALUES (1618, 42, 4);
INSERT INTO favorites VALUES (1618, 10, 3);
INSERT INTO favorites VALUES (1619, 28, 1);
INSERT INTO favorites VALUES (1619, 106, 2);
INSERT INTO favorites VALUES (1619, 26, 3);
INSERT INTO favorites VALUES (1620, 12, 1);
INSERT INTO favorites VALUES (1621, 98, 1);
INSERT INTO favorites VALUES (1621, 64, 2);
INSERT INTO favorites VALUES (1622, 49, 2);
INSERT INTO favorites VALUES (1622, 50, 1);
INSERT INTO favorites VALUES (1622, 29, 3);
INSERT INTO favorites VALUES (1622, 44, 4);
INSERT INTO favorites VALUES (1623, 74, 4);
INSERT INTO favorites VALUES (1623, 79, 3);
INSERT INTO favorites VALUES (1623, 115, 6);
INSERT INTO favorites VALUES (1623, 7, 2);
INSERT INTO favorites VALUES (1623, 56, 1);
INSERT INTO favorites VALUES (1623, 67, 5);
INSERT INTO favorites VALUES (1623, 6, 7);
INSERT INTO favorites VALUES (1623, 21, 9);
INSERT INTO favorites VALUES (1623, 8, 8);
INSERT INTO favorites VALUES (1624, 35, 1);
INSERT INTO favorites VALUES (1626, 12, 3);
INSERT INTO favorites VALUES (1626, 43, 1);
INSERT INTO favorites VALUES (1626, 17, 2);
INSERT INTO favorites VALUES (1626, 57, 4);
INSERT INTO favorites VALUES (1626, 74, 5);
INSERT INTO favorites VALUES (1628, 1, 1);
INSERT INTO favorites VALUES (1628, 93, 2);
INSERT INTO favorites VALUES (1628, 85, 3);
INSERT INTO favorites VALUES (1628, 86, 4);
INSERT INTO favorites VALUES (1628, 50, 6);
INSERT INTO favorites VALUES (1628, 85, 5);
INSERT INTO favorites VALUES (1629, 104, 1);
INSERT INTO favorites VALUES (1630, 73, 1);
INSERT INTO favorites VALUES (1630, 24, 2);
INSERT INTO favorites VALUES (1632, 69, 2);
INSERT INTO favorites VALUES (1632, 28, 1);
INSERT INTO favorites VALUES (1633, 2, 2);
INSERT INTO favorites VALUES (1633, 18, 1);
INSERT INTO favorites VALUES (1634, 57, 1);
INSERT INTO favorites VALUES (1634, 45, 2);
INSERT INTO favorites VALUES (1635, 80, 2);
INSERT INTO favorites VALUES (1635, 83, 1);
INSERT INTO favorites VALUES (1635, 74, 3);
INSERT INTO favorites VALUES (1635, 43, 4);
INSERT INTO favorites VALUES (1636, 43, 1);
INSERT INTO favorites VALUES (1637, 93, 1);
INSERT INTO favorites VALUES (1638, 93, 1);
INSERT INTO favorites VALUES (1638, 96, 2);
INSERT INTO favorites VALUES (1639, 61, 1);
INSERT INTO favorites VALUES (1640, 53, 1);
INSERT INTO favorites VALUES (1640, 95, 2);
INSERT INTO favorites VALUES (1640, 9, 3);
INSERT INTO favorites VALUES (1640, 78, 4);
INSERT INTO favorites VALUES (1641, 27, 1);
INSERT INTO favorites VALUES (1641, 97, 3);
INSERT INTO favorites VALUES (1641, 27, 2);
INSERT INTO favorites VALUES (1642, 32, 2);
INSERT INTO favorites VALUES (1642, 96, 1);
INSERT INTO favorites VALUES (1642, 64, 3);
INSERT INTO favorites VALUES (1642, 43, 4);
INSERT INTO favorites VALUES (1643, 61, 2);
INSERT INTO favorites VALUES (1643, 13, 1);
INSERT INTO favorites VALUES (1643, 38, 4);
INSERT INTO favorites VALUES (1643, 45, 3);
INSERT INTO favorites VALUES (1644, 31, 1);
INSERT INTO favorites VALUES (1644, 39, 3);
INSERT INTO favorites VALUES (1644, 83, 2);
INSERT INTO favorites VALUES (1644, 9, 4);
INSERT INTO favorites VALUES (1645, 56, 2);
INSERT INTO favorites VALUES (1645, 102, 1);
INSERT INTO favorites VALUES (1645, 9, 3);
INSERT INTO favorites VALUES (1646, 34, 1);
INSERT INTO favorites VALUES (1646, 12, 2);
INSERT INTO favorites VALUES (1647, 17, 1);
INSERT INTO favorites VALUES (1647, 97, 3);
INSERT INTO favorites VALUES (1647, 57, 2);
INSERT INTO favorites VALUES (1647, 14, 6);
INSERT INTO favorites VALUES (1647, 109, 5);
INSERT INTO favorites VALUES (1647, 99, 4);
INSERT INTO favorites VALUES (1648, 23, 2);
INSERT INTO favorites VALUES (1648, 76, 1);
INSERT INTO favorites VALUES (1648, 13, 3);
INSERT INTO favorites VALUES (1648, 93, 5);
INSERT INTO favorites VALUES (1648, 72, 6);
INSERT INTO favorites VALUES (1648, 2, 4);
INSERT INTO favorites VALUES (1649, 79, 2);
INSERT INTO favorites VALUES (1649, 49, 1);
INSERT INTO favorites VALUES (1649, 85, 3);
INSERT INTO favorites VALUES (1649, 35, 4);
INSERT INTO favorites VALUES (1650, 59, 2);
INSERT INTO favorites VALUES (1650, 4, 4);
INSERT INTO favorites VALUES (1650, 33, 1);
INSERT INTO favorites VALUES (1650, 40, 6);
INSERT INTO favorites VALUES (1650, 4, 5);
INSERT INTO favorites VALUES (1650, 54, 3);
INSERT INTO favorites VALUES (1650, 36, 7);
INSERT INTO favorites VALUES (1651, 3, 1);
INSERT INTO favorites VALUES (1651, 82, 2);
INSERT INTO favorites VALUES (1652, 76, 1);
INSERT INTO favorites VALUES (1653, 97, 1);
INSERT INTO favorites VALUES (1653, 15, 2);
INSERT INTO favorites VALUES (1654, 5, 2);
INSERT INTO favorites VALUES (1654, 72, 3);
INSERT INTO favorites VALUES (1654, 99, 1);
INSERT INTO favorites VALUES (1655, 78, 1);
INSERT INTO favorites VALUES (1655, 39, 2);
INSERT INTO favorites VALUES (1656, 74, 1);
INSERT INTO favorites VALUES (1657, 105, 2);
INSERT INTO favorites VALUES (1657, 23, 1);
INSERT INTO favorites VALUES (1658, 64, 2);
INSERT INTO favorites VALUES (1658, 23, 1);
INSERT INTO favorites VALUES (1658, 80, 3);
INSERT INTO favorites VALUES (1658, 97, 4);
INSERT INTO favorites VALUES (1659, 101, 2);
INSERT INTO favorites VALUES (1659, 65, 1);
INSERT INTO favorites VALUES (1659, 59, 3);
INSERT INTO favorites VALUES (1659, 18, 4);
INSERT INTO favorites VALUES (1660, 78, 2);
INSERT INTO favorites VALUES (1660, 115, 1);
INSERT INTO favorites VALUES (1660, 24, 3);
INSERT INTO favorites VALUES (1660, 9, 4);
INSERT INTO favorites VALUES (1661, 66, 1);
INSERT INTO favorites VALUES (1661, 109, 2);
INSERT INTO favorites VALUES (1661, 7, 3);
INSERT INTO favorites VALUES (1662, 26, 1);
INSERT INTO favorites VALUES (1662, 105, 2);
INSERT INTO favorites VALUES (1662, 45, 3);
INSERT INTO favorites VALUES (1663, 10, 1);
INSERT INTO favorites VALUES (1664, 109, 1);
INSERT INTO favorites VALUES (1665, 81, 1);
INSERT INTO favorites VALUES (1665, 71, 2);
INSERT INTO favorites VALUES (1665, 33, 3);
INSERT INTO favorites VALUES (1666, 53, 1);
INSERT INTO favorites VALUES (1666, 74, 3);
INSERT INTO favorites VALUES (1666, 27, 2);
INSERT INTO favorites VALUES (1667, 104, 1);
INSERT INTO favorites VALUES (1668, 111, 1);
INSERT INTO favorites VALUES (1669, 51, 1);
INSERT INTO favorites VALUES (1669, 74, 2);
INSERT INTO favorites VALUES (1669, 115, 3);
INSERT INTO favorites VALUES (1670, 51, 1);
INSERT INTO favorites VALUES (1670, 36, 3);
INSERT INTO favorites VALUES (1670, 39, 2);
INSERT INTO favorites VALUES (1671, 73, 2);
INSERT INTO favorites VALUES (1671, 110, 1);
INSERT INTO favorites VALUES (1672, 110, 1);
INSERT INTO favorites VALUES (1672, 23, 2);
INSERT INTO favorites VALUES (1673, 6, 1);
INSERT INTO favorites VALUES (1673, 65, 2);
INSERT INTO favorites VALUES (1674, 25, 1);
INSERT INTO favorites VALUES (1674, 16, 2);
INSERT INTO favorites VALUES (1674, 37, 3);
INSERT INTO favorites VALUES (1675, 108, 2);
INSERT INTO favorites VALUES (1675, 78, 4);
INSERT INTO favorites VALUES (1675, 70, 1);
INSERT INTO favorites VALUES (1675, 94, 3);
INSERT INTO favorites VALUES (1676, 60, 1);
INSERT INTO favorites VALUES (1677, 85, 1);
INSERT INTO favorites VALUES (1678, 64, 1);
INSERT INTO favorites VALUES (1678, 95, 2);
INSERT INTO favorites VALUES (1678, 36, 3);
INSERT INTO favorites VALUES (1679, 69, 1);
INSERT INTO favorites VALUES (1679, 81, 2);
INSERT INTO favorites VALUES (1680, 8, 1);
INSERT INTO favorites VALUES (1681, 83, 1);
INSERT INTO favorites VALUES (1681, 99, 2);
INSERT INTO favorites VALUES (1682, 9, 1);
INSERT INTO favorites VALUES (1682, 18, 2);
INSERT INTO favorites VALUES (1682, 87, 5);
INSERT INTO favorites VALUES (1682, 79, 4);
INSERT INTO favorites VALUES (1682, 39, 3);
INSERT INTO favorites VALUES (1682, 108, 7);
INSERT INTO favorites VALUES (1682, 15, 6);
INSERT INTO favorites VALUES (1683, 19, 1);
INSERT INTO favorites VALUES (1683, 57, 3);
INSERT INTO favorites VALUES (1683, 60, 2);
INSERT INTO favorites VALUES (1684, 38, 1);
INSERT INTO favorites VALUES (1685, 54, 1);
INSERT INTO favorites VALUES (1685, 62, 3);
INSERT INTO favorites VALUES (1685, 59, 2);
INSERT INTO favorites VALUES (1685, 44, 5);
INSERT INTO favorites VALUES (1685, 84, 4);
INSERT INTO favorites VALUES (1685, 91, 6);
INSERT INTO favorites VALUES (1685, 95, 7);
INSERT INTO favorites VALUES (1686, 77, 1);
INSERT INTO favorites VALUES (1686, 12, 2);
INSERT INTO favorites VALUES (1687, 105, 1);
INSERT INTO favorites VALUES (1687, 64, 3);
INSERT INTO favorites VALUES (1687, 63, 2);
INSERT INTO favorites VALUES (1688, 87, 1);
INSERT INTO favorites VALUES (1688, 88, 2);
INSERT INTO favorites VALUES (1689, 75, 2);
INSERT INTO favorites VALUES (1689, 4, 1);
INSERT INTO favorites VALUES (1689, 22, 4);
INSERT INTO favorites VALUES (1689, 79, 3);
INSERT INTO favorites VALUES (1690, 36, 1);
INSERT INTO favorites VALUES (1690, 26, 3);
INSERT INTO favorites VALUES (1690, 113, 2);
INSERT INTO favorites VALUES (1690, 63, 4);
INSERT INTO favorites VALUES (1691, 113, 1);
INSERT INTO favorites VALUES (1691, 6, 2);
INSERT INTO favorites VALUES (1692, 87, 2);
INSERT INTO favorites VALUES (1692, 4, 1);
INSERT INTO favorites VALUES (1693, 50, 1);
INSERT INTO favorites VALUES (1693, 46, 2);
INSERT INTO favorites VALUES (1694, 6, 1);
INSERT INTO favorites VALUES (1694, 71, 2);
INSERT INTO favorites VALUES (1695, 27, 1);
INSERT INTO favorites VALUES (1695, 65, 3);
INSERT INTO favorites VALUES (1695, 115, 2);
INSERT INTO favorites VALUES (1695, 111, 5);
INSERT INTO favorites VALUES (1695, 87, 4);
INSERT INTO favorites VALUES (1696, 78, 1);
INSERT INTO favorites VALUES (1696, 26, 3);
INSERT INTO favorites VALUES (1696, 73, 2);
INSERT INTO favorites VALUES (1697, 72, 1);
INSERT INTO favorites VALUES (1697, 24, 2);
INSERT INTO favorites VALUES (1698, 64, 2);
INSERT INTO favorites VALUES (1698, 82, 1);
INSERT INTO favorites VALUES (1698, 34, 4);
INSERT INTO favorites VALUES (1698, 87, 3);
INSERT INTO favorites VALUES (1699, 21, 1);
INSERT INTO favorites VALUES (1700, 2, 1);
INSERT INTO favorites VALUES (1700, 59, 2);
INSERT INTO favorites VALUES (1701, 11, 1);
INSERT INTO favorites VALUES (1701, 97, 3);
INSERT INTO favorites VALUES (1701, 81, 2);
INSERT INTO favorites VALUES (1702, 76, 2);
INSERT INTO favorites VALUES (1702, 108, 3);
INSERT INTO favorites VALUES (1702, 28, 1);
INSERT INTO favorites VALUES (1702, 38, 4);
INSERT INTO favorites VALUES (1703, 21, 3);
INSERT INTO favorites VALUES (1703, 61, 2);
INSERT INTO favorites VALUES (1703, 66, 1);
INSERT INTO favorites VALUES (1703, 88, 4);
INSERT INTO favorites VALUES (1704, 78, 1);
INSERT INTO favorites VALUES (1704, 80, 2);
INSERT INTO favorites VALUES (1704, 108, 3);
INSERT INTO favorites VALUES (1705, 70, 1);
INSERT INTO favorites VALUES (1705, 43, 2);
INSERT INTO favorites VALUES (1705, 3, 5);
INSERT INTO favorites VALUES (1705, 93, 3);
INSERT INTO favorites VALUES (1705, 93, 4);
INSERT INTO favorites VALUES (1706, 53, 1);
INSERT INTO favorites VALUES (1706, 74, 2);
INSERT INTO favorites VALUES (1706, 36, 5);
INSERT INTO favorites VALUES (1706, 83, 3);
INSERT INTO favorites VALUES (1706, 57, 4);
INSERT INTO favorites VALUES (1707, 23, 1);
INSERT INTO favorites VALUES (1707, 62, 2);
INSERT INTO favorites VALUES (1707, 22, 3);
INSERT INTO favorites VALUES (1707, 92, 5);
INSERT INTO favorites VALUES (1707, 71, 4);
INSERT INTO favorites VALUES (1707, 52, 6);
INSERT INTO favorites VALUES (1709, 16, 1);
INSERT INTO favorites VALUES (1709, 1, 2);
INSERT INTO favorites VALUES (1709, 108, 4);
INSERT INTO favorites VALUES (1709, 62, 3);
INSERT INTO favorites VALUES (1709, 52, 5);
INSERT INTO favorites VALUES (1710, 13, 1);
INSERT INTO favorites VALUES (1710, 64, 3);
INSERT INTO favorites VALUES (1710, 14, 2);
INSERT INTO favorites VALUES (1711, 31, 2);
INSERT INTO favorites VALUES (1711, 111, 1);
INSERT INTO favorites VALUES (1711, 10, 4);
INSERT INTO favorites VALUES (1711, 51, 3);
INSERT INTO favorites VALUES (1712, 29, 1);
INSERT INTO favorites VALUES (1712, 71, 2);
INSERT INTO favorites VALUES (1713, 6, 1);
INSERT INTO favorites VALUES (1713, 52, 2);
INSERT INTO favorites VALUES (1714, 12, 1);
INSERT INTO favorites VALUES (1714, 75, 2);
INSERT INTO favorites VALUES (1714, 8, 3);
INSERT INTO favorites VALUES (1715, 16, 1);
INSERT INTO favorites VALUES (1715, 45, 2);
INSERT INTO favorites VALUES (1716, 75, 1);
INSERT INTO favorites VALUES (1716, 15, 2);
INSERT INTO favorites VALUES (1717, 65, 1);
INSERT INTO favorites VALUES (1717, 56, 3);
INSERT INTO favorites VALUES (1717, 16, 2);
INSERT INTO favorites VALUES (1718, 106, 1);
INSERT INTO favorites VALUES (1718, 39, 2);
INSERT INTO favorites VALUES (1718, 56, 3);
INSERT INTO favorites VALUES (1718, 28, 4);
INSERT INTO favorites VALUES (1719, 26, 1);
INSERT INTO favorites VALUES (1719, 3, 3);
INSERT INTO favorites VALUES (1719, 85, 2);
INSERT INTO favorites VALUES (1719, 3, 4);
INSERT INTO favorites VALUES (1720, 116, 3);
INSERT INTO favorites VALUES (1720, 90, 1);
INSERT INTO favorites VALUES (1720, 14, 2);
INSERT INTO favorites VALUES (1721, 77, 1);
INSERT INTO favorites VALUES (1722, 16, 1);
INSERT INTO favorites VALUES (1722, 72, 2);
INSERT INTO favorites VALUES (1722, 7, 4);
INSERT INTO favorites VALUES (1722, 49, 3);
INSERT INTO favorites VALUES (1723, 75, 1);
INSERT INTO favorites VALUES (1723, 92, 2);
INSERT INTO favorites VALUES (1724, 93, 1);
INSERT INTO favorites VALUES (1724, 25, 3);
INSERT INTO favorites VALUES (1724, 14, 4);
INSERT INTO favorites VALUES (1724, 70, 2);
INSERT INTO favorites VALUES (1725, 50, 1);
INSERT INTO favorites VALUES (1726, 27, 1);
INSERT INTO favorites VALUES (1726, 70, 2);
INSERT INTO favorites VALUES (1726, 30, 3);
INSERT INTO favorites VALUES (1726, 21, 4);
INSERT INTO favorites VALUES (1727, 53, 1);
INSERT INTO favorites VALUES (1727, 38, 2);
INSERT INTO favorites VALUES (1727, 115, 3);
INSERT INTO favorites VALUES (1727, 42, 5);
INSERT INTO favorites VALUES (1727, 106, 4);
INSERT INTO favorites VALUES (1728, 46, 1);
INSERT INTO favorites VALUES (1729, 44, 1);
INSERT INTO favorites VALUES (1729, 92, 3);
INSERT INTO favorites VALUES (1729, 57, 2);
INSERT INTO favorites VALUES (1730, 5, 2);
INSERT INTO favorites VALUES (1730, 69, 3);
INSERT INTO favorites VALUES (1730, 18, 1);
INSERT INTO favorites VALUES (1730, 25, 4);
INSERT INTO favorites VALUES (1731, 6, 1);
INSERT INTO favorites VALUES (1731, 44, 2);
INSERT INTO favorites VALUES (1731, 55, 4);
INSERT INTO favorites VALUES (1731, 84, 3);
INSERT INTO favorites VALUES (1733, 22, 1);
INSERT INTO favorites VALUES (1735, 5, 1);
INSERT INTO favorites VALUES (1735, 46, 2);
INSERT INTO favorites VALUES (1737, 75, 2);
INSERT INTO favorites VALUES (1737, 62, 1);
INSERT INTO favorites VALUES (1737, 114, 3);
INSERT INTO favorites VALUES (1738, 17, 2);
INSERT INTO favorites VALUES (1738, 79, 1);
INSERT INTO favorites VALUES (1738, 31, 3);
INSERT INTO favorites VALUES (1738, 26, 6);
INSERT INTO favorites VALUES (1738, 38, 5);
INSERT INTO favorites VALUES (1738, 102, 4);
INSERT INTO favorites VALUES (1739, 12, 3);
INSERT INTO favorites VALUES (1739, 17, 2);
INSERT INTO favorites VALUES (1739, 42, 1);
INSERT INTO favorites VALUES (1740, 10, 2);
INSERT INTO favorites VALUES (1740, 67, 1);
INSERT INTO favorites VALUES (1740, 28, 3);
INSERT INTO favorites VALUES (1740, 111, 4);
INSERT INTO favorites VALUES (1741, 50, 1);
INSERT INTO favorites VALUES (1741, 86, 2);
INSERT INTO favorites VALUES (1741, 67, 3);
INSERT INTO favorites VALUES (1742, 116, 1);
INSERT INTO favorites VALUES (1742, 5, 2);
INSERT INTO favorites VALUES (1742, 17, 4);
INSERT INTO favorites VALUES (1742, 110, 3);
INSERT INTO favorites VALUES (1743, 80, 1);
INSERT INTO favorites VALUES (1743, 68, 3);
INSERT INTO favorites VALUES (1743, 17, 2);
INSERT INTO favorites VALUES (1743, 18, 5);
INSERT INTO favorites VALUES (1743, 57, 4);
INSERT INTO favorites VALUES (1744, 53, 2);
INSERT INTO favorites VALUES (1744, 47, 1);
INSERT INTO favorites VALUES (1744, 13, 3);
INSERT INTO favorites VALUES (1745, 21, 1);
INSERT INTO favorites VALUES (1745, 34, 3);
INSERT INTO favorites VALUES (1745, 24, 7);
INSERT INTO favorites VALUES (1745, 70, 6);
INSERT INTO favorites VALUES (1745, 38, 2);
INSERT INTO favorites VALUES (1745, 67, 5);
INSERT INTO favorites VALUES (1745, 73, 4);
INSERT INTO favorites VALUES (1746, 49, 1);
INSERT INTO favorites VALUES (1746, 26, 3);
INSERT INTO favorites VALUES (1746, 23, 2);
INSERT INTO favorites VALUES (1747, 40, 1);
INSERT INTO favorites VALUES (1747, 101, 2);
INSERT INTO favorites VALUES (1747, 41, 5);
INSERT INTO favorites VALUES (1747, 23, 4);
INSERT INTO favorites VALUES (1747, 84, 3);
INSERT INTO favorites VALUES (1748, 116, 2);
INSERT INTO favorites VALUES (1748, 29, 1);
INSERT INTO favorites VALUES (1748, 35, 4);
INSERT INTO favorites VALUES (1748, 39, 3);
INSERT INTO favorites VALUES (1748, 15, 6);
INSERT INTO favorites VALUES (1748, 59, 5);
INSERT INTO favorites VALUES (1750, 2, 2);
INSERT INTO favorites VALUES (1750, 44, 1);
INSERT INTO favorites VALUES (1750, 18, 4);
INSERT INTO favorites VALUES (1750, 41, 3);
INSERT INTO favorites VALUES (1751, 33, 2);
INSERT INTO favorites VALUES (1751, 44, 1);
INSERT INTO favorites VALUES (1752, 17, 1);
INSERT INTO favorites VALUES (1752, 112, 2);
INSERT INTO favorites VALUES (1752, 4, 3);
INSERT INTO favorites VALUES (1752, 15, 4);
INSERT INTO favorites VALUES (1752, 35, 5);
INSERT INTO favorites VALUES (1753, 81, 1);
INSERT INTO favorites VALUES (1753, 94, 2);
INSERT INTO favorites VALUES (1754, 72, 1);
INSERT INTO favorites VALUES (1755, 85, 1);
INSERT INTO favorites VALUES (1755, 35, 3);
INSERT INTO favorites VALUES (1755, 79, 4);
INSERT INTO favorites VALUES (1755, 64, 2);
INSERT INTO favorites VALUES (1756, 7, 1);
INSERT INTO favorites VALUES (1756, 93, 2);
INSERT INTO favorites VALUES (1758, 1, 1);
INSERT INTO favorites VALUES (1758, 4, 3);
INSERT INTO favorites VALUES (1758, 96, 2);
INSERT INTO favorites VALUES (1758, 18, 4);
INSERT INTO favorites VALUES (1758, 73, 6);
INSERT INTO favorites VALUES (1758, 36, 5);
INSERT INTO favorites VALUES (1758, 46, 7);
INSERT INTO favorites VALUES (1758, 89, 9);
INSERT INTO favorites VALUES (1758, 36, 8);
INSERT INTO favorites VALUES (1759, 6, 1);
INSERT INTO favorites VALUES (1759, 8, 2);
INSERT INTO favorites VALUES (1760, 66, 1);
INSERT INTO favorites VALUES (1760, 30, 2);
INSERT INTO favorites VALUES (1760, 44, 3);
INSERT INTO favorites VALUES (1760, 66, 4);
INSERT INTO favorites VALUES (1760, 69, 5);
INSERT INTO favorites VALUES (1761, 51, 1);
INSERT INTO favorites VALUES (1761, 81, 3);
INSERT INTO favorites VALUES (1761, 63, 2);
INSERT INTO favorites VALUES (1761, 68, 4);
INSERT INTO favorites VALUES (1762, 12, 1);
INSERT INTO favorites VALUES (1762, 111, 3);
INSERT INTO favorites VALUES (1762, 42, 2);
INSERT INTO favorites VALUES (1763, 108, 2);
INSERT INTO favorites VALUES (1763, 19, 1);
INSERT INTO favorites VALUES (1764, 2, 1);
INSERT INTO favorites VALUES (1765, 84, 1);
INSERT INTO favorites VALUES (1765, 102, 2);
INSERT INTO favorites VALUES (1765, 40, 3);
INSERT INTO favorites VALUES (1766, 31, 1);
INSERT INTO favorites VALUES (1767, 61, 1);
INSERT INTO favorites VALUES (1768, 40, 1);
INSERT INTO favorites VALUES (1768, 96, 2);
INSERT INTO favorites VALUES (1768, 93, 5);
INSERT INTO favorites VALUES (1768, 54, 4);
INSERT INTO favorites VALUES (1768, 3, 3);
INSERT INTO favorites VALUES (1769, 61, 1);
INSERT INTO favorites VALUES (1769, 23, 3);
INSERT INTO favorites VALUES (1769, 34, 2);
INSERT INTO favorites VALUES (1769, 16, 4);
INSERT INTO favorites VALUES (1770, 6, 1);
INSERT INTO favorites VALUES (1771, 14, 1);
INSERT INTO favorites VALUES (1771, 20, 2);
INSERT INTO favorites VALUES (1771, 21, 5);
INSERT INTO favorites VALUES (1771, 15, 3);
INSERT INTO favorites VALUES (1771, 64, 4);
INSERT INTO favorites VALUES (1772, 42, 1);
INSERT INTO favorites VALUES (1773, 32, 1);
INSERT INTO favorites VALUES (1774, 18, 1);
INSERT INTO favorites VALUES (1774, 92, 2);
INSERT INTO favorites VALUES (1775, 38, 1);
INSERT INTO favorites VALUES (1777, 67, 1);
INSERT INTO favorites VALUES (1778, 45, 1);
INSERT INTO favorites VALUES (1778, 7, 2);
INSERT INTO favorites VALUES (1779, 12, 1);
INSERT INTO favorites VALUES (1779, 66, 2);
INSERT INTO favorites VALUES (1780, 45, 1);
INSERT INTO favorites VALUES (1780, 22, 2);
INSERT INTO favorites VALUES (1781, 32, 1);
INSERT INTO favorites VALUES (1781, 69, 2);
INSERT INTO favorites VALUES (1781, 45, 3);
INSERT INTO favorites VALUES (1782, 110, 1);
INSERT INTO favorites VALUES (1783, 57, 1);
INSERT INTO favorites VALUES (1784, 43, 2);
INSERT INTO favorites VALUES (1784, 3, 1);
INSERT INTO favorites VALUES (1785, 45, 1);
INSERT INTO favorites VALUES (1785, 91, 3);
INSERT INTO favorites VALUES (1785, 29, 4);
INSERT INTO favorites VALUES (1785, 67, 2);
INSERT INTO favorites VALUES (1785, 54, 5);
INSERT INTO favorites VALUES (1785, 28, 6);
INSERT INTO favorites VALUES (1786, 20, 1);
INSERT INTO favorites VALUES (1786, 94, 2);
INSERT INTO favorites VALUES (1786, 21, 3);
INSERT INTO favorites VALUES (1786, 8, 4);
INSERT INTO favorites VALUES (1787, 15, 1);
INSERT INTO favorites VALUES (1787, 21, 2);
INSERT INTO favorites VALUES (1787, 60, 3);
INSERT INTO favorites VALUES (1788, 89, 2);
INSERT INTO favorites VALUES (1788, 30, 1);
INSERT INTO favorites VALUES (1788, 63, 3);
INSERT INTO favorites VALUES (1789, 4, 1);
INSERT INTO favorites VALUES (1789, 33, 3);
INSERT INTO favorites VALUES (1789, 60, 2);
INSERT INTO favorites VALUES (1789, 55, 4);
INSERT INTO favorites VALUES (1789, 71, 5);
INSERT INTO favorites VALUES (1790, 63, 2);
INSERT INTO favorites VALUES (1790, 10, 1);
INSERT INTO favorites VALUES (1790, 23, 5);
INSERT INTO favorites VALUES (1790, 9, 4);
INSERT INTO favorites VALUES (1790, 41, 3);
INSERT INTO favorites VALUES (1790, 78, 6);
INSERT INTO favorites VALUES (1791, 86, 1);
INSERT INTO favorites VALUES (1791, 22, 2);
INSERT INTO favorites VALUES (1792, 35, 1);
INSERT INTO favorites VALUES (1792, 104, 2);
INSERT INTO favorites VALUES (1792, 44, 4);
INSERT INTO favorites VALUES (1792, 15, 3);
INSERT INTO favorites VALUES (1793, 111, 1);
INSERT INTO favorites VALUES (1793, 61, 2);
INSERT INTO favorites VALUES (1794, 110, 1);
INSERT INTO favorites VALUES (1794, 6, 3);
INSERT INTO favorites VALUES (1794, 36, 2);
INSERT INTO favorites VALUES (1794, 86, 4);
INSERT INTO favorites VALUES (1795, 1, 1);
INSERT INTO favorites VALUES (1795, 48, 3);
INSERT INTO favorites VALUES (1795, 70, 2);
INSERT INTO favorites VALUES (1795, 82, 5);
INSERT INTO favorites VALUES (1795, 71, 4);
INSERT INTO favorites VALUES (1796, 63, 3);
INSERT INTO favorites VALUES (1796, 20, 2);
INSERT INTO favorites VALUES (1796, 10, 1);
INSERT INTO favorites VALUES (1797, 69, 2);
INSERT INTO favorites VALUES (1797, 83, 1);
INSERT INTO favorites VALUES (1797, 92, 3);
INSERT INTO favorites VALUES (1798, 3, 1);
INSERT INTO favorites VALUES (1798, 45, 2);
INSERT INTO favorites VALUES (1798, 94, 3);
INSERT INTO favorites VALUES (1798, 63, 4);
INSERT INTO favorites VALUES (1798, 111, 5);
INSERT INTO favorites VALUES (1799, 61, 2);
INSERT INTO favorites VALUES (1799, 59, 1);
INSERT INTO favorites VALUES (1799, 106, 3);
INSERT INTO favorites VALUES (1800, 62, 1);
INSERT INTO favorites VALUES (1800, 70, 5);
INSERT INTO favorites VALUES (1800, 41, 6);
INSERT INTO favorites VALUES (1800, 112, 4);
INSERT INTO favorites VALUES (1800, 97, 3);
INSERT INTO favorites VALUES (1800, 21, 2);
INSERT INTO favorites VALUES (1800, 37, 7);
INSERT INTO favorites VALUES (1801, 72, 2);
INSERT INTO favorites VALUES (1801, 26, 1);
INSERT INTO favorites VALUES (1801, 53, 4);
INSERT INTO favorites VALUES (1801, 32, 3);
INSERT INTO favorites VALUES (1801, 59, 5);
INSERT INTO favorites VALUES (1802, 99, 1);
INSERT INTO favorites VALUES (1802, 31, 3);
INSERT INTO favorites VALUES (1802, 60, 2);
INSERT INTO favorites VALUES (1802, 22, 4);
INSERT INTO favorites VALUES (1803, 27, 1);
INSERT INTO favorites VALUES (1803, 95, 2);
INSERT INTO favorites VALUES (1803, 8, 4);
INSERT INTO favorites VALUES (1803, 2, 3);
INSERT INTO favorites VALUES (1803, 38, 5);
INSERT INTO favorites VALUES (1804, 50, 1);
INSERT INTO favorites VALUES (1804, 55, 2);
INSERT INTO favorites VALUES (1804, 12, 4);
INSERT INTO favorites VALUES (1804, 67, 3);
INSERT INTO favorites VALUES (1805, 36, 1);
INSERT INTO favorites VALUES (1805, 43, 2);
INSERT INTO favorites VALUES (1806, 100, 2);
INSERT INTO favorites VALUES (1806, 22, 1);
INSERT INTO favorites VALUES (1807, 33, 1);
INSERT INTO favorites VALUES (1807, 20, 2);
INSERT INTO favorites VALUES (1808, 99, 1);
INSERT INTO favorites VALUES (1808, 103, 2);
INSERT INTO favorites VALUES (1808, 19, 3);
INSERT INTO favorites VALUES (1809, 41, 1);
INSERT INTO favorites VALUES (1809, 45, 2);
INSERT INTO favorites VALUES (1809, 67, 3);
INSERT INTO favorites VALUES (1809, 75, 5);
INSERT INTO favorites VALUES (1809, 23, 4);
INSERT INTO favorites VALUES (1810, 11, 2);
INSERT INTO favorites VALUES (1810, 23, 1);
INSERT INTO favorites VALUES (1810, 75, 3);
INSERT INTO favorites VALUES (1810, 40, 4);
INSERT INTO favorites VALUES (1811, 25, 1);
INSERT INTO favorites VALUES (1811, 6, 2);
INSERT INTO favorites VALUES (1812, 10, 1);
INSERT INTO favorites VALUES (1812, 61, 4);
INSERT INTO favorites VALUES (1812, 24, 3);
INSERT INTO favorites VALUES (1812, 104, 2);
INSERT INTO favorites VALUES (1814, 7, 1);
INSERT INTO favorites VALUES (1814, 87, 2);
INSERT INTO favorites VALUES (1815, 61, 3);
INSERT INTO favorites VALUES (1815, 78, 2);
INSERT INTO favorites VALUES (1815, 42, 1);
INSERT INTO favorites VALUES (1815, 104, 4);
INSERT INTO favorites VALUES (1816, 114, 1);
INSERT INTO favorites VALUES (1816, 24, 2);
INSERT INTO favorites VALUES (1816, 98, 4);
INSERT INTO favorites VALUES (1816, 57, 3);
INSERT INTO favorites VALUES (1816, 5, 5);
INSERT INTO favorites VALUES (1817, 55, 1);
INSERT INTO favorites VALUES (1817, 5, 2);
INSERT INTO favorites VALUES (1818, 18, 1);
INSERT INTO favorites VALUES (1818, 111, 2);
INSERT INTO favorites VALUES (1819, 49, 2);
INSERT INTO favorites VALUES (1819, 20, 3);
INSERT INTO favorites VALUES (1819, 14, 1);
INSERT INTO favorites VALUES (1819, 48, 4);
INSERT INTO favorites VALUES (1820, 10, 2);
INSERT INTO favorites VALUES (1820, 44, 3);
INSERT INTO favorites VALUES (1820, 95, 1);
INSERT INTO favorites VALUES (1820, 110, 4);
INSERT INTO favorites VALUES (1820, 2, 5);
INSERT INTO favorites VALUES (1821, 18, 1);
INSERT INTO favorites VALUES (1821, 97, 2);
INSERT INTO favorites VALUES (1822, 8, 1);
INSERT INTO favorites VALUES (1823, 77, 1);
INSERT INTO favorites VALUES (1823, 2, 2);
INSERT INTO favorites VALUES (1823, 97, 3);
INSERT INTO favorites VALUES (1824, 99, 1);
INSERT INTO favorites VALUES (1824, 10, 2);
INSERT INTO favorites VALUES (1826, 112, 1);
INSERT INTO favorites VALUES (1826, 32, 3);
INSERT INTO favorites VALUES (1826, 52, 4);
INSERT INTO favorites VALUES (1826, 3, 2);
INSERT INTO favorites VALUES (1826, 19, 5);
INSERT INTO favorites VALUES (1827, 1, 3);
INSERT INTO favorites VALUES (1827, 39, 2);
INSERT INTO favorites VALUES (1827, 99, 1);
INSERT INTO favorites VALUES (1828, 3, 1);
INSERT INTO favorites VALUES (1828, 80, 2);
INSERT INTO favorites VALUES (1829, 18, 2);
INSERT INTO favorites VALUES (1829, 56, 1);
INSERT INTO favorites VALUES (1829, 58, 3);
INSERT INTO favorites VALUES (1829, 74, 4);
INSERT INTO favorites VALUES (1829, 60, 6);
INSERT INTO favorites VALUES (1829, 53, 5);
INSERT INTO favorites VALUES (1830, 53, 2);
INSERT INTO favorites VALUES (1830, 90, 1);
INSERT INTO favorites VALUES (1831, 29, 1);
INSERT INTO favorites VALUES (1831, 1, 2);
INSERT INTO favorites VALUES (1832, 110, 3);
INSERT INTO favorites VALUES (1832, 106, 2);
INSERT INTO favorites VALUES (1832, 116, 1);
INSERT INTO favorites VALUES (1832, 51, 4);
INSERT INTO favorites VALUES (1833, 60, 2);
INSERT INTO favorites VALUES (1833, 80, 1);
INSERT INTO favorites VALUES (1833, 84, 3);
INSERT INTO favorites VALUES (1834, 105, 1);
INSERT INTO favorites VALUES (1834, 54, 2);
INSERT INTO favorites VALUES (1834, 68, 3);
INSERT INTO favorites VALUES (1835, 28, 1);
INSERT INTO favorites VALUES (1836, 77, 1);
INSERT INTO favorites VALUES (1837, 11, 2);
INSERT INTO favorites VALUES (1837, 20, 1);
INSERT INTO favorites VALUES (1837, 3, 3);
INSERT INTO favorites VALUES (1837, 102, 4);
INSERT INTO favorites VALUES (1838, 64, 2);
INSERT INTO favorites VALUES (1838, 63, 1);
INSERT INTO favorites VALUES (1838, 22, 3);
INSERT INTO favorites VALUES (1838, 106, 4);
INSERT INTO favorites VALUES (1838, 37, 5);
INSERT INTO favorites VALUES (1839, 91, 1);
INSERT INTO favorites VALUES (1839, 11, 2);
INSERT INTO favorites VALUES (1840, 90, 1);
INSERT INTO favorites VALUES (1840, 3, 3);
INSERT INTO favorites VALUES (1840, 96, 2);
INSERT INTO favorites VALUES (1840, 12, 4);
INSERT INTO favorites VALUES (1841, 14, 1);
INSERT INTO favorites VALUES (1842, 67, 2);
INSERT INTO favorites VALUES (1842, 52, 1);
INSERT INTO favorites VALUES (1842, 16, 4);
INSERT INTO favorites VALUES (1842, 66, 3);
INSERT INTO favorites VALUES (1842, 47, 6);
INSERT INTO favorites VALUES (1842, 85, 5);
INSERT INTO favorites VALUES (1842, 4, 7);
INSERT INTO favorites VALUES (1843, 75, 1);
INSERT INTO favorites VALUES (1843, 53, 3);
INSERT INTO favorites VALUES (1843, 10, 2);
INSERT INTO favorites VALUES (1845, 56, 1);
INSERT INTO favorites VALUES (1845, 42, 2);
INSERT INTO favorites VALUES (1846, 56, 1);
INSERT INTO favorites VALUES (1846, 66, 3);
INSERT INTO favorites VALUES (1846, 21, 2);
INSERT INTO favorites VALUES (1846, 7, 4);
INSERT INTO favorites VALUES (1847, 10, 1);
INSERT INTO favorites VALUES (1849, 74, 1);
INSERT INTO favorites VALUES (1850, 17, 1);
INSERT INTO favorites VALUES (1850, 89, 2);
INSERT INTO favorites VALUES (1850, 25, 4);
INSERT INTO favorites VALUES (1850, 73, 3);
INSERT INTO favorites VALUES (1851, 108, 1);
INSERT INTO favorites VALUES (1852, 21, 3);
INSERT INTO favorites VALUES (1852, 74, 2);
INSERT INTO favorites VALUES (1852, 50, 1);
INSERT INTO favorites VALUES (1852, 20, 4);
INSERT INTO favorites VALUES (1853, 79, 2);
INSERT INTO favorites VALUES (1853, 35, 1);
INSERT INTO favorites VALUES (1854, 58, 1);
INSERT INTO favorites VALUES (1855, 22, 2);
INSERT INTO favorites VALUES (1855, 13, 1);
INSERT INTO favorites VALUES (1855, 44, 3);
INSERT INTO favorites VALUES (1856, 37, 1);
INSERT INTO favorites VALUES (1856, 32, 2);
INSERT INTO favorites VALUES (1856, 23, 3);
INSERT INTO favorites VALUES (1857, 31, 1);
INSERT INTO favorites VALUES (1857, 20, 2);
INSERT INTO favorites VALUES (1858, 38, 1);
INSERT INTO favorites VALUES (1858, 89, 3);
INSERT INTO favorites VALUES (1858, 15, 2);
INSERT INTO favorites VALUES (1858, 67, 4);
INSERT INTO favorites VALUES (1859, 55, 1);
INSERT INTO favorites VALUES (1859, 14, 2);
INSERT INTO favorites VALUES (1860, 18, 1);
INSERT INTO favorites VALUES (1860, 31, 2);
INSERT INTO favorites VALUES (1860, 24, 3);
INSERT INTO favorites VALUES (1861, 26, 4);
INSERT INTO favorites VALUES (1861, 4, 3);
INSERT INTO favorites VALUES (1861, 38, 2);
INSERT INTO favorites VALUES (1861, 10, 1);
INSERT INTO favorites VALUES (1861, 4, 6);
INSERT INTO favorites VALUES (1861, 59, 5);
INSERT INTO favorites VALUES (1861, 27, 7);
INSERT INTO favorites VALUES (1861, 58, 8);
INSERT INTO favorites VALUES (1862, 30, 2);
INSERT INTO favorites VALUES (1862, 68, 1);
INSERT INTO favorites VALUES (1862, 47, 3);
INSERT INTO favorites VALUES (1862, 17, 4);
INSERT INTO favorites VALUES (1863, 47, 1);
INSERT INTO favorites VALUES (1863, 64, 2);
INSERT INTO favorites VALUES (1863, 11, 3);
INSERT INTO favorites VALUES (1864, 41, 1);
INSERT INTO favorites VALUES (1864, 43, 3);
INSERT INTO favorites VALUES (1864, 73, 2);
INSERT INTO favorites VALUES (1865, 30, 2);
INSERT INTO favorites VALUES (1865, 95, 1);
INSERT INTO favorites VALUES (1865, 67, 3);
INSERT INTO favorites VALUES (1865, 45, 5);
INSERT INTO favorites VALUES (1865, 106, 4);
INSERT INTO favorites VALUES (1865, 53, 6);
INSERT INTO favorites VALUES (1866, 44, 1);
INSERT INTO favorites VALUES (1866, 86, 4);
INSERT INTO favorites VALUES (1866, 36, 3);
INSERT INTO favorites VALUES (1866, 15, 2);
INSERT INTO favorites VALUES (1866, 12, 5);
INSERT INTO favorites VALUES (1867, 22, 1);
INSERT INTO favorites VALUES (1868, 15, 1);
INSERT INTO favorites VALUES (1869, 66, 1);
INSERT INTO favorites VALUES (1869, 7, 2);
INSERT INTO favorites VALUES (1869, 98, 3);
INSERT INTO favorites VALUES (1870, 72, 1);
INSERT INTO favorites VALUES (1870, 113, 3);
INSERT INTO favorites VALUES (1870, 45, 2);
INSERT INTO favorites VALUES (1870, 82, 4);
INSERT INTO favorites VALUES (1870, 34, 5);
INSERT INTO favorites VALUES (1871, 86, 1);
INSERT INTO favorites VALUES (1871, 32, 2);
INSERT INTO favorites VALUES (1872, 43, 1);
INSERT INTO favorites VALUES (1872, 55, 2);
INSERT INTO favorites VALUES (1872, 1, 4);
INSERT INTO favorites VALUES (1872, 75, 3);
INSERT INTO favorites VALUES (1873, 40, 1);
INSERT INTO favorites VALUES (1874, 96, 1);
INSERT INTO favorites VALUES (1874, 18, 3);
INSERT INTO favorites VALUES (1874, 45, 2);
INSERT INTO favorites VALUES (1874, 81, 4);
INSERT INTO favorites VALUES (1875, 48, 2);
INSERT INTO favorites VALUES (1875, 45, 1);
INSERT INTO favorites VALUES (1875, 66, 3);
INSERT INTO favorites VALUES (1875, 8, 4);
INSERT INTO favorites VALUES (1876, 1, 1);
INSERT INTO favorites VALUES (1876, 94, 2);
INSERT INTO favorites VALUES (1876, 42, 3);
INSERT INTO favorites VALUES (1877, 77, 2);
INSERT INTO favorites VALUES (1877, 79, 1);
INSERT INTO favorites VALUES (1877, 41, 3);
INSERT INTO favorites VALUES (1878, 10, 1);
INSERT INTO favorites VALUES (1879, 82, 1);
INSERT INTO favorites VALUES (1879, 79, 2);
INSERT INTO favorites VALUES (1879, 51, 3);
INSERT INTO favorites VALUES (1879, 35, 7);
INSERT INTO favorites VALUES (1879, 92, 4);
INSERT INTO favorites VALUES (1879, 22, 5);
INSERT INTO favorites VALUES (1879, 86, 6);
INSERT INTO favorites VALUES (1880, 8, 1);
INSERT INTO favorites VALUES (1881, 77, 1);
INSERT INTO favorites VALUES (1881, 47, 2);
INSERT INTO favorites VALUES (1881, 6, 3);
INSERT INTO favorites VALUES (1882, 84, 1);
INSERT INTO favorites VALUES (1882, 5, 3);
INSERT INTO favorites VALUES (1882, 92, 2);
INSERT INTO favorites VALUES (1883, 112, 1);
INSERT INTO favorites VALUES (1883, 58, 2);
INSERT INTO favorites VALUES (1883, 36, 3);
INSERT INTO favorites VALUES (1884, 76, 1);
INSERT INTO favorites VALUES (1884, 35, 2);
INSERT INTO favorites VALUES (1884, 21, 3);
INSERT INTO favorites VALUES (1885, 111, 1);
INSERT INTO favorites VALUES (1885, 8, 2);
INSERT INTO favorites VALUES (1886, 42, 1);
INSERT INTO favorites VALUES (1887, 43, 1);
INSERT INTO favorites VALUES (1888, 21, 1);
INSERT INTO favorites VALUES (1888, 87, 2);
INSERT INTO favorites VALUES (1888, 10, 4);
INSERT INTO favorites VALUES (1888, 87, 3);
INSERT INTO favorites VALUES (1890, 110, 2);
INSERT INTO favorites VALUES (1890, 2, 1);
INSERT INTO favorites VALUES (1890, 92, 3);
INSERT INTO favorites VALUES (1891, 82, 2);
INSERT INTO favorites VALUES (1891, 17, 1);
INSERT INTO favorites VALUES (1892, 74, 1);
INSERT INTO favorites VALUES (1892, 114, 2);
INSERT INTO favorites VALUES (1892, 112, 3);
INSERT INTO favorites VALUES (1893, 58, 2);
INSERT INTO favorites VALUES (1893, 13, 1);
INSERT INTO favorites VALUES (1894, 111, 1);
INSERT INTO favorites VALUES (1895, 37, 1);
INSERT INTO favorites VALUES (1896, 29, 1);
INSERT INTO favorites VALUES (1896, 44, 2);
INSERT INTO favorites VALUES (1897, 3, 1);
INSERT INTO favorites VALUES (1897, 67, 4);
INSERT INTO favorites VALUES (1897, 36, 3);
INSERT INTO favorites VALUES (1897, 1, 2);
INSERT INTO favorites VALUES (1897, 25, 5);
INSERT INTO favorites VALUES (1897, 96, 6);
INSERT INTO favorites VALUES (1898, 10, 2);
INSERT INTO favorites VALUES (1898, 32, 1);
INSERT INTO favorites VALUES (1898, 56, 3);
INSERT INTO favorites VALUES (1898, 27, 5);
INSERT INTO favorites VALUES (1898, 79, 4);
INSERT INTO favorites VALUES (1898, 69, 7);
INSERT INTO favorites VALUES (1898, 4, 6);
INSERT INTO favorites VALUES (1899, 65, 1);
INSERT INTO favorites VALUES (1899, 8, 3);
INSERT INTO favorites VALUES (1899, 115, 2);
INSERT INTO favorites VALUES (1900, 12, 4);
INSERT INTO favorites VALUES (1900, 90, 1);
INSERT INTO favorites VALUES (1900, 44, 3);
INSERT INTO favorites VALUES (1900, 107, 2);
INSERT INTO favorites VALUES (1901, 98, 1);
INSERT INTO favorites VALUES (1901, 51, 3);
INSERT INTO favorites VALUES (1901, 59, 2);
INSERT INTO favorites VALUES (1902, 66, 2);
INSERT INTO favorites VALUES (1902, 95, 1);
INSERT INTO favorites VALUES (1903, 91, 1);
INSERT INTO favorites VALUES (1903, 63, 3);
INSERT INTO favorites VALUES (1903, 101, 2);
INSERT INTO favorites VALUES (1904, 36, 2);
INSERT INTO favorites VALUES (1904, 37, 3);
INSERT INTO favorites VALUES (1904, 62, 4);
INSERT INTO favorites VALUES (1904, 45, 1);
INSERT INTO favorites VALUES (1905, 91, 2);
INSERT INTO favorites VALUES (1905, 8, 3);
INSERT INTO favorites VALUES (1905, 14, 1);
INSERT INTO favorites VALUES (1906, 79, 2);
INSERT INTO favorites VALUES (1906, 54, 1);
INSERT INTO favorites VALUES (1907, 5, 2);
INSERT INTO favorites VALUES (1907, 91, 3);
INSERT INTO favorites VALUES (1907, 48, 1);
INSERT INTO favorites VALUES (1909, 12, 2);
INSERT INTO favorites VALUES (1909, 60, 1);
INSERT INTO favorites VALUES (1909, 48, 3);
INSERT INTO favorites VALUES (1909, 28, 4);
INSERT INTO favorites VALUES (1910, 21, 2);
INSERT INTO favorites VALUES (1910, 115, 4);
INSERT INTO favorites VALUES (1910, 108, 3);
INSERT INTO favorites VALUES (1910, 58, 1);
INSERT INTO favorites VALUES (1913, 14, 3);
INSERT INTO favorites VALUES (1913, 48, 1);
INSERT INTO favorites VALUES (1913, 27, 2);
INSERT INTO favorites VALUES (1914, 2, 1);
INSERT INTO favorites VALUES (1914, 79, 2);
INSERT INTO favorites VALUES (1915, 12, 1);
INSERT INTO favorites VALUES (1916, 74, 1);
INSERT INTO favorites VALUES (1916, 51, 3);
INSERT INTO favorites VALUES (1916, 18, 2);
INSERT INTO favorites VALUES (1918, 15, 1);
INSERT INTO favorites VALUES (1919, 60, 1);
INSERT INTO favorites VALUES (1919, 77, 2);
INSERT INTO favorites VALUES (1920, 6, 4);
INSERT INTO favorites VALUES (1920, 45, 1);
INSERT INTO favorites VALUES (1920, 17, 2);
INSERT INTO favorites VALUES (1920, 73, 3);
INSERT INTO favorites VALUES (1921, 91, 2);
INSERT INTO favorites VALUES (1921, 20, 1);
INSERT INTO favorites VALUES (1922, 35, 1);
INSERT INTO favorites VALUES (1923, 33, 1);
INSERT INTO favorites VALUES (1924, 45, 1);
INSERT INTO favorites VALUES (1925, 13, 1);
INSERT INTO favorites VALUES (1925, 47, 2);
INSERT INTO favorites VALUES (1925, 21, 3);
INSERT INTO favorites VALUES (1926, 10, 2);
INSERT INTO favorites VALUES (1926, 60, 1);
INSERT INTO favorites VALUES (1926, 59, 3);
INSERT INTO favorites VALUES (1926, 38, 4);
INSERT INTO favorites VALUES (1927, 31, 1);
INSERT INTO favorites VALUES (1928, 52, 1);
INSERT INTO favorites VALUES (1929, 49, 1);
INSERT INTO favorites VALUES (1929, 55, 2);
INSERT INTO favorites VALUES (1930, 82, 1);
INSERT INTO favorites VALUES (1930, 89, 2);
INSERT INTO favorites VALUES (1930, 3, 3);
INSERT INTO favorites VALUES (1931, 34, 1);
INSERT INTO favorites VALUES (1931, 17, 4);
INSERT INTO favorites VALUES (1931, 2, 3);
INSERT INTO favorites VALUES (1931, 8, 2);
INSERT INTO favorites VALUES (1931, 63, 5);
INSERT INTO favorites VALUES (1932, 18, 1);
INSERT INTO favorites VALUES (1933, 5, 1);
INSERT INTO favorites VALUES (1933, 25, 3);
INSERT INTO favorites VALUES (1933, 102, 2);
INSERT INTO favorites VALUES (1934, 22, 1);
INSERT INTO favorites VALUES (1934, 46, 3);
INSERT INTO favorites VALUES (1934, 72, 2);
INSERT INTO favorites VALUES (1935, 53, 1);
INSERT INTO favorites VALUES (1935, 74, 3);
INSERT INTO favorites VALUES (1935, 14, 2);
INSERT INTO favorites VALUES (1936, 21, 2);
INSERT INTO favorites VALUES (1936, 68, 1);
INSERT INTO favorites VALUES (1936, 82, 3);
INSERT INTO favorites VALUES (1936, 50, 4);
INSERT INTO favorites VALUES (1937, 38, 1);
INSERT INTO favorites VALUES (1937, 37, 2);
INSERT INTO favorites VALUES (1937, 103, 3);
INSERT INTO favorites VALUES (1938, 111, 2);
INSERT INTO favorites VALUES (1938, 20, 1);
INSERT INTO favorites VALUES (1938, 77, 3);
INSERT INTO favorites VALUES (1938, 103, 4);
INSERT INTO favorites VALUES (1938, 47, 5);
INSERT INTO favorites VALUES (1938, 54, 6);
INSERT INTO favorites VALUES (1939, 10, 2);
INSERT INTO favorites VALUES (1939, 22, 1);
INSERT INTO favorites VALUES (1940, 19, 1);
INSERT INTO favorites VALUES (1940, 102, 2);
INSERT INTO favorites VALUES (1940, 43, 3);
INSERT INTO favorites VALUES (1941, 12, 2);
INSERT INTO favorites VALUES (1941, 22, 3);
INSERT INTO favorites VALUES (1941, 45, 1);
INSERT INTO favorites VALUES (1942, 17, 1);
INSERT INTO favorites VALUES (1942, 33, 3);
INSERT INTO favorites VALUES (1942, 106, 2);
INSERT INTO favorites VALUES (1942, 18, 4);
INSERT INTO favorites VALUES (1943, 48, 1);
INSERT INTO favorites VALUES (1943, 17, 2);
INSERT INTO favorites VALUES (1943, 98, 3);
INSERT INTO favorites VALUES (1944, 37, 2);
INSERT INTO favorites VALUES (1944, 74, 1);
INSERT INTO favorites VALUES (1944, 108, 4);
INSERT INTO favorites VALUES (1944, 35, 3);
INSERT INTO favorites VALUES (1944, 84, 5);
INSERT INTO favorites VALUES (1945, 115, 2);
INSERT INTO favorites VALUES (1945, 50, 1);
INSERT INTO favorites VALUES (1945, 114, 4);
INSERT INTO favorites VALUES (1945, 115, 3);
INSERT INTO favorites VALUES (1946, 20, 1);
INSERT INTO favorites VALUES (1946, 34, 3);
INSERT INTO favorites VALUES (1946, 61, 2);
INSERT INTO favorites VALUES (1946, 98, 4);
INSERT INTO favorites VALUES (1947, 28, 1);
INSERT INTO favorites VALUES (1947, 84, 3);
INSERT INTO favorites VALUES (1947, 52, 2);
INSERT INTO favorites VALUES (1947, 61, 4);
INSERT INTO favorites VALUES (1948, 103, 1);
INSERT INTO favorites VALUES (1948, 54, 2);
INSERT INTO favorites VALUES (1948, 16, 3);
INSERT INTO favorites VALUES (1948, 17, 4);
INSERT INTO favorites VALUES (1949, 40, 1);
INSERT INTO favorites VALUES (1949, 58, 2);
INSERT INTO favorites VALUES (1951, 6, 2);
INSERT INTO favorites VALUES (1951, 108, 1);
INSERT INTO favorites VALUES (1951, 65, 3);
INSERT INTO favorites VALUES (1952, 64, 1);
INSERT INTO favorites VALUES (1954, 89, 1);
INSERT INTO favorites VALUES (1954, 15, 2);
INSERT INTO favorites VALUES (1955, 76, 1);
INSERT INTO favorites VALUES (1955, 6, 2);
INSERT INTO favorites VALUES (1956, 9, 1);
INSERT INTO favorites VALUES (1956, 42, 3);
INSERT INTO favorites VALUES (1956, 70, 2);
INSERT INTO favorites VALUES (1957, 27, 1);
INSERT INTO favorites VALUES (1957, 60, 2);
INSERT INTO favorites VALUES (1957, 65, 4);
INSERT INTO favorites VALUES (1957, 66, 3);
INSERT INTO favorites VALUES (1958, 46, 1);
INSERT INTO favorites VALUES (1959, 115, 1);
INSERT INTO favorites VALUES (1959, 40, 2);
INSERT INTO favorites VALUES (1959, 46, 3);
INSERT INTO favorites VALUES (1960, 79, 1);
INSERT INTO favorites VALUES (1961, 32, 1);
INSERT INTO favorites VALUES (1961, 38, 2);
INSERT INTO favorites VALUES (1961, 42, 3);
INSERT INTO favorites VALUES (1962, 101, 2);
INSERT INTO favorites VALUES (1962, 2, 1);
INSERT INTO favorites VALUES (1962, 87, 3);
INSERT INTO favorites VALUES (1964, 25, 2);
INSERT INTO favorites VALUES (1964, 45, 1);
INSERT INTO favorites VALUES (1965, 13, 2);
INSERT INTO favorites VALUES (1965, 91, 1);
INSERT INTO favorites VALUES (1965, 2, 4);
INSERT INTO favorites VALUES (1965, 13, 3);
INSERT INTO favorites VALUES (1965, 10, 6);
INSERT INTO favorites VALUES (1965, 55, 5);
INSERT INTO favorites VALUES (1965, 100, 7);
INSERT INTO favorites VALUES (1965, 23, 8);
INSERT INTO favorites VALUES (1966, 34, 1);
INSERT INTO favorites VALUES (1968, 15, 1);
INSERT INTO favorites VALUES (1968, 41, 2);
INSERT INTO favorites VALUES (1968, 12, 3);
INSERT INTO favorites VALUES (1969, 66, 1);
INSERT INTO favorites VALUES (1969, 65, 2);
INSERT INTO favorites VALUES (1969, 12, 3);
INSERT INTO favorites VALUES (1970, 16, 1);
INSERT INTO favorites VALUES (1970, 22, 2);
INSERT INTO favorites VALUES (1971, 86, 1);
INSERT INTO favorites VALUES (1971, 28, 2);
INSERT INTO favorites VALUES (1972, 98, 1);
INSERT INTO favorites VALUES (1972, 65, 2);
INSERT INTO favorites VALUES (1973, 48, 1);
INSERT INTO favorites VALUES (1974, 43, 1);
INSERT INTO favorites VALUES (1974, 100, 3);
INSERT INTO favorites VALUES (1974, 108, 2);
INSERT INTO favorites VALUES (1974, 35, 4);
INSERT INTO favorites VALUES (1975, 45, 1);
INSERT INTO favorites VALUES (1976, 70, 1);
INSERT INTO favorites VALUES (1976, 103, 2);
INSERT INTO favorites VALUES (1977, 16, 1);
INSERT INTO favorites VALUES (1977, 25, 2);
INSERT INTO favorites VALUES (1977, 21, 3);
INSERT INTO favorites VALUES (1977, 112, 4);
INSERT INTO favorites VALUES (1978, 104, 1);
INSERT INTO favorites VALUES (1978, 39, 2);
INSERT INTO favorites VALUES (1979, 28, 1);
INSERT INTO favorites VALUES (1979, 12, 4);
INSERT INTO favorites VALUES (1979, 85, 3);
INSERT INTO favorites VALUES (1979, 79, 2);
INSERT INTO favorites VALUES (1980, 31, 1);
INSERT INTO favorites VALUES (1980, 41, 2);
INSERT INTO favorites VALUES (1980, 109, 4);
INSERT INTO favorites VALUES (1980, 62, 3);
INSERT INTO favorites VALUES (1981, 62, 1);
INSERT INTO favorites VALUES (1981, 16, 3);
INSERT INTO favorites VALUES (1981, 80, 2);
INSERT INTO favorites VALUES (1982, 65, 1);
INSERT INTO favorites VALUES (1982, 73, 2);
INSERT INTO favorites VALUES (1982, 64, 4);
INSERT INTO favorites VALUES (1982, 27, 3);
INSERT INTO favorites VALUES (1983, 19, 1);
INSERT INTO favorites VALUES (1983, 46, 3);
INSERT INTO favorites VALUES (1983, 60, 2);
INSERT INTO favorites VALUES (1983, 7, 4);
INSERT INTO favorites VALUES (1984, 24, 1);
INSERT INTO favorites VALUES (1984, 95, 2);
INSERT INTO favorites VALUES (1984, 30, 3);
INSERT INTO favorites VALUES (1984, 116, 4);
INSERT INTO favorites VALUES (1985, 47, 1);
INSERT INTO favorites VALUES (1985, 102, 2);
INSERT INTO favorites VALUES (1985, 83, 3);
INSERT INTO favorites VALUES (1986, 92, 2);
INSERT INTO favorites VALUES (1986, 21, 1);
INSERT INTO favorites VALUES (1986, 30, 3);
INSERT INTO favorites VALUES (1986, 31, 4);
INSERT INTO favorites VALUES (1987, 16, 1);
INSERT INTO favorites VALUES (1988, 41, 1);
INSERT INTO favorites VALUES (1988, 52, 4);
INSERT INTO favorites VALUES (1988, 8, 3);
INSERT INTO favorites VALUES (1988, 35, 2);
INSERT INTO favorites VALUES (1989, 17, 1);
INSERT INTO favorites VALUES (1989, 33, 2);
INSERT INTO favorites VALUES (1990, 67, 1);
INSERT INTO favorites VALUES (1990, 76, 2);
INSERT INTO favorites VALUES (1991, 3, 1);
INSERT INTO favorites VALUES (1991, 71, 2);
INSERT INTO favorites VALUES (1992, 17, 1);
INSERT INTO favorites VALUES (1992, 55, 2);
INSERT INTO favorites VALUES (1992, 10, 4);
INSERT INTO favorites VALUES (1992, 91, 3);
INSERT INTO favorites VALUES (1993, 20, 2);
INSERT INTO favorites VALUES (1993, 67, 1);
INSERT INTO favorites VALUES (1993, 100, 3);
INSERT INTO favorites VALUES (1994, 11, 1);
INSERT INTO favorites VALUES (1995, 42, 1);
INSERT INTO favorites VALUES (1996, 32, 2);
INSERT INTO favorites VALUES (1996, 23, 1);
INSERT INTO favorites VALUES (1997, 1, 1);
INSERT INTO favorites VALUES (1997, 44, 2);
INSERT INTO favorites VALUES (1997, 46, 3);
INSERT INTO favorites VALUES (1998, 88, 1);
INSERT INTO favorites VALUES (1999, 112, 1);
INSERT INTO favorites VALUES (1999, 7, 2);
INSERT INTO favorites VALUES (1999, 38, 3);
INSERT INTO favorites VALUES (2000, 39, 1);
INSERT INTO favorites VALUES (2001, 72, 1);
INSERT INTO favorites VALUES (2001, 47, 2);
INSERT INTO favorites VALUES (2002, 57, 2);
INSERT INTO favorites VALUES (2002, 107, 1);
INSERT INTO favorites VALUES (2002, 10, 4);
INSERT INTO favorites VALUES (2002, 3, 3);
INSERT INTO favorites VALUES (2003, 77, 1);
INSERT INTO favorites VALUES (2003, 48, 2);
INSERT INTO favorites VALUES (2003, 36, 3);
INSERT INTO favorites VALUES (2004, 7, 1);
INSERT INTO favorites VALUES (2004, 2, 2);
INSERT INTO favorites VALUES (2005, 94, 1);
INSERT INTO favorites VALUES (2005, 58, 2);
INSERT INTO favorites VALUES (2005, 12, 4);
INSERT INTO favorites VALUES (2005, 93, 3);
INSERT INTO favorites VALUES (2005, 43, 5);
INSERT INTO favorites VALUES (2007, 116, 1);
INSERT INTO favorites VALUES (2007, 76, 2);
INSERT INTO favorites VALUES (2008, 24, 2);
INSERT INTO favorites VALUES (2008, 31, 1);
INSERT INTO favorites VALUES (2008, 82, 3);
INSERT INTO favorites VALUES (2009, 94, 3);
INSERT INTO favorites VALUES (2009, 48, 1);
INSERT INTO favorites VALUES (2009, 77, 2);
INSERT INTO favorites VALUES (2009, 41, 4);
INSERT INTO favorites VALUES (2010, 6, 1);
INSERT INTO favorites VALUES (2012, 85, 3);
INSERT INTO favorites VALUES (2012, 13, 2);
INSERT INTO favorites VALUES (2012, 16, 1);
INSERT INTO favorites VALUES (2012, 115, 4);
INSERT INTO favorites VALUES (2012, 72, 5);
INSERT INTO favorites VALUES (2013, 48, 2);
INSERT INTO favorites VALUES (2013, 16, 1);
INSERT INTO favorites VALUES (2013, 47, 3);
INSERT INTO favorites VALUES (2013, 80, 4);
INSERT INTO favorites VALUES (2015, 48, 2);
INSERT INTO favorites VALUES (2015, 97, 3);
INSERT INTO favorites VALUES (2015, 31, 1);
INSERT INTO favorites VALUES (2015, 78, 6);
INSERT INTO favorites VALUES (2015, 1, 5);
INSERT INTO favorites VALUES (2015, 79, 4);
INSERT INTO favorites VALUES (2015, 7, 7);
INSERT INTO favorites VALUES (2016, 75, 2);
INSERT INTO favorites VALUES (2016, 87, 1);
INSERT INTO favorites VALUES (2016, 3, 3);
INSERT INTO favorites VALUES (2017, 42, 1);
INSERT INTO favorites VALUES (2017, 66, 2);
INSERT INTO favorites VALUES (2017, 5, 3);
INSERT INTO favorites VALUES (2018, 16, 2);
INSERT INTO favorites VALUES (2018, 31, 1);
INSERT INTO favorites VALUES (2019, 40, 1);
INSERT INTO favorites VALUES (2019, 105, 2);
INSERT INTO favorites VALUES (2020, 97, 1);
INSERT INTO favorites VALUES (2020, 43, 3);
INSERT INTO favorites VALUES (2020, 2, 2);
INSERT INTO favorites VALUES (2021, 58, 3);
INSERT INTO favorites VALUES (2021, 108, 2);
INSERT INTO favorites VALUES (2021, 103, 1);
INSERT INTO favorites VALUES (2021, 25, 4);
INSERT INTO favorites VALUES (2022, 109, 1);
INSERT INTO favorites VALUES (2022, 50, 2);
INSERT INTO favorites VALUES (2023, 1, 1);
INSERT INTO favorites VALUES (2023, 72, 3);
INSERT INTO favorites VALUES (2023, 78, 2);
INSERT INTO favorites VALUES (2023, 63, 4);
INSERT INTO favorites VALUES (2024, 84, 2);
INSERT INTO favorites VALUES (2024, 2, 1);
INSERT INTO favorites VALUES (2024, 97, 3);
INSERT INTO favorites VALUES (2025, 112, 1);
INSERT INTO favorites VALUES (2025, 102, 2);
INSERT INTO favorites VALUES (2026, 56, 1);
INSERT INTO favorites VALUES (2026, 76, 2);
INSERT INTO favorites VALUES (2026, 34, 4);
INSERT INTO favorites VALUES (2026, 57, 3);
INSERT INTO favorites VALUES (2026, 71, 6);
INSERT INTO favorites VALUES (2026, 5, 5);
INSERT INTO favorites VALUES (2027, 26, 1);
INSERT INTO favorites VALUES (2027, 89, 2);
INSERT INTO favorites VALUES (2029, 115, 1);
INSERT INTO favorites VALUES (2029, 96, 2);
INSERT INTO favorites VALUES (2030, 32, 1);
INSERT INTO favorites VALUES (2030, 33, 2);
INSERT INTO favorites VALUES (2031, 41, 1);
INSERT INTO favorites VALUES (2031, 32, 4);
INSERT INTO favorites VALUES (2031, 104, 3);
INSERT INTO favorites VALUES (2031, 81, 2);
INSERT INTO favorites VALUES (2031, 26, 6);
INSERT INTO favorites VALUES (2031, 84, 5);
INSERT INTO favorites VALUES (2032, 31, 1);
INSERT INTO favorites VALUES (2032, 44, 2);
INSERT INTO favorites VALUES (2034, 9, 2);
INSERT INTO favorites VALUES (2034, 13, 1);
INSERT INTO favorites VALUES (2034, 18, 7);
INSERT INTO favorites VALUES (2034, 27, 4);
INSERT INTO favorites VALUES (2034, 67, 3);
INSERT INTO favorites VALUES (2034, 92, 5);
INSERT INTO favorites VALUES (2034, 101, 6);
INSERT INTO favorites VALUES (2035, 90, 1);
INSERT INTO favorites VALUES (2036, 25, 1);
INSERT INTO favorites VALUES (2036, 104, 2);
INSERT INTO favorites VALUES (2037, 39, 1);
INSERT INTO favorites VALUES (2038, 89, 1);
INSERT INTO favorites VALUES (2038, 13, 2);
INSERT INTO favorites VALUES (2039, 26, 1);
INSERT INTO favorites VALUES (2040, 47, 1);
INSERT INTO favorites VALUES (2041, 59, 2);
INSERT INTO favorites VALUES (2041, 15, 1);
INSERT INTO favorites VALUES (2041, 36, 3);
INSERT INTO favorites VALUES (2042, 35, 1);
INSERT INTO favorites VALUES (2042, 100, 3);
INSERT INTO favorites VALUES (2042, 26, 2);
INSERT INTO favorites VALUES (2042, 31, 4);
INSERT INTO favorites VALUES (2043, 88, 1);
INSERT INTO favorites VALUES (2043, 2, 2);
INSERT INTO favorites VALUES (2043, 70, 3);
INSERT INTO favorites VALUES (2044, 75, 2);
INSERT INTO favorites VALUES (2044, 2, 1);
INSERT INTO favorites VALUES (2044, 68, 3);
INSERT INTO favorites VALUES (2044, 92, 4);
INSERT INTO favorites VALUES (2045, 66, 2);
INSERT INTO favorites VALUES (2045, 3, 1);
INSERT INTO favorites VALUES (2045, 18, 5);
INSERT INTO favorites VALUES (2045, 109, 4);
INSERT INTO favorites VALUES (2045, 60, 3);
INSERT INTO favorites VALUES (2046, 79, 1);
INSERT INTO favorites VALUES (2046, 62, 2);
INSERT INTO favorites VALUES (2047, 42, 1);
INSERT INTO favorites VALUES (2047, 109, 3);
INSERT INTO favorites VALUES (2047, 12, 2);
INSERT INTO favorites VALUES (2047, 88, 7);
INSERT INTO favorites VALUES (2047, 77, 6);
INSERT INTO favorites VALUES (2047, 39, 5);
INSERT INTO favorites VALUES (2047, 29, 4);
INSERT INTO favorites VALUES (2048, 21, 2);
INSERT INTO favorites VALUES (2048, 10, 1);
INSERT INTO favorites VALUES (2048, 42, 3);
INSERT INTO favorites VALUES (2049, 109, 1);
INSERT INTO favorites VALUES (2050, 8, 2);
INSERT INTO favorites VALUES (2050, 29, 1);
INSERT INTO favorites VALUES (2050, 18, 3);
INSERT INTO favorites VALUES (2051, 69, 1);
INSERT INTO favorites VALUES (2051, 51, 2);
INSERT INTO favorites VALUES (2051, 95, 4);
INSERT INTO favorites VALUES (2051, 26, 3);
INSERT INTO favorites VALUES (2052, 13, 1);
INSERT INTO favorites VALUES (2053, 105, 1);
INSERT INTO favorites VALUES (2053, 70, 2);
INSERT INTO favorites VALUES (2053, 31, 3);
INSERT INTO favorites VALUES (2054, 8, 1);
INSERT INTO favorites VALUES (2054, 63, 2);
INSERT INTO favorites VALUES (2055, 61, 2);
INSERT INTO favorites VALUES (2055, 14, 1);
INSERT INTO favorites VALUES (2056, 46, 2);
INSERT INTO favorites VALUES (2056, 6, 1);
INSERT INTO favorites VALUES (2057, 22, 1);
INSERT INTO favorites VALUES (2057, 65, 2);
INSERT INTO favorites VALUES (2058, 112, 1);
INSERT INTO favorites VALUES (2058, 2, 2);
INSERT INTO favorites VALUES (2059, 106, 1);
INSERT INTO favorites VALUES (2059, 114, 3);
INSERT INTO favorites VALUES (2059, 65, 2);
INSERT INTO favorites VALUES (2060, 87, 1);
INSERT INTO favorites VALUES (2060, 57, 2);
INSERT INTO favorites VALUES (2061, 114, 1);
INSERT INTO favorites VALUES (2062, 40, 1);
INSERT INTO favorites VALUES (2063, 116, 1);
INSERT INTO favorites VALUES (2064, 62, 1);
INSERT INTO favorites VALUES (2064, 62, 2);
INSERT INTO favorites VALUES (2064, 23, 4);
INSERT INTO favorites VALUES (2064, 27, 3);
INSERT INTO favorites VALUES (2065, 101, 2);
INSERT INTO favorites VALUES (2065, 107, 1);
INSERT INTO favorites VALUES (2066, 12, 2);
INSERT INTO favorites VALUES (2066, 17, 3);
INSERT INTO favorites VALUES (2066, 9, 1);
INSERT INTO favorites VALUES (2067, 5, 1);
INSERT INTO favorites VALUES (2067, 41, 2);
INSERT INTO favorites VALUES (2067, 9, 3);
INSERT INTO favorites VALUES (2068, 33, 1);
INSERT INTO favorites VALUES (2068, 19, 2);
INSERT INTO favorites VALUES (2069, 97, 1);
INSERT INTO favorites VALUES (2069, 23, 2);
INSERT INTO favorites VALUES (2070, 49, 2);
INSERT INTO favorites VALUES (2070, 32, 1);
INSERT INTO favorites VALUES (2070, 28, 3);
INSERT INTO favorites VALUES (2071, 97, 1);
INSERT INTO favorites VALUES (2071, 26, 2);
INSERT INTO favorites VALUES (2072, 1, 1);
INSERT INTO favorites VALUES (2072, 92, 2);
INSERT INTO favorites VALUES (2073, 13, 1);
INSERT INTO favorites VALUES (2074, 92, 1);
INSERT INTO favorites VALUES (2074, 5, 2);
INSERT INTO favorites VALUES (2075, 48, 2);
INSERT INTO favorites VALUES (2075, 8, 1);
INSERT INTO favorites VALUES (2076, 30, 1);
INSERT INTO favorites VALUES (2076, 113, 3);
INSERT INTO favorites VALUES (2076, 38, 2);
INSERT INTO favorites VALUES (2077, 7, 1);
INSERT INTO favorites VALUES (2077, 108, 2);
INSERT INTO favorites VALUES (2077, 115, 3);
INSERT INTO favorites VALUES (2079, 57, 5);
INSERT INTO favorites VALUES (2079, 54, 4);
INSERT INTO favorites VALUES (2079, 40, 3);
INSERT INTO favorites VALUES (2079, 58, 1);
INSERT INTO favorites VALUES (2079, 74, 2);
INSERT INTO favorites VALUES (2080, 45, 1);
INSERT INTO favorites VALUES (2080, 88, 5);
INSERT INTO favorites VALUES (2080, 108, 2);
INSERT INTO favorites VALUES (2080, 25, 4);
INSERT INTO favorites VALUES (2080, 42, 3);
INSERT INTO favorites VALUES (2080, 23, 6);
INSERT INTO favorites VALUES (2081, 96, 1);
INSERT INTO favorites VALUES (2081, 52, 2);
INSERT INTO favorites VALUES (2081, 9, 3);
INSERT INTO favorites VALUES (2081, 5, 4);
INSERT INTO favorites VALUES (2082, 11, 2);
INSERT INTO favorites VALUES (2082, 55, 1);
INSERT INTO favorites VALUES (2083, 75, 1);
INSERT INTO favorites VALUES (2083, 11, 2);
INSERT INTO favorites VALUES (2084, 101, 2);
INSERT INTO favorites VALUES (2084, 88, 1);
INSERT INTO favorites VALUES (2085, 70, 1);
INSERT INTO favorites VALUES (2085, 45, 2);
INSERT INTO favorites VALUES (2086, 40, 1);
INSERT INTO favorites VALUES (2086, 52, 4);
INSERT INTO favorites VALUES (2086, 22, 3);
INSERT INTO favorites VALUES (2086, 69, 2);
INSERT INTO favorites VALUES (2086, 23, 6);
INSERT INTO favorites VALUES (2086, 43, 7);
INSERT INTO favorites VALUES (2086, 86, 5);
INSERT INTO favorites VALUES (2087, 109, 1);
INSERT INTO favorites VALUES (2087, 36, 2);
INSERT INTO favorites VALUES (2088, 59, 1);
INSERT INTO favorites VALUES (2088, 69, 3);
INSERT INTO favorites VALUES (2088, 47, 2);
INSERT INTO favorites VALUES (2089, 29, 1);
INSERT INTO favorites VALUES (2090, 41, 1);
INSERT INTO favorites VALUES (2090, 49, 2);
INSERT INTO favorites VALUES (2090, 44, 3);
INSERT INTO favorites VALUES (2090, 66, 4);
INSERT INTO favorites VALUES (2091, 79, 1);
INSERT INTO favorites VALUES (2092, 65, 2);
INSERT INTO favorites VALUES (2092, 72, 3);
INSERT INTO favorites VALUES (2092, 83, 1);
INSERT INTO favorites VALUES (2093, 91, 1);
INSERT INTO favorites VALUES (2093, 30, 2);
INSERT INTO favorites VALUES (2094, 61, 3);
INSERT INTO favorites VALUES (2094, 43, 1);
INSERT INTO favorites VALUES (2094, 18, 2);
INSERT INTO favorites VALUES (2094, 10, 4);
INSERT INTO favorites VALUES (2094, 82, 5);
INSERT INTO favorites VALUES (2095, 36, 1);
INSERT INTO favorites VALUES (2095, 81, 3);
INSERT INTO favorites VALUES (2095, 74, 2);
INSERT INTO favorites VALUES (2095, 64, 5);
INSERT INTO favorites VALUES (2095, 58, 4);
INSERT INTO favorites VALUES (2096, 110, 1);
INSERT INTO favorites VALUES (2096, 30, 2);
INSERT INTO favorites VALUES (2097, 111, 1);
INSERT INTO favorites VALUES (2097, 103, 2);
INSERT INTO favorites VALUES (2097, 3, 3);
INSERT INTO favorites VALUES (2098, 29, 1);
INSERT INTO favorites VALUES (2098, 5, 2);
INSERT INTO favorites VALUES (2098, 16, 3);
INSERT INTO favorites VALUES (2099, 72, 1);
INSERT INTO favorites VALUES (2099, 8, 2);
INSERT INTO favorites VALUES (2101, 6, 2);
INSERT INTO favorites VALUES (2101, 4, 1);
INSERT INTO favorites VALUES (2101, 51, 3);
INSERT INTO favorites VALUES (2101, 108, 4);
INSERT INTO favorites VALUES (2101, 89, 5);
INSERT INTO favorites VALUES (2102, 37, 1);
INSERT INTO favorites VALUES (2102, 14, 2);
INSERT INTO favorites VALUES (2103, 16, 1);
INSERT INTO favorites VALUES (2105, 2, 1);
INSERT INTO favorites VALUES (2105, 89, 2);
INSERT INTO favorites VALUES (2105, 40, 4);
INSERT INTO favorites VALUES (2105, 48, 3);
INSERT INTO favorites VALUES (2108, 101, 2);
INSERT INTO favorites VALUES (2108, 6, 3);
INSERT INTO favorites VALUES (2108, 102, 1);
INSERT INTO favorites VALUES (2108, 32, 4);
INSERT INTO favorites VALUES (2109, 15, 2);
INSERT INTO favorites VALUES (2109, 70, 1);
INSERT INTO favorites VALUES (2109, 18, 3);
INSERT INTO favorites VALUES (2109, 20, 4);
INSERT INTO favorites VALUES (2110, 5, 1);
INSERT INTO favorites VALUES (2110, 86, 2);
INSERT INTO favorites VALUES (2110, 85, 3);
INSERT INTO favorites VALUES (2110, 22, 4);
INSERT INTO favorites VALUES (2111, 16, 1);
INSERT INTO favorites VALUES (2112, 37, 1);
INSERT INTO favorites VALUES (2113, 107, 2);
INSERT INTO favorites VALUES (2113, 18, 1);
INSERT INTO favorites VALUES (2114, 62, 1);
INSERT INTO favorites VALUES (2114, 5, 2);
INSERT INTO favorites VALUES (2114, 39, 3);
INSERT INTO favorites VALUES (2115, 53, 1);
INSERT INTO favorites VALUES (2115, 25, 3);
INSERT INTO favorites VALUES (2115, 93, 2);
INSERT INTO favorites VALUES (2115, 38, 6);
INSERT INTO favorites VALUES (2115, 74, 4);
INSERT INTO favorites VALUES (2115, 83, 5);
INSERT INTO favorites VALUES (2116, 111, 1);
INSERT INTO favorites VALUES (2117, 106, 1);
INSERT INTO favorites VALUES (2117, 101, 4);
INSERT INTO favorites VALUES (2117, 86, 3);
INSERT INTO favorites VALUES (2117, 77, 2);
INSERT INTO favorites VALUES (2118, 77, 1);
INSERT INTO favorites VALUES (2118, 20, 2);
INSERT INTO favorites VALUES (2118, 87, 4);
INSERT INTO favorites VALUES (2118, 45, 5);
INSERT INTO favorites VALUES (2118, 97, 3);
INSERT INTO favorites VALUES (2119, 38, 1);
INSERT INTO favorites VALUES (2120, 109, 3);
INSERT INTO favorites VALUES (2120, 38, 2);
INSERT INTO favorites VALUES (2120, 95, 1);
INSERT INTO favorites VALUES (2120, 27, 5);
INSERT INTO favorites VALUES (2120, 25, 4);
INSERT INTO favorites VALUES (2121, 61, 2);
INSERT INTO favorites VALUES (2121, 9, 1);
INSERT INTO favorites VALUES (2121, 32, 3);
INSERT INTO favorites VALUES (2121, 86, 5);
INSERT INTO favorites VALUES (2121, 26, 4);
INSERT INTO favorites VALUES (2122, 50, 1);
INSERT INTO favorites VALUES (2123, 74, 2);
INSERT INTO favorites VALUES (2123, 56, 1);
INSERT INTO favorites VALUES (2124, 69, 1);
INSERT INTO favorites VALUES (2124, 31, 2);
INSERT INTO favorites VALUES (2125, 71, 1);
INSERT INTO favorites VALUES (2126, 4, 1);
INSERT INTO favorites VALUES (2126, 113, 3);
INSERT INTO favorites VALUES (2126, 60, 2);
INSERT INTO favorites VALUES (2126, 102, 7);
INSERT INTO favorites VALUES (2126, 72, 5);
INSERT INTO favorites VALUES (2126, 14, 4);
INSERT INTO favorites VALUES (2126, 58, 8);
INSERT INTO favorites VALUES (2126, 112, 6);
INSERT INTO favorites VALUES (2127, 16, 2);
INSERT INTO favorites VALUES (2127, 38, 1);
INSERT INTO favorites VALUES (2127, 75, 3);
INSERT INTO favorites VALUES (2127, 46, 4);
INSERT INTO favorites VALUES (2128, 70, 2);
INSERT INTO favorites VALUES (2128, 37, 1);
INSERT INTO favorites VALUES (2129, 11, 2);
INSERT INTO favorites VALUES (2129, 8, 3);
INSERT INTO favorites VALUES (2129, 51, 1);
INSERT INTO favorites VALUES (2129, 63, 5);
INSERT INTO favorites VALUES (2129, 41, 4);
INSERT INTO favorites VALUES (2129, 63, 8);
INSERT INTO favorites VALUES (2129, 88, 7);
INSERT INTO favorites VALUES (2129, 62, 6);
INSERT INTO favorites VALUES (2130, 15, 2);
INSERT INTO favorites VALUES (2130, 22, 1);
INSERT INTO favorites VALUES (2130, 10, 3);
INSERT INTO favorites VALUES (2130, 51, 4);
INSERT INTO favorites VALUES (2130, 75, 5);
INSERT INTO favorites VALUES (2131, 17, 1);
INSERT INTO favorites VALUES (2132, 43, 1);
INSERT INTO favorites VALUES (2132, 36, 4);
INSERT INTO favorites VALUES (2132, 100, 2);
INSERT INTO favorites VALUES (2132, 61, 3);
INSERT INTO favorites VALUES (2133, 40, 2);
INSERT INTO favorites VALUES (2133, 35, 1);
INSERT INTO favorites VALUES (2133, 70, 4);
INSERT INTO favorites VALUES (2133, 45, 3);
INSERT INTO favorites VALUES (2133, 98, 7);
INSERT INTO favorites VALUES (2133, 60, 5);
INSERT INTO favorites VALUES (2133, 83, 6);
INSERT INTO favorites VALUES (2133, 78, 8);
INSERT INTO favorites VALUES (2134, 50, 1);
INSERT INTO favorites VALUES (2134, 44, 2);
INSERT INTO favorites VALUES (2135, 38, 1);
INSERT INTO favorites VALUES (2135, 59, 3);
INSERT INTO favorites VALUES (2135, 11, 4);
INSERT INTO favorites VALUES (2135, 17, 2);
INSERT INTO favorites VALUES (2135, 83, 5);
INSERT INTO favorites VALUES (2136, 38, 1);
INSERT INTO favorites VALUES (2136, 71, 2);
INSERT INTO favorites VALUES (2137, 112, 1);
INSERT INTO favorites VALUES (2138, 3, 1);
INSERT INTO favorites VALUES (2138, 107, 2);
INSERT INTO favorites VALUES (2140, 2, 3);
INSERT INTO favorites VALUES (2140, 78, 1);
INSERT INTO favorites VALUES (2140, 45, 2);
INSERT INTO favorites VALUES (2140, 63, 4);
INSERT INTO favorites VALUES (2141, 18, 2);
INSERT INTO favorites VALUES (2141, 108, 1);
INSERT INTO favorites VALUES (2142, 14, 1);
INSERT INTO favorites VALUES (2144, 84, 1);
INSERT INTO favorites VALUES (2145, 71, 1);
INSERT INTO favorites VALUES (2145, 9, 2);
INSERT INTO favorites VALUES (2145, 108, 3);
INSERT INTO favorites VALUES (2145, 64, 4);
INSERT INTO favorites VALUES (2146, 4, 1);
INSERT INTO favorites VALUES (2146, 60, 2);
INSERT INTO favorites VALUES (2147, 97, 1);
INSERT INTO favorites VALUES (2147, 71, 2);
INSERT INTO favorites VALUES (2147, 10, 4);
INSERT INTO favorites VALUES (2147, 25, 3);
INSERT INTO favorites VALUES (2148, 113, 2);
INSERT INTO favorites VALUES (2148, 19, 3);
INSERT INTO favorites VALUES (2148, 20, 1);
INSERT INTO favorites VALUES (2149, 13, 2);
INSERT INTO favorites VALUES (2149, 37, 1);
INSERT INTO favorites VALUES (2150, 2, 1);
INSERT INTO favorites VALUES (2150, 77, 2);
INSERT INTO favorites VALUES (2151, 6, 2);
INSERT INTO favorites VALUES (2151, 65, 1);
INSERT INTO favorites VALUES (2151, 61, 3);
INSERT INTO favorites VALUES (2152, 112, 1);
INSERT INTO favorites VALUES (2153, 3, 1);
INSERT INTO favorites VALUES (2153, 8, 3);
INSERT INTO favorites VALUES (2153, 91, 2);
INSERT INTO favorites VALUES (2154, 35, 2);
INSERT INTO favorites VALUES (2154, 113, 1);
INSERT INTO favorites VALUES (2154, 42, 3);
INSERT INTO favorites VALUES (2155, 45, 1);
INSERT INTO favorites VALUES (2155, 83, 3);
INSERT INTO favorites VALUES (2155, 102, 2);
INSERT INTO favorites VALUES (2156, 6, 1);
INSERT INTO favorites VALUES (2156, 44, 2);
INSERT INTO favorites VALUES (2156, 26, 4);
INSERT INTO favorites VALUES (2156, 58, 3);
INSERT INTO favorites VALUES (2157, 96, 1);
INSERT INTO favorites VALUES (2158, 73, 2);
INSERT INTO favorites VALUES (2158, 91, 1);
INSERT INTO favorites VALUES (2158, 81, 5);
INSERT INTO favorites VALUES (2158, 75, 4);
INSERT INTO favorites VALUES (2158, 50, 3);
INSERT INTO favorites VALUES (2159, 65, 1);
INSERT INTO favorites VALUES (2161, 113, 1);
INSERT INTO favorites VALUES (2161, 110, 3);
INSERT INTO favorites VALUES (2161, 43, 2);
INSERT INTO favorites VALUES (2161, 85, 5);
INSERT INTO favorites VALUES (2161, 2, 4);
INSERT INTO favorites VALUES (2161, 28, 7);
INSERT INTO favorites VALUES (2161, 82, 6);
INSERT INTO favorites VALUES (2162, 86, 1);
INSERT INTO favorites VALUES (2162, 13, 3);
INSERT INTO favorites VALUES (2162, 22, 2);
INSERT INTO favorites VALUES (2163, 60, 3);
INSERT INTO favorites VALUES (2163, 67, 1);
INSERT INTO favorites VALUES (2163, 12, 2);
INSERT INTO favorites VALUES (2163, 52, 5);
INSERT INTO favorites VALUES (2163, 26, 4);
INSERT INTO favorites VALUES (2163, 60, 6);
INSERT INTO favorites VALUES (2164, 39, 2);
INSERT INTO favorites VALUES (2164, 36, 1);
INSERT INTO favorites VALUES (2164, 20, 4);
INSERT INTO favorites VALUES (2164, 9, 3);
INSERT INTO favorites VALUES (2164, 84, 5);
INSERT INTO favorites VALUES (2166, 110, 1);
INSERT INTO favorites VALUES (2166, 98, 2);
INSERT INTO favorites VALUES (2167, 1, 2);
INSERT INTO favorites VALUES (2167, 108, 1);
INSERT INTO favorites VALUES (2168, 101, 2);
INSERT INTO favorites VALUES (2168, 51, 1);
INSERT INTO favorites VALUES (2169, 27, 1);
INSERT INTO favorites VALUES (2169, 100, 3);
INSERT INTO favorites VALUES (2169, 40, 2);
INSERT INTO favorites VALUES (2169, 41, 4);
INSERT INTO favorites VALUES (2170, 61, 4);
INSERT INTO favorites VALUES (2170, 62, 5);
INSERT INTO favorites VALUES (2170, 93, 1);
INSERT INTO favorites VALUES (2170, 45, 3);
INSERT INTO favorites VALUES (2170, 31, 2);
INSERT INTO favorites VALUES (2171, 37, 1);
INSERT INTO favorites VALUES (2171, 1, 2);
INSERT INTO favorites VALUES (2171, 32, 3);
INSERT INTO favorites VALUES (2172, 29, 1);
INSERT INTO favorites VALUES (2172, 12, 2);
INSERT INTO favorites VALUES (2173, 44, 1);
INSERT INTO favorites VALUES (2173, 12, 2);
INSERT INTO favorites VALUES (2173, 36, 3);
INSERT INTO favorites VALUES (2173, 7, 4);
INSERT INTO favorites VALUES (2174, 36, 1);
INSERT INTO favorites VALUES (2175, 32, 2);
INSERT INTO favorites VALUES (2175, 58, 1);
INSERT INTO favorites VALUES (2175, 68, 3);
INSERT INTO favorites VALUES (2176, 73, 1);
INSERT INTO favorites VALUES (2177, 4, 1);
INSERT INTO favorites VALUES (2177, 16, 2);
INSERT INTO favorites VALUES (2177, 101, 3);
INSERT INTO favorites VALUES (2178, 25, 3);
INSERT INTO favorites VALUES (2178, 69, 1);
INSERT INTO favorites VALUES (2178, 40, 2);
INSERT INTO favorites VALUES (2178, 88, 4);
INSERT INTO favorites VALUES (2179, 16, 1);
INSERT INTO favorites VALUES (2179, 73, 4);
INSERT INTO favorites VALUES (2179, 21, 6);
INSERT INTO favorites VALUES (2179, 76, 5);
INSERT INTO favorites VALUES (2179, 54, 3);
INSERT INTO favorites VALUES (2179, 75, 2);
INSERT INTO favorites VALUES (2179, 45, 7);
INSERT INTO favorites VALUES (2180, 39, 2);
INSERT INTO favorites VALUES (2180, 97, 1);
INSERT INTO favorites VALUES (2180, 27, 3);
INSERT INTO favorites VALUES (2181, 74, 1);
INSERT INTO favorites VALUES (2181, 17, 2);
INSERT INTO favorites VALUES (2181, 57, 4);
INSERT INTO favorites VALUES (2181, 72, 3);
INSERT INTO favorites VALUES (2181, 58, 5);
INSERT INTO favorites VALUES (2182, 98, 1);
INSERT INTO favorites VALUES (2182, 64, 2);
INSERT INTO favorites VALUES (2183, 81, 2);
INSERT INTO favorites VALUES (2183, 51, 3);
INSERT INTO favorites VALUES (2183, 1, 1);
INSERT INTO favorites VALUES (2184, 12, 1);
INSERT INTO favorites VALUES (2184, 39, 2);
INSERT INTO favorites VALUES (2184, 42, 3);
INSERT INTO favorites VALUES (2185, 8, 2);
INSERT INTO favorites VALUES (2185, 83, 1);
INSERT INTO favorites VALUES (2185, 52, 4);
INSERT INTO favorites VALUES (2185, 87, 3);
INSERT INTO favorites VALUES (2185, 107, 5);
INSERT INTO favorites VALUES (2186, 15, 4);
INSERT INTO favorites VALUES (2186, 24, 3);
INSERT INTO favorites VALUES (2186, 14, 2);
INSERT INTO favorites VALUES (2186, 105, 1);
INSERT INTO favorites VALUES (2186, 43, 6);
INSERT INTO favorites VALUES (2186, 37, 5);
INSERT INTO favorites VALUES (2186, 57, 8);
INSERT INTO favorites VALUES (2186, 63, 7);
INSERT INTO favorites VALUES (2187, 13, 1);
INSERT INTO favorites VALUES (2188, 29, 1);
INSERT INTO favorites VALUES (2188, 77, 4);
INSERT INTO favorites VALUES (2188, 90, 3);
INSERT INTO favorites VALUES (2188, 60, 2);
INSERT INTO favorites VALUES (2188, 60, 5);
INSERT INTO favorites VALUES (2189, 105, 2);
INSERT INTO favorites VALUES (2189, 76, 1);
INSERT INTO favorites VALUES (2189, 68, 3);
INSERT INTO favorites VALUES (2189, 46, 5);
INSERT INTO favorites VALUES (2189, 34, 4);
INSERT INTO favorites VALUES (2190, 99, 1);
INSERT INTO favorites VALUES (2191, 14, 1);
INSERT INTO favorites VALUES (2191, 48, 2);
INSERT INTO favorites VALUES (2194, 88, 1);
INSERT INTO favorites VALUES (2194, 59, 2);
INSERT INTO favorites VALUES (2194, 47, 3);
INSERT INTO favorites VALUES (2195, 50, 2);
INSERT INTO favorites VALUES (2195, 4, 1);
INSERT INTO favorites VALUES (2196, 3, 1);
INSERT INTO favorites VALUES (2196, 56, 2);
INSERT INTO favorites VALUES (2197, 9, 2);
INSERT INTO favorites VALUES (2197, 53, 1);
INSERT INTO favorites VALUES (2197, 38, 3);
INSERT INTO favorites VALUES (2198, 19, 1);
INSERT INTO favorites VALUES (2198, 70, 2);
INSERT INTO favorites VALUES (2199, 2, 1);
INSERT INTO favorites VALUES (2199, 13, 2);
INSERT INTO favorites VALUES (2200, 1, 1);
INSERT INTO favorites VALUES (2200, 22, 2);
INSERT INTO favorites VALUES (2200, 101, 3);
INSERT INTO favorites VALUES (2202, 69, 6);
INSERT INTO favorites VALUES (2202, 106, 4);
INSERT INTO favorites VALUES (2202, 28, 3);
INSERT INTO favorites VALUES (2202, 23, 5);
INSERT INTO favorites VALUES (2202, 74, 1);
INSERT INTO favorites VALUES (2202, 13, 2);
INSERT INTO favorites VALUES (2202, 9, 7);
INSERT INTO favorites VALUES (2203, 13, 1);
INSERT INTO favorites VALUES (2204, 59, 1);
INSERT INTO favorites VALUES (2205, 6, 1);
INSERT INTO favorites VALUES (2205, 52, 4);
INSERT INTO favorites VALUES (2205, 89, 3);
INSERT INTO favorites VALUES (2205, 29, 2);
INSERT INTO favorites VALUES (2206, 54, 1);
INSERT INTO favorites VALUES (2206, 101, 2);
INSERT INTO favorites VALUES (2206, 94, 3);
INSERT INTO favorites VALUES (2206, 70, 4);
INSERT INTO favorites VALUES (2207, 87, 1);
INSERT INTO favorites VALUES (2207, 14, 2);
INSERT INTO favorites VALUES (2208, 8, 2);
INSERT INTO favorites VALUES (2208, 37, 1);
INSERT INTO favorites VALUES (2210, 85, 1);
INSERT INTO favorites VALUES (2210, 95, 2);
INSERT INTO favorites VALUES (2211, 67, 4);
INSERT INTO favorites VALUES (2211, 37, 5);
INSERT INTO favorites VALUES (2211, 76, 1);
INSERT INTO favorites VALUES (2211, 110, 3);
INSERT INTO favorites VALUES (2211, 36, 2);
INSERT INTO favorites VALUES (2212, 5, 5);
INSERT INTO favorites VALUES (2212, 69, 4);
INSERT INTO favorites VALUES (2212, 106, 3);
INSERT INTO favorites VALUES (2212, 30, 1);
INSERT INTO favorites VALUES (2212, 68, 2);
INSERT INTO favorites VALUES (2213, 84, 3);
INSERT INTO favorites VALUES (2213, 2, 1);
INSERT INTO favorites VALUES (2213, 55, 2);
INSERT INTO favorites VALUES (2214, 17, 1);
INSERT INTO favorites VALUES (2214, 97, 2);
INSERT INTO favorites VALUES (2215, 55, 3);
INSERT INTO favorites VALUES (2215, 90, 2);
INSERT INTO favorites VALUES (2215, 44, 1);
INSERT INTO favorites VALUES (2216, 96, 3);
INSERT INTO favorites VALUES (2216, 26, 1);
INSERT INTO favorites VALUES (2216, 99, 2);
INSERT INTO favorites VALUES (2217, 28, 1);
INSERT INTO favorites VALUES (2218, 44, 2);
INSERT INTO favorites VALUES (2218, 35, 1);
INSERT INTO favorites VALUES (2218, 96, 3);
INSERT INTO favorites VALUES (2219, 20, 5);
INSERT INTO favorites VALUES (2219, 56, 3);
INSERT INTO favorites VALUES (2219, 67, 2);
INSERT INTO favorites VALUES (2219, 27, 1);
INSERT INTO favorites VALUES (2219, 59, 4);
INSERT INTO favorites VALUES (2220, 41, 1);
INSERT INTO favorites VALUES (2221, 37, 4);
INSERT INTO favorites VALUES (2221, 87, 1);
INSERT INTO favorites VALUES (2221, 43, 3);
INSERT INTO favorites VALUES (2221, 98, 2);
INSERT INTO favorites VALUES (2222, 77, 1);
INSERT INTO favorites VALUES (2222, 58, 2);
INSERT INTO favorites VALUES (2223, 5, 2);
INSERT INTO favorites VALUES (2223, 88, 1);
INSERT INTO favorites VALUES (2223, 103, 4);
INSERT INTO favorites VALUES (2223, 29, 3);
INSERT INTO favorites VALUES (2224, 23, 1);
INSERT INTO favorites VALUES (2224, 20, 2);
INSERT INTO favorites VALUES (2225, 109, 1);
INSERT INTO favorites VALUES (2225, 4, 2);
INSERT INTO favorites VALUES (2226, 24, 1);
INSERT INTO favorites VALUES (2226, 36, 2);
INSERT INTO favorites VALUES (2227, 20, 3);
INSERT INTO favorites VALUES (2227, 98, 1);
INSERT INTO favorites VALUES (2227, 90, 2);
INSERT INTO favorites VALUES (2228, 62, 5);
INSERT INTO favorites VALUES (2228, 53, 4);
INSERT INTO favorites VALUES (2228, 24, 1);
INSERT INTO favorites VALUES (2228, 6, 3);
INSERT INTO favorites VALUES (2228, 32, 2);
INSERT INTO favorites VALUES (2229, 72, 1);
INSERT INTO favorites VALUES (2230, 19, 1);
INSERT INTO favorites VALUES (2231, 17, 1);
INSERT INTO favorites VALUES (2231, 67, 2);
INSERT INTO favorites VALUES (2232, 76, 4);
INSERT INTO favorites VALUES (2232, 102, 1);
INSERT INTO favorites VALUES (2232, 39, 3);
INSERT INTO favorites VALUES (2232, 31, 2);
INSERT INTO favorites VALUES (2233, 31, 3);
INSERT INTO favorites VALUES (2233, 52, 1);
INSERT INTO favorites VALUES (2233, 67, 2);
INSERT INTO favorites VALUES (2233, 14, 4);
INSERT INTO favorites VALUES (2234, 3, 2);
INSERT INTO favorites VALUES (2234, 49, 1);
INSERT INTO favorites VALUES (2235, 28, 2);
INSERT INTO favorites VALUES (2235, 110, 3);
INSERT INTO favorites VALUES (2235, 42, 1);
INSERT INTO favorites VALUES (2236, 5, 2);
INSERT INTO favorites VALUES (2236, 17, 3);
INSERT INTO favorites VALUES (2236, 2, 1);
INSERT INTO favorites VALUES (2237, 112, 2);
INSERT INTO favorites VALUES (2237, 47, 1);
INSERT INTO favorites VALUES (2238, 58, 4);
INSERT INTO favorites VALUES (2238, 26, 3);
INSERT INTO favorites VALUES (2238, 38, 1);
INSERT INTO favorites VALUES (2238, 40, 2);
INSERT INTO favorites VALUES (2239, 2, 1);
INSERT INTO favorites VALUES (2240, 12, 2);
INSERT INTO favorites VALUES (2240, 29, 1);
INSERT INTO favorites VALUES (2241, 45, 1);
INSERT INTO favorites VALUES (2242, 61, 4);
INSERT INTO favorites VALUES (2242, 33, 1);
INSERT INTO favorites VALUES (2242, 25, 2);
INSERT INTO favorites VALUES (2242, 31, 3);
INSERT INTO favorites VALUES (2243, 64, 1);
INSERT INTO favorites VALUES (2243, 99, 2);
INSERT INTO favorites VALUES (2244, 79, 3);
INSERT INTO favorites VALUES (2244, 49, 2);
INSERT INTO favorites VALUES (2244, 17, 1);
INSERT INTO favorites VALUES (2245, 42, 1);
INSERT INTO favorites VALUES (2246, 97, 5);
INSERT INTO favorites VALUES (2246, 34, 3);
INSERT INTO favorites VALUES (2246, 18, 2);
INSERT INTO favorites VALUES (2246, 55, 1);
INSERT INTO favorites VALUES (2246, 36, 4);
INSERT INTO favorites VALUES (2247, 7, 1);
INSERT INTO favorites VALUES (2248, 8, 3);
INSERT INTO favorites VALUES (2248, 45, 1);
INSERT INTO favorites VALUES (2248, 53, 2);
INSERT INTO favorites VALUES (2249, 29, 1);
INSERT INTO favorites VALUES (2250, 88, 2);
INSERT INTO favorites VALUES (2250, 31, 1);
INSERT INTO favorites VALUES (2250, 60, 3);
INSERT INTO favorites VALUES (2251, 13, 1);
INSERT INTO favorites VALUES (2252, 13, 3);
INSERT INTO favorites VALUES (2252, 76, 1);
INSERT INTO favorites VALUES (2252, 79, 2);
INSERT INTO favorites VALUES (2253, 16, 2);
INSERT INTO favorites VALUES (2253, 97, 1);
INSERT INTO favorites VALUES (2254, 112, 6);
INSERT INTO favorites VALUES (2254, 1, 7);
INSERT INTO favorites VALUES (2254, 69, 4);
INSERT INTO favorites VALUES (2254, 60, 3);
INSERT INTO favorites VALUES (2254, 26, 2);
INSERT INTO favorites VALUES (2254, 57, 1);
INSERT INTO favorites VALUES (2254, 116, 5);
INSERT INTO favorites VALUES (2255, 31, 3);
INSERT INTO favorites VALUES (2255, 36, 5);
INSERT INTO favorites VALUES (2255, 88, 1);
INSERT INTO favorites VALUES (2255, 43, 2);
INSERT INTO favorites VALUES (2255, 25, 4);
INSERT INTO favorites VALUES (2256, 61, 3);
INSERT INTO favorites VALUES (2256, 13, 1);
INSERT INTO favorites VALUES (2256, 99, 2);
INSERT INTO favorites VALUES (2257, 96, 1);
INSERT INTO favorites VALUES (2258, 4, 2);
INSERT INTO favorites VALUES (2258, 15, 1);
INSERT INTO favorites VALUES (2258, 37, 4);
INSERT INTO favorites VALUES (2258, 53, 3);
INSERT INTO favorites VALUES (2259, 19, 2);
INSERT INTO favorites VALUES (2259, 83, 1);
INSERT INTO favorites VALUES (2260, 1, 1);
INSERT INTO favorites VALUES (2260, 22, 2);
INSERT INTO favorites VALUES (2261, 61, 1);
INSERT INTO favorites VALUES (2262, 110, 1);
INSERT INTO favorites VALUES (2262, 32, 2);
INSERT INTO favorites VALUES (2263, 6, 2);
INSERT INTO favorites VALUES (2263, 12, 1);
INSERT INTO favorites VALUES (2263, 26, 4);
INSERT INTO favorites VALUES (2263, 35, 3);
INSERT INTO favorites VALUES (2264, 47, 3);
INSERT INTO favorites VALUES (2264, 90, 1);
INSERT INTO favorites VALUES (2264, 33, 2);
INSERT INTO favorites VALUES (2266, 75, 3);
INSERT INTO favorites VALUES (2266, 49, 1);
INSERT INTO favorites VALUES (2266, 12, 2);
INSERT INTO favorites VALUES (2267, 14, 1);
INSERT INTO favorites VALUES (2268, 67, 3);
INSERT INTO favorites VALUES (2268, 19, 1);
INSERT INTO favorites VALUES (2268, 29, 2);
INSERT INTO favorites VALUES (2269, 47, 4);
INSERT INTO favorites VALUES (2269, 55, 2);
INSERT INTO favorites VALUES (2269, 23, 1);
INSERT INTO favorites VALUES (2269, 23, 3);
INSERT INTO favorites VALUES (2270, 109, 3);
INSERT INTO favorites VALUES (2270, 35, 1);
INSERT INTO favorites VALUES (2270, 43, 2);
INSERT INTO favorites VALUES (2271, 88, 1);
INSERT INTO favorites VALUES (2272, 101, 2);
INSERT INTO favorites VALUES (2272, 25, 1);
INSERT INTO favorites VALUES (2273, 40, 1);
INSERT INTO favorites VALUES (2274, 98, 2);
INSERT INTO favorites VALUES (2274, 64, 1);
INSERT INTO favorites VALUES (2275, 3, 5);
INSERT INTO favorites VALUES (2275, 1, 1);
INSERT INTO favorites VALUES (2275, 107, 3);
INSERT INTO favorites VALUES (2275, 83, 4);
INSERT INTO favorites VALUES (2275, 61, 2);
INSERT INTO favorites VALUES (2276, 27, 4);
INSERT INTO favorites VALUES (2276, 68, 1);
INSERT INTO favorites VALUES (2276, 49, 2);
INSERT INTO favorites VALUES (2276, 36, 3);
INSERT INTO favorites VALUES (2278, 9, 5);
INSERT INTO favorites VALUES (2278, 2, 3);
INSERT INTO favorites VALUES (2278, 116, 2);
INSERT INTO favorites VALUES (2278, 30, 1);
INSERT INTO favorites VALUES (2278, 13, 4);
INSERT INTO favorites VALUES (2279, 85, 1);
INSERT INTO favorites VALUES (2279, 88, 2);
INSERT INTO favorites VALUES (2280, 92, 1);
INSERT INTO favorites VALUES (2280, 44, 2);
INSERT INTO favorites VALUES (2281, 66, 2);
INSERT INTO favorites VALUES (2281, 116, 1);
INSERT INTO favorites VALUES (2282, 30, 4);
INSERT INTO favorites VALUES (2282, 27, 1);
INSERT INTO favorites VALUES (2282, 18, 2);
INSERT INTO favorites VALUES (2282, 61, 3);
INSERT INTO favorites VALUES (2283, 69, 3);
INSERT INTO favorites VALUES (2283, 29, 2);
INSERT INTO favorites VALUES (2283, 40, 1);
INSERT INTO favorites VALUES (2283, 13, 4);
INSERT INTO favorites VALUES (2285, 34, 5);
INSERT INTO favorites VALUES (2285, 35, 3);
INSERT INTO favorites VALUES (2285, 72, 2);
INSERT INTO favorites VALUES (2285, 70, 1);
INSERT INTO favorites VALUES (2285, 21, 4);
INSERT INTO favorites VALUES (2286, 44, 2);
INSERT INTO favorites VALUES (2286, 58, 1);
INSERT INTO favorites VALUES (2287, 54, 2);
INSERT INTO favorites VALUES (2287, 64, 1);
INSERT INTO favorites VALUES (2288, 87, 1);
INSERT INTO favorites VALUES (2289, 3, 2);
INSERT INTO favorites VALUES (2289, 47, 1);
INSERT INTO favorites VALUES (2289, 12, 3);
INSERT INTO favorites VALUES (2290, 57, 1);
INSERT INTO favorites VALUES (2291, 29, 3);
INSERT INTO favorites VALUES (2291, 8, 1);
INSERT INTO favorites VALUES (2291, 71, 2);
INSERT INTO favorites VALUES (2292, 11, 1);
INSERT INTO favorites VALUES (2293, 80, 1);
INSERT INTO favorites VALUES (2294, 115, 2);
INSERT INTO favorites VALUES (2294, 33, 1);
INSERT INTO favorites VALUES (2295, 34, 1);
INSERT INTO favorites VALUES (2296, 92, 1);
INSERT INTO favorites VALUES (2296, 26, 2);
INSERT INTO favorites VALUES (2297, 68, 1);
INSERT INTO favorites VALUES (2297, 4, 2);
INSERT INTO favorites VALUES (2298, 63, 1);
INSERT INTO favorites VALUES (2299, 27, 1);
INSERT INTO favorites VALUES (2299, 42, 2);
INSERT INTO favorites VALUES (2300, 21, 1);
INSERT INTO favorites VALUES (2300, 85, 2);
INSERT INTO favorites VALUES (2300, 38, 3);
INSERT INTO favorites VALUES (2302, 75, 1);
INSERT INTO favorites VALUES (2303, 29, 1);
INSERT INTO favorites VALUES (2304, 20, 5);
INSERT INTO favorites VALUES (2304, 113, 3);
INSERT INTO favorites VALUES (2304, 19, 2);
INSERT INTO favorites VALUES (2304, 13, 1);
INSERT INTO favorites VALUES (2304, 68, 4);
INSERT INTO favorites VALUES (2305, 98, 1);
INSERT INTO favorites VALUES (2305, 65, 2);
INSERT INTO favorites VALUES (2307, 34, 4);
INSERT INTO favorites VALUES (2307, 88, 5);
INSERT INTO favorites VALUES (2307, 19, 2);
INSERT INTO favorites VALUES (2307, 37, 1);
INSERT INTO favorites VALUES (2307, 79, 3);
INSERT INTO favorites VALUES (2308, 70, 3);
INSERT INTO favorites VALUES (2308, 82, 1);
INSERT INTO favorites VALUES (2308, 66, 2);
INSERT INTO favorites VALUES (2308, 107, 4);
INSERT INTO favorites VALUES (2310, 28, 2);
INSERT INTO favorites VALUES (2310, 8, 1);
INSERT INTO favorites VALUES (2311, 30, 1);
INSERT INTO favorites VALUES (2311, 24, 2);
INSERT INTO favorites VALUES (2312, 83, 3);
INSERT INTO favorites VALUES (2312, 65, 1);
INSERT INTO favorites VALUES (2312, 86, 2);
INSERT INTO favorites VALUES (2313, 91, 1);
INSERT INTO favorites VALUES (2313, 53, 2);
INSERT INTO favorites VALUES (2314, 27, 4);
INSERT INTO favorites VALUES (2314, 11, 5);
INSERT INTO favorites VALUES (2314, 4, 2);
INSERT INTO favorites VALUES (2314, 43, 3);
INSERT INTO favorites VALUES (2314, 40, 1);
INSERT INTO favorites VALUES (2314, 24, 6);
INSERT INTO favorites VALUES (2315, 113, 2);
INSERT INTO favorites VALUES (2315, 83, 1);
INSERT INTO favorites VALUES (2315, 76, 3);
INSERT INTO favorites VALUES (2316, 100, 1);
INSERT INTO favorites VALUES (2316, 107, 2);
INSERT INTO favorites VALUES (2317, 95, 3);
INSERT INTO favorites VALUES (2317, 81, 1);
INSERT INTO favorites VALUES (2317, 90, 2);
INSERT INTO favorites VALUES (2317, 49, 4);
INSERT INTO favorites VALUES (2318, 11, 4);
INSERT INTO favorites VALUES (2318, 102, 5);
INSERT INTO favorites VALUES (2318, 26, 2);
INSERT INTO favorites VALUES (2318, 69, 1);
INSERT INTO favorites VALUES (2318, 2, 3);
INSERT INTO favorites VALUES (2319, 47, 1);
INSERT INTO favorites VALUES (2319, 36, 2);
INSERT INTO favorites VALUES (2320, 45, 1);
INSERT INTO favorites VALUES (2321, 15, 1);
INSERT INTO favorites VALUES (2322, 108, 4);
INSERT INTO favorites VALUES (2322, 114, 1);
INSERT INTO favorites VALUES (2322, 16, 2);
INSERT INTO favorites VALUES (2322, 4, 3);
INSERT INTO favorites VALUES (2323, 57, 3);
INSERT INTO favorites VALUES (2323, 99, 4);
INSERT INTO favorites VALUES (2323, 73, 2);
INSERT INTO favorites VALUES (2323, 98, 1);
INSERT INTO favorites VALUES (2323, 52, 5);
INSERT INTO favorites VALUES (2324, 13, 3);
INSERT INTO favorites VALUES (2324, 96, 4);
INSERT INTO favorites VALUES (2324, 56, 2);
INSERT INTO favorites VALUES (2324, 90, 1);
INSERT INTO favorites VALUES (2324, 52, 5);
INSERT INTO favorites VALUES (2325, 37, 1);
INSERT INTO favorites VALUES (2326, 36, 2);
INSERT INTO favorites VALUES (2326, 114, 4);
INSERT INTO favorites VALUES (2326, 52, 1);
INSERT INTO favorites VALUES (2326, 55, 3);
INSERT INTO favorites VALUES (2327, 113, 3);
INSERT INTO favorites VALUES (2327, 37, 1);
INSERT INTO favorites VALUES (2327, 21, 2);
INSERT INTO favorites VALUES (2328, 91, 3);
INSERT INTO favorites VALUES (2328, 64, 2);
INSERT INTO favorites VALUES (2328, 59, 1);
INSERT INTO favorites VALUES (2329, 47, 2);
INSERT INTO favorites VALUES (2329, 90, 1);
INSERT INTO favorites VALUES (2330, 28, 3);
INSERT INTO favorites VALUES (2330, 26, 4);
INSERT INTO favorites VALUES (2330, 106, 1);
INSERT INTO favorites VALUES (2330, 9, 2);
INSERT INTO favorites VALUES (2330, 10, 5);
INSERT INTO favorites VALUES (2331, 52, 1);
INSERT INTO favorites VALUES (2331, 24, 2);
INSERT INTO favorites VALUES (2332, 113, 1);
INSERT INTO favorites VALUES (2333, 80, 3);
INSERT INTO favorites VALUES (2333, 15, 1);
INSERT INTO favorites VALUES (2333, 30, 2);
INSERT INTO favorites VALUES (2333, 19, 4);
INSERT INTO favorites VALUES (2334, 51, 4);
INSERT INTO favorites VALUES (2334, 90, 1);
INSERT INTO favorites VALUES (2334, 90, 2);
INSERT INTO favorites VALUES (2334, 47, 3);
INSERT INTO favorites VALUES (2335, 7, 3);
INSERT INTO favorites VALUES (2335, 23, 1);
INSERT INTO favorites VALUES (2335, 23, 2);
INSERT INTO favorites VALUES (2336, 34, 7);
INSERT INTO favorites VALUES (2336, 104, 8);
INSERT INTO favorites VALUES (2336, 70, 6);
INSERT INTO favorites VALUES (2336, 18, 3);
INSERT INTO favorites VALUES (2336, 61, 2);
INSERT INTO favorites VALUES (2336, 20, 1);
INSERT INTO favorites VALUES (2336, 70, 4);
INSERT INTO favorites VALUES (2336, 10, 5);
INSERT INTO favorites VALUES (2337, 102, 4);
INSERT INTO favorites VALUES (2337, 21, 5);
INSERT INTO favorites VALUES (2337, 16, 3);
INSERT INTO favorites VALUES (2337, 110, 1);
INSERT INTO favorites VALUES (2337, 27, 2);
INSERT INTO favorites VALUES (2338, 50, 1);
INSERT INTO favorites VALUES (2339, 71, 6);
INSERT INTO favorites VALUES (2339, 107, 7);
INSERT INTO favorites VALUES (2339, 29, 4);
INSERT INTO favorites VALUES (2339, 45, 1);
INSERT INTO favorites VALUES (2339, 19, 3);
INSERT INTO favorites VALUES (2339, 69, 2);
INSERT INTO favorites VALUES (2339, 102, 5);
INSERT INTO favorites VALUES (2340, 9, 3);
INSERT INTO favorites VALUES (2340, 9, 1);
INSERT INTO favorites VALUES (2340, 66, 2);
INSERT INTO favorites VALUES (2341, 109, 2);
INSERT INTO favorites VALUES (2341, 54, 1);
INSERT INTO favorites VALUES (2342, 111, 1);
INSERT INTO favorites VALUES (2343, 12, 3);
INSERT INTO favorites VALUES (2343, 42, 2);
INSERT INTO favorites VALUES (2343, 1, 1);
INSERT INTO favorites VALUES (2344, 29, 5);
INSERT INTO favorites VALUES (2344, 42, 6);
INSERT INTO favorites VALUES (2344, 55, 2);
INSERT INTO favorites VALUES (2344, 67, 4);
INSERT INTO favorites VALUES (2344, 52, 1);
INSERT INTO favorites VALUES (2344, 54, 3);
INSERT INTO favorites VALUES (2345, 88, 1);
INSERT INTO favorites VALUES (2346, 56, 1);
INSERT INTO favorites VALUES (2346, 22, 2);
INSERT INTO favorites VALUES (2347, 45, 3);
INSERT INTO favorites VALUES (2347, 23, 1);
INSERT INTO favorites VALUES (2347, 60, 2);
INSERT INTO favorites VALUES (2348, 22, 2);
INSERT INTO favorites VALUES (2348, 92, 3);
INSERT INTO favorites VALUES (2348, 16, 4);
INSERT INTO favorites VALUES (2348, 74, 1);
INSERT INTO favorites VALUES (2349, 58, 3);
INSERT INTO favorites VALUES (2349, 1, 1);
INSERT INTO favorites VALUES (2349, 95, 2);
INSERT INTO favorites VALUES (2350, 95, 1);
INSERT INTO favorites VALUES (2350, 57, 2);
INSERT INTO favorites VALUES (2351, 71, 4);
INSERT INTO favorites VALUES (2351, 48, 1);
INSERT INTO favorites VALUES (2351, 43, 3);
INSERT INTO favorites VALUES (2351, 2, 2);
INSERT INTO favorites VALUES (2352, 93, 2);
INSERT INTO favorites VALUES (2352, 49, 1);
INSERT INTO favorites VALUES (2353, 39, 3);
INSERT INTO favorites VALUES (2353, 81, 2);
INSERT INTO favorites VALUES (2353, 53, 1);
INSERT INTO favorites VALUES (2354, 63, 4);
INSERT INTO favorites VALUES (2354, 111, 1);
INSERT INTO favorites VALUES (2354, 52, 3);
INSERT INTO favorites VALUES (2354, 9, 2);
INSERT INTO favorites VALUES (2355, 105, 3);
INSERT INTO favorites VALUES (2355, 71, 5);
INSERT INTO favorites VALUES (2355, 87, 1);
INSERT INTO favorites VALUES (2355, 3, 2);
INSERT INTO favorites VALUES (2355, 108, 4);
INSERT INTO favorites VALUES (2356, 8, 8);
INSERT INTO favorites VALUES (2356, 105, 9);
INSERT INTO favorites VALUES (2356, 1, 6);
INSERT INTO favorites VALUES (2356, 46, 7);
INSERT INTO favorites VALUES (2356, 23, 1);
INSERT INTO favorites VALUES (2356, 14, 2);
INSERT INTO favorites VALUES (2356, 47, 3);
INSERT INTO favorites VALUES (2356, 9, 5);
INSERT INTO favorites VALUES (2356, 23, 4);
INSERT INTO favorites VALUES (2357, 49, 1);
INSERT INTO favorites VALUES (2357, 7, 2);
INSERT INTO favorites VALUES (2357, 12, 3);
INSERT INTO favorites VALUES (2358, 42, 1);
INSERT INTO favorites VALUES (2358, 32, 2);
INSERT INTO favorites VALUES (2359, 38, 3);
INSERT INTO favorites VALUES (2359, 33, 1);
INSERT INTO favorites VALUES (2359, 55, 2);
INSERT INTO favorites VALUES (2360, 28, 2);
INSERT INTO favorites VALUES (2360, 115, 1);
INSERT INTO favorites VALUES (2361, 57, 1);
INSERT INTO favorites VALUES (2361, 16, 2);
INSERT INTO favorites VALUES (2362, 1, 1);
INSERT INTO favorites VALUES (2363, 13, 1);
INSERT INTO favorites VALUES (2363, 88, 2);
INSERT INTO favorites VALUES (2364, 42, 1);
INSERT INTO favorites VALUES (2364, 67, 3);
INSERT INTO favorites VALUES (2364, 1, 2);
INSERT INTO favorites VALUES (2365, 112, 1);
INSERT INTO favorites VALUES (2365, 93, 2);
INSERT INTO favorites VALUES (2366, 23, 3);
INSERT INTO favorites VALUES (2366, 49, 1);
INSERT INTO favorites VALUES (2366, 110, 2);
INSERT INTO favorites VALUES (2367, 97, 4);
INSERT INTO favorites VALUES (2367, 57, 5);
INSERT INTO favorites VALUES (2367, 64, 2);
INSERT INTO favorites VALUES (2367, 28, 1);
INSERT INTO favorites VALUES (2367, 34, 3);
INSERT INTO favorites VALUES (2368, 23, 3);
INSERT INTO favorites VALUES (2368, 12, 1);
INSERT INTO favorites VALUES (2368, 15, 2);
INSERT INTO favorites VALUES (2368, 79, 4);
INSERT INTO favorites VALUES (2369, 54, 1);
INSERT INTO favorites VALUES (2369, 12, 2);
INSERT INTO favorites VALUES (2370, 3, 3);
INSERT INTO favorites VALUES (2370, 12, 2);
INSERT INTO favorites VALUES (2370, 15, 1);
INSERT INTO favorites VALUES (2371, 41, 4);
INSERT INTO favorites VALUES (2371, 8, 1);
INSERT INTO favorites VALUES (2371, 103, 2);
INSERT INTO favorites VALUES (2371, 36, 3);
INSERT INTO favorites VALUES (2372, 114, 3);
INSERT INTO favorites VALUES (2372, 84, 2);
INSERT INTO favorites VALUES (2372, 23, 1);
INSERT INTO favorites VALUES (2378, 91, 1);
INSERT INTO favorites VALUES (2378, 92, 2);
INSERT INTO favorites VALUES (2379, 103, 1);
INSERT INTO favorites VALUES (2379, 98, 2);
INSERT INTO favorites VALUES (2382, 1, 4);
INSERT INTO favorites VALUES (2382, 7, 1);
INSERT INTO favorites VALUES (2382, 103, 2);
INSERT INTO favorites VALUES (2382, 99, 3);
INSERT INTO favorites VALUES (2383, 94, 4);
INSERT INTO favorites VALUES (2383, 8, 1);
INSERT INTO favorites VALUES (2383, 63, 2);
INSERT INTO favorites VALUES (2383, 108, 3);
INSERT INTO favorites VALUES (2384, 85, 2);
INSERT INTO favorites VALUES (2384, 80, 1);
INSERT INTO favorites VALUES (2384, 96, 3);
INSERT INTO favorites VALUES (2384, 60, 4);
INSERT INTO favorites VALUES (2385, 53, 2);
INSERT INTO favorites VALUES (2385, 13, 1);
INSERT INTO favorites VALUES (2385, 35, 3);
INSERT INTO favorites VALUES (2386, 105, 1);
INSERT INTO favorites VALUES (2387, 50, 4);
INSERT INTO favorites VALUES (2387, 85, 5);
INSERT INTO favorites VALUES (2387, 11, 2);
INSERT INTO favorites VALUES (2387, 87, 1);
INSERT INTO favorites VALUES (2387, 82, 3);
INSERT INTO favorites VALUES (2388, 3, 4);
INSERT INTO favorites VALUES (2388, 25, 5);
INSERT INTO favorites VALUES (2388, 20, 3);
INSERT INTO favorites VALUES (2388, 16, 1);
INSERT INTO favorites VALUES (2388, 11, 2);
INSERT INTO favorites VALUES (2389, 116, 1);
INSERT INTO favorites VALUES (2389, 102, 4);
INSERT INTO favorites VALUES (2389, 6, 3);
INSERT INTO favorites VALUES (2389, 63, 2);
INSERT INTO favorites VALUES (2390, 22, 6);
INSERT INTO favorites VALUES (2390, 41, 4);
INSERT INTO favorites VALUES (2390, 1, 1);
INSERT INTO favorites VALUES (2390, 60, 3);
INSERT INTO favorites VALUES (2390, 77, 2);
INSERT INTO favorites VALUES (2390, 6, 5);
INSERT INTO favorites VALUES (2391, 75, 1);
INSERT INTO favorites VALUES (2391, 8, 2);
INSERT INTO favorites VALUES (2392, 25, 1);
INSERT INTO favorites VALUES (2392, 39, 2);
INSERT INTO favorites VALUES (2393, 99, 5);
INSERT INTO favorites VALUES (2393, 46, 4);
INSERT INTO favorites VALUES (2393, 113, 1);
INSERT INTO favorites VALUES (2393, 83, 3);
INSERT INTO favorites VALUES (2393, 47, 2);
INSERT INTO favorites VALUES (2394, 11, 3);
INSERT INTO favorites VALUES (2394, 16, 1);
INSERT INTO favorites VALUES (2394, 83, 2);
INSERT INTO favorites VALUES (2395, 115, 2);
INSERT INTO favorites VALUES (2395, 56, 1);
INSERT INTO favorites VALUES (2395, 51, 4);
INSERT INTO favorites VALUES (2395, 96, 3);
INSERT INTO favorites VALUES (2396, 35, 4);
INSERT INTO favorites VALUES (2396, 74, 1);
INSERT INTO favorites VALUES (2396, 16, 2);
INSERT INTO favorites VALUES (2396, 45, 3);
INSERT INTO favorites VALUES (2397, 88, 4);
INSERT INTO favorites VALUES (2397, 17, 1);
INSERT INTO favorites VALUES (2397, 50, 3);
INSERT INTO favorites VALUES (2397, 88, 2);
INSERT INTO favorites VALUES (2398, 69, 4);
INSERT INTO favorites VALUES (2398, 103, 2);
INSERT INTO favorites VALUES (2398, 2, 1);
INSERT INTO favorites VALUES (2398, 35, 3);
INSERT INTO favorites VALUES (2399, 69, 2);
INSERT INTO favorites VALUES (2399, 100, 1);
INSERT INTO favorites VALUES (2399, 19, 3);
INSERT INTO favorites VALUES (2400, 39, 1);
INSERT INTO favorites VALUES (2400, 9, 3);
INSERT INTO favorites VALUES (2400, 106, 2);
INSERT INTO favorites VALUES (2401, 15, 3);
INSERT INTO favorites VALUES (2401, 4, 1);
INSERT INTO favorites VALUES (2401, 92, 2);
INSERT INTO favorites VALUES (2402, 59, 3);
INSERT INTO favorites VALUES (2402, 48, 1);
INSERT INTO favorites VALUES (2402, 21, 2);
INSERT INTO favorites VALUES (2402, 80, 4);
INSERT INTO favorites VALUES (2403, 22, 2);
INSERT INTO favorites VALUES (2403, 16, 1);
INSERT INTO favorites VALUES (2404, 108, 2);
INSERT INTO favorites VALUES (2404, 97, 1);
INSERT INTO favorites VALUES (2404, 48, 3);
INSERT INTO favorites VALUES (2405, 27, 2);
INSERT INTO favorites VALUES (2405, 14, 3);
INSERT INTO favorites VALUES (2405, 77, 1);
INSERT INTO favorites VALUES (2408, 25, 2);
INSERT INTO favorites VALUES (2408, 22, 1);
INSERT INTO favorites VALUES (2409, 64, 2);
INSERT INTO favorites VALUES (2409, 1, 1);
INSERT INTO favorites VALUES (2409, 73, 4);
INSERT INTO favorites VALUES (2409, 40, 3);
INSERT INTO favorites VALUES (2410, 41, 3);
INSERT INTO favorites VALUES (2410, 6, 2);
INSERT INTO favorites VALUES (2410, 58, 1);
INSERT INTO favorites VALUES (2411, 72, 1);
INSERT INTO favorites VALUES (2411, 62, 2);
INSERT INTO favorites VALUES (2412, 3, 2);
INSERT INTO favorites VALUES (2412, 29, 1);
INSERT INTO favorites VALUES (2413, 77, 2);
INSERT INTO favorites VALUES (2413, 37, 1);
INSERT INTO favorites VALUES (2414, 51, 3);
INSERT INTO favorites VALUES (2414, 55, 1);
INSERT INTO favorites VALUES (2414, 62, 4);
INSERT INTO favorites VALUES (2414, 87, 2);
INSERT INTO favorites VALUES (2415, 67, 1);
INSERT INTO favorites VALUES (2415, 78, 2);
INSERT INTO favorites VALUES (2416, 81, 4);
INSERT INTO favorites VALUES (2416, 45, 5);
INSERT INTO favorites VALUES (2416, 9, 1);
INSERT INTO favorites VALUES (2416, 99, 3);
INSERT INTO favorites VALUES (2416, 98, 2);
INSERT INTO favorites VALUES (2417, 109, 2);
INSERT INTO favorites VALUES (2417, 63, 1);
INSERT INTO favorites VALUES (2418, 87, 1);
INSERT INTO favorites VALUES (2419, 107, 1);
INSERT INTO favorites VALUES (2419, 29, 2);
INSERT INTO favorites VALUES (2420, 14, 2);
INSERT INTO favorites VALUES (2420, 66, 1);
INSERT INTO favorites VALUES (2420, 95, 3);
INSERT INTO favorites VALUES (2421, 19, 1);
INSERT INTO favorites VALUES (2421, 8, 2);
INSERT INTO favorites VALUES (2422, 94, 1);
INSERT INTO favorites VALUES (2423, 17, 4);
INSERT INTO favorites VALUES (2423, 48, 2);
INSERT INTO favorites VALUES (2423, 3, 1);
INSERT INTO favorites VALUES (2423, 21, 3);
INSERT INTO favorites VALUES (2424, 83, 4);
INSERT INTO favorites VALUES (2424, 8, 3);
INSERT INTO favorites VALUES (2424, 37, 2);
INSERT INTO favorites VALUES (2424, 111, 1);
INSERT INTO favorites VALUES (2424, 64, 5);
INSERT INTO favorites VALUES (2425, 104, 1);
INSERT INTO favorites VALUES (2426, 33, 1);
INSERT INTO favorites VALUES (2427, 30, 3);
INSERT INTO favorites VALUES (2427, 86, 1);
INSERT INTO favorites VALUES (2427, 43, 2);
INSERT INTO favorites VALUES (2428, 21, 4);
INSERT INTO favorites VALUES (2428, 12, 2);
INSERT INTO favorites VALUES (2428, 40, 1);
INSERT INTO favorites VALUES (2428, 63, 3);
INSERT INTO favorites VALUES (2431, 94, 3);
INSERT INTO favorites VALUES (2431, 3, 1);
INSERT INTO favorites VALUES (2431, 29, 2);
INSERT INTO favorites VALUES (2432, 18, 1);
INSERT INTO favorites VALUES (2433, 45, 1);
INSERT INTO favorites VALUES (2433, 97, 2);
INSERT INTO favorites VALUES (2434, 92, 1);
INSERT INTO favorites VALUES (2434, 53, 2);
INSERT INTO favorites VALUES (2435, 2, 1);
INSERT INTO favorites VALUES (2435, 21, 2);
INSERT INTO favorites VALUES (2436, 80, 1);
INSERT INTO favorites VALUES (2437, 28, 1);
INSERT INTO favorites VALUES (2438, 11, 3);
INSERT INTO favorites VALUES (2438, 12, 1);
INSERT INTO favorites VALUES (2438, 6, 2);
INSERT INTO favorites VALUES (2439, 14, 1);
INSERT INTO favorites VALUES (2440, 46, 1);
INSERT INTO favorites VALUES (2440, 95, 3);
INSERT INTO favorites VALUES (2440, 59, 2);
INSERT INTO favorites VALUES (2441, 25, 1);
INSERT INTO favorites VALUES (2441, 46, 2);
INSERT INTO favorites VALUES (2442, 22, 3);
INSERT INTO favorites VALUES (2442, 71, 2);
INSERT INTO favorites VALUES (2442, 56, 1);
INSERT INTO favorites VALUES (2444, 34, 4);
INSERT INTO favorites VALUES (2444, 42, 3);
INSERT INTO favorites VALUES (2444, 46, 2);
INSERT INTO favorites VALUES (2444, 93, 1);
INSERT INTO favorites VALUES (2445, 50, 3);
INSERT INTO favorites VALUES (2445, 107, 2);
INSERT INTO favorites VALUES (2445, 13, 1);
INSERT INTO favorites VALUES (2445, 40, 4);
INSERT INTO favorites VALUES (2446, 78, 1);
INSERT INTO favorites VALUES (2447, 112, 3);
INSERT INTO favorites VALUES (2447, 116, 2);
INSERT INTO favorites VALUES (2447, 43, 1);
INSERT INTO favorites VALUES (2448, 56, 3);
INSERT INTO favorites VALUES (2448, 93, 1);
INSERT INTO favorites VALUES (2448, 105, 2);
INSERT INTO favorites VALUES (2449, 36, 1);
INSERT INTO favorites VALUES (2449, 59, 2);
INSERT INTO favorites VALUES (2450, 58, 3);
INSERT INTO favorites VALUES (2450, 35, 2);
INSERT INTO favorites VALUES (2450, 2, 1);
INSERT INTO favorites VALUES (2452, 76, 1);
INSERT INTO favorites VALUES (2452, 4, 2);
INSERT INTO favorites VALUES (2454, 22, 3);
INSERT INTO favorites VALUES (2454, 103, 1);
INSERT INTO favorites VALUES (2454, 50, 2);
INSERT INTO favorites VALUES (2455, 72, 1);
INSERT INTO favorites VALUES (2455, 43, 2);
INSERT INTO favorites VALUES (2457, 51, 3);
INSERT INTO favorites VALUES (2457, 93, 4);
INSERT INTO favorites VALUES (2457, 18, 2);
INSERT INTO favorites VALUES (2457, 79, 1);
INSERT INTO favorites VALUES (2457, 27, 5);
INSERT INTO favorites VALUES (2458, 47, 2);
INSERT INTO favorites VALUES (2458, 8, 1);
INSERT INTO favorites VALUES (2458, 35, 3);
INSERT INTO favorites VALUES (2459, 17, 4);
INSERT INTO favorites VALUES (2459, 8, 1);
INSERT INTO favorites VALUES (2459, 14, 2);
INSERT INTO favorites VALUES (2459, 85, 3);
INSERT INTO favorites VALUES (2460, 102, 1);
INSERT INTO favorites VALUES (2460, 20, 2);
INSERT INTO favorites VALUES (2461, 5, 5);
INSERT INTO favorites VALUES (2461, 8, 3);
INSERT INTO favorites VALUES (2461, 21, 1);
INSERT INTO favorites VALUES (2461, 96, 2);
INSERT INTO favorites VALUES (2461, 1, 4);
INSERT INTO favorites VALUES (2462, 73, 1);
INSERT INTO favorites VALUES (2463, 45, 3);
INSERT INTO favorites VALUES (2463, 48, 1);
INSERT INTO favorites VALUES (2463, 8, 2);
INSERT INTO favorites VALUES (2464, 50, 1);
INSERT INTO favorites VALUES (2464, 11, 2);
INSERT INTO favorites VALUES (2465, 72, 1);
INSERT INTO favorites VALUES (2465, 42, 2);
INSERT INTO favorites VALUES (2466, 22, 1);
INSERT INTO favorites VALUES (2467, 22, 1);
INSERT INTO favorites VALUES (2468, 7, 3);
INSERT INTO favorites VALUES (2468, 11, 2);
INSERT INTO favorites VALUES (2468, 107, 1);
INSERT INTO favorites VALUES (2469, 83, 3);
INSERT INTO favorites VALUES (2469, 25, 2);
INSERT INTO favorites VALUES (2469, 50, 1);
INSERT INTO favorites VALUES (2470, 61, 5);
INSERT INTO favorites VALUES (2470, 41, 6);
INSERT INTO favorites VALUES (2470, 47, 1);
INSERT INTO favorites VALUES (2470, 64, 3);
INSERT INTO favorites VALUES (2470, 30, 4);
INSERT INTO favorites VALUES (2470, 3, 2);
INSERT INTO favorites VALUES (2471, 69, 4);
INSERT INTO favorites VALUES (2471, 74, 1);
INSERT INTO favorites VALUES (2471, 59, 3);
INSERT INTO favorites VALUES (2471, 10, 2);
INSERT INTO favorites VALUES (2472, 21, 1);
INSERT INTO favorites VALUES (2472, 1, 2);
INSERT INTO favorites VALUES (2473, 23, 1);
INSERT INTO favorites VALUES (2474, 105, 4);
INSERT INTO favorites VALUES (2474, 23, 2);
INSERT INTO favorites VALUES (2474, 17, 1);
INSERT INTO favorites VALUES (2474, 101, 5);
INSERT INTO favorites VALUES (2474, 38, 3);
INSERT INTO favorites VALUES (2475, 15, 1);
INSERT INTO favorites VALUES (2475, 78, 2);
INSERT INTO favorites VALUES (2476, 15, 1);
INSERT INTO favorites VALUES (2476, 29, 2);
INSERT INTO favorites VALUES (2477, 80, 5);
INSERT INTO favorites VALUES (2477, 73, 4);
INSERT INTO favorites VALUES (2477, 33, 1);
INSERT INTO favorites VALUES (2477, 9, 3);
INSERT INTO favorites VALUES (2477, 34, 2);
INSERT INTO favorites VALUES (2478, 111, 3);
INSERT INTO favorites VALUES (2478, 8, 1);
INSERT INTO favorites VALUES (2478, 95, 2);
INSERT INTO favorites VALUES (2478, 57, 4);
INSERT INTO favorites VALUES (2479, 83, 1);
INSERT INTO favorites VALUES (2480, 13, 3);
INSERT INTO favorites VALUES (2480, 95, 2);
INSERT INTO favorites VALUES (2480, 95, 1);
INSERT INTO favorites VALUES (2481, 94, 1);
INSERT INTO favorites VALUES (2481, 57, 2);
INSERT INTO favorites VALUES (2482, 20, 3);
INSERT INTO favorites VALUES (2482, 55, 1);
INSERT INTO favorites VALUES (2482, 9, 2);
INSERT INTO favorites VALUES (2483, 28, 1);
INSERT INTO favorites VALUES (2483, 97, 2);
INSERT INTO favorites VALUES (2484, 75, 4);
INSERT INTO favorites VALUES (2484, 14, 5);
INSERT INTO favorites VALUES (2484, 75, 1);
INSERT INTO favorites VALUES (2484, 56, 3);
INSERT INTO favorites VALUES (2484, 57, 2);
INSERT INTO favorites VALUES (2485, 31, 7);
INSERT INTO favorites VALUES (2485, 97, 8);
INSERT INTO favorites VALUES (2485, 100, 4);
INSERT INTO favorites VALUES (2485, 10, 3);
INSERT INTO favorites VALUES (2485, 89, 6);
INSERT INTO favorites VALUES (2485, 84, 2);
INSERT INTO favorites VALUES (2485, 31, 1);
INSERT INTO favorites VALUES (2485, 75, 5);
INSERT INTO favorites VALUES (2486, 2, 3);
INSERT INTO favorites VALUES (2486, 19, 1);
INSERT INTO favorites VALUES (2486, 114, 2);
INSERT INTO favorites VALUES (2487, 63, 2);
INSERT INTO favorites VALUES (2487, 26, 1);
INSERT INTO favorites VALUES (2488, 102, 1);
INSERT INTO favorites VALUES (2488, 7, 2);
INSERT INTO favorites VALUES (2489, 62, 1);
INSERT INTO favorites VALUES (2490, 1, 1);
INSERT INTO favorites VALUES (2491, 47, 1);
INSERT INTO favorites VALUES (2492, 85, 3);
INSERT INTO favorites VALUES (2492, 76, 1);
INSERT INTO favorites VALUES (2492, 97, 2);
INSERT INTO favorites VALUES (2493, 115, 4);
INSERT INTO favorites VALUES (2493, 115, 2);
INSERT INTO favorites VALUES (2493, 62, 1);
INSERT INTO favorites VALUES (2493, 2, 3);
INSERT INTO favorites VALUES (2494, 96, 3);
INSERT INTO favorites VALUES (2494, 35, 1);
INSERT INTO favorites VALUES (2494, 7, 2);
INSERT INTO favorites VALUES (2495, 10, 1);
INSERT INTO favorites VALUES (2496, 42, 2);
INSERT INTO favorites VALUES (2496, 23, 1);
INSERT INTO favorites VALUES (2496, 93, 3);
INSERT INTO favorites VALUES (2497, 36, 3);
INSERT INTO favorites VALUES (2497, 99, 2);
INSERT INTO favorites VALUES (2497, 35, 1);
INSERT INTO favorites VALUES (2498, 29, 1);
INSERT INTO favorites VALUES (2498, 111, 2);
INSERT INTO favorites VALUES (2498, 53, 3);
INSERT INTO favorites VALUES (2498, 111, 5);
INSERT INTO favorites VALUES (2498, 41, 4);
INSERT INTO favorites VALUES (2499, 71, 1);
INSERT INTO favorites VALUES (2499, 51, 2);
INSERT INTO favorites VALUES (2500, 32, 1);
INSERT INTO favorites VALUES (2500, 29, 2);
INSERT INTO favorites VALUES (2500, 18, 3);
INSERT INTO favorites VALUES (2500, 13, 4);
INSERT INTO favorites VALUES (2501, 40, 2);
INSERT INTO favorites VALUES (2501, 75, 3);
INSERT INTO favorites VALUES (2501, 79, 1);
INSERT INTO favorites VALUES (2502, 80, 2);
INSERT INTO favorites VALUES (2502, 65, 1);
INSERT INTO favorites VALUES (2502, 2, 3);
INSERT INTO favorites VALUES (2503, 89, 1);
INSERT INTO favorites VALUES (2503, 23, 2);
INSERT INTO favorites VALUES (2505, 93, 1);
INSERT INTO favorites VALUES (2506, 98, 1);
INSERT INTO favorites VALUES (2507, 88, 8);
INSERT INTO favorites VALUES (2507, 89, 4);
INSERT INTO favorites VALUES (2507, 110, 5);
INSERT INTO favorites VALUES (2507, 51, 1);
INSERT INTO favorites VALUES (2507, 65, 3);
INSERT INTO favorites VALUES (2507, 30, 7);
INSERT INTO favorites VALUES (2507, 17, 2);
INSERT INTO favorites VALUES (2507, 22, 6);
INSERT INTO favorites VALUES (2508, 5, 4);
INSERT INTO favorites VALUES (2508, 107, 1);
INSERT INTO favorites VALUES (2508, 114, 2);
INSERT INTO favorites VALUES (2508, 87, 3);
INSERT INTO favorites VALUES (2509, 51, 1);
INSERT INTO favorites VALUES (2509, 85, 2);
INSERT INTO favorites VALUES (2510, 53, 1);
INSERT INTO favorites VALUES (2510, 88, 2);
INSERT INTO favorites VALUES (2511, 56, 1);
INSERT INTO favorites VALUES (2512, 29, 3);
INSERT INTO favorites VALUES (2512, 13, 1);
INSERT INTO favorites VALUES (2512, 32, 2);
INSERT INTO favorites VALUES (2512, 111, 4);
INSERT INTO favorites VALUES (2513, 111, 1);
INSERT INTO favorites VALUES (2513, 66, 2);
INSERT INTO favorites VALUES (2515, 79, 5);
INSERT INTO favorites VALUES (2515, 83, 4);
INSERT INTO favorites VALUES (2515, 3, 1);
INSERT INTO favorites VALUES (2515, 14, 3);
INSERT INTO favorites VALUES (2515, 91, 2);
INSERT INTO favorites VALUES (2516, 13, 4);
INSERT INTO favorites VALUES (2516, 8, 2);
INSERT INTO favorites VALUES (2516, 9, 1);
INSERT INTO favorites VALUES (2516, 54, 3);
INSERT INTO favorites VALUES (2517, 107, 1);
INSERT INTO favorites VALUES (2518, 6, 4);
INSERT INTO favorites VALUES (2518, 84, 1);
INSERT INTO favorites VALUES (2518, 102, 2);
INSERT INTO favorites VALUES (2518, 9, 3);
INSERT INTO favorites VALUES (2519, 1, 3);
INSERT INTO favorites VALUES (2519, 14, 1);
INSERT INTO favorites VALUES (2519, 82, 2);
INSERT INTO favorites VALUES (2521, 8, 3);
INSERT INTO favorites VALUES (2521, 1, 1);
INSERT INTO favorites VALUES (2521, 14, 2);
INSERT INTO favorites VALUES (2522, 25, 1);
INSERT INTO favorites VALUES (2523, 56, 1);
INSERT INTO favorites VALUES (2523, 21, 2);
INSERT INTO favorites VALUES (2524, 23, 4);
INSERT INTO favorites VALUES (2524, 116, 5);
INSERT INTO favorites VALUES (2524, 81, 1);
INSERT INTO favorites VALUES (2524, 33, 3);
INSERT INTO favorites VALUES (2524, 45, 2);
INSERT INTO favorites VALUES (2524, 3, 6);
INSERT INTO favorites VALUES (2525, 64, 2);
INSERT INTO favorites VALUES (2525, 48, 1);
INSERT INTO favorites VALUES (2525, 17, 3);
INSERT INTO favorites VALUES (2526, 9, 4);
INSERT INTO favorites VALUES (2526, 114, 1);
INSERT INTO favorites VALUES (2526, 17, 2);
INSERT INTO favorites VALUES (2526, 69, 3);
INSERT INTO favorites VALUES (2527, 14, 1);
INSERT INTO favorites VALUES (2527, 100, 2);
INSERT INTO favorites VALUES (2528, 47, 1);
INSERT INTO favorites VALUES (2528, 4, 2);
INSERT INTO favorites VALUES (2529, 18, 1);
INSERT INTO favorites VALUES (2529, 101, 2);
INSERT INTO favorites VALUES (2530, 8, 4);
INSERT INTO favorites VALUES (2530, 38, 1);
INSERT INTO favorites VALUES (2530, 62, 3);
INSERT INTO favorites VALUES (2530, 1, 2);
INSERT INTO favorites VALUES (2531, 99, 2);
INSERT INTO favorites VALUES (2531, 63, 1);
INSERT INTO favorites VALUES (2532, 96, 1);
INSERT INTO favorites VALUES (2534, 8, 1);
INSERT INTO favorites VALUES (2534, 95, 2);
INSERT INTO favorites VALUES (2535, 80, 5);
INSERT INTO favorites VALUES (2535, 61, 4);
INSERT INTO favorites VALUES (2535, 113, 2);
INSERT INTO favorites VALUES (2535, 49, 1);
INSERT INTO favorites VALUES (2535, 41, 3);
INSERT INTO favorites VALUES (2536, 93, 1);
INSERT INTO favorites VALUES (2538, 19, 2);
INSERT INTO favorites VALUES (2538, 112, 1);
INSERT INTO favorites VALUES (2538, 80, 3);
INSERT INTO favorites VALUES (2541, 64, 3);
INSERT INTO favorites VALUES (2541, 23, 1);
INSERT INTO favorites VALUES (2541, 67, 2);
INSERT INTO favorites VALUES (2544, 40, 6);
INSERT INTO favorites VALUES (2544, 16, 5);
INSERT INTO favorites VALUES (2544, 108, 2);
INSERT INTO favorites VALUES (2544, 39, 3);
INSERT INTO favorites VALUES (2544, 89, 1);
INSERT INTO favorites VALUES (2544, 100, 4);
INSERT INTO favorites VALUES (2545, 92, 1);
INSERT INTO favorites VALUES (2545, 85, 2);
INSERT INTO favorites VALUES (2546, 53, 2);
INSERT INTO favorites VALUES (2546, 56, 1);
INSERT INTO favorites VALUES (2547, 23, 1);
INSERT INTO favorites VALUES (2548, 114, 1);
INSERT INTO favorites VALUES (2548, 65, 2);
INSERT INTO favorites VALUES (2549, 2, 5);
INSERT INTO favorites VALUES (2549, 83, 3);
INSERT INTO favorites VALUES (2549, 106, 1);
INSERT INTO favorites VALUES (2549, 68, 2);
INSERT INTO favorites VALUES (2549, 74, 4);
INSERT INTO favorites VALUES (2550, 44, 2);
INSERT INTO favorites VALUES (2550, 92, 1);
INSERT INTO favorites VALUES (2552, 16, 6);
INSERT INTO favorites VALUES (2552, 45, 4);
INSERT INTO favorites VALUES (2552, 44, 2);
INSERT INTO favorites VALUES (2552, 34, 3);
INSERT INTO favorites VALUES (2552, 28, 1);
INSERT INTO favorites VALUES (2552, 33, 5);
INSERT INTO favorites VALUES (2553, 1, 3);
INSERT INTO favorites VALUES (2553, 101, 1);
INSERT INTO favorites VALUES (2553, 7, 2);
INSERT INTO favorites VALUES (2554, 31, 7);
INSERT INTO favorites VALUES (2554, 9, 5);
INSERT INTO favorites VALUES (2554, 20, 8);
INSERT INTO favorites VALUES (2554, 67, 3);
INSERT INTO favorites VALUES (2554, 39, 6);
INSERT INTO favorites VALUES (2554, 28, 1);
INSERT INTO favorites VALUES (2554, 72, 2);
INSERT INTO favorites VALUES (2554, 18, 4);
INSERT INTO favorites VALUES (2555, 104, 2);
INSERT INTO favorites VALUES (2555, 6, 1);
INSERT INTO favorites VALUES (2555, 22, 3);
INSERT INTO favorites VALUES (2557, 16, 2);
INSERT INTO favorites VALUES (2557, 6, 1);
INSERT INTO favorites VALUES (2557, 85, 3);
INSERT INTO favorites VALUES (2558, 61, 1);
INSERT INTO favorites VALUES (2559, 26, 2);
INSERT INTO favorites VALUES (2559, 31, 1);
INSERT INTO favorites VALUES (2560, 100, 4);
INSERT INTO favorites VALUES (2560, 91, 2);
INSERT INTO favorites VALUES (2560, 84, 1);
INSERT INTO favorites VALUES (2560, 115, 3);
INSERT INTO favorites VALUES (2561, 5, 2);
INSERT INTO favorites VALUES (2561, 97, 1);
INSERT INTO favorites VALUES (2562, 6, 4);
INSERT INTO favorites VALUES (2562, 50, 5);
INSERT INTO favorites VALUES (2562, 20, 1);
INSERT INTO favorites VALUES (2562, 55, 3);
INSERT INTO favorites VALUES (2562, 16, 2);
INSERT INTO favorites VALUES (2562, 45, 6);
INSERT INTO favorites VALUES (2563, 16, 3);
INSERT INTO favorites VALUES (2563, 46, 1);
INSERT INTO favorites VALUES (2563, 85, 2);
INSERT INTO favorites VALUES (2564, 6, 2);
INSERT INTO favorites VALUES (2564, 60, 1);
INSERT INTO favorites VALUES (2564, 105, 3);
INSERT INTO favorites VALUES (2565, 65, 1);
INSERT INTO favorites VALUES (2567, 116, 3);
INSERT INTO favorites VALUES (2567, 67, 1);
INSERT INTO favorites VALUES (2567, 91, 2);
INSERT INTO favorites VALUES (2568, 20, 1);
INSERT INTO favorites VALUES (2569, 105, 1);
INSERT INTO favorites VALUES (2569, 109, 2);
INSERT INTO favorites VALUES (2570, 49, 1);
INSERT INTO favorites VALUES (2570, 55, 2);
INSERT INTO favorites VALUES (2571, 18, 4);
INSERT INTO favorites VALUES (2571, 94, 5);
INSERT INTO favorites VALUES (2571, 61, 2);
INSERT INTO favorites VALUES (2571, 26, 3);
INSERT INTO favorites VALUES (2571, 6, 1);
INSERT INTO favorites VALUES (2572, 102, 1);
INSERT INTO favorites VALUES (2572, 8, 2);
INSERT INTO favorites VALUES (2573, 25, 7);
INSERT INTO favorites VALUES (2573, 49, 8);
INSERT INTO favorites VALUES (2573, 47, 6);
INSERT INTO favorites VALUES (2573, 59, 5);
INSERT INTO favorites VALUES (2573, 2, 2);
INSERT INTO favorites VALUES (2573, 14, 3);
INSERT INTO favorites VALUES (2573, 13, 1);
INSERT INTO favorites VALUES (2573, 106, 4);
INSERT INTO favorites VALUES (2574, 92, 9);
INSERT INTO favorites VALUES (2574, 83, 6);
INSERT INTO favorites VALUES (2574, 36, 7);
INSERT INTO favorites VALUES (2574, 18, 8);
INSERT INTO favorites VALUES (2574, 65, 5);
INSERT INTO favorites VALUES (2574, 56, 2);
INSERT INTO favorites VALUES (2574, 63, 3);
INSERT INTO favorites VALUES (2574, 81, 1);
INSERT INTO favorites VALUES (2574, 41, 4);
INSERT INTO favorites VALUES (2575, 36, 1);
INSERT INTO favorites VALUES (2576, 60, 5);
INSERT INTO favorites VALUES (2576, 84, 6);
INSERT INTO favorites VALUES (2576, 82, 2);
INSERT INTO favorites VALUES (2576, 96, 3);
INSERT INTO favorites VALUES (2576, 82, 1);
INSERT INTO favorites VALUES (2576, 41, 4);
INSERT INTO favorites VALUES (2577, 31, 6);
INSERT INTO favorites VALUES (2577, 33, 5);
INSERT INTO favorites VALUES (2577, 110, 4);
INSERT INTO favorites VALUES (2577, 66, 2);
INSERT INTO favorites VALUES (2577, 39, 3);
INSERT INTO favorites VALUES (2577, 43, 1);
INSERT INTO favorites VALUES (2578, 56, 4);
INSERT INTO favorites VALUES (2578, 12, 1);
INSERT INTO favorites VALUES (2578, 14, 2);
INSERT INTO favorites VALUES (2578, 81, 3);
INSERT INTO favorites VALUES (2579, 63, 6);
INSERT INTO favorites VALUES (2579, 83, 4);
INSERT INTO favorites VALUES (2579, 80, 3);
INSERT INTO favorites VALUES (2579, 54, 2);
INSERT INTO favorites VALUES (2579, 1, 1);
INSERT INTO favorites VALUES (2579, 20, 5);
INSERT INTO favorites VALUES (2580, 111, 1);
INSERT INTO favorites VALUES (2581, 50, 4);
INSERT INTO favorites VALUES (2581, 7, 5);
INSERT INTO favorites VALUES (2581, 16, 1);
INSERT INTO favorites VALUES (2581, 46, 2);
INSERT INTO favorites VALUES (2581, 9, 3);
INSERT INTO favorites VALUES (2582, 59, 3);
INSERT INTO favorites VALUES (2582, 11, 4);
INSERT INTO favorites VALUES (2582, 41, 1);
INSERT INTO favorites VALUES (2582, 25, 2);
INSERT INTO favorites VALUES (2582, 58, 5);
INSERT INTO favorites VALUES (2583, 90, 4);
INSERT INTO favorites VALUES (2583, 54, 5);
INSERT INTO favorites VALUES (2583, 95, 1);
INSERT INTO favorites VALUES (2583, 6, 3);
INSERT INTO favorites VALUES (2583, 103, 2);
INSERT INTO favorites VALUES (2584, 51, 2);
INSERT INTO favorites VALUES (2584, 21, 1);
INSERT INTO favorites VALUES (2584, 36, 3);
INSERT INTO favorites VALUES (2585, 4, 3);
INSERT INTO favorites VALUES (2585, 86, 1);
INSERT INTO favorites VALUES (2585, 103, 2);
INSERT INTO favorites VALUES (2586, 18, 1);
INSERT INTO favorites VALUES (2587, 106, 3);
INSERT INTO favorites VALUES (2587, 75, 1);
INSERT INTO favorites VALUES (2587, 14, 2);
INSERT INTO favorites VALUES (2588, 75, 1);
INSERT INTO favorites VALUES (2588, 57, 2);
INSERT INTO favorites VALUES (2589, 101, 2);
INSERT INTO favorites VALUES (2589, 47, 1);
INSERT INTO favorites VALUES (2589, 50, 3);
INSERT INTO favorites VALUES (2590, 85, 4);
INSERT INTO favorites VALUES (2590, 36, 1);
INSERT INTO favorites VALUES (2590, 23, 2);
INSERT INTO favorites VALUES (2590, 50, 3);
INSERT INTO favorites VALUES (2591, 59, 3);
INSERT INTO favorites VALUES (2591, 9, 2);
INSERT INTO favorites VALUES (2591, 107, 1);
INSERT INTO favorites VALUES (2591, 61, 4);
INSERT INTO favorites VALUES (2592, 32, 3);
INSERT INTO favorites VALUES (2592, 2, 1);
INSERT INTO favorites VALUES (2592, 26, 2);
INSERT INTO favorites VALUES (2592, 40, 4);
INSERT INTO favorites VALUES (2593, 40, 3);
INSERT INTO favorites VALUES (2593, 50, 2);
INSERT INTO favorites VALUES (2593, 106, 1);
INSERT INTO favorites VALUES (2594, 28, 2);
INSERT INTO favorites VALUES (2594, 53, 1);
INSERT INTO favorites VALUES (2595, 81, 3);
INSERT INTO favorites VALUES (2595, 62, 6);
INSERT INTO favorites VALUES (2595, 39, 1);
INSERT INTO favorites VALUES (2595, 116, 4);
INSERT INTO favorites VALUES (2595, 3, 5);
INSERT INTO favorites VALUES (2595, 17, 2);
INSERT INTO favorites VALUES (2596, 39, 5);
INSERT INTO favorites VALUES (2596, 100, 6);
INSERT INTO favorites VALUES (2596, 10, 2);
INSERT INTO favorites VALUES (2596, 57, 4);
INSERT INTO favorites VALUES (2596, 72, 1);
INSERT INTO favorites VALUES (2596, 45, 3);
INSERT INTO favorites VALUES (2598, 35, 1);
INSERT INTO favorites VALUES (2599, 76, 1);
INSERT INTO favorites VALUES (2600, 112, 1);
INSERT INTO favorites VALUES (2600, 74, 3);
INSERT INTO favorites VALUES (2600, 57, 2);
INSERT INTO favorites VALUES (2601, 70, 1);
INSERT INTO favorites VALUES (2601, 34, 2);
INSERT INTO favorites VALUES (2602, 96, 3);
INSERT INTO favorites VALUES (2602, 56, 1);
INSERT INTO favorites VALUES (2602, 14, 2);
INSERT INTO favorites VALUES (2603, 50, 4);
INSERT INTO favorites VALUES (2603, 9, 2);
INSERT INTO favorites VALUES (2603, 28, 1);
INSERT INTO favorites VALUES (2603, 2, 3);
INSERT INTO favorites VALUES (2604, 57, 1);
INSERT INTO favorites VALUES (2605, 34, 1);
INSERT INTO favorites VALUES (2606, 42, 1);
INSERT INTO favorites VALUES (2606, 41, 2);
INSERT INTO favorites VALUES (2607, 88, 4);
INSERT INTO favorites VALUES (2607, 52, 1);
INSERT INTO favorites VALUES (2607, 18, 2);
INSERT INTO favorites VALUES (2607, 33, 3);
INSERT INTO favorites VALUES (2608, 6, 1);
INSERT INTO favorites VALUES (2608, 73, 2);
INSERT INTO favorites VALUES (2609, 76, 3);
INSERT INTO favorites VALUES (2609, 48, 4);
INSERT INTO favorites VALUES (2609, 48, 2);
INSERT INTO favorites VALUES (2609, 26, 1);
INSERT INTO favorites VALUES (2609, 99, 5);
INSERT INTO favorites VALUES (2610, 13, 7);
INSERT INTO favorites VALUES (2610, 55, 6);
INSERT INTO favorites VALUES (2610, 5, 5);
INSERT INTO favorites VALUES (2610, 81, 4);
INSERT INTO favorites VALUES (2610, 93, 3);
INSERT INTO favorites VALUES (2610, 61, 1);
INSERT INTO favorites VALUES (2610, 88, 2);
INSERT INTO favorites VALUES (2611, 6, 2);
INSERT INTO favorites VALUES (2611, 6, 1);
INSERT INTO favorites VALUES (2611, 92, 3);
INSERT INTO favorites VALUES (2612, 6, 2);
INSERT INTO favorites VALUES (2612, 11, 1);
INSERT INTO favorites VALUES (2612, 97, 3);
INSERT INTO favorites VALUES (2613, 73, 1);
INSERT INTO favorites VALUES (2614, 21, 1);
INSERT INTO favorites VALUES (2616, 53, 1);
INSERT INTO favorites VALUES (2617, 40, 2);
INSERT INTO favorites VALUES (2617, 39, 1);
INSERT INTO favorites VALUES (2618, 36, 3);
INSERT INTO favorites VALUES (2618, 41, 1);
INSERT INTO favorites VALUES (2618, 8, 2);
INSERT INTO favorites VALUES (2619, 33, 3);
INSERT INTO favorites VALUES (2619, 35, 1);
INSERT INTO favorites VALUES (2619, 64, 2);
INSERT INTO favorites VALUES (2620, 84, 3);
INSERT INTO favorites VALUES (2620, 50, 1);
INSERT INTO favorites VALUES (2620, 46, 2);
INSERT INTO favorites VALUES (2621, 29, 1);
INSERT INTO favorites VALUES (2622, 30, 3);
INSERT INTO favorites VALUES (2622, 82, 2);
INSERT INTO favorites VALUES (2622, 84, 1);
INSERT INTO favorites VALUES (2623, 65, 2);
INSERT INTO favorites VALUES (2623, 51, 1);
INSERT INTO favorites VALUES (2624, 64, 4);
INSERT INTO favorites VALUES (2624, 62, 5);
INSERT INTO favorites VALUES (2624, 40, 1);
INSERT INTO favorites VALUES (2624, 59, 3);
INSERT INTO favorites VALUES (2624, 75, 2);
INSERT INTO favorites VALUES (2625, 6, 1);
INSERT INTO favorites VALUES (2626, 101, 2);
INSERT INTO favorites VALUES (2626, 104, 1);
INSERT INTO favorites VALUES (2626, 2, 4);
INSERT INTO favorites VALUES (2626, 51, 3);
INSERT INTO favorites VALUES (2627, 33, 1);
INSERT INTO favorites VALUES (2628, 54, 1);
INSERT INTO favorites VALUES (2628, 96, 2);
INSERT INTO favorites VALUES (2629, 90, 3);
INSERT INTO favorites VALUES (2629, 46, 2);
INSERT INTO favorites VALUES (2629, 101, 1);
INSERT INTO favorites VALUES (2629, 55, 4);
INSERT INTO favorites VALUES (2630, 5, 4);
INSERT INTO favorites VALUES (2630, 94, 5);
INSERT INTO favorites VALUES (2630, 94, 1);
INSERT INTO favorites VALUES (2630, 9, 2);
INSERT INTO favorites VALUES (2630, 53, 3);
INSERT INTO favorites VALUES (2631, 2, 4);
INSERT INTO favorites VALUES (2631, 30, 5);
INSERT INTO favorites VALUES (2631, 12, 3);
INSERT INTO favorites VALUES (2631, 29, 2);
INSERT INTO favorites VALUES (2631, 13, 1);
INSERT INTO favorites VALUES (2632, 90, 1);
INSERT INTO favorites VALUES (2634, 91, 4);
INSERT INTO favorites VALUES (2634, 15, 1);
INSERT INTO favorites VALUES (2634, 45, 3);
INSERT INTO favorites VALUES (2634, 9, 2);
INSERT INTO favorites VALUES (2635, 105, 4);
INSERT INTO favorites VALUES (2635, 93, 1);
INSERT INTO favorites VALUES (2635, 79, 3);
INSERT INTO favorites VALUES (2635, 78, 2);
INSERT INTO favorites VALUES (2637, 6, 4);
INSERT INTO favorites VALUES (2637, 41, 1);
INSERT INTO favorites VALUES (2637, 60, 2);
INSERT INTO favorites VALUES (2637, 39, 3);
INSERT INTO favorites VALUES (2638, 4, 2);
INSERT INTO favorites VALUES (2638, 9, 1);
INSERT INTO favorites VALUES (2638, 60, 3);
INSERT INTO favorites VALUES (2639, 7, 1);
INSERT INTO favorites VALUES (2639, 79, 2);
INSERT INTO favorites VALUES (2640, 55, 2);
INSERT INTO favorites VALUES (2640, 80, 1);
INSERT INTO favorites VALUES (2641, 4, 2);
INSERT INTO favorites VALUES (2641, 69, 1);
INSERT INTO favorites VALUES (2641, 11, 3);
INSERT INTO favorites VALUES (2642, 73, 4);
INSERT INTO favorites VALUES (2642, 113, 1);
INSERT INTO favorites VALUES (2642, 110, 3);
INSERT INTO favorites VALUES (2642, 18, 2);
INSERT INTO favorites VALUES (2643, 35, 8);
INSERT INTO favorites VALUES (2643, 15, 6);
INSERT INTO favorites VALUES (2643, 8, 7);
INSERT INTO favorites VALUES (2643, 42, 1);
INSERT INTO favorites VALUES (2643, 77, 4);
INSERT INTO favorites VALUES (2643, 41, 5);
INSERT INTO favorites VALUES (2643, 113, 2);
INSERT INTO favorites VALUES (2643, 2, 3);
INSERT INTO favorites VALUES (2644, 16, 2);
INSERT INTO favorites VALUES (2644, 3, 1);
INSERT INTO favorites VALUES (2644, 30, 4);
INSERT INTO favorites VALUES (2644, 93, 3);
INSERT INTO favorites VALUES (2645, 44, 3);
INSERT INTO favorites VALUES (2645, 62, 1);
INSERT INTO favorites VALUES (2645, 74, 2);
INSERT INTO favorites VALUES (2645, 39, 4);
INSERT INTO favorites VALUES (2647, 31, 3);
INSERT INTO favorites VALUES (2647, 58, 1);
INSERT INTO favorites VALUES (2647, 10, 2);
INSERT INTO favorites VALUES (2648, 7, 3);
INSERT INTO favorites VALUES (2648, 42, 1);
INSERT INTO favorites VALUES (2648, 66, 2);
INSERT INTO favorites VALUES (2648, 9, 4);
INSERT INTO favorites VALUES (2649, 63, 1);
INSERT INTO favorites VALUES (2649, 90, 2);
INSERT INTO favorites VALUES (2650, 7, 1);
INSERT INTO favorites VALUES (2651, 11, 3);
INSERT INTO favorites VALUES (2651, 8, 2);
INSERT INTO favorites VALUES (2651, 93, 1);
INSERT INTO favorites VALUES (2652, 74, 3);
INSERT INTO favorites VALUES (2652, 19, 2);
INSERT INTO favorites VALUES (2652, 50, 1);
INSERT INTO favorites VALUES (2653, 51, 3);
INSERT INTO favorites VALUES (2653, 94, 2);
INSERT INTO favorites VALUES (2653, 69, 1);
INSERT INTO favorites VALUES (2653, 50, 4);
INSERT INTO favorites VALUES (2654, 20, 4);
INSERT INTO favorites VALUES (2654, 51, 1);
INSERT INTO favorites VALUES (2654, 111, 2);
INSERT INTO favorites VALUES (2654, 81, 3);
INSERT INTO favorites VALUES (2655, 39, 1);
INSERT INTO favorites VALUES (2656, 66, 1);
INSERT INTO favorites VALUES (2656, 110, 3);
INSERT INTO favorites VALUES (2656, 2, 2);
INSERT INTO favorites VALUES (2657, 20, 3);
INSERT INTO favorites VALUES (2657, 69, 1);
INSERT INTO favorites VALUES (2657, 73, 2);
INSERT INTO favorites VALUES (2658, 33, 4);
INSERT INTO favorites VALUES (2658, 32, 5);
INSERT INTO favorites VALUES (2658, 113, 2);
INSERT INTO favorites VALUES (2658, 55, 1);
INSERT INTO favorites VALUES (2658, 39, 3);
INSERT INTO favorites VALUES (2660, 9, 3);
INSERT INTO favorites VALUES (2660, 63, 1);
INSERT INTO favorites VALUES (2660, 10, 2);
INSERT INTO favorites VALUES (2660, 30, 4);
INSERT INTO favorites VALUES (2662, 26, 1);
INSERT INTO favorites VALUES (2663, 31, 1);
INSERT INTO favorites VALUES (2663, 80, 2);
INSERT INTO favorites VALUES (2664, 76, 3);
INSERT INTO favorites VALUES (2664, 6, 1);
INSERT INTO favorites VALUES (2664, 38, 2);
INSERT INTO favorites VALUES (2664, 87, 4);
INSERT INTO favorites VALUES (2665, 7, 1);
INSERT INTO favorites VALUES (2665, 73, 2);
INSERT INTO favorites VALUES (2666, 2, 1);
INSERT INTO favorites VALUES (2666, 12, 2);
INSERT INTO favorites VALUES (2667, 6, 3);
INSERT INTO favorites VALUES (2667, 22, 1);
INSERT INTO favorites VALUES (2667, 107, 2);
INSERT INTO favorites VALUES (2668, 97, 3);
INSERT INTO favorites VALUES (2668, 90, 1);
INSERT INTO favorites VALUES (2668, 91, 2);
INSERT INTO favorites VALUES (2668, 24, 4);
INSERT INTO favorites VALUES (2669, 88, 2);
INSERT INTO favorites VALUES (2669, 14, 1);
INSERT INTO favorites VALUES (2670, 8, 2);
INSERT INTO favorites VALUES (2670, 88, 1);
INSERT INTO favorites VALUES (2670, 58, 3);
INSERT INTO favorites VALUES (2671, 116, 3);
INSERT INTO favorites VALUES (2671, 62, 1);
INSERT INTO favorites VALUES (2671, 41, 2);
INSERT INTO favorites VALUES (2671, 85, 4);
INSERT INTO favorites VALUES (2672, 46, 2);
INSERT INTO favorites VALUES (2672, 47, 3);
INSERT INTO favorites VALUES (2672, 6, 1);
INSERT INTO favorites VALUES (2673, 37, 1);
INSERT INTO favorites VALUES (2673, 83, 2);
INSERT INTO favorites VALUES (2675, 44, 2);
INSERT INTO favorites VALUES (2675, 76, 1);
INSERT INTO favorites VALUES (2676, 38, 4);
INSERT INTO favorites VALUES (2676, 12, 3);
INSERT INTO favorites VALUES (2676, 86, 1);
INSERT INTO favorites VALUES (2676, 2, 2);
INSERT INTO favorites VALUES (2677, 39, 3);
INSERT INTO favorites VALUES (2677, 97, 2);
INSERT INTO favorites VALUES (2677, 7, 1);
INSERT INTO favorites VALUES (2678, 18, 2);
INSERT INTO favorites VALUES (2678, 111, 1);
INSERT INTO favorites VALUES (2678, 16, 4);
INSERT INTO favorites VALUES (2678, 75, 3);
INSERT INTO favorites VALUES (2681, 79, 1);
INSERT INTO favorites VALUES (2682, 51, 4);
INSERT INTO favorites VALUES (2682, 98, 1);
INSERT INTO favorites VALUES (2682, 35, 2);
INSERT INTO favorites VALUES (2682, 71, 3);
INSERT INTO favorites VALUES (2684, 77, 1);
INSERT INTO favorites VALUES (2684, 93, 2);
INSERT INTO favorites VALUES (2685, 59, 1);
INSERT INTO favorites VALUES (2685, 39, 2);
INSERT INTO favorites VALUES (2686, 71, 1);
INSERT INTO favorites VALUES (2687, 73, 4);
INSERT INTO favorites VALUES (2687, 113, 1);
INSERT INTO favorites VALUES (2687, 112, 3);
INSERT INTO favorites VALUES (2687, 47, 2);
INSERT INTO favorites VALUES (2688, 26, 3);
INSERT INTO favorites VALUES (2688, 58, 1);
INSERT INTO favorites VALUES (2688, 46, 2);
INSERT INTO favorites VALUES (2689, 95, 5);
INSERT INTO favorites VALUES (2689, 8, 4);
INSERT INTO favorites VALUES (2689, 42, 1);
INSERT INTO favorites VALUES (2689, 3, 3);
INSERT INTO favorites VALUES (2689, 35, 2);
INSERT INTO favorites VALUES (2690, 58, 1);
INSERT INTO favorites VALUES (2690, 42, 2);
INSERT INTO favorites VALUES (2691, 39, 4);
INSERT INTO favorites VALUES (2691, 23, 5);
INSERT INTO favorites VALUES (2691, 31, 2);
INSERT INTO favorites VALUES (2691, 76, 1);
INSERT INTO favorites VALUES (2691, 42, 3);
INSERT INTO favorites VALUES (2692, 57, 3);
INSERT INTO favorites VALUES (2692, 113, 1);
INSERT INTO favorites VALUES (2692, 25, 2);
INSERT INTO favorites VALUES (2693, 92, 5);
INSERT INTO favorites VALUES (2693, 106, 4);
INSERT INTO favorites VALUES (2693, 105, 2);
INSERT INTO favorites VALUES (2693, 31, 3);
INSERT INTO favorites VALUES (2693, 66, 1);
INSERT INTO favorites VALUES (2694, 100, 2);
INSERT INTO favorites VALUES (2694, 50, 1);
INSERT INTO favorites VALUES (2694, 111, 3);
INSERT INTO favorites VALUES (2695, 76, 4);
INSERT INTO favorites VALUES (2695, 11, 5);
INSERT INTO favorites VALUES (2695, 96, 1);
INSERT INTO favorites VALUES (2695, 84, 2);
INSERT INTO favorites VALUES (2695, 77, 3);
INSERT INTO favorites VALUES (2695, 84, 6);
INSERT INTO favorites VALUES (2696, 88, 3);
INSERT INTO favorites VALUES (2696, 58, 1);
INSERT INTO favorites VALUES (2696, 71, 2);
INSERT INTO favorites VALUES (2699, 22, 4);
INSERT INTO favorites VALUES (2699, 58, 2);
INSERT INTO favorites VALUES (2699, 67, 1);
INSERT INTO favorites VALUES (2699, 21, 3);
INSERT INTO favorites VALUES (2700, 20, 1);
INSERT INTO favorites VALUES (2700, 5, 2);
INSERT INTO favorites VALUES (2700, 68, 3);
INSERT INTO favorites VALUES (2701, 92, 3);
INSERT INTO favorites VALUES (2701, 67, 1);
INSERT INTO favorites VALUES (2701, 1, 2);
INSERT INTO favorites VALUES (2701, 24, 4);
INSERT INTO favorites VALUES (2702, 100, 4);
INSERT INTO favorites VALUES (2702, 98, 2);
INSERT INTO favorites VALUES (2702, 11, 1);
INSERT INTO favorites VALUES (2702, 72, 3);
INSERT INTO favorites VALUES (2703, 7, 1);
INSERT INTO favorites VALUES (2703, 68, 2);
INSERT INTO favorites VALUES (2704, 29, 1);
INSERT INTO favorites VALUES (2704, 107, 3);
INSERT INTO favorites VALUES (2704, 8, 2);
INSERT INTO favorites VALUES (2705, 24, 5);
INSERT INTO favorites VALUES (2705, 4, 4);
INSERT INTO favorites VALUES (2705, 21, 1);
INSERT INTO favorites VALUES (2705, 96, 2);
INSERT INTO favorites VALUES (2705, 2, 3);
INSERT INTO favorites VALUES (2706, 16, 3);
INSERT INTO favorites VALUES (2706, 58, 2);
INSERT INTO favorites VALUES (2706, 34, 1);
INSERT INTO favorites VALUES (2706, 33, 4);
INSERT INTO favorites VALUES (2707, 36, 1);
INSERT INTO favorites VALUES (2707, 30, 3);
INSERT INTO favorites VALUES (2707, 75, 2);
INSERT INTO favorites VALUES (2708, 97, 3);
INSERT INTO favorites VALUES (2708, 94, 1);
INSERT INTO favorites VALUES (2708, 49, 2);
INSERT INTO favorites VALUES (2709, 73, 1);
INSERT INTO favorites VALUES (2709, 36, 2);
INSERT INTO favorites VALUES (2710, 2, 1);
INSERT INTO favorites VALUES (2711, 21, 4);
INSERT INTO favorites VALUES (2711, 1, 1);
INSERT INTO favorites VALUES (2711, 12, 3);
INSERT INTO favorites VALUES (2711, 18, 2);
INSERT INTO favorites VALUES (2712, 114, 1);
INSERT INTO favorites VALUES (2712, 10, 2);
INSERT INTO favorites VALUES (2713, 53, 3);
INSERT INTO favorites VALUES (2713, 110, 2);
INSERT INTO favorites VALUES (2713, 39, 1);
INSERT INTO favorites VALUES (2714, 95, 4);
INSERT INTO favorites VALUES (2714, 68, 1);
INSERT INTO favorites VALUES (2714, 76, 2);
INSERT INTO favorites VALUES (2714, 56, 3);
INSERT INTO favorites VALUES (2715, 75, 1);
INSERT INTO favorites VALUES (2716, 27, 3);
INSERT INTO favorites VALUES (2716, 26, 1);
INSERT INTO favorites VALUES (2716, 107, 2);
INSERT INTO favorites VALUES (2717, 18, 2);
INSERT INTO favorites VALUES (2717, 35, 1);
INSERT INTO favorites VALUES (2717, 44, 3);
INSERT INTO favorites VALUES (2718, 105, 4);
INSERT INTO favorites VALUES (2718, 9, 1);
INSERT INTO favorites VALUES (2718, 28, 2);
INSERT INTO favorites VALUES (2718, 74, 3);
INSERT INTO favorites VALUES (2719, 43, 3);
INSERT INTO favorites VALUES (2719, 25, 1);
INSERT INTO favorites VALUES (2719, 17, 2);
INSERT INTO favorites VALUES (2720, 20, 3);
INSERT INTO favorites VALUES (2720, 65, 2);
INSERT INTO favorites VALUES (2720, 56, 1);
INSERT INTO favorites VALUES (2721, 52, 2);
INSERT INTO favorites VALUES (2721, 97, 1);
INSERT INTO favorites VALUES (2722, 40, 5);
INSERT INTO favorites VALUES (2722, 44, 4);
INSERT INTO favorites VALUES (2722, 74, 1);
INSERT INTO favorites VALUES (2722, 108, 2);
INSERT INTO favorites VALUES (2722, 110, 3);
INSERT INTO favorites VALUES (2722, 109, 6);
INSERT INTO favorites VALUES (2723, 83, 4);
INSERT INTO favorites VALUES (2723, 22, 1);
INSERT INTO favorites VALUES (2723, 80, 3);
INSERT INTO favorites VALUES (2723, 98, 2);
INSERT INTO favorites VALUES (2724, 16, 3);
INSERT INTO favorites VALUES (2724, 85, 2);
INSERT INTO favorites VALUES (2724, 31, 1);
INSERT INTO favorites VALUES (2725, 22, 3);
INSERT INTO favorites VALUES (2725, 24, 4);
INSERT INTO favorites VALUES (2725, 49, 1);
INSERT INTO favorites VALUES (2725, 115, 2);
INSERT INTO favorites VALUES (2726, 63, 1);
INSERT INTO favorites VALUES (2726, 3, 2);
INSERT INTO favorites VALUES (2727, 51, 3);
INSERT INTO favorites VALUES (2727, 36, 1);
INSERT INTO favorites VALUES (2727, 4, 2);
INSERT INTO favorites VALUES (2728, 109, 1);
INSERT INTO favorites VALUES (2730, 10, 1);
INSERT INTO favorites VALUES (2730, 63, 2);
INSERT INTO favorites VALUES (2731, 85, 4);
INSERT INTO favorites VALUES (2731, 91, 1);
INSERT INTO favorites VALUES (2731, 66, 3);
INSERT INTO favorites VALUES (2731, 33, 2);
INSERT INTO favorites VALUES (2732, 32, 5);
INSERT INTO favorites VALUES (2732, 81, 4);
INSERT INTO favorites VALUES (2732, 35, 1);
INSERT INTO favorites VALUES (2732, 87, 3);
INSERT INTO favorites VALUES (2732, 37, 2);
INSERT INTO favorites VALUES (2733, 24, 5);
INSERT INTO favorites VALUES (2733, 22, 4);
INSERT INTO favorites VALUES (2733, 33, 3);
INSERT INTO favorites VALUES (2733, 86, 2);
INSERT INTO favorites VALUES (2733, 87, 1);
INSERT INTO favorites VALUES (2734, 40, 1);
INSERT INTO favorites VALUES (2735, 66, 5);
INSERT INTO favorites VALUES (2735, 112, 4);
INSERT INTO favorites VALUES (2735, 110, 2);
INSERT INTO favorites VALUES (2735, 92, 1);
INSERT INTO favorites VALUES (2735, 110, 3);
INSERT INTO favorites VALUES (2736, 4, 4);
INSERT INTO favorites VALUES (2736, 63, 6);
INSERT INTO favorites VALUES (2736, 79, 2);
INSERT INTO favorites VALUES (2736, 45, 3);
INSERT INTO favorites VALUES (2736, 45, 1);
INSERT INTO favorites VALUES (2736, 104, 5);
INSERT INTO favorites VALUES (2737, 56, 3);
INSERT INTO favorites VALUES (2737, 56, 1);
INSERT INTO favorites VALUES (2737, 4, 4);
INSERT INTO favorites VALUES (2737, 64, 2);
INSERT INTO favorites VALUES (2738, 62, 1);
INSERT INTO favorites VALUES (2738, 19, 2);
INSERT INTO favorites VALUES (2739, 68, 2);
INSERT INTO favorites VALUES (2739, 29, 1);
INSERT INTO favorites VALUES (2740, 22, 4);
INSERT INTO favorites VALUES (2740, 52, 5);
INSERT INTO favorites VALUES (2740, 35, 1);
INSERT INTO favorites VALUES (2740, 66, 2);
INSERT INTO favorites VALUES (2740, 28, 3);
INSERT INTO favorites VALUES (2741, 5, 5);
INSERT INTO favorites VALUES (2741, 55, 2);
INSERT INTO favorites VALUES (2741, 108, 1);
INSERT INTO favorites VALUES (2741, 99, 4);
INSERT INTO favorites VALUES (2741, 41, 3);
INSERT INTO favorites VALUES (2742, 90, 2);
INSERT INTO favorites VALUES (2742, 52, 1);
INSERT INTO favorites VALUES (2742, 81, 3);
INSERT INTO favorites VALUES (2743, 89, 1);
INSERT INTO favorites VALUES (2743, 68, 2);
INSERT INTO favorites VALUES (2744, 46, 1);
INSERT INTO favorites VALUES (2744, 59, 2);
INSERT INTO favorites VALUES (2745, 45, 2);
INSERT INTO favorites VALUES (2745, 60, 1);
INSERT INTO favorites VALUES (2746, 96, 1);
INSERT INTO favorites VALUES (2747, 18, 3);
INSERT INTO favorites VALUES (2747, 8, 2);
INSERT INTO favorites VALUES (2747, 18, 1);
INSERT INTO favorites VALUES (2748, 44, 2);
INSERT INTO favorites VALUES (2748, 40, 1);
INSERT INTO favorites VALUES (2749, 36, 4);
INSERT INTO favorites VALUES (2749, 8, 1);
INSERT INTO favorites VALUES (2749, 21, 3);
INSERT INTO favorites VALUES (2749, 16, 2);
INSERT INTO favorites VALUES (2750, 18, 1);
INSERT INTO favorites VALUES (2751, 95, 1);
INSERT INTO favorites VALUES (2752, 93, 1);
INSERT INTO favorites VALUES (2754, 74, 2);
INSERT INTO favorites VALUES (2754, 15, 1);
INSERT INTO favorites VALUES (2756, 106, 3);
INSERT INTO favorites VALUES (2756, 35, 1);
INSERT INTO favorites VALUES (2756, 48, 2);
INSERT INTO favorites VALUES (2757, 19, 3);
INSERT INTO favorites VALUES (2757, 58, 1);
INSERT INTO favorites VALUES (2757, 4, 2);
INSERT INTO favorites VALUES (2758, 86, 5);
INSERT INTO favorites VALUES (2758, 44, 6);
INSERT INTO favorites VALUES (2758, 15, 3);
INSERT INTO favorites VALUES (2758, 57, 2);
INSERT INTO favorites VALUES (2758, 12, 4);
INSERT INTO favorites VALUES (2758, 3, 1);
INSERT INTO favorites VALUES (2759, 98, 3);
INSERT INTO favorites VALUES (2759, 58, 1);
INSERT INTO favorites VALUES (2759, 37, 2);
INSERT INTO favorites VALUES (2760, 71, 7);
INSERT INTO favorites VALUES (2760, 26, 4);
INSERT INTO favorites VALUES (2760, 36, 5);
INSERT INTO favorites VALUES (2760, 110, 1);
INSERT INTO favorites VALUES (2760, 41, 2);
INSERT INTO favorites VALUES (2760, 29, 3);
INSERT INTO favorites VALUES (2760, 91, 6);
INSERT INTO favorites VALUES (2761, 22, 1);
INSERT INTO favorites VALUES (2761, 13, 2);
INSERT INTO favorites VALUES (2762, 49, 3);
INSERT INTO favorites VALUES (2762, 91, 2);
INSERT INTO favorites VALUES (2762, 42, 1);
INSERT INTO favorites VALUES (2763, 35, 6);
INSERT INTO favorites VALUES (2763, 28, 5);
INSERT INTO favorites VALUES (2763, 37, 1);
INSERT INTO favorites VALUES (2763, 77, 3);
INSERT INTO favorites VALUES (2763, 53, 2);
INSERT INTO favorites VALUES (2763, 115, 4);
INSERT INTO favorites VALUES (2764, 87, 2);
INSERT INTO favorites VALUES (2764, 98, 1);
INSERT INTO favorites VALUES (2765, 106, 3);
INSERT INTO favorites VALUES (2765, 21, 2);
INSERT INTO favorites VALUES (2765, 46, 1);
INSERT INTO favorites VALUES (2766, 67, 1);
INSERT INTO favorites VALUES (2766, 65, 2);
INSERT INTO favorites VALUES (2767, 12, 1);
INSERT INTO favorites VALUES (2768, 9, 3);
INSERT INTO favorites VALUES (2768, 77, 2);
INSERT INTO favorites VALUES (2768, 4, 1);
INSERT INTO favorites VALUES (2770, 19, 1);
INSERT INTO favorites VALUES (2771, 22, 1);
INSERT INTO favorites VALUES (2772, 82, 1);
INSERT INTO favorites VALUES (2773, 77, 2);
INSERT INTO favorites VALUES (2773, 83, 1);
INSERT INTO favorites VALUES (2773, 78, 3);
INSERT INTO favorites VALUES (2774, 12, 1);
INSERT INTO favorites VALUES (2774, 42, 2);
INSERT INTO favorites VALUES (2775, 41, 2);
INSERT INTO favorites VALUES (2775, 71, 1);
INSERT INTO favorites VALUES (2776, 86, 2);
INSERT INTO favorites VALUES (2776, 2, 1);
INSERT INTO favorites VALUES (2777, 27, 3);
INSERT INTO favorites VALUES (2777, 45, 1);
INSERT INTO favorites VALUES (2777, 108, 2);
INSERT INTO favorites VALUES (2777, 104, 4);
INSERT INTO favorites VALUES (2778, 47, 1);
INSERT INTO favorites VALUES (2778, 62, 2);
INSERT INTO favorites VALUES (2779, 112, 1);
INSERT INTO favorites VALUES (2780, 22, 1);
INSERT INTO favorites VALUES (2781, 114, 3);
INSERT INTO favorites VALUES (2781, 1, 2);
INSERT INTO favorites VALUES (2781, 21, 1);
INSERT INTO favorites VALUES (2782, 42, 3);
INSERT INTO favorites VALUES (2782, 102, 1);
INSERT INTO favorites VALUES (2782, 5, 2);
INSERT INTO favorites VALUES (2783, 79, 2);
INSERT INTO favorites VALUES (2783, 29, 1);
INSERT INTO favorites VALUES (2784, 111, 1);
INSERT INTO favorites VALUES (2784, 36, 2);
INSERT INTO favorites VALUES (2785, 23, 3);
INSERT INTO favorites VALUES (2785, 26, 1);
INSERT INTO favorites VALUES (2785, 3, 2);
INSERT INTO favorites VALUES (2786, 56, 5);
INSERT INTO favorites VALUES (2786, 35, 2);
INSERT INTO favorites VALUES (2786, 67, 1);
INSERT INTO favorites VALUES (2786, 67, 4);
INSERT INTO favorites VALUES (2786, 39, 3);
INSERT INTO favorites VALUES (2787, 16, 5);
INSERT INTO favorites VALUES (2787, 13, 3);
INSERT INTO favorites VALUES (2787, 66, 2);
INSERT INTO favorites VALUES (2787, 76, 1);
INSERT INTO favorites VALUES (2787, 69, 4);
INSERT INTO favorites VALUES (2788, 106, 1);
INSERT INTO favorites VALUES (2788, 55, 2);
INSERT INTO favorites VALUES (2789, 20, 1);
INSERT INTO favorites VALUES (2790, 38, 2);
INSERT INTO favorites VALUES (2790, 20, 1);
INSERT INTO favorites VALUES (2791, 27, 1);
INSERT INTO favorites VALUES (2792, 82, 1);
INSERT INTO favorites VALUES (2792, 113, 2);
INSERT INTO favorites VALUES (2795, 71, 3);
INSERT INTO favorites VALUES (2795, 68, 1);
INSERT INTO favorites VALUES (2795, 33, 2);
INSERT INTO favorites VALUES (2796, 62, 3);
INSERT INTO favorites VALUES (2796, 23, 2);
INSERT INTO favorites VALUES (2796, 31, 1);
INSERT INTO favorites VALUES (2797, 41, 3);
INSERT INTO favorites VALUES (2797, 12, 1);
INSERT INTO favorites VALUES (2797, 59, 2);
INSERT INTO favorites VALUES (2798, 51, 3);
INSERT INTO favorites VALUES (2798, 109, 1);
INSERT INTO favorites VALUES (2798, 67, 2);
INSERT INTO favorites VALUES (2799, 25, 1);
INSERT INTO favorites VALUES (2800, 18, 1);
INSERT INTO favorites VALUES (2800, 100, 2);
INSERT INTO favorites VALUES (2801, 77, 3);
INSERT INTO favorites VALUES (2801, 59, 1);
INSERT INTO favorites VALUES (2801, 81, 2);
INSERT INTO favorites VALUES (2802, 9, 1);
INSERT INTO favorites VALUES (2804, 96, 5);
INSERT INTO favorites VALUES (2804, 35, 6);
INSERT INTO favorites VALUES (2804, 56, 2);
INSERT INTO favorites VALUES (2804, 7, 3);
INSERT INTO favorites VALUES (2804, 95, 1);
INSERT INTO favorites VALUES (2804, 76, 4);
INSERT INTO favorites VALUES (2805, 33, 3);
INSERT INTO favorites VALUES (2805, 32, 1);
INSERT INTO favorites VALUES (2805, 92, 2);
INSERT INTO favorites VALUES (2805, 29, 4);
INSERT INTO favorites VALUES (2806, 1, 3);
INSERT INTO favorites VALUES (2806, 67, 1);
INSERT INTO favorites VALUES (2806, 100, 2);
INSERT INTO favorites VALUES (2807, 14, 4);
INSERT INTO favorites VALUES (2807, 56, 1);
INSERT INTO favorites VALUES (2807, 27, 3);
INSERT INTO favorites VALUES (2807, 8, 2);
INSERT INTO favorites VALUES (2808, 80, 1);
INSERT INTO favorites VALUES (2808, 64, 2);
INSERT INTO favorites VALUES (2809, 28, 3);
INSERT INTO favorites VALUES (2809, 31, 1);
INSERT INTO favorites VALUES (2809, 40, 2);
INSERT INTO favorites VALUES (2810, 74, 5);
INSERT INTO favorites VALUES (2810, 2, 3);
INSERT INTO favorites VALUES (2810, 28, 1);
INSERT INTO favorites VALUES (2810, 73, 2);
INSERT INTO favorites VALUES (2810, 72, 4);
INSERT INTO favorites VALUES (2811, 47, 3);
INSERT INTO favorites VALUES (2811, 92, 1);
INSERT INTO favorites VALUES (2811, 57, 2);
INSERT INTO favorites VALUES (2812, 57, 2);
INSERT INTO favorites VALUES (2812, 28, 1);
INSERT INTO favorites VALUES (2812, 5, 3);
INSERT INTO favorites VALUES (2813, 102, 1);
INSERT INTO favorites VALUES (2814, 43, 1);
INSERT INTO favorites VALUES (2814, 83, 2);
INSERT INTO favorites VALUES (2815, 59, 3);
INSERT INTO favorites VALUES (2815, 87, 4);
INSERT INTO favorites VALUES (2815, 114, 1);
INSERT INTO favorites VALUES (2815, 59, 2);
INSERT INTO favorites VALUES (2815, 34, 5);
INSERT INTO favorites VALUES (2816, 103, 4);
INSERT INTO favorites VALUES (2816, 74, 1);
INSERT INTO favorites VALUES (2816, 50, 2);
INSERT INTO favorites VALUES (2816, 52, 3);
INSERT INTO favorites VALUES (2817, 101, 4);
INSERT INTO favorites VALUES (2817, 40, 1);
INSERT INTO favorites VALUES (2817, 39, 3);
INSERT INTO favorites VALUES (2817, 50, 2);
INSERT INTO favorites VALUES (2818, 49, 4);
INSERT INTO favorites VALUES (2818, 96, 5);
INSERT INTO favorites VALUES (2818, 48, 1);
INSERT INTO favorites VALUES (2818, 81, 3);
INSERT INTO favorites VALUES (2818, 19, 2);
INSERT INTO favorites VALUES (2820, 61, 1);
INSERT INTO favorites VALUES (2820, 74, 2);
INSERT INTO favorites VALUES (2821, 20, 1);
INSERT INTO favorites VALUES (2821, 79, 2);
INSERT INTO favorites VALUES (2822, 115, 2);
INSERT INTO favorites VALUES (2822, 20, 1);
INSERT INTO favorites VALUES (2822, 97, 3);
INSERT INTO favorites VALUES (2823, 102, 2);
INSERT INTO favorites VALUES (2823, 13, 1);
INSERT INTO favorites VALUES (2823, 11, 3);
INSERT INTO favorites VALUES (2824, 9, 1);
INSERT INTO favorites VALUES (2824, 12, 2);
INSERT INTO favorites VALUES (2825, 58, 5);
INSERT INTO favorites VALUES (2825, 36, 4);
INSERT INTO favorites VALUES (2825, 101, 1);
INSERT INTO favorites VALUES (2825, 105, 2);
INSERT INTO favorites VALUES (2825, 41, 3);
INSERT INTO favorites VALUES (2826, 73, 3);
INSERT INTO favorites VALUES (2826, 6, 1);
INSERT INTO favorites VALUES (2826, 55, 2);
INSERT INTO favorites VALUES (2827, 17, 1);
INSERT INTO favorites VALUES (2827, 5, 2);
INSERT INTO favorites VALUES (2828, 54, 3);
INSERT INTO favorites VALUES (2828, 19, 1);
INSERT INTO favorites VALUES (2828, 106, 2);
INSERT INTO favorites VALUES (2828, 60, 4);
INSERT INTO favorites VALUES (2829, 27, 3);
INSERT INTO favorites VALUES (2829, 16, 1);
INSERT INTO favorites VALUES (2829, 66, 2);
INSERT INTO favorites VALUES (2830, 101, 1);
INSERT INTO favorites VALUES (2831, 13, 2);
INSERT INTO favorites VALUES (2831, 52, 1);
INSERT INTO favorites VALUES (2831, 98, 3);
INSERT INTO favorites VALUES (2832, 85, 3);
INSERT INTO favorites VALUES (2832, 107, 1);
INSERT INTO favorites VALUES (2832, 100, 2);
INSERT INTO favorites VALUES (2832, 76, 4);
INSERT INTO favorites VALUES (2833, 32, 3);
INSERT INTO favorites VALUES (2833, 94, 1);
INSERT INTO favorites VALUES (2833, 97, 2);
INSERT INTO favorites VALUES (2834, 86, 3);
INSERT INTO favorites VALUES (2834, 76, 2);
INSERT INTO favorites VALUES (2834, 3, 1);
INSERT INTO favorites VALUES (2835, 66, 6);
INSERT INTO favorites VALUES (2835, 27, 5);
INSERT INTO favorites VALUES (2835, 115, 4);
INSERT INTO favorites VALUES (2835, 90, 2);
INSERT INTO favorites VALUES (2835, 11, 3);
INSERT INTO favorites VALUES (2835, 9, 1);
INSERT INTO favorites VALUES (2836, 90, 3);
INSERT INTO favorites VALUES (2836, 39, 1);
INSERT INTO favorites VALUES (2836, 86, 2);
INSERT INTO favorites VALUES (2837, 95, 3);
INSERT INTO favorites VALUES (2837, 52, 5);
INSERT INTO favorites VALUES (2837, 2, 1);
INSERT INTO favorites VALUES (2837, 64, 2);
INSERT INTO favorites VALUES (2837, 29, 4);
INSERT INTO favorites VALUES (2838, 60, 1);
INSERT INTO favorites VALUES (2839, 109, 4);
INSERT INTO favorites VALUES (2839, 102, 1);
INSERT INTO favorites VALUES (2839, 50, 2);
INSERT INTO favorites VALUES (2839, 27, 3);
INSERT INTO favorites VALUES (2840, 37, 6);
INSERT INTO favorites VALUES (2840, 17, 5);
INSERT INTO favorites VALUES (2840, 97, 3);
INSERT INTO favorites VALUES (2840, 53, 1);
INSERT INTO favorites VALUES (2840, 98, 2);
INSERT INTO favorites VALUES (2840, 55, 4);
INSERT INTO favorites VALUES (2841, 52, 1);
INSERT INTO favorites VALUES (2841, 2, 2);
INSERT INTO favorites VALUES (2842, 12, 2);
INSERT INTO favorites VALUES (2842, 43, 1);
INSERT INTO favorites VALUES (2842, 99, 3);
INSERT INTO favorites VALUES (2843, 41, 3);
INSERT INTO favorites VALUES (2843, 105, 1);
INSERT INTO favorites VALUES (2843, 86, 2);
INSERT INTO favorites VALUES (2844, 79, 2);
INSERT INTO favorites VALUES (2844, 30, 1);
INSERT INTO favorites VALUES (2844, 114, 3);
INSERT INTO favorites VALUES (2846, 83, 1);
INSERT INTO favorites VALUES (2847, 26, 2);
INSERT INTO favorites VALUES (2847, 76, 1);
INSERT INTO favorites VALUES (2848, 21, 1);
INSERT INTO favorites VALUES (2849, 32, 1);
INSERT INTO favorites VALUES (2850, 100, 3);
INSERT INTO favorites VALUES (2850, 22, 4);
INSERT INTO favorites VALUES (2850, 12, 1);
INSERT INTO favorites VALUES (2850, 31, 2);
INSERT INTO favorites VALUES (2850, 92, 5);
INSERT INTO favorites VALUES (2851, 45, 2);
INSERT INTO favorites VALUES (2851, 6, 1);
INSERT INTO favorites VALUES (2852, 101, 2);
INSERT INTO favorites VALUES (2852, 13, 1);
INSERT INTO favorites VALUES (2852, 82, 3);
INSERT INTO favorites VALUES (2853, 51, 2);
INSERT INTO favorites VALUES (2853, 97, 1);
INSERT INTO favorites VALUES (2853, 22, 3);
INSERT INTO favorites VALUES (2854, 3, 4);
INSERT INTO favorites VALUES (2854, 65, 1);
INSERT INTO favorites VALUES (2854, 38, 2);
INSERT INTO favorites VALUES (2854, 19, 3);
INSERT INTO favorites VALUES (2855, 23, 4);
INSERT INTO favorites VALUES (2855, 69, 1);
INSERT INTO favorites VALUES (2855, 45, 3);
INSERT INTO favorites VALUES (2855, 114, 2);
INSERT INTO favorites VALUES (2856, 48, 2);
INSERT INTO favorites VALUES (2856, 70, 1);
INSERT INTO favorites VALUES (2856, 19, 3);
INSERT INTO favorites VALUES (2857, 17, 1);
INSERT INTO favorites VALUES (2857, 95, 2);
INSERT INTO favorites VALUES (2858, 83, 1);
INSERT INTO favorites VALUES (2859, 84, 1);
INSERT INTO favorites VALUES (2859, 84, 2);
INSERT INTO favorites VALUES (2860, 93, 5);
INSERT INTO favorites VALUES (2860, 9, 6);
INSERT INTO favorites VALUES (2860, 91, 3);
INSERT INTO favorites VALUES (2860, 102, 1);
INSERT INTO favorites VALUES (2860, 14, 2);
INSERT INTO favorites VALUES (2860, 96, 4);
INSERT INTO favorites VALUES (2861, 9, 1);
INSERT INTO favorites VALUES (2863, 61, 2);
INSERT INTO favorites VALUES (2863, 109, 1);
INSERT INTO favorites VALUES (2863, 109, 3);
INSERT INTO favorites VALUES (2864, 1, 2);
INSERT INTO favorites VALUES (2864, 84, 3);
INSERT INTO favorites VALUES (2864, 1, 1);
INSERT INTO favorites VALUES (2865, 81, 2);
INSERT INTO favorites VALUES (2865, 13, 1);
INSERT INTO favorites VALUES (2866, 99, 3);
INSERT INTO favorites VALUES (2866, 22, 1);
INSERT INTO favorites VALUES (2866, 102, 2);
INSERT INTO favorites VALUES (2867, 23, 1);
INSERT INTO favorites VALUES (2867, 8, 2);
INSERT INTO favorites VALUES (2868, 86, 1);
INSERT INTO favorites VALUES (2869, 41, 5);
INSERT INTO favorites VALUES (2869, 22, 6);
INSERT INTO favorites VALUES (2869, 6, 1);
INSERT INTO favorites VALUES (2869, 44, 2);
INSERT INTO favorites VALUES (2869, 62, 3);
INSERT INTO favorites VALUES (2869, 10, 4);
INSERT INTO favorites VALUES (2870, 59, 1);
INSERT INTO favorites VALUES (2871, 54, 1);
INSERT INTO favorites VALUES (2871, 13, 2);
INSERT INTO favorites VALUES (2872, 101, 3);
INSERT INTO favorites VALUES (2872, 94, 1);
INSERT INTO favorites VALUES (2872, 111, 2);
INSERT INTO favorites VALUES (2872, 20, 4);
INSERT INTO favorites VALUES (2873, 18, 4);
INSERT INTO favorites VALUES (2873, 51, 1);
INSERT INTO favorites VALUES (2873, 80, 2);
INSERT INTO favorites VALUES (2873, 7, 3);
INSERT INTO favorites VALUES (2874, 112, 6);
INSERT INTO favorites VALUES (2874, 87, 5);
INSERT INTO favorites VALUES (2874, 106, 4);
INSERT INTO favorites VALUES (2874, 78, 2);
INSERT INTO favorites VALUES (2874, 101, 3);
INSERT INTO favorites VALUES (2874, 45, 1);
INSERT INTO favorites VALUES (2875, 3, 6);
INSERT INTO favorites VALUES (2875, 44, 7);
INSERT INTO favorites VALUES (2875, 10, 3);
INSERT INTO favorites VALUES (2875, 2, 1);
INSERT INTO favorites VALUES (2875, 19, 5);
INSERT INTO favorites VALUES (2875, 35, 2);
INSERT INTO favorites VALUES (2875, 93, 4);
INSERT INTO favorites VALUES (2876, 12, 4);
INSERT INTO favorites VALUES (2876, 87, 5);
INSERT INTO favorites VALUES (2876, 66, 1);
INSERT INTO favorites VALUES (2876, 41, 2);
INSERT INTO favorites VALUES (2876, 55, 3);
INSERT INTO favorites VALUES (2877, 29, 1);
INSERT INTO favorites VALUES (2878, 37, 4);
INSERT INTO favorites VALUES (2878, 3, 1);
INSERT INTO favorites VALUES (2878, 37, 3);
INSERT INTO favorites VALUES (2878, 7, 2);
INSERT INTO favorites VALUES (2879, 46, 1);
INSERT INTO favorites VALUES (2879, 22, 2);
INSERT INTO favorites VALUES (2880, 108, 1);
INSERT INTO favorites VALUES (2880, 38, 2);
INSERT INTO favorites VALUES (2881, 12, 3);
INSERT INTO favorites VALUES (2881, 7, 2);
INSERT INTO favorites VALUES (2881, 1, 1);
INSERT INTO favorites VALUES (2882, 96, 3);
INSERT INTO favorites VALUES (2882, 89, 1);
INSERT INTO favorites VALUES (2882, 78, 2);
INSERT INTO favorites VALUES (2883, 102, 4);
INSERT INTO favorites VALUES (2883, 17, 2);
INSERT INTO favorites VALUES (2883, 54, 1);
INSERT INTO favorites VALUES (2883, 90, 3);
INSERT INTO favorites VALUES (2885, 69, 3);
INSERT INTO favorites VALUES (2885, 35, 1);
INSERT INTO favorites VALUES (2885, 30, 2);
INSERT INTO favorites VALUES (2885, 46, 4);
INSERT INTO favorites VALUES (2886, 28, 5);
INSERT INTO favorites VALUES (2886, 75, 6);
INSERT INTO favorites VALUES (2886, 80, 1);
INSERT INTO favorites VALUES (2886, 91, 3);
INSERT INTO favorites VALUES (2886, 103, 2);
INSERT INTO favorites VALUES (2886, 86, 4);
INSERT INTO favorites VALUES (2887, 1, 3);
INSERT INTO favorites VALUES (2887, 84, 1);
INSERT INTO favorites VALUES (2887, 81, 2);
INSERT INTO favorites VALUES (2887, 42, 4);
INSERT INTO favorites VALUES (2888, 29, 3);
INSERT INTO favorites VALUES (2888, 96, 1);
INSERT INTO favorites VALUES (2888, 74, 2);
INSERT INTO favorites VALUES (2889, 60, 1);
INSERT INTO favorites VALUES (2891, 24, 4);
INSERT INTO favorites VALUES (2891, 59, 2);
INSERT INTO favorites VALUES (2891, 30, 1);
INSERT INTO favorites VALUES (2891, 12, 3);
INSERT INTO favorites VALUES (2892, 79, 1);
INSERT INTO favorites VALUES (2892, 18, 2);
INSERT INTO favorites VALUES (2893, 80, 1);
INSERT INTO favorites VALUES (2893, 37, 2);
INSERT INTO favorites VALUES (2894, 18, 2);
INSERT INTO favorites VALUES (2894, 30, 3);
INSERT INTO favorites VALUES (2894, 46, 1);
INSERT INTO favorites VALUES (2896, 86, 1);
INSERT INTO favorites VALUES (2896, 16, 2);
INSERT INTO favorites VALUES (2897, 36, 1);
INSERT INTO favorites VALUES (2898, 48, 5);
INSERT INTO favorites VALUES (2898, 55, 3);
INSERT INTO favorites VALUES (2898, 21, 2);
INSERT INTO favorites VALUES (2898, 25, 1);
INSERT INTO favorites VALUES (2898, 2, 4);
INSERT INTO favorites VALUES (2899, 49, 3);
INSERT INTO favorites VALUES (2899, 1, 1);
INSERT INTO favorites VALUES (2899, 91, 2);
INSERT INTO favorites VALUES (2899, 97, 4);
INSERT INTO favorites VALUES (2900, 54, 1);
INSERT INTO favorites VALUES (2901, 34, 6);
INSERT INTO favorites VALUES (2901, 7, 5);
INSERT INTO favorites VALUES (2901, 9, 1);
INSERT INTO favorites VALUES (2901, 10, 3);
INSERT INTO favorites VALUES (2901, 3, 2);
INSERT INTO favorites VALUES (2901, 26, 4);
INSERT INTO favorites VALUES (2902, 28, 5);
INSERT INTO favorites VALUES (2902, 14, 4);
INSERT INTO favorites VALUES (2902, 27, 1);
INSERT INTO favorites VALUES (2902, 63, 2);
INSERT INTO favorites VALUES (2902, 116, 3);
INSERT INTO favorites VALUES (2903, 23, 3);
INSERT INTO favorites VALUES (2903, 2, 1);
INSERT INTO favorites VALUES (2903, 57, 2);
INSERT INTO favorites VALUES (2904, 10, 4);
INSERT INTO favorites VALUES (2904, 101, 3);
INSERT INTO favorites VALUES (2904, 105, 2);
INSERT INTO favorites VALUES (2904, 78, 1);
INSERT INTO favorites VALUES (2905, 46, 3);
INSERT INTO favorites VALUES (2905, 44, 4);
INSERT INTO favorites VALUES (2905, 89, 1);
INSERT INTO favorites VALUES (2905, 91, 5);
INSERT INTO favorites VALUES (2905, 9, 2);
INSERT INTO favorites VALUES (2906, 10, 1);
INSERT INTO favorites VALUES (2907, 2, 4);
INSERT INTO favorites VALUES (2907, 106, 2);
INSERT INTO favorites VALUES (2907, 23, 1);
INSERT INTO favorites VALUES (2907, 10, 3);
INSERT INTO favorites VALUES (2908, 21, 5);
INSERT INTO favorites VALUES (2908, 92, 3);
INSERT INTO favorites VALUES (2908, 102, 1);
INSERT INTO favorites VALUES (2908, 11, 2);
INSERT INTO favorites VALUES (2908, 76, 4);
INSERT INTO favorites VALUES (2909, 92, 1);
INSERT INTO favorites VALUES (2910, 16, 3);
INSERT INTO favorites VALUES (2910, 98, 1);
INSERT INTO favorites VALUES (2910, 53, 2);
INSERT INTO favorites VALUES (2911, 44, 1);
INSERT INTO favorites VALUES (2912, 103, 1);
INSERT INTO favorites VALUES (2912, 18, 2);
INSERT INTO favorites VALUES (2913, 35, 3);
INSERT INTO favorites VALUES (2913, 35, 1);
INSERT INTO favorites VALUES (2913, 63, 2);
INSERT INTO favorites VALUES (2914, 59, 1);
INSERT INTO favorites VALUES (2914, 115, 2);
INSERT INTO favorites VALUES (2915, 64, 3);
INSERT INTO favorites VALUES (2915, 88, 1);
INSERT INTO favorites VALUES (2915, 98, 2);
INSERT INTO favorites VALUES (2915, 87, 4);
INSERT INTO favorites VALUES (2916, 20, 4);
INSERT INTO favorites VALUES (2916, 21, 2);
INSERT INTO favorites VALUES (2916, 92, 1);
INSERT INTO favorites VALUES (2916, 34, 3);
INSERT INTO favorites VALUES (2917, 64, 1);
INSERT INTO favorites VALUES (2917, 71, 3);
INSERT INTO favorites VALUES (2917, 54, 2);
INSERT INTO favorites VALUES (2918, 114, 1);
INSERT INTO favorites VALUES (2919, 99, 3);
INSERT INTO favorites VALUES (2919, 12, 1);
INSERT INTO favorites VALUES (2919, 28, 2);
INSERT INTO favorites VALUES (2920, 70, 1);
INSERT INTO favorites VALUES (2921, 3, 4);
INSERT INTO favorites VALUES (2921, 112, 5);
INSERT INTO favorites VALUES (2921, 81, 1);
INSERT INTO favorites VALUES (2921, 45, 2);
INSERT INTO favorites VALUES (2921, 60, 3);
INSERT INTO favorites VALUES (2922, 79, 4);
INSERT INTO favorites VALUES (2922, 2, 3);
INSERT INTO favorites VALUES (2922, 56, 2);
INSERT INTO favorites VALUES (2922, 23, 1);
INSERT INTO favorites VALUES (2923, 92, 1);
INSERT INTO favorites VALUES (2923, 32, 2);
INSERT INTO favorites VALUES (2924, 61, 3);
INSERT INTO favorites VALUES (2924, 14, 1);
INSERT INTO favorites VALUES (2924, 24, 2);
INSERT INTO favorites VALUES (2925, 95, 1);
INSERT INTO favorites VALUES (2925, 89, 2);
INSERT INTO favorites VALUES (2927, 107, 2);
INSERT INTO favorites VALUES (2927, 107, 1);
INSERT INTO favorites VALUES (2927, 80, 3);
INSERT INTO favorites VALUES (2928, 36, 3);
INSERT INTO favorites VALUES (2928, 67, 2);
INSERT INTO favorites VALUES (2928, 56, 1);
INSERT INTO favorites VALUES (2929, 84, 1);
INSERT INTO favorites VALUES (2929, 32, 2);
INSERT INTO favorites VALUES (2930, 7, 1);
INSERT INTO favorites VALUES (2930, 39, 2);
INSERT INTO favorites VALUES (2931, 98, 1);
INSERT INTO favorites VALUES (2931, 114, 2);
INSERT INTO favorites VALUES (2932, 97, 2);
INSERT INTO favorites VALUES (2932, 101, 3);
INSERT INTO favorites VALUES (2932, 47, 1);
INSERT INTO favorites VALUES (2932, 72, 4);
INSERT INTO favorites VALUES (2933, 91, 1);
INSERT INTO favorites VALUES (2934, 34, 1);
INSERT INTO favorites VALUES (2935, 7, 1);
INSERT INTO favorites VALUES (2935, 107, 2);
INSERT INTO favorites VALUES (2936, 107, 1);
INSERT INTO favorites VALUES (2937, 105, 1);
INSERT INTO favorites VALUES (2938, 62, 1);
INSERT INTO favorites VALUES (2938, 79, 2);
INSERT INTO favorites VALUES (2939, 25, 3);
INSERT INTO favorites VALUES (2939, 52, 2);
INSERT INTO favorites VALUES (2939, 47, 1);
INSERT INTO favorites VALUES (2940, 98, 7);
INSERT INTO favorites VALUES (2940, 41, 5);
INSERT INTO favorites VALUES (2940, 80, 6);
INSERT INTO favorites VALUES (2940, 106, 2);
INSERT INTO favorites VALUES (2940, 103, 4);
INSERT INTO favorites VALUES (2940, 1, 1);
INSERT INTO favorites VALUES (2940, 79, 3);
INSERT INTO favorites VALUES (2941, 20, 1);
INSERT INTO favorites VALUES (2942, 95, 4);
INSERT INTO favorites VALUES (2942, 70, 5);
INSERT INTO favorites VALUES (2942, 32, 1);
INSERT INTO favorites VALUES (2942, 73, 2);
INSERT INTO favorites VALUES (2942, 83, 3);
INSERT INTO favorites VALUES (2943, 24, 4);
INSERT INTO favorites VALUES (2943, 51, 1);
INSERT INTO favorites VALUES (2943, 35, 2);
INSERT INTO favorites VALUES (2943, 37, 3);
INSERT INTO favorites VALUES (2944, 25, 3);
INSERT INTO favorites VALUES (2944, 13, 2);
INSERT INTO favorites VALUES (2944, 38, 1);
INSERT INTO favorites VALUES (2944, 35, 4);
INSERT INTO favorites VALUES (2945, 52, 3);
INSERT INTO favorites VALUES (2945, 56, 1);
INSERT INTO favorites VALUES (2945, 49, 2);
INSERT INTO favorites VALUES (2946, 67, 5);
INSERT INTO favorites VALUES (2946, 14, 4);
INSERT INTO favorites VALUES (2946, 80, 1);
INSERT INTO favorites VALUES (2946, 40, 2);
INSERT INTO favorites VALUES (2946, 3, 3);
INSERT INTO favorites VALUES (2947, 42, 4);
INSERT INTO favorites VALUES (2947, 2, 2);
INSERT INTO favorites VALUES (2947, 87, 1);
INSERT INTO favorites VALUES (2947, 75, 3);
INSERT INTO favorites VALUES (2949, 89, 1);
INSERT INTO favorites VALUES (2950, 105, 2);
INSERT INTO favorites VALUES (2950, 93, 1);
INSERT INTO favorites VALUES (2951, 27, 4);
INSERT INTO favorites VALUES (2951, 114, 1);
INSERT INTO favorites VALUES (2951, 16, 2);
INSERT INTO favorites VALUES (2951, 19, 3);
INSERT INTO favorites VALUES (2952, 18, 2);
INSERT INTO favorites VALUES (2952, 64, 1);
INSERT INTO favorites VALUES (2953, 45, 7);
INSERT INTO favorites VALUES (2953, 88, 6);
INSERT INTO favorites VALUES (2953, 25, 5);
INSERT INTO favorites VALUES (2953, 83, 1);
INSERT INTO favorites VALUES (2953, 10, 4);
INSERT INTO favorites VALUES (2953, 53, 2);
INSERT INTO favorites VALUES (2953, 58, 3);
INSERT INTO favorites VALUES (2954, 90, 1);
INSERT INTO favorites VALUES (2956, 54, 3);
INSERT INTO favorites VALUES (2956, 98, 1);
INSERT INTO favorites VALUES (2956, 99, 2);
INSERT INTO favorites VALUES (2957, 78, 4);
INSERT INTO favorites VALUES (2957, 27, 3);
INSERT INTO favorites VALUES (2957, 43, 1);
INSERT INTO favorites VALUES (2957, 46, 2);
INSERT INTO favorites VALUES (2958, 13, 2);
INSERT INTO favorites VALUES (2958, 65, 1);
INSERT INTO favorites VALUES (2958, 82, 3);
INSERT INTO favorites VALUES (2959, 82, 5);
INSERT INTO favorites VALUES (2959, 14, 4);
INSERT INTO favorites VALUES (2959, 27, 2);
INSERT INTO favorites VALUES (2959, 53, 1);
INSERT INTO favorites VALUES (2959, 71, 3);
INSERT INTO favorites VALUES (2961, 19, 1);
INSERT INTO favorites VALUES (2961, 101, 2);
INSERT INTO favorites VALUES (2962, 65, 4);
INSERT INTO favorites VALUES (2962, 29, 3);
INSERT INTO favorites VALUES (2962, 62, 2);
INSERT INTO favorites VALUES (2962, 13, 1);
INSERT INTO favorites VALUES (2963, 113, 5);
INSERT INTO favorites VALUES (2963, 62, 2);
INSERT INTO favorites VALUES (2963, 5, 1);
INSERT INTO favorites VALUES (2963, 109, 4);
INSERT INTO favorites VALUES (2963, 20, 3);
INSERT INTO favorites VALUES (2964, 4, 1);
INSERT INTO favorites VALUES (2965, 85, 2);
INSERT INTO favorites VALUES (2965, 116, 1);
INSERT INTO favorites VALUES (2965, 37, 3);
INSERT INTO favorites VALUES (2966, 71, 3);
INSERT INTO favorites VALUES (2966, 83, 2);
INSERT INTO favorites VALUES (2966, 76, 1);
INSERT INTO favorites VALUES (2967, 49, 1);
INSERT INTO favorites VALUES (2967, 106, 2);
INSERT INTO favorites VALUES (2968, 40, 2);
INSERT INTO favorites VALUES (2968, 18, 1);
INSERT INTO favorites VALUES (2969, 108, 3);
INSERT INTO favorites VALUES (2969, 34, 1);
INSERT INTO favorites VALUES (2969, 7, 2);
INSERT INTO favorites VALUES (2969, 27, 4);
INSERT INTO favorites VALUES (2970, 94, 1);
INSERT INTO favorites VALUES (2972, 7, 1);
INSERT INTO favorites VALUES (2972, 98, 2);
INSERT INTO favorites VALUES (2973, 65, 4);
INSERT INTO favorites VALUES (2973, 72, 2);
INSERT INTO favorites VALUES (2973, 55, 1);
INSERT INTO favorites VALUES (2973, 1, 3);
INSERT INTO favorites VALUES (2974, 86, 1);
INSERT INTO favorites VALUES (2977, 90, 1);
INSERT INTO favorites VALUES (2977, 85, 2);
INSERT INTO favorites VALUES (2978, 1, 1);
INSERT INTO favorites VALUES (2978, 96, 2);
INSERT INTO favorites VALUES (2979, 87, 3);
INSERT INTO favorites VALUES (2979, 2, 1);
INSERT INTO favorites VALUES (2979, 94, 2);
INSERT INTO favorites VALUES (2980, 44, 1);
INSERT INTO favorites VALUES (2981, 18, 4);
INSERT INTO favorites VALUES (2981, 19, 1);
INSERT INTO favorites VALUES (2981, 88, 2);
INSERT INTO favorites VALUES (2981, 93, 3);
INSERT INTO favorites VALUES (2982, 107, 2);
INSERT INTO favorites VALUES (2982, 62, 1);
INSERT INTO favorites VALUES (2984, 18, 1);
INSERT INTO favorites VALUES (2984, 98, 2);
INSERT INTO favorites VALUES (2985, 22, 5);
INSERT INTO favorites VALUES (2985, 92, 6);
INSERT INTO favorites VALUES (2985, 92, 4);
INSERT INTO favorites VALUES (2985, 51, 2);
INSERT INTO favorites VALUES (2985, 61, 1);
INSERT INTO favorites VALUES (2985, 38, 3);
INSERT INTO favorites VALUES (2987, 13, 4);
INSERT INTO favorites VALUES (2987, 16, 1);
INSERT INTO favorites VALUES (2987, 40, 2);
INSERT INTO favorites VALUES (2987, 81, 3);
INSERT INTO favorites VALUES (2988, 75, 3);
INSERT INTO favorites VALUES (2988, 113, 2);
INSERT INTO favorites VALUES (2988, 30, 1);
INSERT INTO favorites VALUES (2989, 92, 3);
INSERT INTO favorites VALUES (2989, 59, 1);
INSERT INTO favorites VALUES (2989, 112, 2);
INSERT INTO favorites VALUES (2990, 113, 2);
INSERT INTO favorites VALUES (2990, 73, 1);
INSERT INTO favorites VALUES (2990, 63, 4);
INSERT INTO favorites VALUES (2990, 17, 3);
INSERT INTO favorites VALUES (2991, 51, 3);
INSERT INTO favorites VALUES (2991, 108, 1);
INSERT INTO favorites VALUES (2991, 60, 4);
INSERT INTO favorites VALUES (2991, 32, 2);
INSERT INTO favorites VALUES (2992, 114, 1);
INSERT INTO favorites VALUES (2993, 66, 1);
INSERT INTO favorites VALUES (2993, 14, 2);
INSERT INTO favorites VALUES (2994, 17, 1);
INSERT INTO favorites VALUES (2994, 92, 3);
INSERT INTO favorites VALUES (2994, 109, 2);
INSERT INTO favorites VALUES (2995, 69, 3);
INSERT INTO favorites VALUES (2995, 17, 1);
INSERT INTO favorites VALUES (2995, 109, 2);
INSERT INTO favorites VALUES (2996, 3, 4);
INSERT INTO favorites VALUES (2996, 113, 1);
INSERT INTO favorites VALUES (2996, 11, 2);
INSERT INTO favorites VALUES (2996, 79, 3);
INSERT INTO favorites VALUES (2997, 40, 3);
INSERT INTO favorites VALUES (2997, 98, 1);
INSERT INTO favorites VALUES (2997, 111, 2);
INSERT INTO favorites VALUES (2998, 58, 3);
INSERT INTO favorites VALUES (2998, 35, 1);
INSERT INTO favorites VALUES (2998, 16, 2);
INSERT INTO favorites VALUES (2998, 58, 4);
INSERT INTO favorites VALUES (2999, 52, 4);
INSERT INTO favorites VALUES (2999, 52, 1);
INSERT INTO favorites VALUES (2999, 44, 2);
INSERT INTO favorites VALUES (2999, 77, 3);
INSERT INTO favorites VALUES (3000, 51, 1);
INSERT INTO favorites VALUES (3000, 4, 2);
INSERT INTO favorites VALUES (3000, 101, 3);
INSERT INTO favorites VALUES (3000, 43, 4);
INSERT INTO favorites VALUES (3001, 8, 1);
INSERT INTO favorites VALUES (3002, 3, 3);
INSERT INTO favorites VALUES (3002, 60, 2);
INSERT INTO favorites VALUES (3002, 102, 1);
INSERT INTO favorites VALUES (3002, 24, 4);
INSERT INTO favorites VALUES (3003, 6, 7);
INSERT INTO favorites VALUES (3003, 53, 4);
INSERT INTO favorites VALUES (3003, 19, 5);
INSERT INTO favorites VALUES (3003, 106, 2);
INSERT INTO favorites VALUES (3003, 17, 3);
INSERT INTO favorites VALUES (3003, 55, 1);
INSERT INTO favorites VALUES (3003, 113, 6);
INSERT INTO favorites VALUES (3004, 73, 1);
INSERT INTO favorites VALUES (3005, 103, 3);
INSERT INTO favorites VALUES (3005, 25, 5);
INSERT INTO favorites VALUES (3005, 74, 2);
INSERT INTO favorites VALUES (3005, 2, 1);
INSERT INTO favorites VALUES (3005, 38, 4);
INSERT INTO favorites VALUES (3006, 12, 3);
INSERT INTO favorites VALUES (3006, 11, 1);
INSERT INTO favorites VALUES (3006, 24, 2);
INSERT INTO favorites VALUES (3007, 11, 4);
INSERT INTO favorites VALUES (3007, 9, 5);
INSERT INTO favorites VALUES (3007, 18, 1);
INSERT INTO favorites VALUES (3007, 111, 2);
INSERT INTO favorites VALUES (3007, 115, 3);
INSERT INTO favorites VALUES (3008, 13, 3);
INSERT INTO favorites VALUES (3008, 97, 4);
INSERT INTO favorites VALUES (3008, 97, 1);
INSERT INTO favorites VALUES (3008, 14, 2);
INSERT INTO favorites VALUES (3008, 97, 5);
INSERT INTO favorites VALUES (3009, 85, 1);
INSERT INTO favorites VALUES (3009, 20, 2);
INSERT INTO favorites VALUES (3010, 49, 2);
INSERT INTO favorites VALUES (3010, 62, 1);
INSERT INTO favorites VALUES (3011, 73, 3);
INSERT INTO favorites VALUES (3011, 75, 1);
INSERT INTO favorites VALUES (3011, 4, 2);
INSERT INTO favorites VALUES (3012, 115, 1);
INSERT INTO favorites VALUES (3012, 22, 2);
INSERT INTO favorites VALUES (3014, 16, 2);
INSERT INTO favorites VALUES (3014, 10, 1);
INSERT INTO favorites VALUES (3014, 23, 4);
INSERT INTO favorites VALUES (3014, 9, 3);
INSERT INTO favorites VALUES (3015, 44, 3);
INSERT INTO favorites VALUES (3015, 6, 1);
INSERT INTO favorites VALUES (3015, 98, 2);
INSERT INTO favorites VALUES (3016, 14, 5);
INSERT INTO favorites VALUES (3016, 63, 4);
INSERT INTO favorites VALUES (3016, 12, 2);
INSERT INTO favorites VALUES (3016, 52, 1);
INSERT INTO favorites VALUES (3016, 6, 3);
INSERT INTO favorites VALUES (3017, 67, 1);
INSERT INTO favorites VALUES (3017, 89, 2);
INSERT INTO favorites VALUES (3018, 35, 4);
INSERT INTO favorites VALUES (3018, 70, 1);
INSERT INTO favorites VALUES (3018, 8, 2);
INSERT INTO favorites VALUES (3018, 59, 3);
INSERT INTO favorites VALUES (3019, 107, 3);
INSERT INTO favorites VALUES (3019, 107, 1);
INSERT INTO favorites VALUES (3019, 53, 4);
INSERT INTO favorites VALUES (3019, 40, 2);
INSERT INTO favorites VALUES (3021, 3, 1);
INSERT INTO favorites VALUES (3021, 54, 2);
INSERT INTO favorites VALUES (3022, 5, 4);
INSERT INTO favorites VALUES (3022, 78, 5);
INSERT INTO favorites VALUES (3022, 89, 3);
INSERT INTO favorites VALUES (3022, 36, 2);
INSERT INTO favorites VALUES (3022, 59, 1);
INSERT INTO favorites VALUES (3022, 2, 6);
INSERT INTO favorites VALUES (3023, 3, 5);
INSERT INTO favorites VALUES (3023, 72, 6);
INSERT INTO favorites VALUES (3023, 113, 1);
INSERT INTO favorites VALUES (3023, 51, 3);
INSERT INTO favorites VALUES (3023, 17, 4);
INSERT INTO favorites VALUES (3023, 53, 2);
INSERT INTO favorites VALUES (3024, 103, 3);
INSERT INTO favorites VALUES (3024, 16, 1);
INSERT INTO favorites VALUES (3024, 11, 2);
INSERT INTO favorites VALUES (3024, 60, 4);
INSERT INTO favorites VALUES (3025, 29, 1);
INSERT INTO favorites VALUES (3025, 47, 2);
INSERT INTO favorites VALUES (3026, 27, 3);
INSERT INTO favorites VALUES (3026, 35, 2);
INSERT INTO favorites VALUES (3026, 49, 1);
INSERT INTO favorites VALUES (3027, 82, 3);
INSERT INTO favorites VALUES (3027, 37, 5);
INSERT INTO favorites VALUES (3027, 23, 1);
INSERT INTO favorites VALUES (3027, 104, 2);
INSERT INTO favorites VALUES (3027, 75, 4);
INSERT INTO favorites VALUES (3029, 2, 1);
INSERT INTO favorites VALUES (3029, 66, 2);
INSERT INTO favorites VALUES (3030, 75, 4);
INSERT INTO favorites VALUES (3030, 73, 1);
INSERT INTO favorites VALUES (3030, 18, 3);
INSERT INTO favorites VALUES (3030, 97, 2);
INSERT INTO favorites VALUES (3031, 44, 1);
INSERT INTO favorites VALUES (3031, 37, 2);
INSERT INTO favorites VALUES (3032, 36, 5);
INSERT INTO favorites VALUES (3032, 104, 4);
INSERT INTO favorites VALUES (3032, 61, 3);
INSERT INTO favorites VALUES (3032, 39, 1);
INSERT INTO favorites VALUES (3032, 10, 2);
INSERT INTO favorites VALUES (3034, 3, 1);
INSERT INTO favorites VALUES (3035, 116, 4);
INSERT INTO favorites VALUES (3035, 33, 1);
INSERT INTO favorites VALUES (3035, 50, 2);
INSERT INTO favorites VALUES (3035, 57, 3);
INSERT INTO favorites VALUES (3038, 93, 4);
INSERT INTO favorites VALUES (3038, 2, 1);
INSERT INTO favorites VALUES (3038, 39, 3);
INSERT INTO favorites VALUES (3038, 84, 2);
INSERT INTO favorites VALUES (3040, 18, 4);
INSERT INTO favorites VALUES (3040, 16, 1);
INSERT INTO favorites VALUES (3040, 7, 3);
INSERT INTO favorites VALUES (3040, 30, 2);
INSERT INTO favorites VALUES (3041, 40, 1);
INSERT INTO favorites VALUES (3042, 43, 1);
INSERT INTO favorites VALUES (3042, 16, 3);
INSERT INTO favorites VALUES (3042, 96, 2);
INSERT INTO favorites VALUES (3043, 104, 6);
INSERT INTO favorites VALUES (3043, 12, 5);
INSERT INTO favorites VALUES (3043, 86, 3);
INSERT INTO favorites VALUES (3043, 88, 1);
INSERT INTO favorites VALUES (3043, 59, 2);
INSERT INTO favorites VALUES (3043, 55, 4);
INSERT INTO favorites VALUES (3045, 18, 6);
INSERT INTO favorites VALUES (3045, 80, 7);
INSERT INTO favorites VALUES (3045, 63, 4);
INSERT INTO favorites VALUES (3045, 50, 1);
INSERT INTO favorites VALUES (3045, 17, 2);
INSERT INTO favorites VALUES (3045, 76, 3);
INSERT INTO favorites VALUES (3045, 19, 5);
INSERT INTO favorites VALUES (3046, 27, 3);
INSERT INTO favorites VALUES (3046, 38, 1);
INSERT INTO favorites VALUES (3046, 82, 2);
INSERT INTO favorites VALUES (3047, 13, 2);
INSERT INTO favorites VALUES (3047, 76, 1);
INSERT INTO favorites VALUES (3048, 10, 4);
INSERT INTO favorites VALUES (3048, 45, 1);
INSERT INTO favorites VALUES (3048, 101, 2);
INSERT INTO favorites VALUES (3048, 23, 3);
INSERT INTO favorites VALUES (3049, 4, 1);
INSERT INTO favorites VALUES (3050, 53, 1);
INSERT INTO favorites VALUES (3050, 11, 2);
INSERT INTO favorites VALUES (3051, 35, 1);
INSERT INTO favorites VALUES (3052, 36, 3);
INSERT INTO favorites VALUES (3052, 58, 1);
INSERT INTO favorites VALUES (3052, 96, 2);
INSERT INTO favorites VALUES (3054, 33, 3);
INSERT INTO favorites VALUES (3054, 8, 1);
INSERT INTO favorites VALUES (3054, 93, 2);
INSERT INTO favorites VALUES (3055, 74, 1);
INSERT INTO favorites VALUES (3055, 97, 2);
INSERT INTO favorites VALUES (3056, 15, 2);
INSERT INTO favorites VALUES (3056, 29, 1);
INSERT INTO favorites VALUES (3056, 62, 3);
INSERT INTO favorites VALUES (3057, 73, 1);
INSERT INTO favorites VALUES (3057, 39, 2);
INSERT INTO favorites VALUES (3058, 62, 1);
INSERT INTO favorites VALUES (3058, 103, 2);
INSERT INTO favorites VALUES (3059, 11, 1);
INSERT INTO favorites VALUES (3060, 86, 4);
INSERT INTO favorites VALUES (3060, 106, 5);
INSERT INTO favorites VALUES (3060, 17, 3);
INSERT INTO favorites VALUES (3060, 21, 1);
INSERT INTO favorites VALUES (3060, 93, 2);
INSERT INTO favorites VALUES (3061, 54, 1);
INSERT INTO favorites VALUES (3061, 60, 4);
INSERT INTO favorites VALUES (3061, 80, 3);
INSERT INTO favorites VALUES (3061, 91, 2);
INSERT INTO favorites VALUES (3062, 75, 4);
INSERT INTO favorites VALUES (3062, 71, 2);
INSERT INTO favorites VALUES (3062, 59, 1);
INSERT INTO favorites VALUES (3062, 14, 3);
INSERT INTO favorites VALUES (3063, 49, 1);
INSERT INTO favorites VALUES (3063, 84, 2);
INSERT INTO favorites VALUES (3065, 35, 4);
INSERT INTO favorites VALUES (3065, 63, 1);
INSERT INTO favorites VALUES (3065, 67, 3);
INSERT INTO favorites VALUES (3065, 24, 2);
INSERT INTO favorites VALUES (3066, 5, 2);
INSERT INTO favorites VALUES (3066, 23, 1);
INSERT INTO favorites VALUES (3066, 85, 4);
INSERT INTO favorites VALUES (3066, 88, 3);
INSERT INTO favorites VALUES (3067, 49, 1);
INSERT INTO favorites VALUES (3068, 57, 1);
INSERT INTO favorites VALUES (3068, 11, 2);
INSERT INTO favorites VALUES (3069, 18, 3);
INSERT INTO favorites VALUES (3069, 59, 1);
INSERT INTO favorites VALUES (3069, 72, 2);
INSERT INTO favorites VALUES (3070, 50, 2);
INSERT INTO favorites VALUES (3070, 66, 1);
INSERT INTO favorites VALUES (3070, 31, 3);
INSERT INTO favorites VALUES (3071, 32, 3);
INSERT INTO favorites VALUES (3071, 61, 2);
INSERT INTO favorites VALUES (3071, 94, 1);
INSERT INTO favorites VALUES (3072, 18, 4);
INSERT INTO favorites VALUES (3072, 105, 2);
INSERT INTO favorites VALUES (3072, 99, 1);
INSERT INTO favorites VALUES (3072, 1, 3);
INSERT INTO favorites VALUES (3073, 77, 4);
INSERT INTO favorites VALUES (3073, 89, 5);
INSERT INTO favorites VALUES (3073, 71, 1);
INSERT INTO favorites VALUES (3073, 25, 2);
INSERT INTO favorites VALUES (3073, 30, 3);
INSERT INTO favorites VALUES (3074, 54, 1);
INSERT INTO favorites VALUES (3075, 3, 3);
INSERT INTO favorites VALUES (3075, 100, 2);
INSERT INTO favorites VALUES (3075, 103, 1);
INSERT INTO favorites VALUES (3076, 101, 1);
INSERT INTO favorites VALUES (3076, 21, 2);
INSERT INTO favorites VALUES (3077, 54, 7);
INSERT INTO favorites VALUES (3077, 77, 6);
INSERT INTO favorites VALUES (3077, 37, 5);
INSERT INTO favorites VALUES (3077, 11, 2);
INSERT INTO favorites VALUES (3077, 19, 4);
INSERT INTO favorites VALUES (3077, 2, 1);
INSERT INTO favorites VALUES (3077, 36, 3);
INSERT INTO favorites VALUES (3078, 12, 1);
INSERT INTO favorites VALUES (3079, 63, 1);
INSERT INTO favorites VALUES (3080, 58, 6);
INSERT INTO favorites VALUES (3080, 96, 7);
INSERT INTO favorites VALUES (3080, 37, 8);
INSERT INTO favorites VALUES (3080, 39, 2);
INSERT INTO favorites VALUES (3080, 11, 3);
INSERT INTO favorites VALUES (3080, 104, 4);
INSERT INTO favorites VALUES (3080, 2, 1);
INSERT INTO favorites VALUES (3080, 16, 5);
INSERT INTO favorites VALUES (3081, 51, 1);
INSERT INTO favorites VALUES (3082, 84, 4);
INSERT INTO favorites VALUES (3082, 27, 1);
INSERT INTO favorites VALUES (3082, 27, 2);
INSERT INTO favorites VALUES (3082, 22, 3);
INSERT INTO favorites VALUES (3083, 42, 1);
INSERT INTO favorites VALUES (3084, 40, 2);
INSERT INTO favorites VALUES (3084, 90, 3);
INSERT INTO favorites VALUES (3084, 57, 1);
INSERT INTO favorites VALUES (3085, 94, 1);
INSERT INTO favorites VALUES (3086, 103, 1);
INSERT INTO favorites VALUES (3086, 26, 2);
INSERT INTO favorites VALUES (3087, 107, 3);
INSERT INTO favorites VALUES (3087, 44, 1);
INSERT INTO favorites VALUES (3087, 16, 2);
INSERT INTO favorites VALUES (3087, 2, 4);
INSERT INTO favorites VALUES (3088, 83, 1);
INSERT INTO favorites VALUES (3088, 18, 2);
INSERT INTO favorites VALUES (3089, 65, 4);
INSERT INTO favorites VALUES (3089, 28, 1);
INSERT INTO favorites VALUES (3089, 90, 2);
INSERT INTO favorites VALUES (3089, 104, 3);
INSERT INTO favorites VALUES (3090, 107, 4);
INSERT INTO favorites VALUES (3090, 14, 1);
INSERT INTO favorites VALUES (3090, 76, 2);
INSERT INTO favorites VALUES (3090, 4, 3);
INSERT INTO favorites VALUES (3091, 63, 1);
INSERT INTO favorites VALUES (3092, 86, 1);
INSERT INTO favorites VALUES (3092, 110, 2);
INSERT INTO favorites VALUES (3093, 116, 1);
INSERT INTO favorites VALUES (3094, 21, 4);
INSERT INTO favorites VALUES (3094, 61, 5);
INSERT INTO favorites VALUES (3094, 10, 1);
INSERT INTO favorites VALUES (3094, 38, 3);
INSERT INTO favorites VALUES (3094, 115, 2);
INSERT INTO favorites VALUES (3094, 105, 6);
INSERT INTO favorites VALUES (3096, 93, 3);
INSERT INTO favorites VALUES (3096, 54, 4);
INSERT INTO favorites VALUES (3096, 13, 1);
INSERT INTO favorites VALUES (3096, 69, 2);
INSERT INTO favorites VALUES (3096, 8, 5);
INSERT INTO favorites VALUES (3098, 111, 1);
INSERT INTO favorites VALUES (3098, 52, 2);
INSERT INTO favorites VALUES (3099, 90, 4);
INSERT INTO favorites VALUES (3099, 18, 5);
INSERT INTO favorites VALUES (3099, 10, 3);
INSERT INTO favorites VALUES (3099, 113, 1);
INSERT INTO favorites VALUES (3099, 85, 2);
INSERT INTO favorites VALUES (3100, 43, 1);
INSERT INTO favorites VALUES (3100, 77, 3);
INSERT INTO favorites VALUES (3100, 33, 2);
INSERT INTO favorites VALUES (3101, 10, 1);
INSERT INTO favorites VALUES (3101, 32, 2);
INSERT INTO favorites VALUES (3102, 62, 1);
INSERT INTO favorites VALUES (3103, 105, 5);
INSERT INTO favorites VALUES (3103, 114, 4);
INSERT INTO favorites VALUES (3103, 43, 2);
INSERT INTO favorites VALUES (3103, 116, 1);
INSERT INTO favorites VALUES (3103, 47, 6);
INSERT INTO favorites VALUES (3103, 94, 7);
INSERT INTO favorites VALUES (3103, 84, 3);
INSERT INTO favorites VALUES (3104, 24, 5);
INSERT INTO favorites VALUES (3104, 103, 4);
INSERT INTO favorites VALUES (3104, 82, 1);
INSERT INTO favorites VALUES (3104, 92, 2);
INSERT INTO favorites VALUES (3104, 7, 3);
INSERT INTO favorites VALUES (3105, 24, 2);
INSERT INTO favorites VALUES (3105, 3, 1);
INSERT INTO favorites VALUES (3105, 36, 3);
INSERT INTO favorites VALUES (3106, 54, 1);
INSERT INTO favorites VALUES (3107, 36, 1);
INSERT INTO favorites VALUES (3108, 27, 1);
INSERT INTO favorites VALUES (3108, 85, 2);
INSERT INTO favorites VALUES (3109, 97, 2);
INSERT INTO favorites VALUES (3109, 4, 1);
INSERT INTO favorites VALUES (3111, 41, 1);
INSERT INTO favorites VALUES (3111, 92, 3);
INSERT INTO favorites VALUES (3111, 64, 2);
INSERT INTO favorites VALUES (3111, 63, 4);
INSERT INTO favorites VALUES (3112, 100, 1);
INSERT INTO favorites VALUES (3112, 58, 2);
INSERT INTO favorites VALUES (3113, 34, 4);
INSERT INTO favorites VALUES (3113, 109, 2);
INSERT INTO favorites VALUES (3113, 60, 3);
INSERT INTO favorites VALUES (3113, 64, 1);
INSERT INTO favorites VALUES (3114, 115, 1);
INSERT INTO favorites VALUES (3114, 112, 2);
INSERT INTO favorites VALUES (3115, 74, 1);
INSERT INTO favorites VALUES (3115, 94, 2);
INSERT INTO favorites VALUES (3116, 27, 1);
INSERT INTO favorites VALUES (3117, 2, 1);
INSERT INTO favorites VALUES (3117, 49, 3);
INSERT INTO favorites VALUES (3117, 46, 2);
INSERT INTO favorites VALUES (3118, 30, 4);
INSERT INTO favorites VALUES (3118, 71, 3);
INSERT INTO favorites VALUES (3118, 18, 1);
INSERT INTO favorites VALUES (3118, 71, 2);
INSERT INTO favorites VALUES (3119, 95, 1);
INSERT INTO favorites VALUES (3119, 96, 4);
INSERT INTO favorites VALUES (3119, 58, 2);
INSERT INTO favorites VALUES (3119, 3, 3);
INSERT INTO favorites VALUES (3120, 81, 5);
INSERT INTO favorites VALUES (3120, 19, 1);
INSERT INTO favorites VALUES (3120, 32, 6);
INSERT INTO favorites VALUES (3120, 30, 2);
INSERT INTO favorites VALUES (3120, 19, 4);
INSERT INTO favorites VALUES (3120, 114, 3);
INSERT INTO favorites VALUES (3121, 76, 1);
INSERT INTO favorites VALUES (3121, 63, 3);
INSERT INTO favorites VALUES (3121, 106, 2);
INSERT INTO favorites VALUES (3122, 14, 4);
INSERT INTO favorites VALUES (3122, 37, 3);
INSERT INTO favorites VALUES (3122, 65, 1);
INSERT INTO favorites VALUES (3122, 108, 2);
INSERT INTO favorites VALUES (3123, 95, 2);
INSERT INTO favorites VALUES (3123, 11, 1);
INSERT INTO favorites VALUES (3124, 14, 4);
INSERT INTO favorites VALUES (3124, 55, 5);
INSERT INTO favorites VALUES (3124, 29, 1);
INSERT INTO favorites VALUES (3124, 24, 2);
INSERT INTO favorites VALUES (3124, 43, 3);
INSERT INTO favorites VALUES (3125, 37, 3);
INSERT INTO favorites VALUES (3125, 16, 1);
INSERT INTO favorites VALUES (3125, 111, 2);
INSERT INTO favorites VALUES (3126, 22, 1);
INSERT INTO favorites VALUES (3126, 13, 2);
INSERT INTO favorites VALUES (3127, 46, 1);
INSERT INTO favorites VALUES (3128, 83, 4);
INSERT INTO favorites VALUES (3128, 22, 1);
INSERT INTO favorites VALUES (3128, 60, 2);
INSERT INTO favorites VALUES (3128, 48, 3);
INSERT INTO favorites VALUES (3129, 14, 4);
INSERT INTO favorites VALUES (3129, 33, 5);
INSERT INTO favorites VALUES (3129, 89, 1);
INSERT INTO favorites VALUES (3129, 3, 3);
INSERT INTO favorites VALUES (3129, 17, 2);
INSERT INTO favorites VALUES (3130, 20, 5);
INSERT INTO favorites VALUES (3130, 47, 4);
INSERT INTO favorites VALUES (3130, 75, 3);
INSERT INTO favorites VALUES (3130, 86, 2);
INSERT INTO favorites VALUES (3130, 68, 1);
INSERT INTO favorites VALUES (3131, 40, 1);
INSERT INTO favorites VALUES (3132, 12, 2);
INSERT INTO favorites VALUES (3132, 44, 1);
INSERT INTO favorites VALUES (3132, 59, 3);
INSERT INTO favorites VALUES (3133, 5, 1);
INSERT INTO favorites VALUES (3133, 74, 2);
INSERT INTO favorites VALUES (3134, 65, 1);
INSERT INTO favorites VALUES (3134, 53, 3);
INSERT INTO favorites VALUES (3134, 95, 2);
INSERT INTO favorites VALUES (3135, 31, 1);
INSERT INTO favorites VALUES (3136, 68, 1);
INSERT INTO favorites VALUES (3137, 41, 2);
INSERT INTO favorites VALUES (3137, 20, 1);
INSERT INTO favorites VALUES (3137, 71, 3);
INSERT INTO favorites VALUES (3138, 47, 2);
INSERT INTO favorites VALUES (3138, 16, 1);
INSERT INTO favorites VALUES (3138, 60, 3);
INSERT INTO favorites VALUES (3139, 31, 1);
INSERT INTO favorites VALUES (3140, 17, 1);
INSERT INTO favorites VALUES (3140, 35, 2);
INSERT INTO favorites VALUES (3141, 54, 4);
INSERT INTO favorites VALUES (3141, 103, 2);
INSERT INTO favorites VALUES (3141, 88, 1);
INSERT INTO favorites VALUES (3141, 67, 3);
INSERT INTO favorites VALUES (3142, 13, 6);
INSERT INTO favorites VALUES (3142, 57, 5);
INSERT INTO favorites VALUES (3142, 31, 1);
INSERT INTO favorites VALUES (3142, 14, 3);
INSERT INTO favorites VALUES (3142, 63, 2);
INSERT INTO favorites VALUES (3142, 104, 4);
INSERT INTO favorites VALUES (3143, 52, 1);
INSERT INTO favorites VALUES (3143, 69, 2);
INSERT INTO favorites VALUES (3144, 102, 1);
INSERT INTO favorites VALUES (3145, 100, 2);
INSERT INTO favorites VALUES (3145, 87, 1);
INSERT INTO favorites VALUES (3146, 34, 3);
INSERT INTO favorites VALUES (3146, 94, 1);
INSERT INTO favorites VALUES (3146, 100, 2);
INSERT INTO favorites VALUES (3147, 14, 3);
INSERT INTO favorites VALUES (3147, 80, 2);
INSERT INTO favorites VALUES (3147, 56, 1);
INSERT INTO favorites VALUES (3148, 10, 3);
INSERT INTO favorites VALUES (3148, 13, 1);
INSERT INTO favorites VALUES (3148, 52, 2);
INSERT INTO favorites VALUES (3149, 24, 1);
INSERT INTO favorites VALUES (3149, 66, 2);
INSERT INTO favorites VALUES (3150, 37, 2);
INSERT INTO favorites VALUES (3150, 103, 1);
INSERT INTO favorites VALUES (3150, 96, 4);
INSERT INTO favorites VALUES (3150, 6, 3);
INSERT INTO favorites VALUES (3151, 25, 4);
INSERT INTO favorites VALUES (3151, 98, 1);
INSERT INTO favorites VALUES (3151, 84, 3);
INSERT INTO favorites VALUES (3151, 20, 2);
INSERT INTO favorites VALUES (3152, 111, 1);
INSERT INTO favorites VALUES (3153, 57, 4);
INSERT INTO favorites VALUES (3153, 35, 1);
INSERT INTO favorites VALUES (3153, 23, 2);
INSERT INTO favorites VALUES (3153, 114, 3);
INSERT INTO favorites VALUES (3154, 105, 4);
INSERT INTO favorites VALUES (3154, 6, 2);
INSERT INTO favorites VALUES (3154, 17, 1);
INSERT INTO favorites VALUES (3154, 74, 3);
INSERT INTO favorites VALUES (3155, 33, 5);
INSERT INTO favorites VALUES (3155, 19, 6);
INSERT INTO favorites VALUES (3155, 78, 2);
INSERT INTO favorites VALUES (3155, 12, 4);
INSERT INTO favorites VALUES (3155, 40, 1);
INSERT INTO favorites VALUES (3155, 83, 3);
INSERT INTO favorites VALUES (3156, 110, 6);
INSERT INTO favorites VALUES (3156, 5, 4);
INSERT INTO favorites VALUES (3156, 22, 1);
INSERT INTO favorites VALUES (3156, 68, 2);
INSERT INTO favorites VALUES (3156, 80, 3);
INSERT INTO favorites VALUES (3156, 114, 5);
INSERT INTO favorites VALUES (3158, 23, 4);
INSERT INTO favorites VALUES (3158, 87, 1);
INSERT INTO favorites VALUES (3158, 29, 3);
INSERT INTO favorites VALUES (3158, 56, 2);
INSERT INTO favorites VALUES (3159, 11, 3);
INSERT INTO favorites VALUES (3159, 47, 1);
INSERT INTO favorites VALUES (3159, 57, 2);
INSERT INTO favorites VALUES (3160, 31, 1);
INSERT INTO favorites VALUES (3161, 27, 1);
INSERT INTO favorites VALUES (3161, 46, 2);
INSERT INTO favorites VALUES (3162, 71, 1);
INSERT INTO favorites VALUES (3162, 12, 2);
INSERT INTO favorites VALUES (3163, 74, 6);
INSERT INTO favorites VALUES (3163, 4, 5);
INSERT INTO favorites VALUES (3163, 18, 4);
INSERT INTO favorites VALUES (3163, 21, 2);
INSERT INTO favorites VALUES (3163, 61, 3);
INSERT INTO favorites VALUES (3163, 94, 1);
INSERT INTO favorites VALUES (3164, 49, 1);
INSERT INTO favorites VALUES (3164, 37, 2);
INSERT INTO favorites VALUES (3165, 86, 1);
INSERT INTO favorites VALUES (3166, 7, 5);
INSERT INTO favorites VALUES (3166, 18, 4);
INSERT INTO favorites VALUES (3166, 74, 3);
INSERT INTO favorites VALUES (3166, 56, 1);
INSERT INTO favorites VALUES (3166, 12, 2);
INSERT INTO favorites VALUES (3167, 22, 4);
INSERT INTO favorites VALUES (3167, 6, 3);
INSERT INTO favorites VALUES (3167, 49, 1);
INSERT INTO favorites VALUES (3167, 43, 2);
INSERT INTO favorites VALUES (3168, 54, 1);
INSERT INTO favorites VALUES (3168, 70, 2);
INSERT INTO favorites VALUES (3170, 27, 5);
INSERT INTO favorites VALUES (3170, 97, 6);
INSERT INTO favorites VALUES (3170, 28, 2);
INSERT INTO favorites VALUES (3170, 97, 4);
INSERT INTO favorites VALUES (3170, 77, 1);
INSERT INTO favorites VALUES (3170, 1, 3);
INSERT INTO favorites VALUES (3171, 14, 2);
INSERT INTO favorites VALUES (3171, 24, 1);
INSERT INTO favorites VALUES (3172, 21, 1);
INSERT INTO favorites VALUES (3172, 67, 2);
INSERT INTO favorites VALUES (3173, 36, 4);
INSERT INTO favorites VALUES (3173, 77, 3);
INSERT INTO favorites VALUES (3173, 4, 2);
INSERT INTO favorites VALUES (3173, 78, 1);
INSERT INTO favorites VALUES (3175, 28, 6);
INSERT INTO favorites VALUES (3175, 23, 7);
INSERT INTO favorites VALUES (3175, 9, 2);
INSERT INTO favorites VALUES (3175, 10, 1);
INSERT INTO favorites VALUES (3175, 45, 4);
INSERT INTO favorites VALUES (3175, 35, 5);
INSERT INTO favorites VALUES (3175, 73, 3);
INSERT INTO favorites VALUES (3176, 31, 3);
INSERT INTO favorites VALUES (3176, 39, 4);
INSERT INTO favorites VALUES (3176, 1, 1);
INSERT INTO favorites VALUES (3176, 84, 2);
INSERT INTO favorites VALUES (3176, 53, 5);
INSERT INTO favorites VALUES (3177, 61, 1);
INSERT INTO favorites VALUES (3177, 43, 2);
INSERT INTO favorites VALUES (3178, 53, 3);
INSERT INTO favorites VALUES (3178, 116, 1);
INSERT INTO favorites VALUES (3178, 21, 2);
INSERT INTO favorites VALUES (3180, 81, 3);
INSERT INTO favorites VALUES (3180, 14, 2);
INSERT INTO favorites VALUES (3180, 35, 1);
INSERT INTO favorites VALUES (3181, 79, 1);
INSERT INTO favorites VALUES (3182, 103, 1);
INSERT INTO favorites VALUES (3182, 26, 2);
INSERT INTO favorites VALUES (3183, 79, 1);
INSERT INTO favorites VALUES (3183, 49, 2);
INSERT INTO favorites VALUES (3184, 29, 1);
INSERT INTO favorites VALUES (3184, 45, 2);
INSERT INTO favorites VALUES (3185, 13, 4);
INSERT INTO favorites VALUES (3185, 48, 3);
INSERT INTO favorites VALUES (3185, 33, 1);
INSERT INTO favorites VALUES (3185, 29, 2);
INSERT INTO favorites VALUES (3186, 76, 4);
INSERT INTO favorites VALUES (3186, 25, 1);
INSERT INTO favorites VALUES (3186, 15, 2);
INSERT INTO favorites VALUES (3186, 7, 3);
INSERT INTO favorites VALUES (3188, 108, 1);
INSERT INTO favorites VALUES (3188, 99, 2);
INSERT INTO favorites VALUES (3189, 68, 3);
INSERT INTO favorites VALUES (3189, 25, 1);
INSERT INTO favorites VALUES (3189, 73, 2);
INSERT INTO favorites VALUES (3190, 63, 3);
INSERT INTO favorites VALUES (3190, 79, 1);
INSERT INTO favorites VALUES (3190, 102, 2);
INSERT INTO favorites VALUES (3191, 56, 1);
INSERT INTO favorites VALUES (3191, 33, 2);
INSERT INTO favorites VALUES (3192, 111, 6);
INSERT INTO favorites VALUES (3192, 29, 5);
INSERT INTO favorites VALUES (3192, 36, 7);
INSERT INTO favorites VALUES (3192, 4, 2);
INSERT INTO favorites VALUES (3192, 53, 3);
INSERT INTO favorites VALUES (3192, 97, 4);
INSERT INTO favorites VALUES (3192, 60, 1);
INSERT INTO favorites VALUES (3192, 30, 8);
INSERT INTO favorites VALUES (3193, 42, 4);
INSERT INTO favorites VALUES (3193, 14, 1);
INSERT INTO favorites VALUES (3193, 43, 2);
INSERT INTO favorites VALUES (3193, 5, 3);
INSERT INTO favorites VALUES (3194, 38, 1);
INSERT INTO favorites VALUES (3194, 33, 2);
INSERT INTO favorites VALUES (3195, 60, 6);
INSERT INTO favorites VALUES (3195, 1, 4);
INSERT INTO favorites VALUES (3195, 14, 1);
INSERT INTO favorites VALUES (3195, 43, 3);
INSERT INTO favorites VALUES (3195, 44, 2);
INSERT INTO favorites VALUES (3195, 58, 5);
INSERT INTO favorites VALUES (3196, 85, 1);
INSERT INTO favorites VALUES (3196, 31, 2);
INSERT INTO favorites VALUES (3197, 5, 3);
INSERT INTO favorites VALUES (3197, 90, 4);
INSERT INTO favorites VALUES (3197, 12, 2);
INSERT INTO favorites VALUES (3197, 73, 1);
INSERT INTO favorites VALUES (3197, 31, 5);
INSERT INTO favorites VALUES (3199, 61, 1);
INSERT INTO favorites VALUES (3200, 63, 1);
INSERT INTO favorites VALUES (3200, 64, 4);
INSERT INTO favorites VALUES (3200, 33, 3);
INSERT INTO favorites VALUES (3200, 67, 5);
INSERT INTO favorites VALUES (3200, 8, 2);
INSERT INTO favorites VALUES (3201, 32, 2);
INSERT INTO favorites VALUES (3201, 13, 1);
INSERT INTO favorites VALUES (3202, 56, 2);
INSERT INTO favorites VALUES (3202, 1, 1);
INSERT INTO favorites VALUES (3202, 12, 3);
INSERT INTO favorites VALUES (3204, 115, 6);
INSERT INTO favorites VALUES (3204, 80, 7);
INSERT INTO favorites VALUES (3204, 33, 2);
INSERT INTO favorites VALUES (3204, 4, 5);
INSERT INTO favorites VALUES (3204, 1, 4);
INSERT INTO favorites VALUES (3204, 18, 1);
INSERT INTO favorites VALUES (3204, 16, 3);
INSERT INTO favorites VALUES (3205, 51, 5);
INSERT INTO favorites VALUES (3205, 31, 3);
INSERT INTO favorites VALUES (3205, 64, 1);
INSERT INTO favorites VALUES (3205, 41, 2);
INSERT INTO favorites VALUES (3205, 70, 4);
INSERT INTO favorites VALUES (3206, 54, 1);
INSERT INTO favorites VALUES (3207, 72, 2);
INSERT INTO favorites VALUES (3207, 110, 1);
INSERT INTO favorites VALUES (3208, 14, 5);
INSERT INTO favorites VALUES (3208, 48, 4);
INSERT INTO favorites VALUES (3208, 74, 3);
INSERT INTO favorites VALUES (3208, 87, 2);
INSERT INTO favorites VALUES (3208, 51, 1);
INSERT INTO favorites VALUES (3209, 69, 3);
INSERT INTO favorites VALUES (3209, 28, 2);
INSERT INTO favorites VALUES (3209, 7, 1);
INSERT INTO favorites VALUES (3210, 62, 1);
INSERT INTO favorites VALUES (3211, 21, 3);
INSERT INTO favorites VALUES (3211, 54, 1);
INSERT INTO favorites VALUES (3211, 27, 2);
INSERT INTO favorites VALUES (3211, 73, 4);
INSERT INTO favorites VALUES (3212, 30, 1);
INSERT INTO favorites VALUES (3212, 50, 2);
INSERT INTO favorites VALUES (3213, 84, 1);
INSERT INTO favorites VALUES (3213, 86, 2);
INSERT INTO favorites VALUES (3214, 106, 5);
INSERT INTO favorites VALUES (3214, 46, 3);
INSERT INTO favorites VALUES (3214, 2, 1);
INSERT INTO favorites VALUES (3214, 50, 2);
INSERT INTO favorites VALUES (3214, 110, 4);
INSERT INTO favorites VALUES (3215, 95, 4);
INSERT INTO favorites VALUES (3215, 103, 5);
INSERT INTO favorites VALUES (3215, 41, 1);
INSERT INTO favorites VALUES (3215, 77, 3);
INSERT INTO favorites VALUES (3215, 84, 2);
INSERT INTO favorites VALUES (3216, 89, 2);
INSERT INTO favorites VALUES (3216, 4, 1);
INSERT INTO favorites VALUES (3216, 8, 4);
INSERT INTO favorites VALUES (3216, 106, 3);
INSERT INTO favorites VALUES (3217, 35, 1);
INSERT INTO favorites VALUES (3217, 112, 2);
INSERT INTO favorites VALUES (3219, 64, 5);
INSERT INTO favorites VALUES (3219, 24, 1);
INSERT INTO favorites VALUES (3219, 21, 4);
INSERT INTO favorites VALUES (3219, 110, 3);
INSERT INTO favorites VALUES (3219, 87, 2);
INSERT INTO favorites VALUES (3220, 32, 2);
INSERT INTO favorites VALUES (3220, 37, 1);
INSERT INTO favorites VALUES (3220, 108, 4);
INSERT INTO favorites VALUES (3220, 23, 3);
INSERT INTO favorites VALUES (3221, 70, 1);
INSERT INTO favorites VALUES (3221, 31, 2);
INSERT INTO favorites VALUES (3222, 42, 3);
INSERT INTO favorites VALUES (3222, 48, 2);
INSERT INTO favorites VALUES (3222, 70, 1);
INSERT INTO favorites VALUES (3223, 110, 1);
INSERT INTO favorites VALUES (3223, 47, 2);
INSERT INTO favorites VALUES (3224, 8, 4);
INSERT INTO favorites VALUES (3224, 114, 5);
INSERT INTO favorites VALUES (3224, 98, 2);
INSERT INTO favorites VALUES (3224, 44, 3);
INSERT INTO favorites VALUES (3224, 116, 1);
INSERT INTO favorites VALUES (3224, 86, 6);
INSERT INTO favorites VALUES (3225, 17, 4);
INSERT INTO favorites VALUES (3225, 24, 1);
INSERT INTO favorites VALUES (3225, 112, 2);
INSERT INTO favorites VALUES (3225, 114, 3);
INSERT INTO favorites VALUES (3226, 33, 3);
INSERT INTO favorites VALUES (3226, 45, 2);
INSERT INTO favorites VALUES (3226, 45, 1);
INSERT INTO favorites VALUES (3226, 102, 4);
INSERT INTO favorites VALUES (3227, 7, 1);
INSERT INTO favorites VALUES (3229, 4, 5);
INSERT INTO favorites VALUES (3229, 43, 6);
INSERT INTO favorites VALUES (3229, 63, 1);
INSERT INTO favorites VALUES (3229, 40, 3);
INSERT INTO favorites VALUES (3229, 45, 2);
INSERT INTO favorites VALUES (3229, 20, 4);
INSERT INTO favorites VALUES (3230, 57, 3);
INSERT INTO favorites VALUES (3230, 89, 2);
INSERT INTO favorites VALUES (3230, 35, 1);
INSERT INTO favorites VALUES (3231, 35, 3);
INSERT INTO favorites VALUES (3231, 113, 1);
INSERT INTO favorites VALUES (3231, 17, 2);
INSERT INTO favorites VALUES (3232, 30, 1);
INSERT INTO favorites VALUES (3232, 9, 2);
INSERT INTO favorites VALUES (3233, 21, 1);
INSERT INTO favorites VALUES (3233, 105, 2);
INSERT INTO favorites VALUES (3234, 108, 5);
INSERT INTO favorites VALUES (3234, 10, 4);
INSERT INTO favorites VALUES (3234, 4, 1);
INSERT INTO favorites VALUES (3234, 24, 2);
INSERT INTO favorites VALUES (3234, 21, 3);
INSERT INTO favorites VALUES (3236, 21, 4);
INSERT INTO favorites VALUES (3236, 106, 5);
INSERT INTO favorites VALUES (3236, 71, 2);
INSERT INTO favorites VALUES (3236, 99, 3);
INSERT INTO favorites VALUES (3236, 14, 1);
INSERT INTO favorites VALUES (3236, 50, 6);
INSERT INTO favorites VALUES (3237, 107, 1);
INSERT INTO favorites VALUES (3237, 52, 2);
INSERT INTO favorites VALUES (3238, 21, 1);
INSERT INTO favorites VALUES (3238, 111, 2);
INSERT INTO favorites VALUES (3239, 110, 3);
INSERT INTO favorites VALUES (3239, 11, 1);
INSERT INTO favorites VALUES (3239, 82, 2);
INSERT INTO favorites VALUES (3240, 63, 1);
INSERT INTO favorites VALUES (3241, 98, 1);
INSERT INTO favorites VALUES (3242, 52, 2);
INSERT INTO favorites VALUES (3242, 101, 1);
INSERT INTO favorites VALUES (3242, 65, 4);
INSERT INTO favorites VALUES (3242, 51, 3);
INSERT INTO favorites VALUES (3243, 64, 3);
INSERT INTO favorites VALUES (3243, 59, 2);
INSERT INTO favorites VALUES (3243, 111, 1);
INSERT INTO favorites VALUES (3244, 9, 1);
INSERT INTO favorites VALUES (3245, 46, 1);
INSERT INTO favorites VALUES (3245, 40, 2);
INSERT INTO favorites VALUES (3246, 16, 4);
INSERT INTO favorites VALUES (3246, 63, 5);
INSERT INTO favorites VALUES (3246, 52, 3);
INSERT INTO favorites VALUES (3246, 103, 2);
INSERT INTO favorites VALUES (3246, 55, 1);
INSERT INTO favorites VALUES (3247, 36, 1);
INSERT INTO favorites VALUES (3248, 84, 4);
INSERT INTO favorites VALUES (3248, 113, 1);
INSERT INTO favorites VALUES (3248, 84, 3);
INSERT INTO favorites VALUES (3248, 16, 2);
INSERT INTO favorites VALUES (3249, 71, 2);
INSERT INTO favorites VALUES (3249, 76, 3);
INSERT INTO favorites VALUES (3249, 88, 1);
INSERT INTO favorites VALUES (3250, 90, 2);
INSERT INTO favorites VALUES (3250, 40, 1);
INSERT INTO favorites VALUES (3250, 26, 4);
INSERT INTO favorites VALUES (3250, 114, 3);
INSERT INTO favorites VALUES (3251, 93, 1);
INSERT INTO favorites VALUES (3252, 107, 3);
INSERT INTO favorites VALUES (3252, 70, 1);
INSERT INTO favorites VALUES (3252, 33, 2);
INSERT INTO favorites VALUES (3253, 34, 5);
INSERT INTO favorites VALUES (3253, 46, 2);
INSERT INTO favorites VALUES (3253, 8, 4);
INSERT INTO favorites VALUES (3253, 16, 1);
INSERT INTO favorites VALUES (3253, 73, 3);
INSERT INTO favorites VALUES (3254, 66, 1);
INSERT INTO favorites VALUES (3254, 44, 2);
INSERT INTO favorites VALUES (3255, 69, 4);
INSERT INTO favorites VALUES (3255, 6, 2);
INSERT INTO favorites VALUES (3255, 2, 1);
INSERT INTO favorites VALUES (3255, 33, 3);
INSERT INTO favorites VALUES (3256, 69, 2);
INSERT INTO favorites VALUES (3256, 111, 1);
INSERT INTO favorites VALUES (3257, 18, 1);
INSERT INTO favorites VALUES (3257, 75, 2);
INSERT INTO favorites VALUES (3259, 18, 2);
INSERT INTO favorites VALUES (3259, 10, 1);
INSERT INTO favorites VALUES (3259, 105, 3);
INSERT INTO favorites VALUES (3260, 10, 4);
INSERT INTO favorites VALUES (3260, 11, 2);
INSERT INTO favorites VALUES (3260, 84, 1);
INSERT INTO favorites VALUES (3260, 81, 3);
INSERT INTO favorites VALUES (3261, 67, 3);
INSERT INTO favorites VALUES (3261, 24, 2);
INSERT INTO favorites VALUES (3261, 64, 1);
INSERT INTO favorites VALUES (3261, 81, 4);
INSERT INTO favorites VALUES (3263, 88, 3);
INSERT INTO favorites VALUES (3263, 73, 2);
INSERT INTO favorites VALUES (3263, 44, 1);
INSERT INTO favorites VALUES (3263, 8, 4);
INSERT INTO favorites VALUES (3264, 39, 3);
INSERT INTO favorites VALUES (3264, 65, 1);
INSERT INTO favorites VALUES (3264, 19, 2);
INSERT INTO favorites VALUES (3265, 79, 3);
INSERT INTO favorites VALUES (3265, 14, 1);
INSERT INTO favorites VALUES (3265, 81, 2);
INSERT INTO favorites VALUES (3266, 101, 2);
INSERT INTO favorites VALUES (3266, 60, 1);
INSERT INTO favorites VALUES (3266, 22, 3);
INSERT INTO favorites VALUES (3267, 95, 1);
INSERT INTO favorites VALUES (3267, 11, 2);
INSERT INTO favorites VALUES (3268, 58, 1);
INSERT INTO favorites VALUES (3269, 43, 3);
INSERT INTO favorites VALUES (3269, 98, 1);
INSERT INTO favorites VALUES (3269, 64, 2);
INSERT INTO favorites VALUES (3270, 20, 3);
INSERT INTO favorites VALUES (3270, 94, 1);
INSERT INTO favorites VALUES (3270, 36, 2);
INSERT INTO favorites VALUES (3271, 9, 5);
INSERT INTO favorites VALUES (3271, 21, 6);
INSERT INTO favorites VALUES (3271, 101, 1);
INSERT INTO favorites VALUES (3271, 21, 3);
INSERT INTO favorites VALUES (3271, 112, 2);
INSERT INTO favorites VALUES (3271, 92, 4);
INSERT INTO favorites VALUES (3272, 65, 2);
INSERT INTO favorites VALUES (3272, 90, 1);
INSERT INTO favorites VALUES (3273, 49, 4);
INSERT INTO favorites VALUES (3273, 42, 1);
INSERT INTO favorites VALUES (3273, 10, 3);
INSERT INTO favorites VALUES (3273, 13, 2);
INSERT INTO favorites VALUES (3274, 1, 4);
INSERT INTO favorites VALUES (3274, 57, 1);
INSERT INTO favorites VALUES (3274, 15, 3);
INSERT INTO favorites VALUES (3274, 110, 2);
INSERT INTO favorites VALUES (3275, 45, 1);
INSERT INTO favorites VALUES (3275, 96, 2);
INSERT INTO favorites VALUES (3276, 10, 1);
INSERT INTO favorites VALUES (3277, 110, 3);
INSERT INTO favorites VALUES (3277, 23, 1);
INSERT INTO favorites VALUES (3277, 100, 2);
INSERT INTO favorites VALUES (3278, 84, 1);
INSERT INTO favorites VALUES (3278, 15, 2);
INSERT INTO favorites VALUES (3281, 52, 1);
INSERT INTO favorites VALUES (3281, 62, 2);
INSERT INTO favorites VALUES (3281, 50, 3);
INSERT INTO favorites VALUES (3281, 39, 4);
INSERT INTO favorites VALUES (3282, 85, 5);
INSERT INTO favorites VALUES (3282, 90, 2);
INSERT INTO favorites VALUES (3282, 28, 3);
INSERT INTO favorites VALUES (3282, 107, 1);
INSERT INTO favorites VALUES (3282, 64, 6);
INSERT INTO favorites VALUES (3282, 40, 4);
INSERT INTO favorites VALUES (3283, 91, 1);
INSERT INTO favorites VALUES (3284, 15, 1);
INSERT INTO favorites VALUES (3284, 70, 2);
INSERT INTO favorites VALUES (3286, 46, 3);
INSERT INTO favorites VALUES (3286, 67, 1);
INSERT INTO favorites VALUES (3286, 76, 2);
INSERT INTO favorites VALUES (3287, 114, 2);
INSERT INTO favorites VALUES (3287, 58, 3);
INSERT INTO favorites VALUES (3287, 46, 4);
INSERT INTO favorites VALUES (3287, 25, 1);
INSERT INTO favorites VALUES (3287, 45, 5);
INSERT INTO favorites VALUES (3288, 95, 3);
INSERT INTO favorites VALUES (3288, 48, 2);
INSERT INTO favorites VALUES (3288, 112, 1);
INSERT INTO favorites VALUES (3289, 76, 3);
INSERT INTO favorites VALUES (3289, 48, 4);
INSERT INTO favorites VALUES (3289, 81, 1);
INSERT INTO favorites VALUES (3289, 12, 2);
INSERT INTO favorites VALUES (3290, 60, 4);
INSERT INTO favorites VALUES (3290, 53, 2);
INSERT INTO favorites VALUES (3290, 51, 1);
INSERT INTO favorites VALUES (3290, 91, 3);
INSERT INTO favorites VALUES (3290, 52, 5);
INSERT INTO favorites VALUES (3291, 77, 5);
INSERT INTO favorites VALUES (3291, 7, 4);
INSERT INTO favorites VALUES (3291, 78, 1);
INSERT INTO favorites VALUES (3291, 15, 2);
INSERT INTO favorites VALUES (3291, 8, 3);
INSERT INTO favorites VALUES (3292, 98, 1);
INSERT INTO favorites VALUES (3292, 3, 2);
INSERT INTO favorites VALUES (3294, 67, 2);
INSERT INTO favorites VALUES (3294, 33, 1);
INSERT INTO favorites VALUES (3295, 15, 1);
INSERT INTO favorites VALUES (3296, 25, 1);
INSERT INTO favorites VALUES (3296, 2, 2);
INSERT INTO favorites VALUES (3297, 44, 6);
INSERT INTO favorites VALUES (3297, 58, 4);
INSERT INTO favorites VALUES (3297, 31, 2);
INSERT INTO favorites VALUES (3297, 39, 3);
INSERT INTO favorites VALUES (3297, 38, 1);
INSERT INTO favorites VALUES (3297, 30, 5);
INSERT INTO favorites VALUES (3298, 6, 1);
INSERT INTO favorites VALUES (3298, 64, 2);
INSERT INTO favorites VALUES (3299, 69, 1);
INSERT INTO favorites VALUES (3299, 67, 3);
INSERT INTO favorites VALUES (3299, 98, 2);
INSERT INTO favorites VALUES (3300, 76, 1);
INSERT INTO favorites VALUES (3300, 74, 3);
INSERT INTO favorites VALUES (3300, 77, 4);
INSERT INTO favorites VALUES (3300, 79, 2);
INSERT INTO favorites VALUES (3301, 37, 1);
INSERT INTO favorites VALUES (3301, 46, 2);
INSERT INTO favorites VALUES (3302, 99, 3);
INSERT INTO favorites VALUES (3302, 114, 1);
INSERT INTO favorites VALUES (3302, 78, 2);
INSERT INTO favorites VALUES (3303, 33, 4);
INSERT INTO favorites VALUES (3303, 46, 1);
INSERT INTO favorites VALUES (3303, 42, 2);
INSERT INTO favorites VALUES (3303, 104, 3);
INSERT INTO favorites VALUES (3304, 82, 1);
INSERT INTO favorites VALUES (3305, 23, 1);
INSERT INTO favorites VALUES (3305, 7, 2);
INSERT INTO favorites VALUES (3306, 112, 5);
INSERT INTO favorites VALUES (3306, 13, 3);
INSERT INTO favorites VALUES (3306, 111, 2);
INSERT INTO favorites VALUES (3306, 38, 1);
INSERT INTO favorites VALUES (3306, 45, 4);
INSERT INTO favorites VALUES (3307, 70, 1);
INSERT INTO favorites VALUES (3308, 78, 1);
INSERT INTO favorites VALUES (3309, 47, 1);
INSERT INTO favorites VALUES (3309, 54, 2);
INSERT INTO favorites VALUES (3310, 9, 4);
INSERT INTO favorites VALUES (3310, 71, 1);
INSERT INTO favorites VALUES (3310, 97, 2);
INSERT INTO favorites VALUES (3310, 22, 3);
INSERT INTO favorites VALUES (3311, 49, 1);
INSERT INTO favorites VALUES (3312, 21, 3);
INSERT INTO favorites VALUES (3312, 42, 2);
INSERT INTO favorites VALUES (3312, 40, 1);
INSERT INTO favorites VALUES (3313, 42, 3);
INSERT INTO favorites VALUES (3313, 13, 1);
INSERT INTO favorites VALUES (3313, 9, 2);
INSERT INTO favorites VALUES (3313, 62, 4);
INSERT INTO favorites VALUES (3314, 56, 1);
INSERT INTO favorites VALUES (3316, 26, 2);
INSERT INTO favorites VALUES (3316, 40, 3);
INSERT INTO favorites VALUES (3316, 20, 1);
INSERT INTO favorites VALUES (3316, 65, 5);
INSERT INTO favorites VALUES (3316, 70, 4);
INSERT INTO favorites VALUES (3317, 14, 4);
INSERT INTO favorites VALUES (3317, 13, 5);
INSERT INTO favorites VALUES (3317, 84, 1);
INSERT INTO favorites VALUES (3317, 80, 3);
INSERT INTO favorites VALUES (3317, 63, 2);
INSERT INTO favorites VALUES (3319, 41, 1);
INSERT INTO favorites VALUES (3319, 72, 2);
INSERT INTO favorites VALUES (3321, 47, 1);
INSERT INTO favorites VALUES (3321, 112, 3);
INSERT INTO favorites VALUES (3321, 87, 2);
INSERT INTO favorites VALUES (3323, 26, 1);
INSERT INTO favorites VALUES (3324, 49, 3);
INSERT INTO favorites VALUES (3324, 56, 2);
INSERT INTO favorites VALUES (3324, 109, 1);
INSERT INTO favorites VALUES (3325, 47, 1);
INSERT INTO favorites VALUES (3326, 90, 3);
INSERT INTO favorites VALUES (3326, 25, 2);
INSERT INTO favorites VALUES (3326, 65, 1);
INSERT INTO favorites VALUES (3327, 89, 5);
INSERT INTO favorites VALUES (3327, 74, 2);
INSERT INTO favorites VALUES (3327, 102, 1);
INSERT INTO favorites VALUES (3327, 38, 4);
INSERT INTO favorites VALUES (3327, 81, 3);
INSERT INTO favorites VALUES (3328, 22, 2);
INSERT INTO favorites VALUES (3328, 58, 1);
INSERT INTO favorites VALUES (3329, 44, 4);
INSERT INTO favorites VALUES (3329, 11, 5);
INSERT INTO favorites VALUES (3329, 11, 1);
INSERT INTO favorites VALUES (3329, 27, 2);
INSERT INTO favorites VALUES (3329, 101, 3);
INSERT INTO favorites VALUES (3330, 61, 3);
INSERT INTO favorites VALUES (3330, 68, 2);
INSERT INTO favorites VALUES (3330, 50, 1);
INSERT INTO favorites VALUES (3331, 26, 3);
INSERT INTO favorites VALUES (3331, 44, 1);
INSERT INTO favorites VALUES (3331, 49, 2);
INSERT INTO favorites VALUES (3331, 45, 4);
INSERT INTO favorites VALUES (3332, 42, 3);
INSERT INTO favorites VALUES (3332, 88, 1);
INSERT INTO favorites VALUES (3332, 3, 2);
INSERT INTO favorites VALUES (3333, 6, 2);
INSERT INTO favorites VALUES (3333, 27, 1);
INSERT INTO favorites VALUES (3334, 14, 1);
INSERT INTO favorites VALUES (3334, 83, 2);
INSERT INTO favorites VALUES (3335, 113, 1);
INSERT INTO favorites VALUES (3336, 109, 3);
INSERT INTO favorites VALUES (3336, 72, 1);
INSERT INTO favorites VALUES (3336, 113, 2);
INSERT INTO favorites VALUES (3336, 5, 4);
INSERT INTO favorites VALUES (3337, 24, 1);
INSERT INTO favorites VALUES (3337, 73, 2);
INSERT INTO favorites VALUES (3338, 59, 1);
INSERT INTO favorites VALUES (3340, 63, 1);
INSERT INTO favorites VALUES (3340, 37, 2);
INSERT INTO favorites VALUES (3341, 11, 2);
INSERT INTO favorites VALUES (3341, 110, 1);
INSERT INTO favorites VALUES (3341, 44, 3);
INSERT INTO favorites VALUES (3342, 66, 2);
INSERT INTO favorites VALUES (3342, 7, 1);
INSERT INTO favorites VALUES (3343, 30, 3);
INSERT INTO favorites VALUES (3343, 54, 1);
INSERT INTO favorites VALUES (3343, 92, 2);
INSERT INTO favorites VALUES (3344, 65, 4);
INSERT INTO favorites VALUES (3344, 72, 5);
INSERT INTO favorites VALUES (3344, 72, 2);
INSERT INTO favorites VALUES (3344, 42, 1);
INSERT INTO favorites VALUES (3344, 90, 3);
INSERT INTO favorites VALUES (3345, 91, 3);
INSERT INTO favorites VALUES (3345, 97, 1);
INSERT INTO favorites VALUES (3345, 99, 2);
INSERT INTO favorites VALUES (3346, 70, 5);
INSERT INTO favorites VALUES (3346, 73, 4);
INSERT INTO favorites VALUES (3346, 25, 3);
INSERT INTO favorites VALUES (3346, 115, 1);
INSERT INTO favorites VALUES (3346, 40, 2);
INSERT INTO favorites VALUES (3347, 71, 1);
INSERT INTO favorites VALUES (3348, 27, 1);
INSERT INTO favorites VALUES (3348, 15, 2);
INSERT INTO favorites VALUES (3349, 16, 1);
INSERT INTO favorites VALUES (3350, 52, 3);
INSERT INTO favorites VALUES (3350, 53, 1);
INSERT INTO favorites VALUES (3350, 6, 2);
INSERT INTO favorites VALUES (3351, 55, 1);
INSERT INTO favorites VALUES (3351, 99, 2);
INSERT INTO favorites VALUES (3352, 8, 5);
INSERT INTO favorites VALUES (3352, 24, 3);
INSERT INTO favorites VALUES (3352, 35, 1);
INSERT INTO favorites VALUES (3352, 111, 6);
INSERT INTO favorites VALUES (3352, 22, 2);
INSERT INTO favorites VALUES (3352, 44, 4);
INSERT INTO favorites VALUES (3353, 98, 4);
INSERT INTO favorites VALUES (3353, 26, 3);
INSERT INTO favorites VALUES (3353, 54, 1);
INSERT INTO favorites VALUES (3353, 28, 2);
INSERT INTO favorites VALUES (3354, 72, 3);
INSERT INTO favorites VALUES (3354, 10, 2);
INSERT INTO favorites VALUES (3354, 45, 1);
INSERT INTO favorites VALUES (3355, 81, 1);
INSERT INTO favorites VALUES (3355, 18, 2);
INSERT INTO favorites VALUES (3356, 112, 3);
INSERT INTO favorites VALUES (3356, 37, 1);
INSERT INTO favorites VALUES (3356, 16, 2);
INSERT INTO favorites VALUES (3357, 103, 1);
INSERT INTO favorites VALUES (3357, 64, 2);
INSERT INTO favorites VALUES (3360, 70, 2);
INSERT INTO favorites VALUES (3360, 36, 1);
INSERT INTO favorites VALUES (3361, 38, 2);
INSERT INTO favorites VALUES (3361, 23, 1);
INSERT INTO favorites VALUES (3362, 60, 8);
INSERT INTO favorites VALUES (3362, 44, 9);
INSERT INTO favorites VALUES (3362, 50, 7);
INSERT INTO favorites VALUES (3362, 42, 3);
INSERT INTO favorites VALUES (3362, 35, 2);
INSERT INTO favorites VALUES (3362, 112, 6);
INSERT INTO favorites VALUES (3362, 17, 1);
INSERT INTO favorites VALUES (3362, 97, 4);
INSERT INTO favorites VALUES (3362, 15, 5);
INSERT INTO favorites VALUES (3363, 1, 1);
INSERT INTO favorites VALUES (3363, 79, 2);
INSERT INTO favorites VALUES (3364, 2, 1);
INSERT INTO favorites VALUES (3365, 4, 1);
INSERT INTO favorites VALUES (3366, 35, 7);
INSERT INTO favorites VALUES (3366, 62, 6);
INSERT INTO favorites VALUES (3366, 101, 5);
INSERT INTO favorites VALUES (3366, 66, 4);
INSERT INTO favorites VALUES (3366, 80, 1);
INSERT INTO favorites VALUES (3366, 80, 2);
INSERT INTO favorites VALUES (3366, 70, 3);
INSERT INTO favorites VALUES (3367, 9, 2);
INSERT INTO favorites VALUES (3367, 56, 1);
INSERT INTO favorites VALUES (3368, 18, 2);
INSERT INTO favorites VALUES (3368, 2, 1);
INSERT INTO favorites VALUES (3368, 2, 3);
INSERT INTO favorites VALUES (3369, 77, 3);
INSERT INTO favorites VALUES (3369, 25, 1);
INSERT INTO favorites VALUES (3369, 7, 2);
INSERT INTO favorites VALUES (3370, 34, 1);
INSERT INTO favorites VALUES (3370, 57, 2);
INSERT INTO favorites VALUES (3371, 26, 1);
INSERT INTO favorites VALUES (3371, 47, 2);
INSERT INTO favorites VALUES (3372, 55, 2);
INSERT INTO favorites VALUES (3372, 60, 1);
INSERT INTO favorites VALUES (3372, 71, 3);
INSERT INTO favorites VALUES (3373, 84, 1);
INSERT INTO favorites VALUES (3374, 23, 4);
INSERT INTO favorites VALUES (3374, 27, 5);
INSERT INTO favorites VALUES (3374, 18, 1);
INSERT INTO favorites VALUES (3374, 3, 3);
INSERT INTO favorites VALUES (3374, 28, 2);
INSERT INTO favorites VALUES (3375, 26, 2);
INSERT INTO favorites VALUES (3375, 28, 1);
INSERT INTO favorites VALUES (3376, 91, 1);
INSERT INTO favorites VALUES (3377, 68, 3);
INSERT INTO favorites VALUES (3377, 23, 2);
INSERT INTO favorites VALUES (3377, 53, 1);
INSERT INTO favorites VALUES (3377, 44, 4);
INSERT INTO favorites VALUES (3378, 36, 1);
INSERT INTO favorites VALUES (3379, 85, 4);
INSERT INTO favorites VALUES (3379, 49, 1);
INSERT INTO favorites VALUES (3379, 62, 3);
INSERT INTO favorites VALUES (3379, 22, 2);
INSERT INTO favorites VALUES (3382, 105, 1);
INSERT INTO favorites VALUES (3383, 78, 1);
INSERT INTO favorites VALUES (3384, 70, 2);
INSERT INTO favorites VALUES (3384, 93, 1);
INSERT INTO favorites VALUES (3384, 12, 3);
INSERT INTO favorites VALUES (3385, 72, 2);
INSERT INTO favorites VALUES (3385, 74, 3);
INSERT INTO favorites VALUES (3385, 64, 1);
INSERT INTO favorites VALUES (3385, 26, 5);
INSERT INTO favorites VALUES (3385, 79, 4);
INSERT INTO favorites VALUES (3386, 62, 7);
INSERT INTO favorites VALUES (3386, 33, 5);
INSERT INTO favorites VALUES (3386, 3, 6);
INSERT INTO favorites VALUES (3386, 5, 3);
INSERT INTO favorites VALUES (3386, 4, 2);
INSERT INTO favorites VALUES (3386, 35, 4);
INSERT INTO favorites VALUES (3386, 13, 1);
INSERT INTO favorites VALUES (3386, 64, 8);
INSERT INTO favorites VALUES (3387, 58, 1);
INSERT INTO favorites VALUES (3388, 46, 3);
INSERT INTO favorites VALUES (3388, 71, 1);
INSERT INTO favorites VALUES (3388, 45, 2);
INSERT INTO favorites VALUES (3389, 89, 4);
INSERT INTO favorites VALUES (3389, 68, 2);
INSERT INTO favorites VALUES (3389, 50, 1);
INSERT INTO favorites VALUES (3389, 23, 3);
INSERT INTO favorites VALUES (3390, 68, 4);
INSERT INTO favorites VALUES (3390, 97, 5);
INSERT INTO favorites VALUES (3390, 109, 1);
INSERT INTO favorites VALUES (3390, 36, 2);
INSERT INTO favorites VALUES (3390, 44, 3);
INSERT INTO favorites VALUES (3391, 102, 1);
INSERT INTO favorites VALUES (3391, 63, 2);
INSERT INTO favorites VALUES (3392, 81, 2);
INSERT INTO favorites VALUES (3392, 113, 1);
INSERT INTO favorites VALUES (3392, 114, 3);
INSERT INTO favorites VALUES (3393, 20, 2);
INSERT INTO favorites VALUES (3393, 23, 1);
INSERT INTO favorites VALUES (3393, 67, 3);
INSERT INTO favorites VALUES (3394, 4, 2);
INSERT INTO favorites VALUES (3394, 59, 1);
INSERT INTO favorites VALUES (3394, 87, 3);
INSERT INTO favorites VALUES (3395, 60, 1);
INSERT INTO favorites VALUES (3397, 107, 4);
INSERT INTO favorites VALUES (3397, 28, 1);
INSERT INTO favorites VALUES (3397, 37, 2);
INSERT INTO favorites VALUES (3397, 57, 3);
INSERT INTO favorites VALUES (3398, 70, 3);
INSERT INTO favorites VALUES (3398, 62, 1);
INSERT INTO favorites VALUES (3398, 22, 2);
INSERT INTO favorites VALUES (3400, 16, 1);
INSERT INTO favorites VALUES (3400, 84, 2);
INSERT INTO favorites VALUES (3400, 49, 3);
INSERT INTO favorites VALUES (3400, 66, 4);
INSERT INTO favorites VALUES (3401, 63, 3);
INSERT INTO favorites VALUES (3401, 49, 1);
INSERT INTO favorites VALUES (3401, 101, 2);
INSERT INTO favorites VALUES (3402, 48, 2);
INSERT INTO favorites VALUES (3402, 73, 1);
INSERT INTO favorites VALUES (3403, 101, 1);
INSERT INTO favorites VALUES (3404, 90, 1);
INSERT INTO favorites VALUES (3404, 66, 2);
INSERT INTO favorites VALUES (3405, 6, 4);
INSERT INTO favorites VALUES (3405, 9, 1);
INSERT INTO favorites VALUES (3405, 101, 2);
INSERT INTO favorites VALUES (3405, 81, 3);
INSERT INTO favorites VALUES (3407, 57, 3);
INSERT INTO favorites VALUES (3407, 59, 1);
INSERT INTO favorites VALUES (3407, 46, 2);
INSERT INTO favorites VALUES (3408, 63, 3);
INSERT INTO favorites VALUES (3408, 81, 2);
INSERT INTO favorites VALUES (3408, 56, 1);
INSERT INTO favorites VALUES (3409, 54, 4);
INSERT INTO favorites VALUES (3409, 11, 1);
INSERT INTO favorites VALUES (3409, 35, 3);
INSERT INTO favorites VALUES (3409, 70, 2);
INSERT INTO favorites VALUES (3410, 51, 1);
INSERT INTO favorites VALUES (3410, 114, 2);
INSERT INTO favorites VALUES (3411, 77, 1);
INSERT INTO favorites VALUES (3411, 48, 2);
INSERT INTO favorites VALUES (3412, 33, 3);
INSERT INTO favorites VALUES (3412, 85, 1);
INSERT INTO favorites VALUES (3412, 115, 2);
INSERT INTO favorites VALUES (3413, 25, 1);
INSERT INTO favorites VALUES (3413, 100, 2);
INSERT INTO favorites VALUES (3414, 38, 3);
INSERT INTO favorites VALUES (3414, 53, 1);
INSERT INTO favorites VALUES (3414, 27, 2);
INSERT INTO favorites VALUES (3414, 66, 4);
INSERT INTO favorites VALUES (3415, 44, 1);
INSERT INTO favorites VALUES (3415, 3, 2);
INSERT INTO favorites VALUES (3416, 7, 1);
INSERT INTO favorites VALUES (3416, 73, 2);
INSERT INTO favorites VALUES (3417, 65, 2);
INSERT INTO favorites VALUES (3417, 95, 1);
INSERT INTO favorites VALUES (3418, 9, 1);
INSERT INTO favorites VALUES (3418, 109, 2);
INSERT INTO favorites VALUES (3419, 113, 3);
INSERT INTO favorites VALUES (3419, 82, 2);
INSERT INTO favorites VALUES (3419, 40, 1);
INSERT INTO favorites VALUES (3419, 42, 4);
INSERT INTO favorites VALUES (3420, 11, 2);
INSERT INTO favorites VALUES (3420, 60, 3);
INSERT INTO favorites VALUES (3420, 102, 1);
INSERT INTO favorites VALUES (3422, 12, 3);
INSERT INTO favorites VALUES (3422, 46, 2);
INSERT INTO favorites VALUES (3422, 19, 1);
INSERT INTO favorites VALUES (3423, 96, 3);
INSERT INTO favorites VALUES (3423, 26, 2);
INSERT INTO favorites VALUES (3423, 26, 1);
INSERT INTO favorites VALUES (3423, 100, 4);
INSERT INTO favorites VALUES (3425, 26, 4);
INSERT INTO favorites VALUES (3425, 58, 1);
INSERT INTO favorites VALUES (3425, 100, 2);
INSERT INTO favorites VALUES (3425, 91, 3);
INSERT INTO favorites VALUES (3426, 78, 1);
INSERT INTO favorites VALUES (3427, 65, 1);
INSERT INTO favorites VALUES (3427, 25, 2);
INSERT INTO favorites VALUES (3428, 2, 2);
INSERT INTO favorites VALUES (3428, 85, 1);
INSERT INTO favorites VALUES (3428, 83, 4);
INSERT INTO favorites VALUES (3428, 10, 3);
INSERT INTO favorites VALUES (3429, 115, 3);
INSERT INTO favorites VALUES (3429, 58, 1);
INSERT INTO favorites VALUES (3429, 27, 2);
INSERT INTO favorites VALUES (3429, 95, 4);
INSERT INTO favorites VALUES (3430, 113, 1);
INSERT INTO favorites VALUES (3430, 80, 2);
INSERT INTO favorites VALUES (3431, 34, 3);
INSERT INTO favorites VALUES (3431, 72, 2);
INSERT INTO favorites VALUES (3431, 40, 1);
INSERT INTO favorites VALUES (3431, 61, 4);
INSERT INTO favorites VALUES (3432, 11, 1);
INSERT INTO favorites VALUES (3432, 9, 2);
INSERT INTO favorites VALUES (3434, 22, 4);
INSERT INTO favorites VALUES (3434, 2, 1);
INSERT INTO favorites VALUES (3434, 25, 3);
INSERT INTO favorites VALUES (3434, 3, 2);
INSERT INTO favorites VALUES (3435, 42, 2);
INSERT INTO favorites VALUES (3435, 58, 1);
INSERT INTO favorites VALUES (3436, 22, 6);
INSERT INTO favorites VALUES (3436, 95, 7);
INSERT INTO favorites VALUES (3436, 65, 5);
INSERT INTO favorites VALUES (3436, 89, 4);
INSERT INTO favorites VALUES (3436, 16, 3);
INSERT INTO favorites VALUES (3436, 28, 1);
INSERT INTO favorites VALUES (3436, 7, 2);
INSERT INTO favorites VALUES (3437, 79, 3);
INSERT INTO favorites VALUES (3437, 18, 1);
INSERT INTO favorites VALUES (3437, 36, 2);
INSERT INTO favorites VALUES (3438, 70, 1);
INSERT INTO favorites VALUES (3438, 74, 2);
INSERT INTO favorites VALUES (3439, 76, 2);
INSERT INTO favorites VALUES (3439, 38, 1);
INSERT INTO favorites VALUES (3440, 80, 2);
INSERT INTO favorites VALUES (3440, 41, 1);
INSERT INTO favorites VALUES (3441, 103, 3);
INSERT INTO favorites VALUES (3441, 17, 1);
INSERT INTO favorites VALUES (3441, 23, 2);
INSERT INTO favorites VALUES (3442, 63, 1);
INSERT INTO favorites VALUES (3443, 17, 1);
INSERT INTO favorites VALUES (3444, 80, 1);
INSERT INTO favorites VALUES (3444, 45, 2);
INSERT INTO favorites VALUES (3445, 99, 1);
INSERT INTO favorites VALUES (3445, 14, 2);
INSERT INTO favorites VALUES (3446, 28, 4);
INSERT INTO favorites VALUES (3446, 65, 3);
INSERT INTO favorites VALUES (3446, 64, 2);
INSERT INTO favorites VALUES (3446, 32, 1);
INSERT INTO favorites VALUES (3447, 42, 1);
INSERT INTO favorites VALUES (3447, 43, 2);
INSERT INTO favorites VALUES (3448, 26, 3);
INSERT INTO favorites VALUES (3448, 67, 1);
INSERT INTO favorites VALUES (3448, 60, 2);
INSERT INTO favorites VALUES (3449, 51, 1);
INSERT INTO favorites VALUES (3449, 103, 2);
INSERT INTO favorites VALUES (3450, 92, 3);
INSERT INTO favorites VALUES (3450, 16, 1);
INSERT INTO favorites VALUES (3450, 33, 2);
INSERT INTO favorites VALUES (3451, 107, 3);
INSERT INTO favorites VALUES (3451, 30, 1);
INSERT INTO favorites VALUES (3451, 20, 2);
INSERT INTO favorites VALUES (3452, 63, 1);
INSERT INTO favorites VALUES (3453, 90, 1);
INSERT INTO favorites VALUES (3454, 59, 3);
INSERT INTO favorites VALUES (3454, 7, 2);
INSERT INTO favorites VALUES (3454, 32, 1);
INSERT INTO favorites VALUES (3455, 19, 1);
INSERT INTO favorites VALUES (3456, 88, 5);
INSERT INTO favorites VALUES (3456, 95, 4);
INSERT INTO favorites VALUES (3456, 91, 3);
INSERT INTO favorites VALUES (3456, 111, 1);
INSERT INTO favorites VALUES (3456, 6, 2);
INSERT INTO favorites VALUES (3457, 9, 6);
INSERT INTO favorites VALUES (3457, 49, 5);
INSERT INTO favorites VALUES (3457, 19, 1);
INSERT INTO favorites VALUES (3457, 69, 2);
INSERT INTO favorites VALUES (3457, 83, 4);
INSERT INTO favorites VALUES (3457, 26, 3);
INSERT INTO favorites VALUES (3458, 22, 1);
INSERT INTO favorites VALUES (3458, 114, 2);
INSERT INTO favorites VALUES (3459, 109, 8);
INSERT INTO favorites VALUES (3459, 22, 5);
INSERT INTO favorites VALUES (3459, 32, 6);
INSERT INTO favorites VALUES (3459, 18, 1);
INSERT INTO favorites VALUES (3459, 75, 2);
INSERT INTO favorites VALUES (3459, 9, 3);
INSERT INTO favorites VALUES (3459, 9, 4);
INSERT INTO favorites VALUES (3459, 97, 7);
INSERT INTO favorites VALUES (3460, 6, 1);
INSERT INTO favorites VALUES (3461, 8, 3);
INSERT INTO favorites VALUES (3461, 33, 1);
INSERT INTO favorites VALUES (3461, 116, 2);
INSERT INTO favorites VALUES (3462, 24, 3);
INSERT INTO favorites VALUES (3462, 107, 2);
INSERT INTO favorites VALUES (3462, 116, 1);
INSERT INTO favorites VALUES (3463, 43, 1);
INSERT INTO favorites VALUES (3463, 43, 2);
INSERT INTO favorites VALUES (3464, 17, 1);
INSERT INTO favorites VALUES (3466, 57, 6);
INSERT INTO favorites VALUES (3466, 4, 7);
INSERT INTO favorites VALUES (3466, 55, 4);
INSERT INTO favorites VALUES (3466, 102, 1);
INSERT INTO favorites VALUES (3466, 1, 3);
INSERT INTO favorites VALUES (3466, 12, 2);
INSERT INTO favorites VALUES (3466, 107, 5);
INSERT INTO favorites VALUES (3467, 22, 3);
INSERT INTO favorites VALUES (3467, 46, 1);
INSERT INTO favorites VALUES (3467, 21, 2);
INSERT INTO favorites VALUES (3469, 24, 1);
INSERT INTO favorites VALUES (3469, 13, 2);
INSERT INTO favorites VALUES (3470, 56, 2);
INSERT INTO favorites VALUES (3470, 13, 1);
INSERT INTO favorites VALUES (3471, 11, 3);
INSERT INTO favorites VALUES (3471, 33, 4);
INSERT INTO favorites VALUES (3471, 83, 5);
INSERT INTO favorites VALUES (3471, 94, 2);
INSERT INTO favorites VALUES (3471, 80, 1);
INSERT INTO favorites VALUES (3472, 90, 1);
INSERT INTO favorites VALUES (3473, 15, 5);
INSERT INTO favorites VALUES (3473, 9, 4);
INSERT INTO favorites VALUES (3473, 85, 3);
INSERT INTO favorites VALUES (3473, 12, 2);
INSERT INTO favorites VALUES (3473, 83, 1);
INSERT INTO favorites VALUES (3474, 34, 1);
INSERT INTO favorites VALUES (3474, 24, 2);
INSERT INTO favorites VALUES (3475, 44, 1);
INSERT INTO favorites VALUES (3476, 21, 5);
INSERT INTO favorites VALUES (3476, 4, 4);
INSERT INTO favorites VALUES (3476, 81, 1);
INSERT INTO favorites VALUES (3476, 53, 2);
INSERT INTO favorites VALUES (3476, 29, 3);
INSERT INTO favorites VALUES (3477, 71, 5);
INSERT INTO favorites VALUES (3477, 107, 3);
INSERT INTO favorites VALUES (3477, 62, 1);
INSERT INTO favorites VALUES (3477, 7, 2);
INSERT INTO favorites VALUES (3477, 20, 4);
INSERT INTO favorites VALUES (3478, 28, 6);
INSERT INTO favorites VALUES (3478, 31, 4);
INSERT INTO favorites VALUES (3478, 9, 2);
INSERT INTO favorites VALUES (3478, 60, 3);
INSERT INTO favorites VALUES (3478, 42, 1);
INSERT INTO favorites VALUES (3478, 27, 5);
INSERT INTO favorites VALUES (3480, 70, 3);
INSERT INTO favorites VALUES (3480, 15, 1);
INSERT INTO favorites VALUES (3480, 7, 2);
INSERT INTO favorites VALUES (3481, 26, 4);
INSERT INTO favorites VALUES (3481, 106, 2);
INSERT INTO favorites VALUES (3481, 39, 1);
INSERT INTO favorites VALUES (3481, 9, 3);
INSERT INTO favorites VALUES (3482, 102, 2);
INSERT INTO favorites VALUES (3482, 79, 1);
INSERT INTO favorites VALUES (3483, 74, 1);
INSERT INTO favorites VALUES (3483, 97, 2);
INSERT INTO favorites VALUES (3484, 29, 4);
INSERT INTO favorites VALUES (3484, 37, 1);
INSERT INTO favorites VALUES (3484, 108, 2);
INSERT INTO favorites VALUES (3484, 83, 3);
INSERT INTO favorites VALUES (3485, 63, 1);
INSERT INTO favorites VALUES (3485, 61, 2);
INSERT INTO favorites VALUES (3486, 15, 3);
INSERT INTO favorites VALUES (3486, 41, 1);
INSERT INTO favorites VALUES (3486, 4, 2);
INSERT INTO favorites VALUES (3487, 29, 3);
INSERT INTO favorites VALUES (3487, 69, 2);
INSERT INTO favorites VALUES (3487, 9, 1);
INSERT INTO favorites VALUES (3488, 63, 1);
INSERT INTO favorites VALUES (3489, 10, 1);
INSERT INTO favorites VALUES (3489, 14, 2);
INSERT INTO favorites VALUES (3490, 12, 1);
INSERT INTO favorites VALUES (3490, 61, 2);
INSERT INTO favorites VALUES (3491, 100, 5);
INSERT INTO favorites VALUES (3491, 7, 1);
INSERT INTO favorites VALUES (3491, 1, 3);
INSERT INTO favorites VALUES (3491, 24, 4);
INSERT INTO favorites VALUES (3491, 1, 2);
INSERT INTO favorites VALUES (3492, 55, 1);
INSERT INTO favorites VALUES (3493, 78, 3);
INSERT INTO favorites VALUES (3493, 24, 2);
INSERT INTO favorites VALUES (3493, 86, 4);
INSERT INTO favorites VALUES (3493, 42, 1);
INSERT INTO favorites VALUES (3494, 70, 3);
INSERT INTO favorites VALUES (3494, 52, 1);
INSERT INTO favorites VALUES (3494, 103, 2);
INSERT INTO favorites VALUES (3496, 25, 2);
INSERT INTO favorites VALUES (3496, 5, 1);
INSERT INTO favorites VALUES (3496, 20, 3);
INSERT INTO favorites VALUES (3497, 67, 1);
INSERT INTO favorites VALUES (3497, 77, 2);
INSERT INTO favorites VALUES (3498, 9, 2);
INSERT INTO favorites VALUES (3498, 88, 3);
INSERT INTO favorites VALUES (3498, 50, 1);
INSERT INTO favorites VALUES (3499, 15, 4);
INSERT INTO favorites VALUES (3499, 105, 1);
INSERT INTO favorites VALUES (3499, 94, 2);
INSERT INTO favorites VALUES (3499, 93, 3);
INSERT INTO favorites VALUES (3500, 40, 1);
INSERT INTO favorites VALUES (3500, 43, 2);
INSERT INTO favorites VALUES (3501, 101, 1);
INSERT INTO favorites VALUES (3501, 96, 2);
INSERT INTO favorites VALUES (3502, 104, 2);
INSERT INTO favorites VALUES (3502, 15, 3);
INSERT INTO favorites VALUES (3502, 32, 4);
INSERT INTO favorites VALUES (3502, 65, 1);
INSERT INTO favorites VALUES (3503, 86, 6);
INSERT INTO favorites VALUES (3503, 95, 3);
INSERT INTO favorites VALUES (3503, 23, 1);
INSERT INTO favorites VALUES (3503, 61, 5);
INSERT INTO favorites VALUES (3503, 72, 4);
INSERT INTO favorites VALUES (3503, 6, 2);
INSERT INTO favorites VALUES (3504, 94, 2);
INSERT INTO favorites VALUES (3504, 1, 1);
INSERT INTO favorites VALUES (3505, 96, 5);
INSERT INTO favorites VALUES (3505, 79, 4);
INSERT INTO favorites VALUES (3505, 32, 1);
INSERT INTO favorites VALUES (3505, 21, 3);
INSERT INTO favorites VALUES (3505, 18, 2);
INSERT INTO favorites VALUES (3506, 9, 1);
INSERT INTO favorites VALUES (3506, 56, 2);
INSERT INTO favorites VALUES (3506, 21, 3);
INSERT INTO favorites VALUES (3506, 34, 4);
INSERT INTO favorites VALUES (3507, 6, 2);
INSERT INTO favorites VALUES (3507, 14, 1);
INSERT INTO favorites VALUES (3508, 8, 1);
INSERT INTO favorites VALUES (3508, 90, 2);
INSERT INTO favorites VALUES (3510, 79, 1);
INSERT INTO favorites VALUES (3511, 23, 1);
INSERT INTO favorites VALUES (3512, 78, 1);
INSERT INTO favorites VALUES (3512, 45, 3);
INSERT INTO favorites VALUES (3512, 22, 2);
INSERT INTO favorites VALUES (3513, 17, 1);
INSERT INTO favorites VALUES (3514, 32, 1);
INSERT INTO favorites VALUES (3514, 44, 2);
INSERT INTO favorites VALUES (3514, 95, 4);
INSERT INTO favorites VALUES (3514, 23, 3);
INSERT INTO favorites VALUES (3515, 14, 1);
INSERT INTO favorites VALUES (3515, 2, 3);
INSERT INTO favorites VALUES (3515, 71, 2);
INSERT INTO favorites VALUES (3516, 31, 1);
INSERT INTO favorites VALUES (3516, 19, 2);
INSERT INTO favorites VALUES (3516, 1, 3);
INSERT INTO favorites VALUES (3517, 62, 2);
INSERT INTO favorites VALUES (3517, 5, 1);
INSERT INTO favorites VALUES (3517, 93, 3);
INSERT INTO favorites VALUES (3517, 32, 4);
INSERT INTO favorites VALUES (3518, 11, 1);
INSERT INTO favorites VALUES (3518, 58, 3);
INSERT INTO favorites VALUES (3518, 86, 2);
INSERT INTO favorites VALUES (3519, 23, 1);
INSERT INTO favorites VALUES (3520, 19, 3);
INSERT INTO favorites VALUES (3520, 29, 2);
INSERT INTO favorites VALUES (3520, 28, 1);
INSERT INTO favorites VALUES (3521, 11, 1);
INSERT INTO favorites VALUES (3521, 15, 2);
INSERT INTO favorites VALUES (3521, 106, 3);
INSERT INTO favorites VALUES (3523, 90, 4);
INSERT INTO favorites VALUES (3523, 80, 3);
INSERT INTO favorites VALUES (3523, 86, 2);
INSERT INTO favorites VALUES (3523, 78, 1);
INSERT INTO favorites VALUES (3524, 70, 1);
INSERT INTO favorites VALUES (3524, 53, 2);
INSERT INTO favorites VALUES (3525, 55, 3);
INSERT INTO favorites VALUES (3525, 32, 1);
INSERT INTO favorites VALUES (3525, 6, 2);
INSERT INTO favorites VALUES (3526, 101, 4);
INSERT INTO favorites VALUES (3526, 18, 1);
INSERT INTO favorites VALUES (3526, 44, 3);
INSERT INTO favorites VALUES (3526, 26, 2);
INSERT INTO favorites VALUES (3527, 111, 1);
INSERT INTO favorites VALUES (3529, 66, 1);
INSERT INTO favorites VALUES (3530, 15, 3);
INSERT INTO favorites VALUES (3530, 96, 1);
INSERT INTO favorites VALUES (3530, 40, 2);
INSERT INTO favorites VALUES (3531, 62, 2);
INSERT INTO favorites VALUES (3531, 55, 1);
INSERT INTO favorites VALUES (3531, 4, 4);
INSERT INTO favorites VALUES (3531, 15, 3);
INSERT INTO favorites VALUES (3532, 61, 1);
INSERT INTO favorites VALUES (3533, 92, 1);
INSERT INTO favorites VALUES (3533, 88, 2);
INSERT INTO favorites VALUES (3534, 75, 1);
INSERT INTO favorites VALUES (3534, 89, 2);
INSERT INTO favorites VALUES (3535, 43, 1);
INSERT INTO favorites VALUES (3535, 29, 2);
INSERT INTO favorites VALUES (3536, 17, 3);
INSERT INTO favorites VALUES (3536, 3, 1);
INSERT INTO favorites VALUES (3536, 113, 2);
INSERT INTO favorites VALUES (3538, 26, 2);
INSERT INTO favorites VALUES (3538, 39, 1);
INSERT INTO favorites VALUES (3539, 59, 4);
INSERT INTO favorites VALUES (3539, 51, 2);
INSERT INTO favorites VALUES (3539, 82, 3);
INSERT INTO favorites VALUES (3539, 50, 1);
INSERT INTO favorites VALUES (3540, 46, 1);
INSERT INTO favorites VALUES (3541, 30, 5);
INSERT INTO favorites VALUES (3541, 39, 4);
INSERT INTO favorites VALUES (3541, 88, 2);
INSERT INTO favorites VALUES (3541, 92, 1);
INSERT INTO favorites VALUES (3541, 41, 3);
INSERT INTO favorites VALUES (3542, 46, 4);
INSERT INTO favorites VALUES (3542, 65, 2);
INSERT INTO favorites VALUES (3542, 43, 1);
INSERT INTO favorites VALUES (3542, 30, 3);
INSERT INTO favorites VALUES (3543, 3, 4);
INSERT INTO favorites VALUES (3543, 41, 1);
INSERT INTO favorites VALUES (3543, 48, 2);
INSERT INTO favorites VALUES (3543, 14, 3);
INSERT INTO favorites VALUES (3544, 22, 1);
INSERT INTO favorites VALUES (3544, 97, 2);
INSERT INTO favorites VALUES (3545, 25, 2);
INSERT INTO favorites VALUES (3545, 62, 1);
INSERT INTO favorites VALUES (3545, 18, 3);
INSERT INTO favorites VALUES (3546, 96, 3);
INSERT INTO favorites VALUES (3546, 113, 4);
INSERT INTO favorites VALUES (3546, 6, 2);
INSERT INTO favorites VALUES (3546, 17, 5);
INSERT INTO favorites VALUES (3546, 32, 1);
INSERT INTO favorites VALUES (3547, 96, 3);
INSERT INTO favorites VALUES (3547, 54, 4);
INSERT INTO favorites VALUES (3547, 63, 1);
INSERT INTO favorites VALUES (3547, 100, 6);
INSERT INTO favorites VALUES (3547, 24, 2);
INSERT INTO favorites VALUES (3547, 45, 5);
INSERT INTO favorites VALUES (3548, 101, 1);
INSERT INTO favorites VALUES (3548, 43, 2);
INSERT INTO favorites VALUES (3549, 65, 5);
INSERT INTO favorites VALUES (3549, 68, 3);
INSERT INTO favorites VALUES (3549, 35, 1);
INSERT INTO favorites VALUES (3549, 112, 2);
INSERT INTO favorites VALUES (3549, 9, 4);
INSERT INTO favorites VALUES (3550, 95, 4);
INSERT INTO favorites VALUES (3550, 53, 3);
INSERT INTO favorites VALUES (3550, 111, 1);
INSERT INTO favorites VALUES (3550, 6, 2);
INSERT INTO favorites VALUES (3550, 22, 5);
INSERT INTO favorites VALUES (3551, 87, 4);
INSERT INTO favorites VALUES (3551, 70, 3);
INSERT INTO favorites VALUES (3551, 5, 2);
INSERT INTO favorites VALUES (3551, 58, 1);
INSERT INTO favorites VALUES (3552, 105, 1);
INSERT INTO favorites VALUES (3552, 97, 2);
INSERT INTO favorites VALUES (3553, 45, 3);
INSERT INTO favorites VALUES (3553, 36, 1);
INSERT INTO favorites VALUES (3553, 58, 2);
INSERT INTO favorites VALUES (3554, 37, 1);
INSERT INTO favorites VALUES (3555, 21, 3);
INSERT INTO favorites VALUES (3555, 34, 1);
INSERT INTO favorites VALUES (3555, 75, 2);
INSERT INTO favorites VALUES (3556, 23, 3);
INSERT INTO favorites VALUES (3556, 13, 2);
INSERT INTO favorites VALUES (3556, 42, 1);
INSERT INTO favorites VALUES (3557, 53, 1);
INSERT INTO favorites VALUES (3557, 12, 2);
INSERT INTO favorites VALUES (3558, 78, 3);
INSERT INTO favorites VALUES (3558, 35, 2);
INSERT INTO favorites VALUES (3558, 104, 1);
INSERT INTO favorites VALUES (3559, 57, 5);
INSERT INTO favorites VALUES (3559, 33, 4);
INSERT INTO favorites VALUES (3559, 15, 1);
INSERT INTO favorites VALUES (3559, 26, 2);
INSERT INTO favorites VALUES (3559, 54, 3);
INSERT INTO favorites VALUES (3560, 46, 1);
INSERT INTO favorites VALUES (3561, 65, 5);
INSERT INTO favorites VALUES (3561, 4, 3);
INSERT INTO favorites VALUES (3561, 74, 2);
INSERT INTO favorites VALUES (3561, 20, 1);
INSERT INTO favorites VALUES (3561, 23, 4);
INSERT INTO favorites VALUES (3563, 8, 1);
INSERT INTO favorites VALUES (3563, 108, 2);
INSERT INTO favorites VALUES (3564, 102, 4);
INSERT INTO favorites VALUES (3564, 60, 3);
INSERT INTO favorites VALUES (3564, 104, 1);
INSERT INTO favorites VALUES (3564, 29, 2);
INSERT INTO favorites VALUES (3565, 71, 1);
INSERT INTO favorites VALUES (3567, 32, 2);
INSERT INTO favorites VALUES (3567, 69, 1);
INSERT INTO favorites VALUES (3567, 62, 3);
INSERT INTO favorites VALUES (3568, 82, 2);
INSERT INTO favorites VALUES (3568, 71, 1);
INSERT INTO favorites VALUES (3568, 27, 4);
INSERT INTO favorites VALUES (3568, 64, 3);
INSERT INTO favorites VALUES (3569, 114, 1);
INSERT INTO favorites VALUES (3569, 54, 2);
INSERT INTO favorites VALUES (3570, 45, 3);
INSERT INTO favorites VALUES (3570, 87, 2);
INSERT INTO favorites VALUES (3570, 100, 1);
INSERT INTO favorites VALUES (3570, 39, 4);
INSERT INTO favorites VALUES (3571, 32, 1);
INSERT INTO favorites VALUES (3572, 69, 3);
INSERT INTO favorites VALUES (3572, 69, 2);
INSERT INTO favorites VALUES (3572, 71, 1);
INSERT INTO favorites VALUES (3573, 69, 1);
INSERT INTO favorites VALUES (3573, 41, 2);
INSERT INTO favorites VALUES (3574, 5, 1);
INSERT INTO favorites VALUES (3575, 90, 1);
INSERT INTO favorites VALUES (3575, 37, 2);
INSERT INTO favorites VALUES (3576, 57, 6);
INSERT INTO favorites VALUES (3576, 78, 7);
INSERT INTO favorites VALUES (3576, 55, 5);
INSERT INTO favorites VALUES (3576, 7, 2);
INSERT INTO favorites VALUES (3576, 44, 8);
INSERT INTO favorites VALUES (3576, 33, 3);
INSERT INTO favorites VALUES (3576, 66, 1);
INSERT INTO favorites VALUES (3576, 91, 4);
INSERT INTO favorites VALUES (3577, 12, 1);
INSERT INTO favorites VALUES (3578, 102, 1);
INSERT INTO favorites VALUES (3578, 8, 2);
INSERT INTO favorites VALUES (3579, 55, 3);
INSERT INTO favorites VALUES (3579, 50, 1);
INSERT INTO favorites VALUES (3579, 114, 2);
INSERT INTO favorites VALUES (3580, 24, 1);
INSERT INTO favorites VALUES (3581, 96, 1);
INSERT INTO favorites VALUES (3582, 79, 6);
INSERT INTO favorites VALUES (3582, 101, 3);
INSERT INTO favorites VALUES (3582, 93, 4);
INSERT INTO favorites VALUES (3582, 2, 2);
INSERT INTO favorites VALUES (3582, 50, 7);
INSERT INTO favorites VALUES (3582, 55, 1);
INSERT INTO favorites VALUES (3582, 63, 5);
INSERT INTO favorites VALUES (3583, 111, 4);
INSERT INTO favorites VALUES (3583, 88, 3);
INSERT INTO favorites VALUES (3583, 60, 2);
INSERT INTO favorites VALUES (3583, 78, 1);
INSERT INTO favorites VALUES (3584, 104, 1);
INSERT INTO favorites VALUES (3584, 30, 2);
INSERT INTO favorites VALUES (3585, 85, 1);
INSERT INTO favorites VALUES (3585, 76, 2);
INSERT INTO favorites VALUES (3586, 91, 3);
INSERT INTO favorites VALUES (3586, 45, 2);
INSERT INTO favorites VALUES (3586, 12, 1);
INSERT INTO favorites VALUES (3587, 41, 1);
INSERT INTO favorites VALUES (3587, 91, 2);
INSERT INTO favorites VALUES (3588, 52, 5);
INSERT INTO favorites VALUES (3588, 87, 3);
INSERT INTO favorites VALUES (3588, 59, 2);
INSERT INTO favorites VALUES (3588, 15, 1);
INSERT INTO favorites VALUES (3588, 21, 4);
INSERT INTO favorites VALUES (3590, 82, 2);
INSERT INTO favorites VALUES (3590, 67, 1);
INSERT INTO favorites VALUES (3590, 36, 3);
INSERT INTO favorites VALUES (3591, 32, 1);
INSERT INTO favorites VALUES (3591, 26, 2);
INSERT INTO favorites VALUES (3592, 98, 5);
INSERT INTO favorites VALUES (3592, 30, 4);
INSERT INTO favorites VALUES (3592, 50, 3);
INSERT INTO favorites VALUES (3592, 93, 2);
INSERT INTO favorites VALUES (3592, 15, 1);
INSERT INTO favorites VALUES (3593, 59, 3);
INSERT INTO favorites VALUES (3593, 3, 2);
INSERT INTO favorites VALUES (3593, 99, 1);
INSERT INTO favorites VALUES (3593, 74, 4);
INSERT INTO favorites VALUES (3596, 100, 1);
INSERT INTO favorites VALUES (3596, 46, 2);
INSERT INTO favorites VALUES (3597, 52, 4);
INSERT INTO favorites VALUES (3597, 3, 2);
INSERT INTO favorites VALUES (3597, 25, 1);
INSERT INTO favorites VALUES (3597, 114, 3);
INSERT INTO favorites VALUES (3598, 82, 1);
INSERT INTO favorites VALUES (3599, 11, 1);
INSERT INTO favorites VALUES (3599, 64, 2);
INSERT INTO favorites VALUES (3600, 16, 1);
INSERT INTO favorites VALUES (3601, 1, 3);
INSERT INTO favorites VALUES (3601, 18, 5);
INSERT INTO favorites VALUES (3601, 9, 2);
INSERT INTO favorites VALUES (3601, 18, 1);
INSERT INTO favorites VALUES (3601, 75, 4);
INSERT INTO favorites VALUES (3603, 14, 1);
INSERT INTO favorites VALUES (3605, 59, 1);
INSERT INTO favorites VALUES (3605, 59, 2);
INSERT INTO favorites VALUES (3606, 36, 4);
INSERT INTO favorites VALUES (3606, 115, 2);
INSERT INTO favorites VALUES (3606, 29, 1);
INSERT INTO favorites VALUES (3606, 66, 3);
INSERT INTO favorites VALUES (3607, 64, 4);
INSERT INTO favorites VALUES (3607, 65, 2);
INSERT INTO favorites VALUES (3607, 26, 1);
INSERT INTO favorites VALUES (3607, 105, 3);
INSERT INTO favorites VALUES (3608, 68, 1);
INSERT INTO favorites VALUES (3608, 98, 3);
INSERT INTO favorites VALUES (3608, 22, 2);
INSERT INTO favorites VALUES (3609, 39, 4);
INSERT INTO favorites VALUES (3609, 103, 1);
INSERT INTO favorites VALUES (3609, 36, 2);
INSERT INTO favorites VALUES (3609, 14, 3);
INSERT INTO favorites VALUES (3611, 12, 1);
INSERT INTO favorites VALUES (3612, 43, 1);
INSERT INTO favorites VALUES (3612, 14, 2);
INSERT INTO favorites VALUES (3613, 4, 3);
INSERT INTO favorites VALUES (3613, 16, 1);
INSERT INTO favorites VALUES (3613, 75, 2);
INSERT INTO favorites VALUES (3614, 97, 2);
INSERT INTO favorites VALUES (3614, 84, 1);
INSERT INTO favorites VALUES (3615, 39, 5);
INSERT INTO favorites VALUES (3615, 39, 4);
INSERT INTO favorites VALUES (3615, 66, 3);
INSERT INTO favorites VALUES (3615, 56, 1);
INSERT INTO favorites VALUES (3615, 107, 2);
INSERT INTO favorites VALUES (3616, 114, 3);
INSERT INTO favorites VALUES (3616, 9, 1);
INSERT INTO favorites VALUES (3616, 11, 2);
INSERT INTO favorites VALUES (3617, 26, 1);
INSERT INTO favorites VALUES (3617, 100, 2);
INSERT INTO favorites VALUES (3618, 22, 1);
INSERT INTO favorites VALUES (3619, 63, 2);
INSERT INTO favorites VALUES (3619, 71, 1);
INSERT INTO favorites VALUES (3620, 35, 1);
INSERT INTO favorites VALUES (3621, 76, 5);
INSERT INTO favorites VALUES (3621, 110, 4);
INSERT INTO favorites VALUES (3621, 113, 3);
INSERT INTO favorites VALUES (3621, 97, 1);
INSERT INTO favorites VALUES (3621, 60, 2);
INSERT INTO favorites VALUES (3622, 6, 4);
INSERT INTO favorites VALUES (3622, 50, 1);
INSERT INTO favorites VALUES (3622, 28, 2);
INSERT INTO favorites VALUES (3622, 15, 3);
INSERT INTO favorites VALUES (3623, 104, 1);
INSERT INTO favorites VALUES (3623, 63, 2);
INSERT INTO favorites VALUES (3624, 68, 1);
INSERT INTO favorites VALUES (3625, 111, 1);
INSERT INTO favorites VALUES (3625, 2, 2);
INSERT INTO favorites VALUES (3626, 7, 1);
INSERT INTO favorites VALUES (3627, 10, 3);
INSERT INTO favorites VALUES (3627, 103, 1);
INSERT INTO favorites VALUES (3627, 100, 2);
INSERT INTO favorites VALUES (3628, 75, 4);
INSERT INTO favorites VALUES (3628, 2, 1);
INSERT INTO favorites VALUES (3628, 61, 3);
INSERT INTO favorites VALUES (3628, 25, 2);
INSERT INTO favorites VALUES (3630, 66, 4);
INSERT INTO favorites VALUES (3630, 102, 2);
INSERT INTO favorites VALUES (3630, 48, 1);
INSERT INTO favorites VALUES (3630, 49, 3);
INSERT INTO favorites VALUES (3631, 62, 1);
INSERT INTO favorites VALUES (3631, 37, 2);
INSERT INTO favorites VALUES (3632, 92, 2);
INSERT INTO favorites VALUES (3632, 102, 1);
INSERT INTO favorites VALUES (3632, 90, 3);
INSERT INTO favorites VALUES (3633, 27, 3);
INSERT INTO favorites VALUES (3633, 96, 1);
INSERT INTO favorites VALUES (3633, 3, 2);
INSERT INTO favorites VALUES (3634, 42, 1);
INSERT INTO favorites VALUES (3634, 36, 2);
INSERT INTO favorites VALUES (3635, 116, 1);
INSERT INTO favorites VALUES (3636, 66, 5);
INSERT INTO favorites VALUES (3636, 61, 6);
INSERT INTO favorites VALUES (3636, 9, 1);
INSERT INTO favorites VALUES (3636, 69, 3);
INSERT INTO favorites VALUES (3636, 97, 2);
INSERT INTO favorites VALUES (3636, 50, 4);
INSERT INTO favorites VALUES (3637, 38, 1);
INSERT INTO favorites VALUES (3637, 105, 2);
INSERT INTO favorites VALUES (3638, 2, 1);
INSERT INTO favorites VALUES (3638, 24, 2);
INSERT INTO favorites VALUES (3639, 28, 1);
INSERT INTO favorites VALUES (3640, 73, 1);
INSERT INTO favorites VALUES (3640, 9, 2);
INSERT INTO favorites VALUES (3641, 34, 3);
INSERT INTO favorites VALUES (3641, 24, 1);
INSERT INTO favorites VALUES (3641, 3, 2);
INSERT INTO favorites VALUES (3642, 25, 1);
INSERT INTO favorites VALUES (3643, 9, 1);
INSERT INTO favorites VALUES (3643, 78, 2);
INSERT INTO favorites VALUES (3643, 23, 3);
INSERT INTO favorites VALUES (3645, 88, 5);
INSERT INTO favorites VALUES (3645, 47, 4);
INSERT INTO favorites VALUES (3645, 61, 3);
INSERT INTO favorites VALUES (3645, 101, 2);
INSERT INTO favorites VALUES (3645, 11, 1);
INSERT INTO favorites VALUES (3646, 94, 5);
INSERT INTO favorites VALUES (3646, 108, 6);
INSERT INTO favorites VALUES (3646, 25, 2);
INSERT INTO favorites VALUES (3646, 30, 4);
INSERT INTO favorites VALUES (3646, 71, 1);
INSERT INTO favorites VALUES (3646, 52, 3);
INSERT INTO favorites VALUES (3647, 90, 1);
INSERT INTO favorites VALUES (3647, 70, 2);
INSERT INTO favorites VALUES (3648, 31, 3);
INSERT INTO favorites VALUES (3648, 95, 1);
INSERT INTO favorites VALUES (3648, 78, 2);
INSERT INTO favorites VALUES (3649, 17, 1);
INSERT INTO favorites VALUES (3649, 6, 2);
INSERT INTO favorites VALUES (3651, 11, 3);
INSERT INTO favorites VALUES (3651, 70, 2);
INSERT INTO favorites VALUES (3651, 56, 1);
INSERT INTO favorites VALUES (3652, 11, 3);
INSERT INTO favorites VALUES (3652, 109, 1);
INSERT INTO favorites VALUES (3652, 24, 2);
INSERT INTO favorites VALUES (3653, 87, 6);
INSERT INTO favorites VALUES (3653, 59, 7);
INSERT INTO favorites VALUES (3653, 93, 4);
INSERT INTO favorites VALUES (3653, 80, 2);
INSERT INTO favorites VALUES (3653, 81, 3);
INSERT INTO favorites VALUES (3653, 55, 1);
INSERT INTO favorites VALUES (3653, 7, 5);
INSERT INTO favorites VALUES (3654, 42, 3);
INSERT INTO favorites VALUES (3654, 44, 1);
INSERT INTO favorites VALUES (3654, 46, 2);
INSERT INTO favorites VALUES (3655, 32, 4);
INSERT INTO favorites VALUES (3655, 32, 5);
INSERT INTO favorites VALUES (3655, 7, 1);
INSERT INTO favorites VALUES (3655, 69, 3);
INSERT INTO favorites VALUES (3655, 104, 2);
INSERT INTO favorites VALUES (3655, 83, 6);
INSERT INTO favorites VALUES (3656, 42, 2);
INSERT INTO favorites VALUES (3656, 100, 1);
INSERT INTO favorites VALUES (3656, 108, 3);
INSERT INTO favorites VALUES (3657, 2, 1);
INSERT INTO favorites VALUES (3658, 27, 1);
INSERT INTO favorites VALUES (3659, 106, 2);
INSERT INTO favorites VALUES (3659, 34, 1);
INSERT INTO favorites VALUES (3659, 49, 3);
INSERT INTO favorites VALUES (3660, 96, 3);
INSERT INTO favorites VALUES (3660, 71, 1);
INSERT INTO favorites VALUES (3660, 106, 2);
INSERT INTO favorites VALUES (3661, 65, 3);
INSERT INTO favorites VALUES (3661, 59, 2);
INSERT INTO favorites VALUES (3661, 73, 1);
INSERT INTO favorites VALUES (3662, 91, 1);
INSERT INTO favorites VALUES (3663, 67, 1);
INSERT INTO favorites VALUES (3663, 101, 2);
INSERT INTO favorites VALUES (3664, 37, 1);
INSERT INTO favorites VALUES (3664, 13, 2);
INSERT INTO favorites VALUES (3665, 69, 1);
INSERT INTO favorites VALUES (3666, 19, 3);
INSERT INTO favorites VALUES (3666, 95, 1);
INSERT INTO favorites VALUES (3666, 8, 2);
INSERT INTO favorites VALUES (3667, 87, 3);
INSERT INTO favorites VALUES (3667, 27, 1);
INSERT INTO favorites VALUES (3667, 94, 2);
INSERT INTO favorites VALUES (3668, 47, 4);
INSERT INTO favorites VALUES (3668, 78, 1);
INSERT INTO favorites VALUES (3668, 34, 3);
INSERT INTO favorites VALUES (3668, 58, 2);
INSERT INTO favorites VALUES (3669, 74, 4);
INSERT INTO favorites VALUES (3669, 83, 2);
INSERT INTO favorites VALUES (3669, 38, 1);
INSERT INTO favorites VALUES (3669, 21, 3);
INSERT INTO favorites VALUES (3670, 29, 4);
INSERT INTO favorites VALUES (3670, 15, 1);
INSERT INTO favorites VALUES (3670, 106, 2);
INSERT INTO favorites VALUES (3670, 59, 3);
INSERT INTO favorites VALUES (3671, 76, 1);
INSERT INTO favorites VALUES (3671, 45, 2);
INSERT INTO favorites VALUES (3672, 3, 6);
INSERT INTO favorites VALUES (3672, 47, 5);
INSERT INTO favorites VALUES (3672, 68, 1);
INSERT INTO favorites VALUES (3672, 46, 4);
INSERT INTO favorites VALUES (3672, 55, 2);
INSERT INTO favorites VALUES (3672, 114, 3);
INSERT INTO favorites VALUES (3673, 28, 4);
INSERT INTO favorites VALUES (3673, 11, 5);
INSERT INTO favorites VALUES (3673, 101, 1);
INSERT INTO favorites VALUES (3673, 40, 2);
INSERT INTO favorites VALUES (3673, 10, 3);
INSERT INTO favorites VALUES (3674, 54, 1);
INSERT INTO favorites VALUES (3675, 87, 1);
INSERT INTO favorites VALUES (3676, 33, 4);
INSERT INTO favorites VALUES (3676, 13, 1);
INSERT INTO favorites VALUES (3676, 58, 2);
INSERT INTO favorites VALUES (3676, 69, 3);
INSERT INTO favorites VALUES (3677, 15, 6);
INSERT INTO favorites VALUES (3677, 5, 7);
INSERT INTO favorites VALUES (3677, 80, 5);
INSERT INTO favorites VALUES (3677, 67, 2);
INSERT INTO favorites VALUES (3677, 54, 4);
INSERT INTO favorites VALUES (3677, 17, 1);
INSERT INTO favorites VALUES (3677, 77, 3);
INSERT INTO favorites VALUES (3678, 105, 1);
INSERT INTO favorites VALUES (3678, 111, 2);
INSERT INTO favorites VALUES (3679, 4, 3);
INSERT INTO favorites VALUES (3679, 42, 2);
INSERT INTO favorites VALUES (3679, 114, 1);
INSERT INTO favorites VALUES (3680, 35, 1);
INSERT INTO favorites VALUES (3680, 93, 2);
INSERT INTO favorites VALUES (3681, 23, 5);
INSERT INTO favorites VALUES (3681, 89, 4);
INSERT INTO favorites VALUES (3681, 113, 3);
INSERT INTO favorites VALUES (3681, 16, 2);
INSERT INTO favorites VALUES (3681, 4, 1);
INSERT INTO favorites VALUES (3682, 113, 1);
INSERT INTO favorites VALUES (3683, 96, 3);
INSERT INTO favorites VALUES (3683, 39, 1);
INSERT INTO favorites VALUES (3683, 43, 2);
INSERT INTO favorites VALUES (3684, 5, 1);
INSERT INTO favorites VALUES (3685, 49, 3);
INSERT INTO favorites VALUES (3685, 13, 1);
INSERT INTO favorites VALUES (3685, 100, 2);
INSERT INTO favorites VALUES (3686, 42, 3);
INSERT INTO favorites VALUES (3686, 89, 1);
INSERT INTO favorites VALUES (3686, 13, 2);
INSERT INTO favorites VALUES (3687, 90, 4);
INSERT INTO favorites VALUES (3687, 116, 2);
INSERT INTO favorites VALUES (3687, 32, 3);
INSERT INTO favorites VALUES (3687, 1, 1);
INSERT INTO favorites VALUES (3688, 60, 1);
INSERT INTO favorites VALUES (3689, 86, 4);
INSERT INTO favorites VALUES (3689, 102, 1);
INSERT INTO favorites VALUES (3689, 99, 2);
INSERT INTO favorites VALUES (3689, 60, 3);
INSERT INTO favorites VALUES (3690, 97, 4);
INSERT INTO favorites VALUES (3690, 115, 1);
INSERT INTO favorites VALUES (3690, 66, 2);
INSERT INTO favorites VALUES (3690, 36, 3);
INSERT INTO favorites VALUES (3691, 21, 3);
INSERT INTO favorites VALUES (3691, 17, 1);
INSERT INTO favorites VALUES (3691, 96, 2);
INSERT INTO favorites VALUES (3692, 68, 4);
INSERT INTO favorites VALUES (3692, 36, 5);
INSERT INTO favorites VALUES (3692, 92, 3);
INSERT INTO favorites VALUES (3692, 70, 2);
INSERT INTO favorites VALUES (3692, 58, 1);
INSERT INTO favorites VALUES (3693, 50, 6);
INSERT INTO favorites VALUES (3693, 106, 3);
INSERT INTO favorites VALUES (3693, 63, 4);
INSERT INTO favorites VALUES (3693, 5, 1);
INSERT INTO favorites VALUES (3693, 115, 2);
INSERT INTO favorites VALUES (3693, 64, 5);
INSERT INTO favorites VALUES (3694, 49, 1);
INSERT INTO favorites VALUES (3695, 116, 1);
INSERT INTO favorites VALUES (3696, 23, 7);
INSERT INTO favorites VALUES (3696, 5, 8);
INSERT INTO favorites VALUES (3696, 50, 5);
INSERT INTO favorites VALUES (3696, 23, 1);
INSERT INTO favorites VALUES (3696, 10, 2);
INSERT INTO favorites VALUES (3696, 77, 3);
INSERT INTO favorites VALUES (3696, 78, 4);
INSERT INTO favorites VALUES (3696, 16, 6);
INSERT INTO favorites VALUES (3697, 74, 4);
INSERT INTO favorites VALUES (3697, 13, 1);
INSERT INTO favorites VALUES (3697, 63, 2);
INSERT INTO favorites VALUES (3697, 13, 3);
INSERT INTO favorites VALUES (3698, 16, 1);
INSERT INTO favorites VALUES (3699, 61, 3);
INSERT INTO favorites VALUES (3699, 76, 1);
INSERT INTO favorites VALUES (3699, 4, 2);
INSERT INTO favorites VALUES (3700, 85, 1);
INSERT INTO favorites VALUES (3700, 7, 2);
INSERT INTO favorites VALUES (3701, 73, 1);
INSERT INTO favorites VALUES (3701, 85, 3);
INSERT INTO favorites VALUES (3701, 32, 2);
INSERT INTO favorites VALUES (3701, 82, 5);
INSERT INTO favorites VALUES (3701, 55, 4);
INSERT INTO favorites VALUES (3702, 29, 1);
INSERT INTO favorites VALUES (3703, 31, 1);
INSERT INTO favorites VALUES (3703, 9, 3);
INSERT INTO favorites VALUES (3703, 110, 2);
INSERT INTO favorites VALUES (3704, 14, 2);
INSERT INTO favorites VALUES (3704, 63, 6);
INSERT INTO favorites VALUES (3704, 99, 4);
INSERT INTO favorites VALUES (3704, 52, 1);
INSERT INTO favorites VALUES (3704, 84, 3);
INSERT INTO favorites VALUES (3704, 16, 7);
INSERT INTO favorites VALUES (3704, 11, 5);
INSERT INTO favorites VALUES (3705, 12, 2);
INSERT INTO favorites VALUES (3705, 58, 1);
INSERT INTO favorites VALUES (3706, 16, 2);
INSERT INTO favorites VALUES (3706, 47, 1);
INSERT INTO favorites VALUES (3706, 61, 3);
INSERT INTO favorites VALUES (3707, 88, 1);
INSERT INTO favorites VALUES (3707, 25, 3);
INSERT INTO favorites VALUES (3707, 81, 2);
INSERT INTO favorites VALUES (3708, 85, 2);
INSERT INTO favorites VALUES (3708, 2, 1);
INSERT INTO favorites VALUES (3709, 63, 2);
INSERT INTO favorites VALUES (3709, 24, 1);
INSERT INTO favorites VALUES (3709, 17, 3);
INSERT INTO favorites VALUES (3709, 17, 4);
INSERT INTO favorites VALUES (3710, 2, 1);
INSERT INTO favorites VALUES (3710, 93, 2);
INSERT INTO favorites VALUES (3710, 25, 3);
INSERT INTO favorites VALUES (3711, 49, 3);
INSERT INTO favorites VALUES (3711, 77, 2);
INSERT INTO favorites VALUES (3711, 19, 4);
INSERT INTO favorites VALUES (3711, 8, 1);
INSERT INTO favorites VALUES (3712, 38, 1);
INSERT INTO favorites VALUES (3712, 116, 3);
INSERT INTO favorites VALUES (3712, 61, 2);
INSERT INTO favorites VALUES (3713, 44, 5);
INSERT INTO favorites VALUES (3713, 81, 3);
INSERT INTO favorites VALUES (3713, 4, 1);
INSERT INTO favorites VALUES (3713, 89, 4);
INSERT INTO favorites VALUES (3713, 33, 2);
INSERT INTO favorites VALUES (3714, 115, 2);
INSERT INTO favorites VALUES (3714, 21, 1);
INSERT INTO favorites VALUES (3715, 87, 2);
INSERT INTO favorites VALUES (3715, 61, 3);
INSERT INTO favorites VALUES (3715, 35, 1);
INSERT INTO favorites VALUES (3716, 12, 1);
INSERT INTO favorites VALUES (3716, 106, 2);
INSERT INTO favorites VALUES (3717, 96, 1);
INSERT INTO favorites VALUES (3717, 31, 2);
INSERT INTO favorites VALUES (3718, 34, 2);
INSERT INTO favorites VALUES (3718, 30, 1);
INSERT INTO favorites VALUES (3719, 74, 2);
INSERT INTO favorites VALUES (3719, 75, 1);
INSERT INTO favorites VALUES (3721, 64, 2);
INSERT INTO favorites VALUES (3721, 71, 1);
INSERT INTO favorites VALUES (3722, 67, 2);
INSERT INTO favorites VALUES (3722, 11, 1);
INSERT INTO favorites VALUES (3723, 1, 6);
INSERT INTO favorites VALUES (3723, 5, 5);
INSERT INTO favorites VALUES (3723, 68, 2);
INSERT INTO favorites VALUES (3723, 63, 3);
INSERT INTO favorites VALUES (3723, 66, 1);
INSERT INTO favorites VALUES (3723, 94, 4);
INSERT INTO favorites VALUES (3724, 68, 2);
INSERT INTO favorites VALUES (3724, 97, 1);
INSERT INTO favorites VALUES (3726, 39, 5);
INSERT INTO favorites VALUES (3726, 12, 3);
INSERT INTO favorites VALUES (3726, 33, 1);
INSERT INTO favorites VALUES (3726, 87, 2);
INSERT INTO favorites VALUES (3726, 43, 4);
INSERT INTO favorites VALUES (3727, 99, 4);
INSERT INTO favorites VALUES (3727, 40, 1);
INSERT INTO favorites VALUES (3727, 85, 2);
INSERT INTO favorites VALUES (3727, 97, 3);
INSERT INTO favorites VALUES (3728, 60, 1);
INSERT INTO favorites VALUES (3729, 47, 2);
INSERT INTO favorites VALUES (3729, 105, 3);
INSERT INTO favorites VALUES (3729, 29, 1);
INSERT INTO favorites VALUES (3729, 27, 5);
INSERT INTO favorites VALUES (3729, 34, 4);
INSERT INTO favorites VALUES (3730, 45, 3);
INSERT INTO favorites VALUES (3730, 111, 1);
INSERT INTO favorites VALUES (3730, 74, 2);
INSERT INTO favorites VALUES (3731, 44, 4);
INSERT INTO favorites VALUES (3731, 9, 1);
INSERT INTO favorites VALUES (3731, 1, 2);
INSERT INTO favorites VALUES (3731, 28, 3);
INSERT INTO favorites VALUES (3732, 37, 3);
INSERT INTO favorites VALUES (3732, 32, 1);
INSERT INTO favorites VALUES (3732, 62, 2);
INSERT INTO favorites VALUES (3733, 40, 1);
INSERT INTO favorites VALUES (3734, 96, 6);
INSERT INTO favorites VALUES (3734, 39, 5);
INSERT INTO favorites VALUES (3734, 39, 1);
INSERT INTO favorites VALUES (3734, 29, 2);
INSERT INTO favorites VALUES (3734, 70, 3);
INSERT INTO favorites VALUES (3734, 73, 4);
INSERT INTO favorites VALUES (3735, 66, 5);
INSERT INTO favorites VALUES (3735, 34, 6);
INSERT INTO favorites VALUES (3735, 25, 2);
INSERT INTO favorites VALUES (3735, 9, 4);
INSERT INTO favorites VALUES (3735, 21, 1);
INSERT INTO favorites VALUES (3735, 63, 3);
INSERT INTO favorites VALUES (3736, 26, 1);
INSERT INTO favorites VALUES (3736, 67, 2);
INSERT INTO favorites VALUES (3737, 21, 1);
INSERT INTO favorites VALUES (3738, 25, 3);
INSERT INTO favorites VALUES (3738, 67, 1);
INSERT INTO favorites VALUES (3738, 36, 2);
INSERT INTO favorites VALUES (3739, 72, 1);
INSERT INTO favorites VALUES (3739, 42, 2);
INSERT INTO favorites VALUES (3741, 97, 1);
INSERT INTO favorites VALUES (3741, 5, 2);
INSERT INTO favorites VALUES (3742, 4, 2);
INSERT INTO favorites VALUES (3742, 112, 1);
INSERT INTO favorites VALUES (3742, 17, 3);
INSERT INTO favorites VALUES (3743, 46, 3);
INSERT INTO favorites VALUES (3743, 10, 1);
INSERT INTO favorites VALUES (3743, 51, 2);
INSERT INTO favorites VALUES (3744, 33, 5);
INSERT INTO favorites VALUES (3744, 36, 4);
INSERT INTO favorites VALUES (3744, 29, 1);
INSERT INTO favorites VALUES (3744, 104, 2);
INSERT INTO favorites VALUES (3744, 8, 3);
INSERT INTO favorites VALUES (3745, 17, 1);
INSERT INTO favorites VALUES (3745, 43, 2);
INSERT INTO favorites VALUES (3746, 31, 5);
INSERT INTO favorites VALUES (3746, 60, 2);
INSERT INTO favorites VALUES (3746, 31, 1);
INSERT INTO favorites VALUES (3746, 2, 4);
INSERT INTO favorites VALUES (3746, 66, 3);
INSERT INTO favorites VALUES (3747, 57, 3);
INSERT INTO favorites VALUES (3747, 22, 1);
INSERT INTO favorites VALUES (3747, 23, 2);
INSERT INTO favorites VALUES (3748, 59, 1);
INSERT INTO favorites VALUES (3749, 49, 3);
INSERT INTO favorites VALUES (3749, 72, 2);
INSERT INTO favorites VALUES (3749, 77, 1);
INSERT INTO favorites VALUES (3750, 76, 4);
INSERT INTO favorites VALUES (3750, 85, 5);
INSERT INTO favorites VALUES (3750, 71, 1);
INSERT INTO favorites VALUES (3750, 20, 2);
INSERT INTO favorites VALUES (3750, 36, 3);
INSERT INTO favorites VALUES (3751, 7, 2);
INSERT INTO favorites VALUES (3751, 59, 1);
INSERT INTO favorites VALUES (3751, 47, 3);
INSERT INTO favorites VALUES (3752, 48, 4);
INSERT INTO favorites VALUES (3752, 27, 1);
INSERT INTO favorites VALUES (3752, 24, 2);
INSERT INTO favorites VALUES (3752, 6, 3);
INSERT INTO favorites VALUES (3753, 16, 4);
INSERT INTO favorites VALUES (3753, 40, 2);
INSERT INTO favorites VALUES (3753, 12, 1);
INSERT INTO favorites VALUES (3753, 18, 3);
INSERT INTO favorites VALUES (3754, 114, 5);
INSERT INTO favorites VALUES (3754, 29, 4);
INSERT INTO favorites VALUES (3754, 44, 2);
INSERT INTO favorites VALUES (3754, 60, 1);
INSERT INTO favorites VALUES (3754, 116, 3);
INSERT INTO favorites VALUES (3756, 4, 1);
INSERT INTO favorites VALUES (3757, 3, 1);
INSERT INTO favorites VALUES (3758, 79, 4);
INSERT INTO favorites VALUES (3758, 78, 3);
INSERT INTO favorites VALUES (3758, 115, 1);
INSERT INTO favorites VALUES (3758, 96, 2);
INSERT INTO favorites VALUES (3759, 47, 1);
INSERT INTO favorites VALUES (3761, 9, 1);
INSERT INTO favorites VALUES (3762, 26, 4);
INSERT INTO favorites VALUES (3762, 61, 5);
INSERT INTO favorites VALUES (3762, 82, 1);
INSERT INTO favorites VALUES (3762, 33, 3);
INSERT INTO favorites VALUES (3762, 3, 2);
INSERT INTO favorites VALUES (3764, 53, 3);
INSERT INTO favorites VALUES (3764, 73, 1);
INSERT INTO favorites VALUES (3764, 8, 2);
INSERT INTO favorites VALUES (3764, 114, 4);
INSERT INTO favorites VALUES (3765, 23, 3);
INSERT INTO favorites VALUES (3765, 81, 1);
INSERT INTO favorites VALUES (3765, 47, 2);
INSERT INTO favorites VALUES (3766, 68, 1);
INSERT INTO favorites VALUES (3766, 38, 2);
INSERT INTO favorites VALUES (3767, 20, 1);
INSERT INTO favorites VALUES (3768, 78, 2);
INSERT INTO favorites VALUES (3768, 68, 1);
INSERT INTO favorites VALUES (3768, 17, 3);
INSERT INTO favorites VALUES (3769, 11, 1);
INSERT INTO favorites VALUES (3769, 109, 2);
INSERT INTO favorites VALUES (3770, 92, 1);
INSERT INTO favorites VALUES (3770, 52, 2);
INSERT INTO favorites VALUES (3771, 3, 4);
INSERT INTO favorites VALUES (3771, 40, 2);
INSERT INTO favorites VALUES (3771, 37, 1);
INSERT INTO favorites VALUES (3771, 8, 3);
INSERT INTO favorites VALUES (3772, 24, 1);
INSERT INTO favorites VALUES (3773, 73, 3);
INSERT INTO favorites VALUES (3773, 15, 1);
INSERT INTO favorites VALUES (3773, 105, 2);
INSERT INTO favorites VALUES (3773, 8, 4);
INSERT INTO favorites VALUES (3774, 33, 1);
INSERT INTO favorites VALUES (3774, 49, 2);
INSERT INTO favorites VALUES (3775, 47, 1);
INSERT INTO favorites VALUES (3775, 8, 2);
INSERT INTO favorites VALUES (3776, 71, 2);
INSERT INTO favorites VALUES (3776, 75, 1);
INSERT INTO favorites VALUES (3778, 95, 1);
INSERT INTO favorites VALUES (3778, 90, 2);
INSERT INTO favorites VALUES (3779, 95, 3);
INSERT INTO favorites VALUES (3779, 110, 1);
INSERT INTO favorites VALUES (3779, 88, 2);
INSERT INTO favorites VALUES (3780, 72, 1);
INSERT INTO favorites VALUES (3780, 51, 2);
INSERT INTO favorites VALUES (3781, 116, 1);
INSERT INTO favorites VALUES (3781, 94, 2);
INSERT INTO favorites VALUES (3782, 96, 1);
INSERT INTO favorites VALUES (3783, 98, 1);
INSERT INTO favorites VALUES (3783, 41, 2);
INSERT INTO favorites VALUES (3784, 21, 1);
INSERT INTO favorites VALUES (3785, 12, 3);
INSERT INTO favorites VALUES (3785, 33, 2);
INSERT INTO favorites VALUES (3785, 55, 1);
INSERT INTO favorites VALUES (3786, 21, 1);
INSERT INTO favorites VALUES (3786, 31, 2);
INSERT INTO favorites VALUES (3787, 98, 1);
INSERT INTO favorites VALUES (3787, 30, 2);
INSERT INTO favorites VALUES (3788, 60, 1);
INSERT INTO favorites VALUES (3790, 56, 1);
INSERT INTO favorites VALUES (3790, 32, 2);
INSERT INTO favorites VALUES (3791, 7, 1);
INSERT INTO favorites VALUES (3792, 85, 4);
INSERT INTO favorites VALUES (3792, 30, 3);
INSERT INTO favorites VALUES (3792, 2, 1);
INSERT INTO favorites VALUES (3792, 64, 2);
INSERT INTO favorites VALUES (3793, 45, 3);
INSERT INTO favorites VALUES (3793, 67, 2);
INSERT INTO favorites VALUES (3793, 98, 1);
INSERT INTO favorites VALUES (3794, 33, 1);
INSERT INTO favorites VALUES (3794, 113, 2);
INSERT INTO favorites VALUES (3795, 23, 4);
INSERT INTO favorites VALUES (3795, 59, 1);
INSERT INTO favorites VALUES (3795, 76, 2);
INSERT INTO favorites VALUES (3795, 48, 3);
INSERT INTO favorites VALUES (3796, 10, 3);
INSERT INTO favorites VALUES (3796, 90, 4);
INSERT INTO favorites VALUES (3796, 31, 2);
INSERT INTO favorites VALUES (3796, 10, 1);
INSERT INTO favorites VALUES (3796, 56, 5);
INSERT INTO favorites VALUES (3797, 111, 4);
INSERT INTO favorites VALUES (3797, 90, 2);
INSERT INTO favorites VALUES (3797, 104, 1);
INSERT INTO favorites VALUES (3797, 28, 3);
INSERT INTO favorites VALUES (3798, 72, 5);
INSERT INTO favorites VALUES (3798, 26, 2);
INSERT INTO favorites VALUES (3798, 16, 1);
INSERT INTO favorites VALUES (3798, 24, 4);
INSERT INTO favorites VALUES (3798, 54, 3);
INSERT INTO favorites VALUES (3799, 12, 3);
INSERT INTO favorites VALUES (3799, 26, 1);
INSERT INTO favorites VALUES (3799, 101, 2);
INSERT INTO favorites VALUES (3800, 109, 1);
INSERT INTO favorites VALUES (3800, 10, 2);
INSERT INTO favorites VALUES (3800, 65, 3);
INSERT INTO favorites VALUES (3800, 55, 4);
INSERT INTO favorites VALUES (3801, 82, 2);
INSERT INTO favorites VALUES (3801, 49, 1);
INSERT INTO favorites VALUES (3801, 34, 4);
INSERT INTO favorites VALUES (3801, 111, 3);
INSERT INTO favorites VALUES (3802, 22, 1);
INSERT INTO favorites VALUES (3802, 116, 2);
INSERT INTO favorites VALUES (3803, 15, 3);
INSERT INTO favorites VALUES (3803, 80, 1);
INSERT INTO favorites VALUES (3803, 76, 2);
INSERT INTO favorites VALUES (3804, 70, 3);
INSERT INTO favorites VALUES (3804, 108, 1);
INSERT INTO favorites VALUES (3804, 69, 2);
INSERT INTO favorites VALUES (3806, 101, 1);
INSERT INTO favorites VALUES (3806, 45, 2);
INSERT INTO favorites VALUES (3807, 18, 3);
INSERT INTO favorites VALUES (3807, 13, 1);
INSERT INTO favorites VALUES (3807, 34, 2);
INSERT INTO favorites VALUES (3808, 63, 1);
INSERT INTO favorites VALUES (3810, 13, 4);
INSERT INTO favorites VALUES (3810, 7, 5);
INSERT INTO favorites VALUES (3810, 42, 1);
INSERT INTO favorites VALUES (3810, 23, 3);
INSERT INTO favorites VALUES (3810, 96, 2);
INSERT INTO favorites VALUES (3810, 50, 6);
INSERT INTO favorites VALUES (3811, 71, 1);
INSERT INTO favorites VALUES (3811, 23, 2);
INSERT INTO favorites VALUES (3812, 83, 2);
INSERT INTO favorites VALUES (3812, 114, 1);
INSERT INTO favorites VALUES (3813, 15, 1);
INSERT INTO favorites VALUES (3813, 7, 3);
INSERT INTO favorites VALUES (3813, 58, 2);
INSERT INTO favorites VALUES (3814, 61, 2);
INSERT INTO favorites VALUES (3814, 27, 1);
INSERT INTO favorites VALUES (3815, 16, 2);
INSERT INTO favorites VALUES (3815, 46, 1);
INSERT INTO favorites VALUES (3815, 49, 4);
INSERT INTO favorites VALUES (3815, 34, 3);
INSERT INTO favorites VALUES (3816, 96, 3);
INSERT INTO favorites VALUES (3816, 89, 1);
INSERT INTO favorites VALUES (3816, 80, 2);
INSERT INTO favorites VALUES (3817, 51, 4);
INSERT INTO favorites VALUES (3817, 113, 2);
INSERT INTO favorites VALUES (3817, 20, 1);
INSERT INTO favorites VALUES (3817, 115, 3);
INSERT INTO favorites VALUES (3818, 36, 2);
INSERT INTO favorites VALUES (3818, 30, 1);
INSERT INTO favorites VALUES (3819, 83, 3);
INSERT INTO favorites VALUES (3819, 16, 1);
INSERT INTO favorites VALUES (3819, 47, 2);
INSERT INTO favorites VALUES (3819, 11, 4);
INSERT INTO favorites VALUES (3820, 44, 3);
INSERT INTO favorites VALUES (3820, 69, 1);
INSERT INTO favorites VALUES (3820, 116, 2);
INSERT INTO favorites VALUES (3821, 26, 3);
INSERT INTO favorites VALUES (3821, 30, 1);
INSERT INTO favorites VALUES (3821, 13, 2);
INSERT INTO favorites VALUES (3822, 33, 1);
INSERT INTO favorites VALUES (3822, 43, 2);
INSERT INTO favorites VALUES (3823, 49, 4);
INSERT INTO favorites VALUES (3823, 2, 1);
INSERT INTO favorites VALUES (3823, 26, 2);
INSERT INTO favorites VALUES (3823, 50, 3);
INSERT INTO favorites VALUES (3824, 10, 1);
INSERT INTO favorites VALUES (3824, 3, 2);
INSERT INTO favorites VALUES (3825, 1, 1);
INSERT INTO favorites VALUES (3825, 44, 2);
INSERT INTO favorites VALUES (3826, 34, 1);
INSERT INTO favorites VALUES (3826, 24, 4);
INSERT INTO favorites VALUES (3826, 73, 3);
INSERT INTO favorites VALUES (3826, 11, 2);
INSERT INTO favorites VALUES (3827, 99, 5);
INSERT INTO favorites VALUES (3827, 34, 6);
INSERT INTO favorites VALUES (3827, 35, 1);
INSERT INTO favorites VALUES (3827, 40, 3);
INSERT INTO favorites VALUES (3827, 66, 4);
INSERT INTO favorites VALUES (3827, 2, 2);
INSERT INTO favorites VALUES (3829, 20, 1);
INSERT INTO favorites VALUES (3829, 24, 2);
INSERT INTO favorites VALUES (3830, 26, 1);
INSERT INTO favorites VALUES (3830, 21, 2);
INSERT INTO favorites VALUES (3831, 85, 1);
INSERT INTO favorites VALUES (3831, 70, 2);
INSERT INTO favorites VALUES (3832, 56, 1);
INSERT INTO favorites VALUES (3832, 52, 2);
INSERT INTO favorites VALUES (3833, 54, 4);
INSERT INTO favorites VALUES (3833, 72, 3);
INSERT INTO favorites VALUES (3833, 10, 2);
INSERT INTO favorites VALUES (3833, 66, 1);
INSERT INTO favorites VALUES (3834, 44, 5);
INSERT INTO favorites VALUES (3834, 104, 3);
INSERT INTO favorites VALUES (3834, 57, 1);
INSERT INTO favorites VALUES (3834, 92, 2);
INSERT INTO favorites VALUES (3834, 5, 4);
INSERT INTO favorites VALUES (3835, 19, 4);
INSERT INTO favorites VALUES (3835, 31, 1);
INSERT INTO favorites VALUES (3835, 35, 2);
INSERT INTO favorites VALUES (3835, 64, 3);
INSERT INTO favorites VALUES (3836, 109, 3);
INSERT INTO favorites VALUES (3836, 35, 2);
INSERT INTO favorites VALUES (3836, 26, 1);
INSERT INTO favorites VALUES (3837, 17, 1);
INSERT INTO favorites VALUES (3837, 103, 2);
INSERT INTO favorites VALUES (3838, 20, 5);
INSERT INTO favorites VALUES (3838, 85, 6);
INSERT INTO favorites VALUES (3838, 21, 3);
INSERT INTO favorites VALUES (3838, 18, 2);
INSERT INTO favorites VALUES (3838, 37, 1);
INSERT INTO favorites VALUES (3838, 4, 4);
INSERT INTO favorites VALUES (3839, 106, 3);
INSERT INTO favorites VALUES (3839, 55, 1);
INSERT INTO favorites VALUES (3839, 16, 2);
INSERT INTO favorites VALUES (3839, 40, 4);
INSERT INTO favorites VALUES (3840, 53, 4);
INSERT INTO favorites VALUES (3840, 7, 2);
INSERT INTO favorites VALUES (3840, 61, 1);
INSERT INTO favorites VALUES (3840, 12, 3);
INSERT INTO favorites VALUES (3841, 43, 1);
INSERT INTO favorites VALUES (3842, 106, 3);
INSERT INTO favorites VALUES (3842, 19, 1);
INSERT INTO favorites VALUES (3842, 86, 2);
INSERT INTO favorites VALUES (3842, 4, 4);
INSERT INTO favorites VALUES (3843, 5, 3);
INSERT INTO favorites VALUES (3843, 78, 1);
INSERT INTO favorites VALUES (3843, 23, 2);
INSERT INTO favorites VALUES (3844, 27, 1);
INSERT INTO favorites VALUES (3844, 102, 2);
INSERT INTO favorites VALUES (3845, 62, 1);
INSERT INTO favorites VALUES (3846, 60, 4);
INSERT INTO favorites VALUES (3846, 8, 5);
INSERT INTO favorites VALUES (3846, 37, 1);
INSERT INTO favorites VALUES (3846, 13, 2);
INSERT INTO favorites VALUES (3846, 36, 3);
INSERT INTO favorites VALUES (3847, 96, 1);
INSERT INTO favorites VALUES (3848, 8, 1);
INSERT INTO favorites VALUES (3848, 37, 2);
INSERT INTO favorites VALUES (3849, 6, 1);
INSERT INTO favorites VALUES (3849, 41, 2);
INSERT INTO favorites VALUES (3850, 101, 2);
INSERT INTO favorites VALUES (3850, 27, 1);
INSERT INTO favorites VALUES (3851, 95, 5);
INSERT INTO favorites VALUES (3851, 76, 4);
INSERT INTO favorites VALUES (3851, 81, 2);
INSERT INTO favorites VALUES (3851, 11, 1);
INSERT INTO favorites VALUES (3851, 13, 3);
INSERT INTO favorites VALUES (3852, 39, 1);
INSERT INTO favorites VALUES (3852, 51, 2);
INSERT INTO favorites VALUES (3853, 2, 2);
INSERT INTO favorites VALUES (3853, 68, 1);
INSERT INTO favorites VALUES (3854, 68, 2);
INSERT INTO favorites VALUES (3854, 76, 1);
INSERT INTO favorites VALUES (3855, 37, 1);
INSERT INTO favorites VALUES (3855, 63, 2);
INSERT INTO favorites VALUES (3856, 55, 2);
INSERT INTO favorites VALUES (3856, 28, 1);
INSERT INTO favorites VALUES (3857, 71, 1);
INSERT INTO favorites VALUES (3857, 45, 2);
INSERT INTO favorites VALUES (3858, 55, 3);
INSERT INTO favorites VALUES (3858, 43, 2);
INSERT INTO favorites VALUES (3858, 74, 1);
INSERT INTO favorites VALUES (3859, 22, 5);
INSERT INTO favorites VALUES (3859, 62, 7);
INSERT INTO favorites VALUES (3859, 7, 8);
INSERT INTO favorites VALUES (3859, 11, 2);
INSERT INTO favorites VALUES (3859, 47, 3);
INSERT INTO favorites VALUES (3859, 86, 4);
INSERT INTO favorites VALUES (3859, 2, 1);
INSERT INTO favorites VALUES (3859, 101, 6);
INSERT INTO favorites VALUES (3861, 95, 1);
INSERT INTO favorites VALUES (3861, 32, 2);
INSERT INTO favorites VALUES (3862, 92, 3);
INSERT INTO favorites VALUES (3862, 9, 2);
INSERT INTO favorites VALUES (3862, 35, 1);
INSERT INTO favorites VALUES (3863, 24, 3);
INSERT INTO favorites VALUES (3863, 110, 1);
INSERT INTO favorites VALUES (3863, 6, 2);
INSERT INTO favorites VALUES (3863, 10, 4);
INSERT INTO favorites VALUES (3864, 47, 4);
INSERT INTO favorites VALUES (3864, 27, 1);
INSERT INTO favorites VALUES (3864, 79, 2);
INSERT INTO favorites VALUES (3864, 25, 3);
INSERT INTO favorites VALUES (3865, 22, 1);
INSERT INTO favorites VALUES (3865, 40, 2);
INSERT INTO favorites VALUES (3866, 86, 2);
INSERT INTO favorites VALUES (3866, 24, 1);
INSERT INTO favorites VALUES (3866, 36, 3);
INSERT INTO favorites VALUES (3867, 105, 2);
INSERT INTO favorites VALUES (3867, 25, 1);
INSERT INTO favorites VALUES (3867, 61, 3);
INSERT INTO favorites VALUES (3868, 105, 3);
INSERT INTO favorites VALUES (3868, 61, 1);
INSERT INTO favorites VALUES (3868, 2, 2);
INSERT INTO favorites VALUES (3869, 25, 3);
INSERT INTO favorites VALUES (3869, 70, 2);
INSERT INTO favorites VALUES (3869, 21, 1);
INSERT INTO favorites VALUES (3870, 6, 2);
INSERT INTO favorites VALUES (3870, 17, 1);
INSERT INTO favorites VALUES (3870, 71, 3);
INSERT INTO favorites VALUES (3871, 54, 3);
INSERT INTO favorites VALUES (3871, 76, 1);
INSERT INTO favorites VALUES (3871, 7, 2);
INSERT INTO favorites VALUES (3872, 40, 1);
INSERT INTO favorites VALUES (3873, 103, 2);
INSERT INTO favorites VALUES (3873, 42, 1);
INSERT INTO favorites VALUES (3873, 113, 3);
INSERT INTO favorites VALUES (3875, 4, 5);
INSERT INTO favorites VALUES (3875, 9, 4);
INSERT INTO favorites VALUES (3875, 86, 1);
INSERT INTO favorites VALUES (3875, 17, 3);
INSERT INTO favorites VALUES (3875, 10, 2);
INSERT INTO favorites VALUES (3876, 51, 3);
INSERT INTO favorites VALUES (3876, 39, 1);
INSERT INTO favorites VALUES (3876, 98, 2);
INSERT INTO favorites VALUES (3877, 107, 1);
INSERT INTO favorites VALUES (3877, 15, 2);
INSERT INTO favorites VALUES (3878, 18, 3);
INSERT INTO favorites VALUES (3878, 71, 2);
INSERT INTO favorites VALUES (3878, 35, 1);
INSERT INTO favorites VALUES (3878, 5, 4);
INSERT INTO favorites VALUES (3879, 61, 5);
INSERT INTO favorites VALUES (3879, 12, 3);
INSERT INTO favorites VALUES (3879, 2, 1);
INSERT INTO favorites VALUES (3879, 55, 2);
INSERT INTO favorites VALUES (3879, 88, 4);
INSERT INTO favorites VALUES (3880, 95, 3);
INSERT INTO favorites VALUES (3880, 73, 2);
INSERT INTO favorites VALUES (3880, 38, 1);
INSERT INTO favorites VALUES (3882, 24, 2);
INSERT INTO favorites VALUES (3882, 89, 1);
INSERT INTO favorites VALUES (3883, 58, 1);
INSERT INTO favorites VALUES (3883, 31, 2);
INSERT INTO favorites VALUES (3884, 57, 1);
INSERT INTO favorites VALUES (3885, 103, 4);
INSERT INTO favorites VALUES (3885, 98, 1);
INSERT INTO favorites VALUES (3885, 44, 2);
INSERT INTO favorites VALUES (3885, 110, 3);
INSERT INTO favorites VALUES (3886, 96, 1);
INSERT INTO favorites VALUES (3887, 95, 4);
INSERT INTO favorites VALUES (3887, 28, 1);
INSERT INTO favorites VALUES (3887, 22, 3);
INSERT INTO favorites VALUES (3887, 35, 2);
INSERT INTO favorites VALUES (3888, 57, 2);
INSERT INTO favorites VALUES (3888, 32, 1);
INSERT INTO favorites VALUES (3888, 67, 3);
INSERT INTO favorites VALUES (3889, 96, 1);
INSERT INTO favorites VALUES (3889, 51, 2);
INSERT INTO favorites VALUES (3890, 97, 2);
INSERT INTO favorites VALUES (3890, 105, 1);
INSERT INTO favorites VALUES (3891, 90, 3);
INSERT INTO favorites VALUES (3891, 33, 5);
INSERT INTO favorites VALUES (3891, 109, 1);
INSERT INTO favorites VALUES (3891, 33, 2);
INSERT INTO favorites VALUES (3891, 49, 4);
INSERT INTO favorites VALUES (3892, 24, 2);
INSERT INTO favorites VALUES (3892, 62, 1);
INSERT INTO favorites VALUES (3892, 23, 3);
INSERT INTO favorites VALUES (3893, 42, 5);
INSERT INTO favorites VALUES (3893, 19, 4);
INSERT INTO favorites VALUES (3893, 11, 1);
INSERT INTO favorites VALUES (3893, 83, 3);
INSERT INTO favorites VALUES (3893, 50, 2);
INSERT INTO favorites VALUES (3894, 2, 4);
INSERT INTO favorites VALUES (3894, 10, 5);
INSERT INTO favorites VALUES (3894, 68, 1);
INSERT INTO favorites VALUES (3894, 42, 2);
INSERT INTO favorites VALUES (3894, 85, 3);
INSERT INTO favorites VALUES (3895, 79, 1);
INSERT INTO favorites VALUES (3896, 20, 3);
INSERT INTO favorites VALUES (3896, 30, 1);
INSERT INTO favorites VALUES (3896, 18, 2);
INSERT INTO favorites VALUES (3897, 96, 3);
INSERT INTO favorites VALUES (3897, 9, 1);
INSERT INTO favorites VALUES (3897, 73, 2);
INSERT INTO favorites VALUES (3897, 16, 4);
INSERT INTO favorites VALUES (3898, 25, 1);
INSERT INTO favorites VALUES (3898, 74, 2);
INSERT INTO favorites VALUES (3899, 97, 3);
INSERT INTO favorites VALUES (3899, 29, 1);
INSERT INTO favorites VALUES (3899, 6, 2);
INSERT INTO favorites VALUES (3900, 12, 1);
INSERT INTO favorites VALUES (3902, 25, 1);
INSERT INTO favorites VALUES (3903, 18, 1);
INSERT INTO favorites VALUES (3903, 102, 2);
INSERT INTO favorites VALUES (3904, 71, 4);
INSERT INTO favorites VALUES (3904, 57, 3);
INSERT INTO favorites VALUES (3904, 92, 1);
INSERT INTO favorites VALUES (3904, 74, 2);
INSERT INTO favorites VALUES (3905, 92, 2);
INSERT INTO favorites VALUES (3905, 87, 3);
INSERT INTO favorites VALUES (3905, 10, 1);
INSERT INTO favorites VALUES (3906, 6, 5);
INSERT INTO favorites VALUES (3906, 63, 4);
INSERT INTO favorites VALUES (3906, 57, 1);
INSERT INTO favorites VALUES (3906, 33, 3);
INSERT INTO favorites VALUES (3906, 13, 2);
INSERT INTO favorites VALUES (3907, 33, 5);
INSERT INTO favorites VALUES (3907, 75, 4);
INSERT INTO favorites VALUES (3907, 37, 1);
INSERT INTO favorites VALUES (3907, 98, 2);
INSERT INTO favorites VALUES (3907, 64, 3);
INSERT INTO favorites VALUES (3908, 11, 2);
INSERT INTO favorites VALUES (3908, 96, 1);
INSERT INTO favorites VALUES (3908, 43, 3);
INSERT INTO favorites VALUES (3909, 79, 1);
INSERT INTO favorites VALUES (3910, 17, 1);
INSERT INTO favorites VALUES (3910, 45, 2);
INSERT INTO favorites VALUES (3912, 86, 4);
INSERT INTO favorites VALUES (3912, 115, 5);
INSERT INTO favorites VALUES (3912, 115, 1);
INSERT INTO favorites VALUES (3912, 105, 2);
INSERT INTO favorites VALUES (3912, 15, 3);
INSERT INTO favorites VALUES (3913, 43, 1);
INSERT INTO favorites VALUES (3913, 19, 2);
INSERT INTO favorites VALUES (3914, 65, 2);
INSERT INTO favorites VALUES (3914, 94, 1);
INSERT INTO favorites VALUES (3915, 87, 5);
INSERT INTO favorites VALUES (3915, 115, 4);
INSERT INTO favorites VALUES (3915, 47, 1);
INSERT INTO favorites VALUES (3915, 82, 2);
INSERT INTO favorites VALUES (3915, 60, 3);
INSERT INTO favorites VALUES (3916, 8, 2);
INSERT INTO favorites VALUES (3916, 19, 1);
INSERT INTO favorites VALUES (3918, 64, 4);
INSERT INTO favorites VALUES (3918, 26, 5);
INSERT INTO favorites VALUES (3918, 12, 2);
INSERT INTO favorites VALUES (3918, 42, 1);
INSERT INTO favorites VALUES (3918, 90, 3);
INSERT INTO favorites VALUES (3919, 24, 2);
INSERT INTO favorites VALUES (3919, 90, 1);
INSERT INTO favorites VALUES (3919, 21, 3);
INSERT INTO favorites VALUES (3920, 84, 1);
INSERT INTO favorites VALUES (3920, 56, 2);
INSERT INTO favorites VALUES (3921, 103, 4);
INSERT INTO favorites VALUES (3921, 84, 1);
INSERT INTO favorites VALUES (3921, 100, 2);
INSERT INTO favorites VALUES (3921, 58, 3);
INSERT INTO favorites VALUES (3922, 72, 1);
INSERT INTO favorites VALUES (3922, 112, 2);
INSERT INTO favorites VALUES (3923, 41, 1);
INSERT INTO favorites VALUES (3923, 70, 2);
INSERT INTO favorites VALUES (3924, 77, 5);
INSERT INTO favorites VALUES (3924, 6, 3);
INSERT INTO favorites VALUES (3924, 8, 2);
INSERT INTO favorites VALUES (3924, 96, 1);
INSERT INTO favorites VALUES (3924, 15, 4);
INSERT INTO favorites VALUES (3925, 20, 1);
INSERT INTO favorites VALUES (3925, 82, 2);
INSERT INTO favorites VALUES (3927, 116, 3);
INSERT INTO favorites VALUES (3927, 7, 1);
INSERT INTO favorites VALUES (3927, 23, 2);
INSERT INTO favorites VALUES (3929, 69, 2);
INSERT INTO favorites VALUES (3929, 82, 1);
INSERT INTO favorites VALUES (3930, 43, 2);
INSERT INTO favorites VALUES (3930, 16, 1);
INSERT INTO favorites VALUES (3931, 104, 1);
INSERT INTO favorites VALUES (3931, 43, 2);
INSERT INTO favorites VALUES (3932, 106, 6);
INSERT INTO favorites VALUES (3932, 79, 7);
INSERT INTO favorites VALUES (3932, 31, 8);
INSERT INTO favorites VALUES (3932, 19, 5);
INSERT INTO favorites VALUES (3932, 90, 2);
INSERT INTO favorites VALUES (3932, 69, 1);
INSERT INTO favorites VALUES (3932, 8, 4);
INSERT INTO favorites VALUES (3932, 57, 3);
INSERT INTO favorites VALUES (3933, 10, 1);
INSERT INTO favorites VALUES (3933, 11, 2);
INSERT INTO favorites VALUES (3934, 62, 1);
INSERT INTO favorites VALUES (3934, 55, 2);
INSERT INTO favorites VALUES (3935, 18, 2);
INSERT INTO favorites VALUES (3935, 72, 1);
INSERT INTO favorites VALUES (3935, 31, 3);
INSERT INTO favorites VALUES (3936, 86, 4);
INSERT INTO favorites VALUES (3936, 96, 3);
INSERT INTO favorites VALUES (3936, 54, 2);
INSERT INTO favorites VALUES (3936, 60, 1);
INSERT INTO favorites VALUES (3937, 44, 7);
INSERT INTO favorites VALUES (3937, 63, 6);
INSERT INTO favorites VALUES (3937, 47, 5);
INSERT INTO favorites VALUES (3937, 79, 3);
INSERT INTO favorites VALUES (3937, 95, 1);
INSERT INTO favorites VALUES (3937, 77, 2);
INSERT INTO favorites VALUES (3937, 7, 4);
INSERT INTO favorites VALUES (3938, 104, 2);
INSERT INTO favorites VALUES (3938, 85, 1);
INSERT INTO favorites VALUES (3939, 61, 1);
INSERT INTO favorites VALUES (3939, 61, 2);
INSERT INTO favorites VALUES (3940, 54, 3);
INSERT INTO favorites VALUES (3940, 32, 1);
INSERT INTO favorites VALUES (3940, 107, 2);
INSERT INTO favorites VALUES (3941, 89, 1);
INSERT INTO favorites VALUES (3941, 11, 2);
INSERT INTO favorites VALUES (3942, 27, 2);
INSERT INTO favorites VALUES (3942, 47, 1);
INSERT INTO favorites VALUES (3942, 96, 3);
INSERT INTO favorites VALUES (3944, 57, 2);
INSERT INTO favorites VALUES (3944, 60, 1);
INSERT INTO favorites VALUES (3944, 64, 4);
INSERT INTO favorites VALUES (3944, 95, 3);
INSERT INTO favorites VALUES (3945, 7, 5);
INSERT INTO favorites VALUES (3945, 61, 2);
INSERT INTO favorites VALUES (3945, 2, 1);
INSERT INTO favorites VALUES (3945, 108, 4);
INSERT INTO favorites VALUES (3945, 4, 3);
INSERT INTO favorites VALUES (3947, 116, 1);
INSERT INTO favorites VALUES (3947, 25, 2);
INSERT INTO favorites VALUES (3948, 65, 3);
INSERT INTO favorites VALUES (3948, 2, 1);
INSERT INTO favorites VALUES (3948, 88, 2);
INSERT INTO favorites VALUES (3948, 67, 4);
INSERT INTO favorites VALUES (3949, 17, 1);
INSERT INTO favorites VALUES (3950, 84, 1);
INSERT INTO favorites VALUES (3951, 27, 1);
INSERT INTO favorites VALUES (3952, 24, 1);
INSERT INTO favorites VALUES (3952, 7, 2);
INSERT INTO favorites VALUES (3953, 42, 6);
INSERT INTO favorites VALUES (3953, 72, 5);
INSERT INTO favorites VALUES (3953, 12, 1);
INSERT INTO favorites VALUES (3953, 20, 3);
INSERT INTO favorites VALUES (3953, 91, 2);
INSERT INTO favorites VALUES (3953, 75, 4);
INSERT INTO favorites VALUES (3954, 4, 1);
INSERT INTO favorites VALUES (3955, 71, 1);
INSERT INTO favorites VALUES (3956, 53, 2);
INSERT INTO favorites VALUES (3956, 97, 3);
INSERT INTO favorites VALUES (3956, 19, 1);
INSERT INTO favorites VALUES (3956, 96, 5);
INSERT INTO favorites VALUES (3956, 108, 4);
INSERT INTO favorites VALUES (3957, 43, 4);
INSERT INTO favorites VALUES (3957, 21, 2);
INSERT INTO favorites VALUES (3957, 48, 1);
INSERT INTO favorites VALUES (3957, 114, 3);
INSERT INTO favorites VALUES (3958, 65, 4);
INSERT INTO favorites VALUES (3958, 28, 1);
INSERT INTO favorites VALUES (3958, 75, 2);
INSERT INTO favorites VALUES (3958, 85, 3);
INSERT INTO favorites VALUES (3959, 106, 1);
INSERT INTO favorites VALUES (3959, 104, 2);
INSERT INTO favorites VALUES (3960, 20, 1);
INSERT INTO favorites VALUES (3961, 5, 4);
INSERT INTO favorites VALUES (3961, 8, 1);
INSERT INTO favorites VALUES (3961, 58, 2);
INSERT INTO favorites VALUES (3961, 33, 3);
INSERT INTO favorites VALUES (3965, 7, 4);
INSERT INTO favorites VALUES (3965, 106, 1);
INSERT INTO favorites VALUES (3965, 60, 2);
INSERT INTO favorites VALUES (3965, 42, 3);
INSERT INTO favorites VALUES (3966, 43, 3);
INSERT INTO favorites VALUES (3966, 88, 2);
INSERT INTO favorites VALUES (3966, 60, 1);
INSERT INTO favorites VALUES (3966, 8, 4);
INSERT INTO favorites VALUES (3967, 59, 3);
INSERT INTO favorites VALUES (3967, 69, 2);
INSERT INTO favorites VALUES (3967, 97, 1);
INSERT INTO favorites VALUES (3967, 73, 4);
INSERT INTO favorites VALUES (3968, 96, 1);
INSERT INTO favorites VALUES (3968, 81, 2);
INSERT INTO favorites VALUES (3969, 23, 1);
INSERT INTO favorites VALUES (3969, 99, 2);
INSERT INTO favorites VALUES (3970, 102, 3);
INSERT INTO favorites VALUES (3970, 43, 1);
INSERT INTO favorites VALUES (3970, 96, 2);
INSERT INTO favorites VALUES (3972, 18, 3);
INSERT INTO favorites VALUES (3972, 25, 1);
INSERT INTO favorites VALUES (3972, 42, 2);
INSERT INTO favorites VALUES (3973, 52, 4);
INSERT INTO favorites VALUES (3973, 60, 5);
INSERT INTO favorites VALUES (3973, 99, 1);
INSERT INTO favorites VALUES (3973, 97, 2);
INSERT INTO favorites VALUES (3973, 60, 3);
INSERT INTO favorites VALUES (3975, 69, 5);
INSERT INTO favorites VALUES (3975, 59, 4);
INSERT INTO favorites VALUES (3975, 43, 1);
INSERT INTO favorites VALUES (3975, 45, 2);
INSERT INTO favorites VALUES (3975, 58, 3);
INSERT INTO favorites VALUES (3976, 51, 4);
INSERT INTO favorites VALUES (3976, 78, 1);
INSERT INTO favorites VALUES (3976, 17, 3);
INSERT INTO favorites VALUES (3976, 45, 2);
INSERT INTO favorites VALUES (3977, 53, 4);
INSERT INTO favorites VALUES (3977, 72, 6);
INSERT INTO favorites VALUES (3977, 71, 1);
INSERT INTO favorites VALUES (3977, 27, 2);
INSERT INTO favorites VALUES (3977, 40, 3);
INSERT INTO favorites VALUES (3977, 23, 5);
INSERT INTO favorites VALUES (3978, 97, 1);
INSERT INTO favorites VALUES (3978, 78, 2);
INSERT INTO favorites VALUES (3979, 27, 1);
INSERT INTO favorites VALUES (3980, 116, 3);
INSERT INTO favorites VALUES (3980, 87, 1);
INSERT INTO favorites VALUES (3980, 27, 2);
INSERT INTO favorites VALUES (3980, 107, 4);
INSERT INTO favorites VALUES (3981, 98, 1);
INSERT INTO favorites VALUES (3982, 23, 5);
INSERT INTO favorites VALUES (3982, 102, 4);
INSERT INTO favorites VALUES (3982, 71, 1);
INSERT INTO favorites VALUES (3982, 29, 3);
INSERT INTO favorites VALUES (3982, 86, 2);
INSERT INTO favorites VALUES (3983, 75, 1);
INSERT INTO favorites VALUES (3983, 30, 2);
INSERT INTO favorites VALUES (3984, 73, 1);
INSERT INTO favorites VALUES (3984, 29, 2);
INSERT INTO favorites VALUES (3985, 8, 2);
INSERT INTO favorites VALUES (3985, 28, 1);
INSERT INTO favorites VALUES (3985, 16, 4);
INSERT INTO favorites VALUES (3985, 73, 3);
INSERT INTO favorites VALUES (3986, 24, 4);
INSERT INTO favorites VALUES (3986, 11, 3);
INSERT INTO favorites VALUES (3986, 71, 2);
INSERT INTO favorites VALUES (3986, 92, 1);
INSERT INTO favorites VALUES (3987, 76, 4);
INSERT INTO favorites VALUES (3987, 70, 1);
INSERT INTO favorites VALUES (3987, 17, 2);
INSERT INTO favorites VALUES (3987, 58, 3);
INSERT INTO favorites VALUES (3988, 97, 3);
INSERT INTO favorites VALUES (3988, 30, 1);
INSERT INTO favorites VALUES (3988, 94, 2);
INSERT INTO favorites VALUES (3989, 94, 3);
INSERT INTO favorites VALUES (3989, 105, 1);
INSERT INTO favorites VALUES (3989, 40, 2);
INSERT INTO favorites VALUES (3990, 94, 3);
INSERT INTO favorites VALUES (3990, 20, 1);
INSERT INTO favorites VALUES (3990, 39, 2);
INSERT INTO favorites VALUES (3990, 53, 4);
INSERT INTO favorites VALUES (3991, 19, 4);
INSERT INTO favorites VALUES (3991, 78, 1);
INSERT INTO favorites VALUES (3991, 50, 2);
INSERT INTO favorites VALUES (3991, 57, 3);
INSERT INTO favorites VALUES (3992, 40, 4);
INSERT INTO favorites VALUES (3992, 104, 5);
INSERT INTO favorites VALUES (3992, 33, 1);
INSERT INTO favorites VALUES (3992, 47, 2);
INSERT INTO favorites VALUES (3992, 57, 3);
INSERT INTO favorites VALUES (3994, 17, 1);
INSERT INTO favorites VALUES (3994, 13, 2);
INSERT INTO favorites VALUES (3995, 71, 6);
INSERT INTO favorites VALUES (3995, 56, 4);
INSERT INTO favorites VALUES (3995, 14, 1);
INSERT INTO favorites VALUES (3995, 8, 2);
INSERT INTO favorites VALUES (3995, 50, 3);
INSERT INTO favorites VALUES (3995, 14, 5);
INSERT INTO favorites VALUES (3996, 34, 3);
INSERT INTO favorites VALUES (3996, 53, 1);
INSERT INTO favorites VALUES (3996, 24, 2);
INSERT INTO favorites VALUES (3997, 49, 1);
INSERT INTO favorites VALUES (3997, 3, 2);
INSERT INTO favorites VALUES (3998, 31, 2);
INSERT INTO favorites VALUES (3998, 91, 1);
INSERT INTO favorites VALUES (3998, 32, 4);
INSERT INTO favorites VALUES (3998, 78, 3);
INSERT INTO favorites VALUES (3999, 22, 1);
INSERT INTO favorites VALUES (4000, 8, 1);
INSERT INTO favorites VALUES (4000, 52, 2);
INSERT INTO favorites VALUES (4000, 37, 3);
INSERT INTO favorites VALUES (4001, 55, 2);
INSERT INTO favorites VALUES (4001, 115, 1);
INSERT INTO favorites VALUES (4001, 113, 4);
INSERT INTO favorites VALUES (4001, 20, 3);
INSERT INTO favorites VALUES (4002, 39, 4);
INSERT INTO favorites VALUES (4002, 49, 1);
INSERT INTO favorites VALUES (4002, 86, 3);
INSERT INTO favorites VALUES (4002, 86, 2);
INSERT INTO favorites VALUES (4003, 71, 1);
INSERT INTO favorites VALUES (4003, 98, 2);
INSERT INTO favorites VALUES (4004, 69, 1);
INSERT INTO favorites VALUES (4004, 4, 2);
INSERT INTO favorites VALUES (4005, 47, 3);
INSERT INTO favorites VALUES (4005, 2, 1);
INSERT INTO favorites VALUES (4005, 7, 2);
INSERT INTO favorites VALUES (4006, 104, 1);
INSERT INTO favorites VALUES (4007, 3, 4);
INSERT INTO favorites VALUES (4007, 60, 1);
INSERT INTO favorites VALUES (4007, 22, 3);
INSERT INTO favorites VALUES (4007, 4, 2);
INSERT INTO favorites VALUES (4008, 111, 6);
INSERT INTO favorites VALUES (4008, 26, 5);
INSERT INTO favorites VALUES (4008, 83, 1);
INSERT INTO favorites VALUES (4008, 86, 2);
INSERT INTO favorites VALUES (4008, 2, 3);
INSERT INTO favorites VALUES (4008, 5, 4);
INSERT INTO favorites VALUES (4009, 25, 3);
INSERT INTO favorites VALUES (4009, 99, 2);
INSERT INTO favorites VALUES (4009, 3, 1);
INSERT INTO favorites VALUES (4010, 107, 3);
INSERT INTO favorites VALUES (4010, 28, 2);
INSERT INTO favorites VALUES (4010, 10, 1);
INSERT INTO favorites VALUES (4011, 63, 3);
INSERT INTO favorites VALUES (4011, 89, 1);
INSERT INTO favorites VALUES (4011, 17, 2);
INSERT INTO favorites VALUES (4012, 66, 2);
INSERT INTO favorites VALUES (4012, 83, 1);
INSERT INTO favorites VALUES (4013, 72, 3);
INSERT INTO favorites VALUES (4013, 52, 1);
INSERT INTO favorites VALUES (4013, 17, 2);
INSERT INTO favorites VALUES (4014, 69, 3);
INSERT INTO favorites VALUES (4014, 55, 1);
INSERT INTO favorites VALUES (4014, 4, 2);
INSERT INTO favorites VALUES (4014, 4, 4);
INSERT INTO favorites VALUES (4015, 59, 3);
INSERT INTO favorites VALUES (4015, 116, 1);
INSERT INTO favorites VALUES (4015, 9, 2);
INSERT INTO favorites VALUES (4016, 40, 3);
INSERT INTO favorites VALUES (4016, 63, 1);
INSERT INTO favorites VALUES (4016, 62, 2);
INSERT INTO favorites VALUES (4017, 54, 5);
INSERT INTO favorites VALUES (4017, 41, 4);
INSERT INTO favorites VALUES (4017, 22, 2);
INSERT INTO favorites VALUES (4017, 67, 1);
INSERT INTO favorites VALUES (4017, 16, 3);
INSERT INTO favorites VALUES (4018, 43, 1);
INSERT INTO favorites VALUES (4019, 99, 4);
INSERT INTO favorites VALUES (4019, 40, 5);
INSERT INTO favorites VALUES (4019, 4, 1);
INSERT INTO favorites VALUES (4019, 44, 3);
INSERT INTO favorites VALUES (4019, 11, 2);
INSERT INTO favorites VALUES (4021, 70, 1);
INSERT INTO favorites VALUES (4022, 88, 7);
INSERT INTO favorites VALUES (4022, 1, 5);
INSERT INTO favorites VALUES (4022, 50, 6);
INSERT INTO favorites VALUES (4022, 69, 4);
INSERT INTO favorites VALUES (4022, 1, 2);
INSERT INTO favorites VALUES (4022, 1, 3);
INSERT INTO favorites VALUES (4022, 92, 1);
INSERT INTO favorites VALUES (4023, 22, 1);
INSERT INTO favorites VALUES (4023, 6, 4);
INSERT INTO favorites VALUES (4023, 82, 3);
INSERT INTO favorites VALUES (4023, 28, 2);
INSERT INTO favorites VALUES (4024, 12, 1);
INSERT INTO favorites VALUES (4025, 12, 4);
INSERT INTO favorites VALUES (4025, 41, 5);
INSERT INTO favorites VALUES (4025, 74, 3);
INSERT INTO favorites VALUES (4025, 5, 2);
INSERT INTO favorites VALUES (4025, 116, 1);
INSERT INTO favorites VALUES (4026, 108, 3);
INSERT INTO favorites VALUES (4026, 46, 1);
INSERT INTO favorites VALUES (4026, 66, 2);
INSERT INTO favorites VALUES (4027, 24, 2);
INSERT INTO favorites VALUES (4027, 35, 1);
INSERT INTO favorites VALUES (4027, 20, 3);
INSERT INTO favorites VALUES (4028, 3, 4);
INSERT INTO favorites VALUES (4028, 74, 1);
INSERT INTO favorites VALUES (4028, 95, 2);
INSERT INTO favorites VALUES (4028, 48, 3);
INSERT INTO favorites VALUES (4029, 4, 4);
INSERT INTO favorites VALUES (4029, 50, 1);
INSERT INTO favorites VALUES (4029, 43, 3);
INSERT INTO favorites VALUES (4029, 40, 2);
INSERT INTO favorites VALUES (4030, 57, 2);
INSERT INTO favorites VALUES (4030, 11, 1);
INSERT INTO favorites VALUES (4030, 43, 3);
INSERT INTO favorites VALUES (4031, 56, 1);
INSERT INTO favorites VALUES (4032, 6, 1);
INSERT INTO favorites VALUES (4032, 48, 2);
INSERT INTO favorites VALUES (4033, 15, 6);
INSERT INTO favorites VALUES (4033, 57, 4);
INSERT INTO favorites VALUES (4033, 54, 3);
INSERT INTO favorites VALUES (4033, 6, 1);
INSERT INTO favorites VALUES (4033, 21, 2);
INSERT INTO favorites VALUES (4033, 45, 5);
INSERT INTO favorites VALUES (4034, 1, 1);
INSERT INTO favorites VALUES (4034, 27, 2);
INSERT INTO favorites VALUES (4035, 60, 3);
INSERT INTO favorites VALUES (4035, 15, 1);
INSERT INTO favorites VALUES (4035, 30, 2);
INSERT INTO favorites VALUES (4035, 51, 4);
INSERT INTO favorites VALUES (4036, 74, 4);
INSERT INTO favorites VALUES (4036, 53, 1);
INSERT INTO favorites VALUES (4036, 4, 2);
INSERT INTO favorites VALUES (4036, 21, 3);
INSERT INTO favorites VALUES (4038, 4, 3);
INSERT INTO favorites VALUES (4038, 63, 2);
INSERT INTO favorites VALUES (4038, 29, 1);
INSERT INTO favorites VALUES (4039, 8, 1);
INSERT INTO favorites VALUES (4039, 2, 2);
INSERT INTO favorites VALUES (4040, 58, 1);
INSERT INTO favorites VALUES (4041, 90, 3);
INSERT INTO favorites VALUES (4041, 53, 1);
INSERT INTO favorites VALUES (4041, 34, 2);
INSERT INTO favorites VALUES (4042, 97, 1);
INSERT INTO favorites VALUES (4042, 86, 2);
INSERT INTO favorites VALUES (4043, 84, 5);
INSERT INTO favorites VALUES (4043, 70, 4);
INSERT INTO favorites VALUES (4043, 61, 1);
INSERT INTO favorites VALUES (4043, 47, 2);
INSERT INTO favorites VALUES (4043, 20, 3);
INSERT INTO favorites VALUES (4044, 75, 1);
INSERT INTO favorites VALUES (4044, 58, 2);
INSERT INTO favorites VALUES (4045, 82, 1);
INSERT INTO favorites VALUES (4046, 111, 1);
INSERT INTO favorites VALUES (4046, 110, 2);
INSERT INTO favorites VALUES (4046, 81, 3);
INSERT INTO favorites VALUES (4047, 23, 1);
INSERT INTO favorites VALUES (4048, 61, 2);
INSERT INTO favorites VALUES (4048, 72, 1);
INSERT INTO favorites VALUES (4048, 115, 3);
INSERT INTO favorites VALUES (4049, 107, 1);
INSERT INTO favorites VALUES (4050, 32, 1);
INSERT INTO favorites VALUES (4050, 19, 2);
INSERT INTO favorites VALUES (4051, 26, 2);
INSERT INTO favorites VALUES (4051, 1, 1);
INSERT INTO favorites VALUES (4051, 58, 3);
INSERT INTO favorites VALUES (4053, 9, 1);
INSERT INTO favorites VALUES (4053, 78, 2);
INSERT INTO favorites VALUES (4054, 73, 3);
INSERT INTO favorites VALUES (4054, 2, 1);
INSERT INTO favorites VALUES (4054, 85, 2);
INSERT INTO favorites VALUES (4055, 1, 2);
INSERT INTO favorites VALUES (4055, 57, 1);
INSERT INTO favorites VALUES (4055, 69, 3);
INSERT INTO favorites VALUES (4056, 55, 1);
INSERT INTO favorites VALUES (4057, 91, 5);
INSERT INTO favorites VALUES (4057, 116, 4);
INSERT INTO favorites VALUES (4057, 19, 1);
INSERT INTO favorites VALUES (4057, 2, 2);
INSERT INTO favorites VALUES (4057, 62, 3);
INSERT INTO favorites VALUES (4058, 100, 1);
INSERT INTO favorites VALUES (4058, 60, 2);
INSERT INTO favorites VALUES (4059, 44, 3);
INSERT INTO favorites VALUES (4059, 29, 1);
INSERT INTO favorites VALUES (4059, 63, 2);
INSERT INTO favorites VALUES (4060, 3, 3);
INSERT INTO favorites VALUES (4060, 24, 2);
INSERT INTO favorites VALUES (4060, 35, 1);
INSERT INTO favorites VALUES (4061, 67, 1);
INSERT INTO favorites VALUES (4061, 51, 2);
INSERT INTO favorites VALUES (4062, 25, 1);
INSERT INTO favorites VALUES (4062, 44, 2);
INSERT INTO favorites VALUES (4064, 18, 4);
INSERT INTO favorites VALUES (4064, 77, 1);
INSERT INTO favorites VALUES (4064, 11, 2);
INSERT INTO favorites VALUES (4064, 56, 3);
INSERT INTO favorites VALUES (4066, 60, 1);
INSERT INTO favorites VALUES (4066, 97, 2);
INSERT INTO favorites VALUES (4067, 13, 1);
INSERT INTO favorites VALUES (4068, 64, 3);
INSERT INTO favorites VALUES (4068, 22, 2);
INSERT INTO favorites VALUES (4068, 42, 1);
INSERT INTO favorites VALUES (4068, 96, 4);
INSERT INTO favorites VALUES (4069, 3, 3);
INSERT INTO favorites VALUES (4069, 114, 1);
INSERT INTO favorites VALUES (4069, 15, 2);
INSERT INTO favorites VALUES (4070, 43, 3);
INSERT INTO favorites VALUES (4070, 107, 1);
INSERT INTO favorites VALUES (4070, 69, 2);
INSERT INTO favorites VALUES (4071, 71, 1);
INSERT INTO favorites VALUES (4072, 36, 6);
INSERT INTO favorites VALUES (4072, 27, 5);
INSERT INTO favorites VALUES (4072, 38, 2);
INSERT INTO favorites VALUES (4072, 71, 3);
INSERT INTO favorites VALUES (4072, 3, 1);
INSERT INTO favorites VALUES (4072, 103, 4);
INSERT INTO favorites VALUES (4073, 33, 5);
INSERT INTO favorites VALUES (4073, 97, 6);
INSERT INTO favorites VALUES (4073, 30, 7);
INSERT INTO favorites VALUES (4073, 64, 1);
INSERT INTO favorites VALUES (4073, 113, 3);
INSERT INTO favorites VALUES (4073, 74, 2);
INSERT INTO favorites VALUES (4073, 103, 4);
INSERT INTO favorites VALUES (4074, 54, 5);
INSERT INTO favorites VALUES (4074, 61, 4);
INSERT INTO favorites VALUES (4074, 14, 1);
INSERT INTO favorites VALUES (4074, 38, 2);
INSERT INTO favorites VALUES (4074, 56, 3);
INSERT INTO favorites VALUES (4074, 26, 6);
INSERT INTO favorites VALUES (4075, 15, 3);
INSERT INTO favorites VALUES (4075, 17, 2);
INSERT INTO favorites VALUES (4075, 21, 1);
INSERT INTO favorites VALUES (4075, 70, 4);
INSERT INTO favorites VALUES (4076, 66, 1);
INSERT INTO favorites VALUES (4077, 42, 1);
INSERT INTO favorites VALUES (4077, 88, 2);
INSERT INTO favorites VALUES (4078, 61, 2);
INSERT INTO favorites VALUES (4078, 65, 1);
INSERT INTO favorites VALUES (4078, 9, 3);
INSERT INTO favorites VALUES (4079, 18, 3);
INSERT INTO favorites VALUES (4079, 13, 1);
INSERT INTO favorites VALUES (4079, 38, 2);
INSERT INTO favorites VALUES (4080, 73, 1);
INSERT INTO favorites VALUES (4081, 105, 1);
INSERT INTO favorites VALUES (4081, 48, 2);
INSERT INTO favorites VALUES (4082, 95, 3);
INSERT INTO favorites VALUES (4082, 59, 2);
INSERT INTO favorites VALUES (4082, 46, 1);
INSERT INTO favorites VALUES (4083, 48, 2);
INSERT INTO favorites VALUES (4083, 9, 1);
INSERT INTO favorites VALUES (4084, 107, 6);
INSERT INTO favorites VALUES (4084, 17, 4);
INSERT INTO favorites VALUES (4084, 40, 1);
INSERT INTO favorites VALUES (4084, 34, 3);
INSERT INTO favorites VALUES (4084, 22, 2);
INSERT INTO favorites VALUES (4084, 92, 5);
INSERT INTO favorites VALUES (4085, 95, 1);
INSERT INTO favorites VALUES (4085, 3, 2);
INSERT INTO favorites VALUES (4086, 55, 4);
INSERT INTO favorites VALUES (4086, 80, 1);
INSERT INTO favorites VALUES (4086, 43, 2);
INSERT INTO favorites VALUES (4086, 51, 3);
INSERT INTO favorites VALUES (4088, 8, 2);
INSERT INTO favorites VALUES (4088, 86, 1);
INSERT INTO favorites VALUES (4088, 32, 3);
INSERT INTO favorites VALUES (4089, 108, 2);
INSERT INTO favorites VALUES (4089, 59, 1);
INSERT INTO favorites VALUES (4089, 94, 3);
INSERT INTO favorites VALUES (4090, 77, 3);
INSERT INTO favorites VALUES (4090, 16, 1);
INSERT INTO favorites VALUES (4090, 32, 2);
INSERT INTO favorites VALUES (4090, 4, 4);
INSERT INTO favorites VALUES (4091, 96, 3);
INSERT INTO favorites VALUES (4091, 60, 1);
INSERT INTO favorites VALUES (4091, 11, 2);
INSERT INTO favorites VALUES (4092, 46, 2);
INSERT INTO favorites VALUES (4092, 111, 1);
INSERT INTO favorites VALUES (4092, 114, 3);
INSERT INTO favorites VALUES (4093, 56, 4);
INSERT INTO favorites VALUES (4093, 79, 1);
INSERT INTO favorites VALUES (4093, 76, 2);
INSERT INTO favorites VALUES (4093, 112, 3);
INSERT INTO favorites VALUES (4094, 25, 1);
INSERT INTO favorites VALUES (4095, 30, 4);
INSERT INTO favorites VALUES (4095, 34, 1);
INSERT INTO favorites VALUES (4095, 30, 3);
INSERT INTO favorites VALUES (4095, 69, 2);
INSERT INTO favorites VALUES (4096, 76, 3);
INSERT INTO favorites VALUES (4096, 72, 1);
INSERT INTO favorites VALUES (4096, 22, 2);
INSERT INTO favorites VALUES (4097, 13, 2);
INSERT INTO favorites VALUES (4097, 3, 1);
INSERT INTO favorites VALUES (4097, 59, 3);
INSERT INTO favorites VALUES (4098, 18, 3);
INSERT INTO favorites VALUES (4098, 5, 1);
INSERT INTO favorites VALUES (4098, 108, 2);
INSERT INTO favorites VALUES (4098, 67, 4);
INSERT INTO favorites VALUES (4100, 106, 1);
INSERT INTO favorites VALUES (4101, 37, 1);
INSERT INTO favorites VALUES (4102, 1, 1);
INSERT INTO favorites VALUES (4102, 20, 2);
INSERT INTO favorites VALUES (4104, 106, 3);
INSERT INTO favorites VALUES (4104, 72, 6);
INSERT INTO favorites VALUES (4104, 27, 1);
INSERT INTO favorites VALUES (4104, 95, 5);
INSERT INTO favorites VALUES (4104, 115, 2);
INSERT INTO favorites VALUES (4104, 65, 4);
INSERT INTO favorites VALUES (4105, 37, 2);
INSERT INTO favorites VALUES (4105, 94, 1);
INSERT INTO favorites VALUES (4105, 114, 3);
INSERT INTO favorites VALUES (4106, 71, 4);
INSERT INTO favorites VALUES (4106, 97, 6);
INSERT INTO favorites VALUES (4106, 50, 1);
INSERT INTO favorites VALUES (4106, 10, 3);
INSERT INTO favorites VALUES (4106, 50, 2);
INSERT INTO favorites VALUES (4106, 21, 5);
INSERT INTO favorites VALUES (4107, 90, 2);
INSERT INTO favorites VALUES (4107, 21, 1);
INSERT INTO favorites VALUES (4107, 4, 3);
INSERT INTO favorites VALUES (4108, 59, 1);
INSERT INTO favorites VALUES (4109, 94, 2);
INSERT INTO favorites VALUES (4109, 88, 1);
INSERT INTO favorites VALUES (4110, 42, 1);
INSERT INTO favorites VALUES (4111, 79, 1);
INSERT INTO favorites VALUES (4112, 49, 3);
INSERT INTO favorites VALUES (4112, 81, 2);
INSERT INTO favorites VALUES (4112, 109, 1);
INSERT INTO favorites VALUES (4112, 32, 4);
INSERT INTO favorites VALUES (4113, 112, 3);
INSERT INTO favorites VALUES (4113, 86, 4);
INSERT INTO favorites VALUES (4113, 91, 1);
INSERT INTO favorites VALUES (4113, 18, 2);
INSERT INTO favorites VALUES (4113, 32, 5);
INSERT INTO favorites VALUES (4114, 7, 1);
INSERT INTO favorites VALUES (4115, 101, 5);
INSERT INTO favorites VALUES (4115, 16, 4);
INSERT INTO favorites VALUES (4115, 74, 1);
INSERT INTO favorites VALUES (4115, 77, 2);
INSERT INTO favorites VALUES (4115, 6, 3);
INSERT INTO favorites VALUES (4116, 30, 1);
INSERT INTO favorites VALUES (4116, 3, 2);
INSERT INTO favorites VALUES (4118, 30, 3);
INSERT INTO favorites VALUES (4118, 86, 1);
INSERT INTO favorites VALUES (4118, 46, 2);
INSERT INTO favorites VALUES (4120, 42, 1);
INSERT INTO favorites VALUES (4120, 27, 2);
INSERT INTO favorites VALUES (4122, 28, 1);
INSERT INTO favorites VALUES (4122, 8, 2);
INSERT INTO favorites VALUES (4123, 9, 1);
INSERT INTO favorites VALUES (4123, 75, 3);
INSERT INTO favorites VALUES (4123, 22, 2);
INSERT INTO favorites VALUES (4124, 53, 4);
INSERT INTO favorites VALUES (4124, 35, 1);
INSERT INTO favorites VALUES (4124, 36, 2);
INSERT INTO favorites VALUES (4124, 80, 3);
INSERT INTO favorites VALUES (4125, 46, 4);
INSERT INTO favorites VALUES (4125, 20, 1);
INSERT INTO favorites VALUES (4125, 5, 2);
INSERT INTO favorites VALUES (4125, 62, 3);
INSERT INTO favorites VALUES (4126, 18, 3);
INSERT INTO favorites VALUES (4126, 26, 1);
INSERT INTO favorites VALUES (4126, 2, 2);
INSERT INTO favorites VALUES (4127, 64, 1);
INSERT INTO favorites VALUES (4127, 64, 2);
INSERT INTO favorites VALUES (4129, 51, 2);
INSERT INTO favorites VALUES (4129, 67, 1);
INSERT INTO favorites VALUES (4129, 6, 3);
INSERT INTO favorites VALUES (4130, 35, 3);
INSERT INTO favorites VALUES (4130, 35, 1);
INSERT INTO favorites VALUES (4130, 38, 2);
INSERT INTO favorites VALUES (4131, 41, 1);
INSERT INTO favorites VALUES (4132, 19, 2);
INSERT INTO favorites VALUES (4132, 42, 1);
INSERT INTO favorites VALUES (4133, 72, 2);
INSERT INTO favorites VALUES (4133, 15, 1);
INSERT INTO favorites VALUES (4133, 80, 3);
INSERT INTO favorites VALUES (4134, 85, 3);
INSERT INTO favorites VALUES (4134, 66, 1);
INSERT INTO favorites VALUES (4134, 81, 2);
INSERT INTO favorites VALUES (4135, 38, 1);
INSERT INTO favorites VALUES (4135, 97, 2);
INSERT INTO favorites VALUES (4136, 97, 1);
INSERT INTO favorites VALUES (4137, 58, 1);
INSERT INTO favorites VALUES (4138, 14, 1);
INSERT INTO favorites VALUES (4139, 96, 3);
INSERT INTO favorites VALUES (4139, 113, 2);
INSERT INTO favorites VALUES (4139, 115, 1);
INSERT INTO favorites VALUES (4140, 51, 2);
INSERT INTO favorites VALUES (4140, 36, 1);
INSERT INTO favorites VALUES (4140, 59, 3);
INSERT INTO favorites VALUES (4141, 103, 1);
INSERT INTO favorites VALUES (4141, 36, 2);
INSERT INTO favorites VALUES (4142, 50, 1);
INSERT INTO favorites VALUES (4142, 77, 2);
INSERT INTO favorites VALUES (4143, 84, 4);
INSERT INTO favorites VALUES (4143, 49, 1);
INSERT INTO favorites VALUES (4143, 56, 2);
INSERT INTO favorites VALUES (4143, 109, 3);
INSERT INTO favorites VALUES (4144, 68, 4);
INSERT INTO favorites VALUES (4144, 61, 1);
INSERT INTO favorites VALUES (4144, 82, 3);
INSERT INTO favorites VALUES (4144, 58, 2);
INSERT INTO favorites VALUES (4145, 69, 5);
INSERT INTO favorites VALUES (4145, 34, 6);
INSERT INTO favorites VALUES (4145, 63, 1);
INSERT INTO favorites VALUES (4145, 11, 3);
INSERT INTO favorites VALUES (4145, 96, 2);
INSERT INTO favorites VALUES (4145, 14, 4);
INSERT INTO favorites VALUES (4146, 45, 4);
INSERT INTO favorites VALUES (4146, 88, 1);
INSERT INTO favorites VALUES (4146, 26, 2);
INSERT INTO favorites VALUES (4146, 53, 3);
INSERT INTO favorites VALUES (4147, 78, 2);
INSERT INTO favorites VALUES (4147, 113, 1);
INSERT INTO favorites VALUES (4147, 79, 3);
INSERT INTO favorites VALUES (4148, 66, 3);
INSERT INTO favorites VALUES (4148, 108, 4);
INSERT INTO favorites VALUES (4148, 76, 1);
INSERT INTO favorites VALUES (4148, 113, 2);
INSERT INTO favorites VALUES (4148, 36, 5);
INSERT INTO favorites VALUES (4149, 61, 3);
INSERT INTO favorites VALUES (4149, 18, 1);
INSERT INTO favorites VALUES (4149, 4, 2);
INSERT INTO favorites VALUES (4150, 63, 1);
INSERT INTO favorites VALUES (4150, 58, 2);
INSERT INTO favorites VALUES (4151, 93, 6);
INSERT INTO favorites VALUES (4151, 68, 7);
INSERT INTO favorites VALUES (4151, 60, 8);
INSERT INTO favorites VALUES (4151, 33, 1);
INSERT INTO favorites VALUES (4151, 97, 5);
INSERT INTO favorites VALUES (4151, 55, 2);
INSERT INTO favorites VALUES (4151, 109, 3);
INSERT INTO favorites VALUES (4151, 46, 4);
INSERT INTO favorites VALUES (4154, 82, 2);
INSERT INTO favorites VALUES (4154, 51, 1);
INSERT INTO favorites VALUES (4155, 57, 6);
INSERT INTO favorites VALUES (4155, 57, 4);
INSERT INTO favorites VALUES (4155, 38, 1);
INSERT INTO favorites VALUES (4155, 72, 3);
INSERT INTO favorites VALUES (4155, 18, 2);
INSERT INTO favorites VALUES (4155, 86, 5);
INSERT INTO favorites VALUES (4156, 31, 3);
INSERT INTO favorites VALUES (4156, 75, 2);
INSERT INTO favorites VALUES (4156, 73, 1);
INSERT INTO favorites VALUES (4156, 83, 4);
INSERT INTO favorites VALUES (4157, 27, 3);
INSERT INTO favorites VALUES (4157, 91, 1);
INSERT INTO favorites VALUES (4157, 37, 2);
INSERT INTO favorites VALUES (4157, 28, 4);
INSERT INTO favorites VALUES (4158, 101, 3);
INSERT INTO favorites VALUES (4158, 69, 1);
INSERT INTO favorites VALUES (4158, 29, 2);
INSERT INTO favorites VALUES (4159, 37, 3);
INSERT INTO favorites VALUES (4159, 72, 1);
INSERT INTO favorites VALUES (4159, 68, 2);
INSERT INTO favorites VALUES (4159, 17, 4);
INSERT INTO favorites VALUES (4160, 72, 5);
INSERT INTO favorites VALUES (4160, 46, 4);
INSERT INTO favorites VALUES (4160, 92, 2);
INSERT INTO favorites VALUES (4160, 53, 1);
INSERT INTO favorites VALUES (4160, 99, 3);
INSERT INTO favorites VALUES (4161, 22, 6);
INSERT INTO favorites VALUES (4161, 70, 5);
INSERT INTO favorites VALUES (4161, 50, 1);
INSERT INTO favorites VALUES (4161, 16, 4);
INSERT INTO favorites VALUES (4161, 69, 2);
INSERT INTO favorites VALUES (4161, 21, 3);
INSERT INTO favorites VALUES (4163, 75, 3);
INSERT INTO favorites VALUES (4163, 28, 2);
INSERT INTO favorites VALUES (4163, 36, 1);
INSERT INTO favorites VALUES (4164, 93, 1);
INSERT INTO favorites VALUES (4164, 95, 3);
INSERT INTO favorites VALUES (4164, 10, 2);
INSERT INTO favorites VALUES (4165, 92, 3);
INSERT INTO favorites VALUES (4165, 90, 1);
INSERT INTO favorites VALUES (4165, 16, 2);
INSERT INTO favorites VALUES (4165, 38, 4);
INSERT INTO favorites VALUES (4166, 62, 4);
INSERT INTO favorites VALUES (4166, 22, 1);
INSERT INTO favorites VALUES (4166, 116, 3);
INSERT INTO favorites VALUES (4166, 93, 2);
INSERT INTO favorites VALUES (4167, 97, 1);
INSERT INTO favorites VALUES (4167, 87, 2);
INSERT INTO favorites VALUES (4168, 25, 4);
INSERT INTO favorites VALUES (4168, 5, 1);
INSERT INTO favorites VALUES (4168, 112, 2);
INSERT INTO favorites VALUES (4168, 64, 3);
INSERT INTO favorites VALUES (4169, 42, 1);
INSERT INTO favorites VALUES (4169, 74, 2);
INSERT INTO favorites VALUES (4170, 40, 7);
INSERT INTO favorites VALUES (4170, 114, 6);
INSERT INTO favorites VALUES (4170, 13, 4);
INSERT INTO favorites VALUES (4170, 95, 2);
INSERT INTO favorites VALUES (4170, 48, 3);
INSERT INTO favorites VALUES (4170, 11, 1);
INSERT INTO favorites VALUES (4170, 77, 5);
INSERT INTO favorites VALUES (4171, 67, 3);
INSERT INTO favorites VALUES (4171, 42, 1);
INSERT INTO favorites VALUES (4171, 75, 2);
INSERT INTO favorites VALUES (4172, 75, 1);
INSERT INTO favorites VALUES (4172, 111, 2);
INSERT INTO favorites VALUES (4173, 116, 3);
INSERT INTO favorites VALUES (4173, 106, 2);
INSERT INTO favorites VALUES (4173, 4, 1);
INSERT INTO favorites VALUES (4174, 46, 1);
INSERT INTO favorites VALUES (4174, 94, 2);
INSERT INTO favorites VALUES (4175, 10, 1);
INSERT INTO favorites VALUES (4175, 69, 2);
INSERT INTO favorites VALUES (4176, 5, 2);
INSERT INTO favorites VALUES (4176, 95, 1);
INSERT INTO favorites VALUES (4176, 68, 3);
INSERT INTO favorites VALUES (4177, 88, 2);
INSERT INTO favorites VALUES (4177, 22, 1);
INSERT INTO favorites VALUES (4178, 29, 3);
INSERT INTO favorites VALUES (4178, 89, 2);
INSERT INTO favorites VALUES (4178, 71, 1);
INSERT INTO favorites VALUES (4179, 33, 5);
INSERT INTO favorites VALUES (4179, 40, 4);
INSERT INTO favorites VALUES (4179, 41, 1);
INSERT INTO favorites VALUES (4179, 14, 2);
INSERT INTO favorites VALUES (4179, 73, 3);
INSERT INTO favorites VALUES (4180, 24, 1);
INSERT INTO favorites VALUES (4180, 80, 2);
INSERT INTO favorites VALUES (4181, 85, 1);
INSERT INTO favorites VALUES (4182, 28, 1);
INSERT INTO favorites VALUES (4183, 21, 1);
INSERT INTO favorites VALUES (4184, 4, 4);
INSERT INTO favorites VALUES (4184, 3, 5);
INSERT INTO favorites VALUES (4184, 82, 6);
INSERT INTO favorites VALUES (4184, 47, 2);
INSERT INTO favorites VALUES (4184, 102, 8);
INSERT INTO favorites VALUES (4184, 110, 3);
INSERT INTO favorites VALUES (4184, 9, 1);
INSERT INTO favorites VALUES (4184, 40, 7);
INSERT INTO favorites VALUES (4185, 89, 1);
INSERT INTO favorites VALUES (4185, 36, 2);
INSERT INTO favorites VALUES (4187, 28, 1);
INSERT INTO favorites VALUES (4188, 84, 1);
INSERT INTO favorites VALUES (4188, 33, 2);
INSERT INTO favorites VALUES (4190, 64, 6);
INSERT INTO favorites VALUES (4190, 8, 8);
INSERT INTO favorites VALUES (4190, 87, 7);
INSERT INTO favorites VALUES (4190, 67, 3);
INSERT INTO favorites VALUES (4190, 55, 5);
INSERT INTO favorites VALUES (4190, 55, 1);
INSERT INTO favorites VALUES (4190, 79, 2);
INSERT INTO favorites VALUES (4190, 86, 4);
INSERT INTO favorites VALUES (4191, 89, 5);
INSERT INTO favorites VALUES (4191, 2, 4);
INSERT INTO favorites VALUES (4191, 34, 1);
INSERT INTO favorites VALUES (4191, 4, 3);
INSERT INTO favorites VALUES (4191, 66, 2);
INSERT INTO favorites VALUES (4192, 14, 1);
INSERT INTO favorites VALUES (4192, 23, 3);
INSERT INTO favorites VALUES (4192, 2, 2);
INSERT INTO favorites VALUES (4193, 38, 6);
INSERT INTO favorites VALUES (4193, 46, 3);
INSERT INTO favorites VALUES (4193, 44, 1);
INSERT INTO favorites VALUES (4193, 1, 5);
INSERT INTO favorites VALUES (4193, 101, 2);
INSERT INTO favorites VALUES (4193, 88, 4);
INSERT INTO favorites VALUES (4194, 15, 1);
INSERT INTO favorites VALUES (4194, 7, 2);
INSERT INTO favorites VALUES (4195, 20, 2);
INSERT INTO favorites VALUES (4195, 41, 1);
INSERT INTO favorites VALUES (4196, 62, 1);
INSERT INTO favorites VALUES (4196, 37, 2);
INSERT INTO favorites VALUES (4197, 80, 2);
INSERT INTO favorites VALUES (4197, 70, 3);
INSERT INTO favorites VALUES (4197, 111, 1);
INSERT INTO favorites VALUES (4197, 43, 5);
INSERT INTO favorites VALUES (4197, 42, 6);
INSERT INTO favorites VALUES (4197, 107, 4);
INSERT INTO favorites VALUES (4198, 50, 1);
INSERT INTO favorites VALUES (4199, 6, 4);
INSERT INTO favorites VALUES (4199, 30, 3);
INSERT INTO favorites VALUES (4199, 9, 2);
INSERT INTO favorites VALUES (4199, 1, 1);
INSERT INTO favorites VALUES (4200, 70, 2);
INSERT INTO favorites VALUES (4200, 18, 1);
INSERT INTO favorites VALUES (4200, 3, 3);
INSERT INTO favorites VALUES (4200, 14, 6);
INSERT INTO favorites VALUES (4200, 63, 7);
INSERT INTO favorites VALUES (4200, 109, 4);
INSERT INTO favorites VALUES (4200, 43, 5);
INSERT INTO favorites VALUES (4201, 39, 1);
INSERT INTO favorites VALUES (4202, 19, 1);
INSERT INTO favorites VALUES (4202, 63, 2);
INSERT INTO favorites VALUES (4203, 7, 1);
INSERT INTO favorites VALUES (4204, 95, 1);
INSERT INTO favorites VALUES (4204, 97, 2);
INSERT INTO favorites VALUES (4205, 49, 2);
INSERT INTO favorites VALUES (4205, 90, 4);
INSERT INTO favorites VALUES (4205, 17, 1);
INSERT INTO favorites VALUES (4205, 6, 3);
INSERT INTO favorites VALUES (4206, 26, 1);
INSERT INTO favorites VALUES (4206, 2, 2);
INSERT INTO favorites VALUES (4207, 35, 7);
INSERT INTO favorites VALUES (4207, 41, 6);
INSERT INTO favorites VALUES (4207, 40, 4);
INSERT INTO favorites VALUES (4207, 89, 2);
INSERT INTO favorites VALUES (4207, 78, 3);
INSERT INTO favorites VALUES (4207, 47, 1);
INSERT INTO favorites VALUES (4207, 31, 5);
INSERT INTO favorites VALUES (4208, 37, 4);
INSERT INTO favorites VALUES (4208, 14, 2);
INSERT INTO favorites VALUES (4208, 92, 1);
INSERT INTO favorites VALUES (4208, 85, 3);
INSERT INTO favorites VALUES (4209, 81, 1);
INSERT INTO favorites VALUES (4210, 94, 3);
INSERT INTO favorites VALUES (4210, 104, 1);
INSERT INTO favorites VALUES (4210, 34, 2);
INSERT INTO favorites VALUES (4211, 19, 1);
INSERT INTO favorites VALUES (4212, 87, 3);
INSERT INTO favorites VALUES (4212, 3, 2);
INSERT INTO favorites VALUES (4212, 40, 1);
INSERT INTO favorites VALUES (4212, 77, 4);
INSERT INTO favorites VALUES (4213, 52, 4);
INSERT INTO favorites VALUES (4213, 35, 2);
INSERT INTO favorites VALUES (4213, 49, 1);
INSERT INTO favorites VALUES (4213, 69, 3);
INSERT INTO favorites VALUES (4215, 97, 3);
INSERT INTO favorites VALUES (4215, 74, 1);
INSERT INTO favorites VALUES (4215, 7, 2);
INSERT INTO favorites VALUES (4216, 30, 3);
INSERT INTO favorites VALUES (4216, 77, 2);
INSERT INTO favorites VALUES (4216, 23, 1);
INSERT INTO favorites VALUES (4217, 20, 4);
INSERT INTO favorites VALUES (4217, 4, 3);
INSERT INTO favorites VALUES (4217, 10, 2);
INSERT INTO favorites VALUES (4217, 30, 1);
INSERT INTO favorites VALUES (4218, 21, 4);
INSERT INTO favorites VALUES (4218, 45, 6);
INSERT INTO favorites VALUES (4218, 27, 3);
INSERT INTO favorites VALUES (4218, 1, 1);
INSERT INTO favorites VALUES (4218, 6, 2);
INSERT INTO favorites VALUES (4218, 33, 5);
INSERT INTO favorites VALUES (4218, 64, 7);
INSERT INTO favorites VALUES (4219, 50, 1);
INSERT INTO favorites VALUES (4219, 89, 2);
INSERT INTO favorites VALUES (4220, 92, 4);
INSERT INTO favorites VALUES (4220, 99, 1);
INSERT INTO favorites VALUES (4220, 45, 3);
INSERT INTO favorites VALUES (4220, 12, 2);
INSERT INTO favorites VALUES (4221, 17, 4);
INSERT INTO favorites VALUES (4221, 26, 5);
INSERT INTO favorites VALUES (4221, 12, 2);
INSERT INTO favorites VALUES (4221, 11, 1);
INSERT INTO favorites VALUES (4221, 29, 3);
INSERT INTO favorites VALUES (4222, 65, 4);
INSERT INTO favorites VALUES (4222, 63, 1);
INSERT INTO favorites VALUES (4222, 22, 2);
INSERT INTO favorites VALUES (4222, 28, 3);
INSERT INTO favorites VALUES (4223, 61, 4);
INSERT INTO favorites VALUES (4223, 96, 1);
INSERT INTO favorites VALUES (4223, 87, 2);
INSERT INTO favorites VALUES (4223, 74, 3);
INSERT INTO favorites VALUES (4225, 52, 1);
INSERT INTO favorites VALUES (4225, 11, 2);
INSERT INTO favorites VALUES (4226, 10, 3);
INSERT INTO favorites VALUES (4226, 66, 1);
INSERT INTO favorites VALUES (4226, 12, 2);
INSERT INTO favorites VALUES (4227, 88, 1);
INSERT INTO favorites VALUES (4228, 36, 2);
INSERT INTO favorites VALUES (4228, 21, 1);
INSERT INTO favorites VALUES (4229, 11, 3);
INSERT INTO favorites VALUES (4229, 13, 2);
INSERT INTO favorites VALUES (4229, 108, 1);
INSERT INTO favorites VALUES (4230, 45, 1);
INSERT INTO favorites VALUES (4230, 109, 2);
INSERT INTO favorites VALUES (4231, 113, 3);
INSERT INTO favorites VALUES (4231, 33, 2);
INSERT INTO favorites VALUES (4231, 79, 1);
INSERT INTO favorites VALUES (4232, 106, 1);
INSERT INTO favorites VALUES (4232, 115, 2);
INSERT INTO favorites VALUES (4234, 30, 2);
INSERT INTO favorites VALUES (4234, 28, 1);
INSERT INTO favorites VALUES (4235, 14, 1);
INSERT INTO favorites VALUES (4236, 49, 1);
INSERT INTO favorites VALUES (4237, 97, 4);
INSERT INTO favorites VALUES (4237, 90, 1);
INSERT INTO favorites VALUES (4237, 57, 3);
INSERT INTO favorites VALUES (4237, 57, 2);
INSERT INTO favorites VALUES (4238, 71, 3);
INSERT INTO favorites VALUES (4238, 22, 2);
INSERT INTO favorites VALUES (4238, 54, 1);
INSERT INTO favorites VALUES (4239, 50, 3);
INSERT INTO favorites VALUES (4239, 21, 1);
INSERT INTO favorites VALUES (4239, 4, 4);
INSERT INTO favorites VALUES (4239, 6, 2);
INSERT INTO favorites VALUES (4242, 2, 3);
INSERT INTO favorites VALUES (4242, 65, 1);
INSERT INTO favorites VALUES (4242, 25, 2);
INSERT INTO favorites VALUES (4244, 4, 1);
INSERT INTO favorites VALUES (4245, 60, 1);
INSERT INTO favorites VALUES (4246, 60, 4);
INSERT INTO favorites VALUES (4246, 44, 6);
INSERT INTO favorites VALUES (4246, 42, 5);
INSERT INTO favorites VALUES (4246, 57, 3);
INSERT INTO favorites VALUES (4246, 89, 1);
INSERT INTO favorites VALUES (4246, 64, 2);
INSERT INTO favorites VALUES (4247, 99, 4);
INSERT INTO favorites VALUES (4247, 55, 5);
INSERT INTO favorites VALUES (4247, 60, 3);
INSERT INTO favorites VALUES (4247, 55, 1);
INSERT INTO favorites VALUES (4247, 54, 2);
INSERT INTO favorites VALUES (4248, 12, 3);
INSERT INTO favorites VALUES (4248, 2, 1);
INSERT INTO favorites VALUES (4248, 13, 2);
INSERT INTO favorites VALUES (4249, 5, 1);
INSERT INTO favorites VALUES (4249, 106, 2);
INSERT INTO favorites VALUES (4251, 91, 1);
INSERT INTO favorites VALUES (4251, 42, 3);
INSERT INTO favorites VALUES (4251, 36, 2);
INSERT INTO favorites VALUES (4252, 24, 1);
INSERT INTO favorites VALUES (4252, 35, 2);
INSERT INTO favorites VALUES (4254, 5, 1);
INSERT INTO favorites VALUES (4255, 112, 3);
INSERT INTO favorites VALUES (4255, 69, 1);
INSERT INTO favorites VALUES (4255, 24, 2);
INSERT INTO favorites VALUES (4256, 17, 3);
INSERT INTO favorites VALUES (4256, 23, 1);
INSERT INTO favorites VALUES (4256, 58, 2);
INSERT INTO favorites VALUES (4257, 63, 3);
INSERT INTO favorites VALUES (4257, 5, 1);
INSERT INTO favorites VALUES (4257, 73, 2);
INSERT INTO favorites VALUES (4258, 51, 1);
INSERT INTO favorites VALUES (4258, 56, 3);
INSERT INTO favorites VALUES (4258, 68, 2);
INSERT INTO favorites VALUES (4259, 100, 6);
INSERT INTO favorites VALUES (4259, 67, 4);
INSERT INTO favorites VALUES (4259, 54, 5);
INSERT INTO favorites VALUES (4259, 22, 1);
INSERT INTO favorites VALUES (4259, 34, 2);
INSERT INTO favorites VALUES (4259, 27, 3);
INSERT INTO favorites VALUES (4260, 47, 7);
INSERT INTO favorites VALUES (4260, 114, 6);
INSERT INTO favorites VALUES (4260, 84, 5);
INSERT INTO favorites VALUES (4260, 23, 4);
INSERT INTO favorites VALUES (4260, 103, 2);
INSERT INTO favorites VALUES (4260, 15, 1);
INSERT INTO favorites VALUES (4260, 10, 3);
INSERT INTO favorites VALUES (4261, 91, 3);
INSERT INTO favorites VALUES (4261, 102, 2);
INSERT INTO favorites VALUES (4261, 97, 1);
INSERT INTO favorites VALUES (4262, 105, 1);
INSERT INTO favorites VALUES (4263, 93, 3);
INSERT INTO favorites VALUES (4263, 18, 1);
INSERT INTO favorites VALUES (4263, 28, 2);
INSERT INTO favorites VALUES (4264, 88, 4);
INSERT INTO favorites VALUES (4264, 86, 3);
INSERT INTO favorites VALUES (4264, 69, 2);
INSERT INTO favorites VALUES (4264, 38, 1);
INSERT INTO favorites VALUES (4265, 72, 1);
INSERT INTO favorites VALUES (4265, 96, 2);
INSERT INTO favorites VALUES (4266, 13, 1);
INSERT INTO favorites VALUES (4266, 43, 2);
INSERT INTO favorites VALUES (4267, 63, 2);
INSERT INTO favorites VALUES (4267, 50, 1);
INSERT INTO favorites VALUES (4268, 103, 5);
INSERT INTO favorites VALUES (4268, 72, 6);
INSERT INTO favorites VALUES (4268, 96, 1);
INSERT INTO favorites VALUES (4268, 82, 3);
INSERT INTO favorites VALUES (4268, 53, 4);
INSERT INTO favorites VALUES (4268, 79, 2);
INSERT INTO favorites VALUES (4269, 30, 5);
INSERT INTO favorites VALUES (4269, 5, 4);
INSERT INTO favorites VALUES (4269, 89, 3);
INSERT INTO favorites VALUES (4269, 46, 2);
INSERT INTO favorites VALUES (4269, 73, 1);
INSERT INTO favorites VALUES (4269, 37, 6);
INSERT INTO favorites VALUES (4270, 29, 1);
INSERT INTO favorites VALUES (4271, 31, 4);
INSERT INTO favorites VALUES (4271, 27, 5);
INSERT INTO favorites VALUES (4271, 6, 1);
INSERT INTO favorites VALUES (4271, 90, 2);
INSERT INTO favorites VALUES (4271, 10, 3);
INSERT INTO favorites VALUES (4272, 81, 1);
INSERT INTO favorites VALUES (4273, 92, 3);
INSERT INTO favorites VALUES (4273, 40, 2);
INSERT INTO favorites VALUES (4273, 100, 1);
INSERT INTO favorites VALUES (4274, 110, 1);
INSERT INTO favorites VALUES (4274, 103, 2);
INSERT INTO favorites VALUES (4276, 67, 1);
INSERT INTO favorites VALUES (4277, 6, 3);
INSERT INTO favorites VALUES (4277, 90, 2);
INSERT INTO favorites VALUES (4277, 113, 1);
INSERT INTO favorites VALUES (4278, 101, 3);
INSERT INTO favorites VALUES (4278, 24, 1);
INSERT INTO favorites VALUES (4278, 54, 2);
INSERT INTO favorites VALUES (4279, 96, 1);
INSERT INTO favorites VALUES (4279, 96, 2);
INSERT INTO favorites VALUES (4280, 53, 2);
INSERT INTO favorites VALUES (4280, 80, 3);
INSERT INTO favorites VALUES (4280, 35, 1);
INSERT INTO favorites VALUES (4281, 84, 1);
INSERT INTO favorites VALUES (4281, 78, 2);
INSERT INTO favorites VALUES (4282, 41, 3);
INSERT INTO favorites VALUES (4282, 62, 1);
INSERT INTO favorites VALUES (4282, 47, 2);
INSERT INTO favorites VALUES (4283, 15, 2);
INSERT INTO favorites VALUES (4283, 113, 1);
INSERT INTO favorites VALUES (4284, 71, 3);
INSERT INTO favorites VALUES (4284, 3, 1);
INSERT INTO favorites VALUES (4284, 11, 2);
INSERT INTO favorites VALUES (4285, 3, 1);
INSERT INTO favorites VALUES (4286, 92, 3);
INSERT INTO favorites VALUES (4286, 80, 1);
INSERT INTO favorites VALUES (4286, 31, 2);
INSERT INTO favorites VALUES (4287, 77, 1);
INSERT INTO favorites VALUES (4287, 53, 2);
INSERT INTO favorites VALUES (4288, 46, 1);
INSERT INTO favorites VALUES (4289, 92, 1);
INSERT INTO favorites VALUES (4289, 68, 2);
INSERT INTO favorites VALUES (4290, 49, 1);
INSERT INTO favorites VALUES (4290, 5, 2);
INSERT INTO favorites VALUES (4291, 47, 6);
INSERT INTO favorites VALUES (4291, 50, 5);
INSERT INTO favorites VALUES (4291, 95, 1);
INSERT INTO favorites VALUES (4291, 68, 4);
INSERT INTO favorites VALUES (4291, 9, 2);
INSERT INTO favorites VALUES (4291, 35, 3);
INSERT INTO favorites VALUES (4292, 61, 2);
INSERT INTO favorites VALUES (4292, 73, 1);
INSERT INTO favorites VALUES (4292, 71, 3);
INSERT INTO favorites VALUES (4293, 102, 1);
INSERT INTO favorites VALUES (4294, 25, 7);
INSERT INTO favorites VALUES (4294, 32, 4);
INSERT INTO favorites VALUES (4294, 47, 5);
INSERT INTO favorites VALUES (4294, 81, 1);
INSERT INTO favorites VALUES (4294, 24, 2);
INSERT INTO favorites VALUES (4294, 105, 3);
INSERT INTO favorites VALUES (4294, 32, 6);
INSERT INTO favorites VALUES (4295, 82, 1);
INSERT INTO favorites VALUES (4296, 60, 3);
INSERT INTO favorites VALUES (4296, 103, 1);
INSERT INTO favorites VALUES (4296, 60, 2);
INSERT INTO favorites VALUES (4297, 90, 1);
INSERT INTO favorites VALUES (4298, 101, 1);
INSERT INTO favorites VALUES (4298, 78, 2);
INSERT INTO favorites VALUES (4299, 114, 1);
INSERT INTO favorites VALUES (4300, 54, 1);
INSERT INTO favorites VALUES (4301, 9, 5);
INSERT INTO favorites VALUES (4301, 32, 6);
INSERT INTO favorites VALUES (4301, 38, 1);
INSERT INTO favorites VALUES (4301, 12, 3);
INSERT INTO favorites VALUES (4301, 1, 2);
INSERT INTO favorites VALUES (4301, 105, 4);
INSERT INTO favorites VALUES (4302, 76, 1);
INSERT INTO favorites VALUES (4302, 7, 2);
INSERT INTO favorites VALUES (4303, 38, 4);
INSERT INTO favorites VALUES (4303, 95, 1);
INSERT INTO favorites VALUES (4303, 22, 3);
INSERT INTO favorites VALUES (4303, 16, 2);
INSERT INTO favorites VALUES (4304, 7, 1);
INSERT INTO favorites VALUES (4304, 5, 2);
INSERT INTO favorites VALUES (4305, 82, 2);
INSERT INTO favorites VALUES (4305, 39, 1);
INSERT INTO favorites VALUES (4305, 6, 4);
INSERT INTO favorites VALUES (4305, 114, 3);
INSERT INTO favorites VALUES (4306, 100, 4);
INSERT INTO favorites VALUES (4306, 73, 3);
INSERT INTO favorites VALUES (4306, 28, 1);
INSERT INTO favorites VALUES (4306, 10, 2);
INSERT INTO favorites VALUES (4307, 48, 1);
INSERT INTO favorites VALUES (4308, 26, 9);
INSERT INTO favorites VALUES (4308, 105, 8);
INSERT INTO favorites VALUES (4308, 31, 5);
INSERT INTO favorites VALUES (4308, 11, 6);
INSERT INTO favorites VALUES (4308, 114, 2);
INSERT INTO favorites VALUES (4308, 104, 3);
INSERT INTO favorites VALUES (4308, 42, 4);
INSERT INTO favorites VALUES (4308, 39, 1);
INSERT INTO favorites VALUES (4308, 71, 7);
INSERT INTO favorites VALUES (4309, 80, 1);
INSERT INTO favorites VALUES (4310, 22, 2);
INSERT INTO favorites VALUES (4310, 37, 1);
INSERT INTO favorites VALUES (4310, 97, 3);
INSERT INTO favorites VALUES (4311, 1, 1);
INSERT INTO favorites VALUES (4311, 23, 2);
INSERT INTO favorites VALUES (4312, 97, 2);
INSERT INTO favorites VALUES (4312, 28, 1);
INSERT INTO favorites VALUES (4313, 73, 3);
INSERT INTO favorites VALUES (4313, 54, 2);
INSERT INTO favorites VALUES (4313, 45, 1);
INSERT INTO favorites VALUES (4314, 36, 3);
INSERT INTO favorites VALUES (4314, 80, 2);
INSERT INTO favorites VALUES (4314, 85, 1);
INSERT INTO favorites VALUES (4315, 107, 3);
INSERT INTO favorites VALUES (4315, 76, 1);
INSERT INTO favorites VALUES (4315, 48, 2);
INSERT INTO favorites VALUES (4316, 28, 4);
INSERT INTO favorites VALUES (4316, 84, 1);
INSERT INTO favorites VALUES (4316, 26, 3);
INSERT INTO favorites VALUES (4316, 78, 2);
INSERT INTO favorites VALUES (4317, 62, 3);
INSERT INTO favorites VALUES (4317, 97, 1);
INSERT INTO favorites VALUES (4317, 53, 2);
INSERT INTO favorites VALUES (4318, 91, 3);
INSERT INTO favorites VALUES (4318, 15, 1);
INSERT INTO favorites VALUES (4318, 86, 2);
INSERT INTO favorites VALUES (4319, 84, 1);
INSERT INTO favorites VALUES (4319, 60, 2);
INSERT INTO favorites VALUES (4320, 9, 1);
INSERT INTO favorites VALUES (4320, 116, 2);
INSERT INTO favorites VALUES (4321, 39, 2);
INSERT INTO favorites VALUES (4321, 111, 1);
INSERT INTO favorites VALUES (4322, 5, 1);
INSERT INTO favorites VALUES (4322, 104, 2);
INSERT INTO favorites VALUES (4323, 51, 3);
INSERT INTO favorites VALUES (4323, 5, 1);
INSERT INTO favorites VALUES (4323, 78, 2);
INSERT INTO favorites VALUES (4324, 96, 4);
INSERT INTO favorites VALUES (4324, 63, 1);
INSERT INTO favorites VALUES (4324, 12, 2);
INSERT INTO favorites VALUES (4324, 99, 3);
INSERT INTO favorites VALUES (4325, 2, 5);
INSERT INTO favorites VALUES (4325, 46, 4);
INSERT INTO favorites VALUES (4325, 80, 1);
INSERT INTO favorites VALUES (4325, 27, 3);
INSERT INTO favorites VALUES (4325, 14, 2);
INSERT INTO favorites VALUES (4326, 81, 1);
INSERT INTO favorites VALUES (4326, 58, 2);
INSERT INTO favorites VALUES (4327, 35, 1);
INSERT INTO favorites VALUES (4328, 77, 2);
INSERT INTO favorites VALUES (4328, 20, 1);
INSERT INTO favorites VALUES (4329, 78, 2);
INSERT INTO favorites VALUES (4329, 85, 1);
INSERT INTO favorites VALUES (4329, 27, 3);
INSERT INTO favorites VALUES (4331, 64, 1);
INSERT INTO favorites VALUES (4333, 88, 3);
INSERT INTO favorites VALUES (4333, 24, 2);
INSERT INTO favorites VALUES (4333, 45, 1);
INSERT INTO favorites VALUES (4334, 44, 1);
INSERT INTO favorites VALUES (4335, 38, 4);
INSERT INTO favorites VALUES (4335, 97, 1);
INSERT INTO favorites VALUES (4335, 73, 2);
INSERT INTO favorites VALUES (4335, 31, 3);
INSERT INTO favorites VALUES (4336, 66, 1);
INSERT INTO favorites VALUES (4336, 111, 2);
INSERT INTO favorites VALUES (4337, 5, 1);
INSERT INTO favorites VALUES (4337, 58, 2);
INSERT INTO favorites VALUES (4338, 99, 1);
INSERT INTO favorites VALUES (4338, 30, 2);
INSERT INTO favorites VALUES (4339, 21, 1);
INSERT INTO favorites VALUES (4339, 56, 2);
INSERT INTO favorites VALUES (4340, 41, 4);
INSERT INTO favorites VALUES (4340, 3, 1);
INSERT INTO favorites VALUES (4340, 84, 3);
INSERT INTO favorites VALUES (4340, 31, 2);
INSERT INTO favorites VALUES (4341, 91, 4);
INSERT INTO favorites VALUES (4341, 55, 5);
INSERT INTO favorites VALUES (4341, 15, 2);
INSERT INTO favorites VALUES (4341, 50, 3);
INSERT INTO favorites VALUES (4341, 13, 1);
INSERT INTO favorites VALUES (4342, 55, 5);
INSERT INTO favorites VALUES (4342, 115, 4);
INSERT INTO favorites VALUES (4342, 88, 1);
INSERT INTO favorites VALUES (4342, 26, 3);
INSERT INTO favorites VALUES (4342, 51, 2);
INSERT INTO favorites VALUES (4343, 7, 1);
INSERT INTO favorites VALUES (4344, 93, 1);
INSERT INTO favorites VALUES (4345, 36, 1);
INSERT INTO favorites VALUES (4345, 41, 2);
INSERT INTO favorites VALUES (4347, 58, 1);
INSERT INTO favorites VALUES (4347, 24, 2);
INSERT INTO favorites VALUES (4348, 19, 1);
INSERT INTO favorites VALUES (4349, 73, 4);
INSERT INTO favorites VALUES (4349, 96, 1);
INSERT INTO favorites VALUES (4349, 18, 3);
INSERT INTO favorites VALUES (4349, 98, 2);
INSERT INTO favorites VALUES (4350, 105, 2);
INSERT INTO favorites VALUES (4350, 9, 1);
INSERT INTO favorites VALUES (4351, 50, 1);
INSERT INTO favorites VALUES (4351, 70, 2);
INSERT INTO favorites VALUES (4353, 97, 4);
INSERT INTO favorites VALUES (4353, 115, 1);
INSERT INTO favorites VALUES (4353, 7, 3);
INSERT INTO favorites VALUES (4353, 37, 2);
INSERT INTO favorites VALUES (4354, 114, 2);
INSERT INTO favorites VALUES (4354, 62, 1);
INSERT INTO favorites VALUES (4354, 89, 3);
INSERT INTO favorites VALUES (4355, 38, 1);
INSERT INTO favorites VALUES (4356, 77, 3);
INSERT INTO favorites VALUES (4356, 38, 1);
INSERT INTO favorites VALUES (4356, 25, 2);
INSERT INTO favorites VALUES (4356, 7, 4);
INSERT INTO favorites VALUES (4357, 31, 4);
INSERT INTO favorites VALUES (4357, 61, 1);
INSERT INTO favorites VALUES (4357, 80, 2);
INSERT INTO favorites VALUES (4357, 24, 3);
INSERT INTO favorites VALUES (4358, 32, 1);
INSERT INTO favorites VALUES (4359, 42, 3);
INSERT INTO favorites VALUES (4359, 78, 2);
INSERT INTO favorites VALUES (4359, 35, 1);
INSERT INTO favorites VALUES (4360, 22, 1);
INSERT INTO favorites VALUES (4361, 3, 2);
INSERT INTO favorites VALUES (4361, 31, 3);
INSERT INTO favorites VALUES (4361, 60, 1);
INSERT INTO favorites VALUES (4361, 3, 5);
INSERT INTO favorites VALUES (4361, 42, 4);
INSERT INTO favorites VALUES (4362, 33, 1);
INSERT INTO favorites VALUES (4362, 115, 2);
INSERT INTO favorites VALUES (4363, 109, 1);
INSERT INTO favorites VALUES (4364, 23, 4);
INSERT INTO favorites VALUES (4364, 16, 2);
INSERT INTO favorites VALUES (4364, 56, 1);
INSERT INTO favorites VALUES (4364, 8, 3);
INSERT INTO favorites VALUES (4365, 92, 3);
INSERT INTO favorites VALUES (4365, 93, 1);
INSERT INTO favorites VALUES (4365, 45, 2);
INSERT INTO favorites VALUES (4367, 93, 1);
INSERT INTO favorites VALUES (4367, 32, 2);
INSERT INTO favorites VALUES (4368, 63, 1);
INSERT INTO favorites VALUES (4369, 73, 1);
INSERT INTO favorites VALUES (4369, 57, 2);
INSERT INTO favorites VALUES (4370, 105, 2);
INSERT INTO favorites VALUES (4370, 16, 1);
INSERT INTO favorites VALUES (4370, 42, 3);
INSERT INTO favorites VALUES (4371, 71, 1);
INSERT INTO favorites VALUES (4372, 13, 4);
INSERT INTO favorites VALUES (4372, 13, 1);
INSERT INTO favorites VALUES (4372, 43, 3);
INSERT INTO favorites VALUES (4372, 79, 2);
INSERT INTO favorites VALUES (4373, 30, 3);
INSERT INTO favorites VALUES (4373, 35, 1);
INSERT INTO favorites VALUES (4373, 92, 2);
INSERT INTO favorites VALUES (4374, 21, 1);
INSERT INTO favorites VALUES (4375, 26, 4);
INSERT INTO favorites VALUES (4375, 40, 5);
INSERT INTO favorites VALUES (4375, 17, 1);
INSERT INTO favorites VALUES (4375, 50, 2);
INSERT INTO favorites VALUES (4375, 52, 3);
INSERT INTO favorites VALUES (4376, 74, 1);
INSERT INTO favorites VALUES (4377, 14, 1);
INSERT INTO favorites VALUES (4378, 29, 4);
INSERT INTO favorites VALUES (4378, 11, 5);
INSERT INTO favorites VALUES (4378, 47, 1);
INSERT INTO favorites VALUES (4378, 74, 2);
INSERT INTO favorites VALUES (4378, 14, 3);
INSERT INTO favorites VALUES (4379, 35, 3);
INSERT INTO favorites VALUES (4379, 97, 1);
INSERT INTO favorites VALUES (4379, 48, 2);
INSERT INTO favorites VALUES (4380, 39, 1);
INSERT INTO favorites VALUES (4381, 17, 1);
INSERT INTO favorites VALUES (4381, 107, 2);
INSERT INTO favorites VALUES (4382, 54, 1);
INSERT INTO favorites VALUES (4383, 1, 1);
INSERT INTO favorites VALUES (4385, 71, 1);
INSERT INTO favorites VALUES (4386, 86, 4);
INSERT INTO favorites VALUES (4386, 88, 3);
INSERT INTO favorites VALUES (4386, 67, 2);
INSERT INTO favorites VALUES (4386, 107, 1);
INSERT INTO favorites VALUES (4387, 37, 4);
INSERT INTO favorites VALUES (4387, 36, 2);
INSERT INTO favorites VALUES (4387, 12, 1);
INSERT INTO favorites VALUES (4387, 5, 3);
INSERT INTO favorites VALUES (4388, 64, 3);
INSERT INTO favorites VALUES (4388, 103, 1);
INSERT INTO favorites VALUES (4388, 84, 2);
INSERT INTO favorites VALUES (4389, 111, 1);
INSERT INTO favorites VALUES (4390, 61, 4);
INSERT INTO favorites VALUES (4390, 16, 3);
INSERT INTO favorites VALUES (4390, 87, 2);
INSERT INTO favorites VALUES (4390, 10, 1);
INSERT INTO favorites VALUES (4391, 65, 4);
INSERT INTO favorites VALUES (4391, 47, 1);
INSERT INTO favorites VALUES (4391, 107, 3);
INSERT INTO favorites VALUES (4391, 36, 2);
INSERT INTO favorites VALUES (4392, 4, 1);
INSERT INTO favorites VALUES (4392, 6, 3);
INSERT INTO favorites VALUES (4392, 31, 2);
INSERT INTO favorites VALUES (4393, 81, 1);
INSERT INTO favorites VALUES (4393, 45, 2);
INSERT INTO favorites VALUES (4394, 5, 4);
INSERT INTO favorites VALUES (4394, 15, 1);
INSERT INTO favorites VALUES (4394, 8, 3);
INSERT INTO favorites VALUES (4394, 35, 2);
INSERT INTO favorites VALUES (4395, 37, 1);
INSERT INTO favorites VALUES (4395, 29, 2);
INSERT INTO favorites VALUES (4396, 95, 3);
INSERT INTO favorites VALUES (4396, 57, 1);
INSERT INTO favorites VALUES (4396, 41, 2);
INSERT INTO favorites VALUES (4396, 65, 4);
INSERT INTO favorites VALUES (4397, 105, 1);
INSERT INTO favorites VALUES (4397, 88, 2);
INSERT INTO favorites VALUES (4400, 88, 1);
INSERT INTO favorites VALUES (4400, 85, 2);
INSERT INTO favorites VALUES (4400, 12, 3);
INSERT INTO favorites VALUES (4400, 63, 4);
INSERT INTO favorites VALUES (4400, 46, 5);
INSERT INTO favorites VALUES (4401, 5, 3);
INSERT INTO favorites VALUES (4401, 114, 1);
INSERT INTO favorites VALUES (4401, 61, 4);
INSERT INTO favorites VALUES (4401, 12, 2);
INSERT INTO favorites VALUES (4403, 44, 3);
INSERT INTO favorites VALUES (4403, 69, 1);
INSERT INTO favorites VALUES (4403, 48, 2);
INSERT INTO favorites VALUES (4404, 40, 3);
INSERT INTO favorites VALUES (4404, 23, 1);
INSERT INTO favorites VALUES (4404, 9, 2);
INSERT INTO favorites VALUES (4404, 87, 4);
INSERT INTO favorites VALUES (4405, 54, 3);
INSERT INTO favorites VALUES (4405, 62, 1);
INSERT INTO favorites VALUES (4405, 42, 2);
INSERT INTO favorites VALUES (4406, 80, 1);
INSERT INTO favorites VALUES (4407, 69, 4);
INSERT INTO favorites VALUES (4407, 84, 3);
INSERT INTO favorites VALUES (4407, 4, 1);
INSERT INTO favorites VALUES (4407, 39, 2);
INSERT INTO favorites VALUES (4407, 63, 5);
INSERT INTO favorites VALUES (4410, 71, 3);
INSERT INTO favorites VALUES (4410, 26, 1);
INSERT INTO favorites VALUES (4410, 13, 2);
INSERT INTO favorites VALUES (4411, 45, 1);
INSERT INTO favorites VALUES (4412, 47, 1);
INSERT INTO favorites VALUES (4412, 28, 2);
INSERT INTO favorites VALUES (4413, 94, 3);
INSERT INTO favorites VALUES (4413, 96, 1);
INSERT INTO favorites VALUES (4413, 93, 2);
INSERT INTO favorites VALUES (4414, 90, 1);
INSERT INTO favorites VALUES (4416, 110, 2);
INSERT INTO favorites VALUES (4416, 23, 1);
INSERT INTO favorites VALUES (4417, 63, 1);
INSERT INTO favorites VALUES (4418, 56, 5);
INSERT INTO favorites VALUES (4418, 37, 3);
INSERT INTO favorites VALUES (4418, 75, 2);
INSERT INTO favorites VALUES (4418, 64, 1);
INSERT INTO favorites VALUES (4418, 87, 4);
INSERT INTO favorites VALUES (4419, 60, 3);
INSERT INTO favorites VALUES (4419, 87, 1);
INSERT INTO favorites VALUES (4419, 32, 2);
INSERT INTO favorites VALUES (4419, 7, 4);
INSERT INTO favorites VALUES (4420, 8, 2);
INSERT INTO favorites VALUES (4420, 81, 1);
INSERT INTO favorites VALUES (4420, 105, 3);
INSERT INTO favorites VALUES (4421, 71, 4);
INSERT INTO favorites VALUES (4421, 54, 1);
INSERT INTO favorites VALUES (4421, 39, 2);
INSERT INTO favorites VALUES (4421, 104, 3);
INSERT INTO favorites VALUES (4422, 17, 1);
INSERT INTO favorites VALUES (4422, 88, 2);
INSERT INTO favorites VALUES (4423, 77, 7);
INSERT INTO favorites VALUES (4423, 114, 6);
INSERT INTO favorites VALUES (4423, 115, 4);
INSERT INTO favorites VALUES (4423, 12, 5);
INSERT INTO favorites VALUES (4423, 30, 3);
INSERT INTO favorites VALUES (4423, 80, 1);
INSERT INTO favorites VALUES (4423, 48, 2);
INSERT INTO favorites VALUES (4424, 18, 1);
INSERT INTO favorites VALUES (4425, 51, 1);
INSERT INTO favorites VALUES (4425, 65, 2);
INSERT INTO favorites VALUES (4426, 26, 1);
INSERT INTO favorites VALUES (4426, 9, 2);
INSERT INTO favorites VALUES (4427, 38, 2);
INSERT INTO favorites VALUES (4427, 75, 3);
INSERT INTO favorites VALUES (4427, 23, 1);
INSERT INTO favorites VALUES (4427, 111, 5);
INSERT INTO favorites VALUES (4427, 51, 4);
INSERT INTO favorites VALUES (4428, 30, 2);
INSERT INTO favorites VALUES (4428, 101, 3);
INSERT INTO favorites VALUES (4428, 98, 1);
INSERT INTO favorites VALUES (4429, 111, 3);
INSERT INTO favorites VALUES (4429, 45, 1);
INSERT INTO favorites VALUES (4429, 44, 2);
INSERT INTO favorites VALUES (4430, 58, 1);
INSERT INTO favorites VALUES (4430, 100, 2);
INSERT INTO favorites VALUES (4431, 100, 3);
INSERT INTO favorites VALUES (4431, 84, 2);
INSERT INTO favorites VALUES (4431, 12, 1);
INSERT INTO favorites VALUES (4432, 22, 3);
INSERT INTO favorites VALUES (4432, 8, 2);
INSERT INTO favorites VALUES (4432, 41, 1);
INSERT INTO favorites VALUES (4433, 48, 3);
INSERT INTO favorites VALUES (4433, 63, 1);
INSERT INTO favorites VALUES (4433, 34, 2);
INSERT INTO favorites VALUES (4433, 49, 4);
INSERT INTO favorites VALUES (4434, 44, 3);
INSERT INTO favorites VALUES (4434, 104, 1);
INSERT INTO favorites VALUES (4434, 8, 2);
INSERT INTO favorites VALUES (4435, 17, 4);
INSERT INTO favorites VALUES (4435, 43, 2);
INSERT INTO favorites VALUES (4435, 16, 1);
INSERT INTO favorites VALUES (4435, 115, 3);
INSERT INTO favorites VALUES (4436, 8, 4);
INSERT INTO favorites VALUES (4436, 13, 5);
INSERT INTO favorites VALUES (4436, 13, 3);
INSERT INTO favorites VALUES (4436, 96, 2);
INSERT INTO favorites VALUES (4436, 33, 1);
INSERT INTO favorites VALUES (4436, 40, 6);
INSERT INTO favorites VALUES (4437, 8, 1);
INSERT INTO favorites VALUES (4439, 4, 3);
INSERT INTO favorites VALUES (4439, 37, 1);
INSERT INTO favorites VALUES (4439, 38, 2);
INSERT INTO favorites VALUES (4440, 102, 1);
INSERT INTO favorites VALUES (4441, 20, 1);
INSERT INTO favorites VALUES (4441, 13, 2);
INSERT INTO favorites VALUES (4442, 13, 4);
INSERT INTO favorites VALUES (4442, 56, 2);
INSERT INTO favorites VALUES (4442, 109, 1);
INSERT INTO favorites VALUES (4442, 74, 3);
INSERT INTO favorites VALUES (4443, 50, 1);
INSERT INTO favorites VALUES (4444, 45, 2);
INSERT INTO favorites VALUES (4444, 34, 1);
INSERT INTO favorites VALUES (4445, 63, 1);
INSERT INTO favorites VALUES (4445, 100, 2);
INSERT INTO favorites VALUES (4446, 105, 4);
INSERT INTO favorites VALUES (4446, 42, 1);
INSERT INTO favorites VALUES (4446, 24, 2);
INSERT INTO favorites VALUES (4446, 34, 3);
INSERT INTO favorites VALUES (4448, 12, 3);
INSERT INTO favorites VALUES (4448, 8, 2);
INSERT INTO favorites VALUES (4448, 2, 1);
INSERT INTO favorites VALUES (4450, 65, 1);
INSERT INTO favorites VALUES (4451, 66, 4);
INSERT INTO favorites VALUES (4451, 25, 2);
INSERT INTO favorites VALUES (4451, 20, 1);
INSERT INTO favorites VALUES (4451, 47, 3);
INSERT INTO favorites VALUES (4452, 75, 1);
INSERT INTO favorites VALUES (4453, 92, 1);
INSERT INTO favorites VALUES (4454, 86, 2);
INSERT INTO favorites VALUES (4454, 24, 1);
INSERT INTO favorites VALUES (4454, 49, 3);
INSERT INTO favorites VALUES (4455, 19, 1);
INSERT INTO favorites VALUES (4455, 8, 2);
INSERT INTO favorites VALUES (4456, 26, 3);
INSERT INTO favorites VALUES (4456, 9, 2);
INSERT INTO favorites VALUES (4456, 31, 1);
INSERT INTO favorites VALUES (4457, 18, 1);
INSERT INTO favorites VALUES (4460, 35, 1);
INSERT INTO favorites VALUES (4460, 26, 3);
INSERT INTO favorites VALUES (4460, 90, 2);
INSERT INTO favorites VALUES (4462, 65, 3);
INSERT INTO favorites VALUES (4462, 31, 2);
INSERT INTO favorites VALUES (4462, 23, 1);
INSERT INTO favorites VALUES (4463, 109, 4);
INSERT INTO favorites VALUES (4463, 28, 5);
INSERT INTO favorites VALUES (4463, 32, 1);
INSERT INTO favorites VALUES (4463, 1, 3);
INSERT INTO favorites VALUES (4463, 2, 2);
INSERT INTO favorites VALUES (4464, 108, 1);
INSERT INTO favorites VALUES (4465, 18, 1);
INSERT INTO favorites VALUES (4465, 31, 2);
INSERT INTO favorites VALUES (4466, 45, 1);
INSERT INTO favorites VALUES (4466, 15, 2);
INSERT INTO favorites VALUES (4467, 18, 5);
INSERT INTO favorites VALUES (4467, 81, 3);
INSERT INTO favorites VALUES (4467, 71, 2);
INSERT INTO favorites VALUES (4467, 41, 1);
INSERT INTO favorites VALUES (4467, 95, 4);
INSERT INTO favorites VALUES (4468, 40, 3);
INSERT INTO favorites VALUES (4468, 84, 1);
INSERT INTO favorites VALUES (4468, 43, 2);
INSERT INTO favorites VALUES (4468, 41, 4);
INSERT INTO favorites VALUES (4469, 91, 4);
INSERT INTO favorites VALUES (4469, 62, 5);
INSERT INTO favorites VALUES (4469, 66, 1);
INSERT INTO favorites VALUES (4469, 90, 2);
INSERT INTO favorites VALUES (4469, 1, 3);
INSERT INTO favorites VALUES (4470, 37, 6);
INSERT INTO favorites VALUES (4470, 40, 5);
INSERT INTO favorites VALUES (4470, 31, 3);
INSERT INTO favorites VALUES (4470, 28, 2);
INSERT INTO favorites VALUES (4470, 7, 1);
INSERT INTO favorites VALUES (4470, 52, 4);
INSERT INTO favorites VALUES (4471, 45, 3);
INSERT INTO favorites VALUES (4471, 1, 1);
INSERT INTO favorites VALUES (4471, 38, 2);
INSERT INTO favorites VALUES (4472, 93, 5);
INSERT INTO favorites VALUES (4472, 18, 4);
INSERT INTO favorites VALUES (4472, 107, 1);
INSERT INTO favorites VALUES (4472, 55, 3);
INSERT INTO favorites VALUES (4472, 105, 2);
INSERT INTO favorites VALUES (4474, 22, 1);
INSERT INTO favorites VALUES (4475, 22, 1);
INSERT INTO favorites VALUES (4475, 7, 2);
INSERT INTO favorites VALUES (4477, 25, 8);
INSERT INTO favorites VALUES (4477, 36, 6);
INSERT INTO favorites VALUES (4477, 18, 7);
INSERT INTO favorites VALUES (4477, 18, 1);
INSERT INTO favorites VALUES (4477, 104, 3);
INSERT INTO favorites VALUES (4477, 70, 5);
INSERT INTO favorites VALUES (4477, 37, 2);
INSERT INTO favorites VALUES (4477, 33, 4);
INSERT INTO favorites VALUES (4478, 14, 4);
INSERT INTO favorites VALUES (4478, 80, 5);
INSERT INTO favorites VALUES (4478, 82, 1);
INSERT INTO favorites VALUES (4478, 45, 2);
INSERT INTO favorites VALUES (4478, 86, 3);
INSERT INTO favorites VALUES (4479, 85, 1);
INSERT INTO favorites VALUES (4479, 13, 2);
INSERT INTO favorites VALUES (4480, 83, 2);
INSERT INTO favorites VALUES (4480, 75, 1);
INSERT INTO favorites VALUES (4480, 9, 3);
INSERT INTO favorites VALUES (4481, 54, 3);
INSERT INTO favorites VALUES (4481, 35, 1);
INSERT INTO favorites VALUES (4481, 32, 2);
INSERT INTO favorites VALUES (4482, 54, 1);
INSERT INTO favorites VALUES (4483, 114, 4);
INSERT INTO favorites VALUES (4483, 6, 1);
INSERT INTO favorites VALUES (4483, 52, 3);
INSERT INTO favorites VALUES (4483, 44, 2);
INSERT INTO favorites VALUES (4484, 14, 2);
INSERT INTO favorites VALUES (4484, 26, 1);
INSERT INTO favorites VALUES (4484, 21, 3);
INSERT INTO favorites VALUES (4485, 27, 5);
INSERT INTO favorites VALUES (4485, 10, 4);
INSERT INTO favorites VALUES (4485, 64, 2);
INSERT INTO favorites VALUES (4485, 67, 1);
INSERT INTO favorites VALUES (4485, 54, 3);
INSERT INTO favorites VALUES (4486, 104, 1);
INSERT INTO favorites VALUES (4486, 116, 2);
INSERT INTO favorites VALUES (4487, 50, 2);
INSERT INTO favorites VALUES (4487, 86, 1);
INSERT INTO favorites VALUES (4488, 3, 2);
INSERT INTO favorites VALUES (4488, 19, 1);
INSERT INTO favorites VALUES (4488, 61, 3);
INSERT INTO favorites VALUES (4489, 81, 1);
INSERT INTO favorites VALUES (4490, 24, 3);
INSERT INTO favorites VALUES (4490, 22, 1);
INSERT INTO favorites VALUES (4490, 2, 2);
INSERT INTO favorites VALUES (4491, 84, 1);
INSERT INTO favorites VALUES (4492, 22, 4);
INSERT INTO favorites VALUES (4492, 45, 1);
INSERT INTO favorites VALUES (4492, 5, 2);
INSERT INTO favorites VALUES (4492, 86, 3);
INSERT INTO favorites VALUES (4494, 62, 3);
INSERT INTO favorites VALUES (4494, 71, 2);
INSERT INTO favorites VALUES (4494, 49, 1);
INSERT INTO favorites VALUES (4495, 5, 3);
INSERT INTO favorites VALUES (4495, 81, 2);
INSERT INTO favorites VALUES (4495, 34, 1);
INSERT INTO favorites VALUES (4495, 115, 4);
INSERT INTO favorites VALUES (4496, 43, 1);
INSERT INTO favorites VALUES (4496, 2, 2);
INSERT INTO favorites VALUES (4497, 17, 2);
INSERT INTO favorites VALUES (4497, 29, 3);
INSERT INTO favorites VALUES (4497, 3, 5);
INSERT INTO favorites VALUES (4497, 26, 1);
INSERT INTO favorites VALUES (4497, 106, 4);
INSERT INTO favorites VALUES (4498, 80, 6);
INSERT INTO favorites VALUES (4498, 70, 3);
INSERT INTO favorites VALUES (4498, 34, 1);
INSERT INTO favorites VALUES (4498, 20, 5);
INSERT INTO favorites VALUES (4498, 104, 2);
INSERT INTO favorites VALUES (4498, 66, 4);
INSERT INTO favorites VALUES (4499, 4, 3);
INSERT INTO favorites VALUES (4499, 95, 1);
INSERT INTO favorites VALUES (4499, 30, 2);
INSERT INTO favorites VALUES (4499, 4, 4);
INSERT INTO favorites VALUES (4500, 39, 1);
INSERT INTO favorites VALUES (4500, 73, 2);
INSERT INTO favorites VALUES (4500, 63, 3);
INSERT INTO favorites VALUES (4501, 29, 2);
INSERT INTO favorites VALUES (4501, 35, 1);
INSERT INTO favorites VALUES (4501, 7, 3);
INSERT INTO favorites VALUES (4502, 9, 3);
INSERT INTO favorites VALUES (4502, 7, 1);
INSERT INTO favorites VALUES (4502, 17, 2);
INSERT INTO favorites VALUES (4503, 47, 4);
INSERT INTO favorites VALUES (4503, 90, 2);
INSERT INTO favorites VALUES (4503, 46, 1);
INSERT INTO favorites VALUES (4503, 24, 3);
INSERT INTO favorites VALUES (4504, 26, 5);
INSERT INTO favorites VALUES (4504, 36, 4);
INSERT INTO favorites VALUES (4504, 14, 1);
INSERT INTO favorites VALUES (4504, 25, 2);
INSERT INTO favorites VALUES (4504, 13, 3);
INSERT INTO favorites VALUES (4505, 47, 2);
INSERT INTO favorites VALUES (4505, 39, 1);
INSERT INTO favorites VALUES (4505, 82, 4);
INSERT INTO favorites VALUES (4505, 99, 3);
INSERT INTO favorites VALUES (4506, 116, 1);
INSERT INTO favorites VALUES (4506, 113, 2);
INSERT INTO favorites VALUES (4507, 47, 1);
INSERT INTO favorites VALUES (4508, 11, 2);
INSERT INTO favorites VALUES (4508, 82, 1);
INSERT INTO favorites VALUES (4508, 14, 3);
INSERT INTO favorites VALUES (4509, 62, 2);
INSERT INTO favorites VALUES (4509, 63, 1);
INSERT INTO favorites VALUES (4510, 41, 4);
INSERT INTO favorites VALUES (4510, 48, 1);
INSERT INTO favorites VALUES (4510, 63, 2);
INSERT INTO favorites VALUES (4510, 5, 3);
INSERT INTO favorites VALUES (4511, 60, 3);
INSERT INTO favorites VALUES (4511, 38, 2);
INSERT INTO favorites VALUES (4511, 49, 1);
INSERT INTO favorites VALUES (4511, 100, 4);
INSERT INTO favorites VALUES (4512, 87, 1);
INSERT INTO favorites VALUES (4513, 10, 5);
INSERT INTO favorites VALUES (4513, 15, 4);
INSERT INTO favorites VALUES (4513, 63, 2);
INSERT INTO favorites VALUES (4513, 33, 1);
INSERT INTO favorites VALUES (4513, 38, 3);
INSERT INTO favorites VALUES (4514, 1, 1);
INSERT INTO favorites VALUES (4515, 72, 1);
INSERT INTO favorites VALUES (4515, 73, 2);
INSERT INTO favorites VALUES (4516, 82, 1);
INSERT INTO favorites VALUES (4517, 107, 1);
INSERT INTO favorites VALUES (4517, 65, 2);
INSERT INTO favorites VALUES (4518, 67, 5);
INSERT INTO favorites VALUES (4518, 53, 2);
INSERT INTO favorites VALUES (4518, 111, 1);
INSERT INTO favorites VALUES (4518, 2, 4);
INSERT INTO favorites VALUES (4518, 88, 3);
INSERT INTO favorites VALUES (4519, 29, 5);
INSERT INTO favorites VALUES (4519, 86, 3);
INSERT INTO favorites VALUES (4519, 82, 2);
INSERT INTO favorites VALUES (4519, 113, 1);
INSERT INTO favorites VALUES (4519, 8, 4);
INSERT INTO favorites VALUES (4520, 25, 1);
INSERT INTO favorites VALUES (4520, 19, 2);
INSERT INTO favorites VALUES (4521, 44, 1);
INSERT INTO favorites VALUES (4521, 92, 2);
INSERT INTO favorites VALUES (4523, 78, 2);
INSERT INTO favorites VALUES (4523, 74, 1);
INSERT INTO favorites VALUES (4524, 50, 1);
INSERT INTO favorites VALUES (4525, 32, 3);
INSERT INTO favorites VALUES (4525, 9, 2);
INSERT INTO favorites VALUES (4525, 44, 1);
INSERT INTO favorites VALUES (4526, 24, 1);
INSERT INTO favorites VALUES (4526, 50, 2);
INSERT INTO favorites VALUES (4528, 97, 4);
INSERT INTO favorites VALUES (4528, 60, 5);
INSERT INTO favorites VALUES (4528, 69, 2);
INSERT INTO favorites VALUES (4528, 101, 1);
INSERT INTO favorites VALUES (4528, 106, 3);
INSERT INTO favorites VALUES (4529, 15, 1);
INSERT INTO favorites VALUES (4529, 58, 2);
INSERT INTO favorites VALUES (4530, 17, 1);
INSERT INTO favorites VALUES (4531, 23, 1);
INSERT INTO favorites VALUES (4532, 53, 4);
INSERT INTO favorites VALUES (4532, 75, 1);
INSERT INTO favorites VALUES (4532, 98, 3);
INSERT INTO favorites VALUES (4532, 7, 2);
INSERT INTO favorites VALUES (4533, 18, 3);
INSERT INTO favorites VALUES (4533, 106, 2);
INSERT INTO favorites VALUES (4533, 78, 1);
INSERT INTO favorites VALUES (4534, 87, 1);
INSERT INTO favorites VALUES (4534, 34, 2);
INSERT INTO favorites VALUES (4535, 9, 3);
INSERT INTO favorites VALUES (4535, 63, 1);
INSERT INTO favorites VALUES (4535, 94, 2);
INSERT INTO favorites VALUES (4536, 43, 3);
INSERT INTO favorites VALUES (4536, 79, 1);
INSERT INTO favorites VALUES (4536, 35, 2);
INSERT INTO favorites VALUES (4537, 81, 4);
INSERT INTO favorites VALUES (4537, 62, 5);
INSERT INTO favorites VALUES (4537, 42, 2);
INSERT INTO favorites VALUES (4537, 60, 1);
INSERT INTO favorites VALUES (4537, 3, 3);
INSERT INTO favorites VALUES (4538, 3, 3);
INSERT INTO favorites VALUES (4538, 26, 2);
INSERT INTO favorites VALUES (4538, 106, 1);
INSERT INTO favorites VALUES (4539, 6, 1);
INSERT INTO favorites VALUES (4540, 23, 1);
INSERT INTO favorites VALUES (4541, 116, 1);
INSERT INTO favorites VALUES (4541, 22, 2);
INSERT INTO favorites VALUES (4542, 89, 3);
INSERT INTO favorites VALUES (4542, 51, 1);
INSERT INTO favorites VALUES (4542, 4, 2);
INSERT INTO favorites VALUES (4543, 105, 4);
INSERT INTO favorites VALUES (4543, 112, 2);
INSERT INTO favorites VALUES (4543, 19, 1);
INSERT INTO favorites VALUES (4543, 12, 3);
INSERT INTO favorites VALUES (4544, 39, 3);
INSERT INTO favorites VALUES (4544, 51, 1);
INSERT INTO favorites VALUES (4544, 32, 2);
INSERT INTO favorites VALUES (4545, 113, 3);
INSERT INTO favorites VALUES (4545, 74, 2);
INSERT INTO favorites VALUES (4545, 23, 1);
INSERT INTO favorites VALUES (4545, 81, 4);
INSERT INTO favorites VALUES (4546, 65, 1);
INSERT INTO favorites VALUES (4547, 33, 3);
INSERT INTO favorites VALUES (4547, 58, 1);
INSERT INTO favorites VALUES (4547, 98, 2);
INSERT INTO favorites VALUES (4548, 50, 1);
INSERT INTO favorites VALUES (4548, 65, 2);
INSERT INTO favorites VALUES (4549, 44, 1);
INSERT INTO favorites VALUES (4549, 90, 2);
INSERT INTO favorites VALUES (4550, 51, 4);
INSERT INTO favorites VALUES (4550, 47, 2);
INSERT INTO favorites VALUES (4550, 2, 3);
INSERT INTO favorites VALUES (4550, 17, 1);
INSERT INTO favorites VALUES (4551, 26, 2);
INSERT INTO favorites VALUES (4551, 32, 1);
INSERT INTO favorites VALUES (4552, 4, 3);
INSERT INTO favorites VALUES (4552, 82, 1);
INSERT INTO favorites VALUES (4552, 16, 2);
INSERT INTO favorites VALUES (4553, 15, 3);
INSERT INTO favorites VALUES (4553, 92, 1);
INSERT INTO favorites VALUES (4553, 22, 2);
INSERT INTO favorites VALUES (4554, 82, 3);
INSERT INTO favorites VALUES (4554, 30, 1);
INSERT INTO favorites VALUES (4554, 17, 2);
INSERT INTO favorites VALUES (4555, 18, 3);
INSERT INTO favorites VALUES (4555, 81, 2);
INSERT INTO favorites VALUES (4555, 36, 1);
INSERT INTO favorites VALUES (4555, 37, 4);
INSERT INTO favorites VALUES (4556, 35, 4);
INSERT INTO favorites VALUES (4556, 16, 1);
INSERT INTO favorites VALUES (4556, 9, 3);
INSERT INTO favorites VALUES (4556, 59, 2);
INSERT INTO favorites VALUES (4557, 92, 4);
INSERT INTO favorites VALUES (4557, 56, 1);
INSERT INTO favorites VALUES (4557, 41, 2);
INSERT INTO favorites VALUES (4557, 78, 3);
INSERT INTO favorites VALUES (4558, 24, 1);
INSERT INTO favorites VALUES (4558, 24, 2);
INSERT INTO favorites VALUES (4559, 38, 3);
INSERT INTO favorites VALUES (4559, 7, 1);
INSERT INTO favorites VALUES (4559, 78, 2);
INSERT INTO favorites VALUES (4561, 27, 3);
INSERT INTO favorites VALUES (4561, 65, 1);
INSERT INTO favorites VALUES (4561, 96, 2);
INSERT INTO favorites VALUES (4563, 53, 1);
INSERT INTO favorites VALUES (4564, 95, 3);
INSERT INTO favorites VALUES (4564, 60, 1);
INSERT INTO favorites VALUES (4564, 68, 2);
INSERT INTO favorites VALUES (4564, 84, 4);
INSERT INTO favorites VALUES (4565, 60, 3);
INSERT INTO favorites VALUES (4565, 29, 2);
INSERT INTO favorites VALUES (4565, 4, 1);
INSERT INTO favorites VALUES (4566, 112, 1);
INSERT INTO favorites VALUES (4567, 48, 1);
INSERT INTO favorites VALUES (4567, 112, 2);
INSERT INTO favorites VALUES (4569, 73, 1);
INSERT INTO favorites VALUES (4570, 27, 1);
INSERT INTO favorites VALUES (4570, 9, 2);
INSERT INTO favorites VALUES (4573, 2, 1);
INSERT INTO favorites VALUES (4574, 17, 3);
INSERT INTO favorites VALUES (4574, 47, 1);
INSERT INTO favorites VALUES (4574, 34, 2);
INSERT INTO favorites VALUES (4575, 65, 6);
INSERT INTO favorites VALUES (4575, 14, 4);
INSERT INTO favorites VALUES (4575, 73, 3);
INSERT INTO favorites VALUES (4575, 97, 2);
INSERT INTO favorites VALUES (4575, 73, 1);
INSERT INTO favorites VALUES (4575, 82, 5);
INSERT INTO favorites VALUES (4576, 100, 1);
INSERT INTO favorites VALUES (4576, 36, 2);
INSERT INTO favorites VALUES (4577, 98, 3);
INSERT INTO favorites VALUES (4577, 14, 1);
INSERT INTO favorites VALUES (4577, 46, 2);
INSERT INTO favorites VALUES (4578, 47, 1);
INSERT INTO favorites VALUES (4578, 14, 2);
INSERT INTO favorites VALUES (4579, 102, 3);
INSERT INTO favorites VALUES (4579, 43, 2);
INSERT INTO favorites VALUES (4579, 40, 1);
INSERT INTO favorites VALUES (4580, 105, 1);
INSERT INTO favorites VALUES (4580, 80, 2);
INSERT INTO favorites VALUES (4581, 13, 3);
INSERT INTO favorites VALUES (4581, 24, 1);
INSERT INTO favorites VALUES (4581, 31, 2);
INSERT INTO favorites VALUES (4582, 95, 4);
INSERT INTO favorites VALUES (4582, 67, 3);
INSERT INTO favorites VALUES (4582, 107, 2);
INSERT INTO favorites VALUES (4582, 87, 1);
INSERT INTO favorites VALUES (4583, 16, 2);
INSERT INTO favorites VALUES (4583, 7, 1);
INSERT INTO favorites VALUES (4583, 19, 3);
INSERT INTO favorites VALUES (4584, 65, 3);
INSERT INTO favorites VALUES (4584, 59, 1);
INSERT INTO favorites VALUES (4584, 14, 2);
INSERT INTO favorites VALUES (4585, 58, 4);
INSERT INTO favorites VALUES (4585, 54, 5);
INSERT INTO favorites VALUES (4585, 14, 1);
INSERT INTO favorites VALUES (4585, 68, 2);
INSERT INTO favorites VALUES (4585, 39, 3);
INSERT INTO favorites VALUES (4586, 59, 5);
INSERT INTO favorites VALUES (4586, 43, 4);
INSERT INTO favorites VALUES (4586, 24, 3);
INSERT INTO favorites VALUES (4586, 103, 2);
INSERT INTO favorites VALUES (4586, 19, 1);
INSERT INTO favorites VALUES (4587, 57, 4);
INSERT INTO favorites VALUES (4587, 28, 1);
INSERT INTO favorites VALUES (4587, 60, 2);
INSERT INTO favorites VALUES (4587, 36, 3);
INSERT INTO favorites VALUES (4588, 24, 6);
INSERT INTO favorites VALUES (4588, 2, 4);
INSERT INTO favorites VALUES (4588, 63, 1);
INSERT INTO favorites VALUES (4588, 15, 2);
INSERT INTO favorites VALUES (4588, 58, 3);
INSERT INTO favorites VALUES (4588, 52, 5);
INSERT INTO favorites VALUES (4589, 67, 1);
INSERT INTO favorites VALUES (4590, 38, 5);
INSERT INTO favorites VALUES (4590, 89, 6);
INSERT INTO favorites VALUES (4590, 47, 1);
INSERT INTO favorites VALUES (4590, 53, 2);
INSERT INTO favorites VALUES (4590, 35, 3);
INSERT INTO favorites VALUES (4590, 45, 4);
INSERT INTO favorites VALUES (4591, 74, 3);
INSERT INTO favorites VALUES (4591, 113, 1);
INSERT INTO favorites VALUES (4591, 28, 2);
INSERT INTO favorites VALUES (4592, 26, 1);
INSERT INTO favorites VALUES (4593, 55, 7);
INSERT INTO favorites VALUES (4593, 34, 3);
INSERT INTO favorites VALUES (4593, 46, 4);
INSERT INTO favorites VALUES (4593, 20, 2);
INSERT INTO favorites VALUES (4593, 83, 6);
INSERT INTO favorites VALUES (4593, 15, 1);
INSERT INTO favorites VALUES (4593, 39, 5);
INSERT INTO favorites VALUES (4594, 94, 4);
INSERT INTO favorites VALUES (4594, 29, 5);
INSERT INTO favorites VALUES (4594, 103, 2);
INSERT INTO favorites VALUES (4594, 88, 1);
INSERT INTO favorites VALUES (4594, 34, 3);
INSERT INTO favorites VALUES (4596, 7, 2);
INSERT INTO favorites VALUES (4596, 108, 1);
INSERT INTO favorites VALUES (4597, 14, 4);
INSERT INTO favorites VALUES (4597, 97, 1);
INSERT INTO favorites VALUES (4597, 68, 2);
INSERT INTO favorites VALUES (4597, 40, 3);
INSERT INTO favorites VALUES (4598, 85, 3);
INSERT INTO favorites VALUES (4598, 42, 2);
INSERT INTO favorites VALUES (4598, 41, 1);
INSERT INTO favorites VALUES (4598, 98, 4);
INSERT INTO favorites VALUES (4599, 22, 1);
INSERT INTO favorites VALUES (4600, 24, 1);
INSERT INTO favorites VALUES (4600, 7, 2);
INSERT INTO favorites VALUES (4600, 103, 3);
INSERT INTO favorites VALUES (4600, 64, 4);
INSERT INTO favorites VALUES (4600, 85, 5);
INSERT INTO favorites VALUES (4600, 100, 6);
INSERT INTO favorites VALUES (4601, 94, 1);
INSERT INTO favorites VALUES (4601, 42, 2);
INSERT INTO favorites VALUES (4603, 32, 3);
INSERT INTO favorites VALUES (4603, 1, 1);
INSERT INTO favorites VALUES (4603, 13, 2);
INSERT INTO favorites VALUES (4604, 97, 1);
INSERT INTO favorites VALUES (4604, 104, 2);
INSERT INTO favorites VALUES (4605, 85, 2);
INSERT INTO favorites VALUES (4605, 10, 1);
INSERT INTO favorites VALUES (4605, 90, 4);
INSERT INTO favorites VALUES (4605, 101, 3);
INSERT INTO favorites VALUES (4606, 112, 1);
INSERT INTO favorites VALUES (4606, 86, 2);
INSERT INTO favorites VALUES (4608, 20, 1);
INSERT INTO favorites VALUES (4608, 85, 2);
INSERT INTO favorites VALUES (4610, 47, 1);
INSERT INTO favorites VALUES (4610, 57, 2);
INSERT INTO favorites VALUES (4611, 52, 5);
INSERT INTO favorites VALUES (4611, 102, 3);
INSERT INTO favorites VALUES (4611, 81, 6);
INSERT INTO favorites VALUES (4611, 25, 1);
INSERT INTO favorites VALUES (4611, 6, 4);
INSERT INTO favorites VALUES (4611, 50, 2);
INSERT INTO favorites VALUES (4611, 78, 7);
INSERT INTO favorites VALUES (4612, 4, 3);
INSERT INTO favorites VALUES (4612, 103, 2);
INSERT INTO favorites VALUES (4612, 101, 1);
INSERT INTO favorites VALUES (4613, 29, 6);
INSERT INTO favorites VALUES (4613, 43, 7);
INSERT INTO favorites VALUES (4613, 87, 8);
INSERT INTO favorites VALUES (4613, 56, 9);
INSERT INTO favorites VALUES (4613, 8, 5);
INSERT INTO favorites VALUES (4613, 61, 4);
INSERT INTO favorites VALUES (4613, 19, 2);
INSERT INTO favorites VALUES (4613, 77, 3);
INSERT INTO favorites VALUES (4613, 19, 1);
INSERT INTO favorites VALUES (4613, 39, 10);
INSERT INTO favorites VALUES (4614, 79, 3);
INSERT INTO favorites VALUES (4614, 87, 2);
INSERT INTO favorites VALUES (4614, 27, 1);
INSERT INTO favorites VALUES (4615, 88, 4);
INSERT INTO favorites VALUES (4615, 8, 5);
INSERT INTO favorites VALUES (4615, 79, 3);
INSERT INTO favorites VALUES (4615, 13, 2);
INSERT INTO favorites VALUES (4615, 49, 1);
INSERT INTO favorites VALUES (4616, 23, 3);
INSERT INTO favorites VALUES (4616, 2, 1);
INSERT INTO favorites VALUES (4616, 61, 2);
INSERT INTO favorites VALUES (4617, 14, 3);
INSERT INTO favorites VALUES (4617, 48, 1);
INSERT INTO favorites VALUES (4617, 26, 2);
INSERT INTO favorites VALUES (4618, 35, 4);
INSERT INTO favorites VALUES (4618, 2, 1);
INSERT INTO favorites VALUES (4618, 6, 2);
INSERT INTO favorites VALUES (4618, 19, 3);
INSERT INTO favorites VALUES (4620, 5, 2);
INSERT INTO favorites VALUES (4620, 85, 1);
INSERT INTO favorites VALUES (4622, 25, 1);
INSERT INTO favorites VALUES (4623, 83, 1);
INSERT INTO favorites VALUES (4623, 18, 2);
INSERT INTO favorites VALUES (4624, 91, 1);
INSERT INTO favorites VALUES (4624, 19, 2);
INSERT INTO favorites VALUES (4625, 46, 3);
INSERT INTO favorites VALUES (4625, 40, 1);
INSERT INTO favorites VALUES (4625, 7, 2);
INSERT INTO favorites VALUES (4626, 21, 1);
INSERT INTO favorites VALUES (4626, 78, 2);
INSERT INTO favorites VALUES (4627, 52, 1);
INSERT INTO favorites VALUES (4627, 60, 2);
INSERT INTO favorites VALUES (4628, 87, 1);
INSERT INTO favorites VALUES (4629, 89, 4);
INSERT INTO favorites VALUES (4629, 109, 2);
INSERT INTO favorites VALUES (4629, 46, 1);
INSERT INTO favorites VALUES (4629, 9, 3);
INSERT INTO favorites VALUES (4630, 52, 2);
INSERT INTO favorites VALUES (4630, 46, 1);
INSERT INTO favorites VALUES (4631, 65, 1);
INSERT INTO favorites VALUES (4632, 97, 1);
INSERT INTO favorites VALUES (4634, 66, 3);
INSERT INTO favorites VALUES (4634, 7, 2);
INSERT INTO favorites VALUES (4634, 84, 1);
INSERT INTO favorites VALUES (4635, 107, 2);
INSERT INTO favorites VALUES (4635, 36, 3);
INSERT INTO favorites VALUES (4635, 63, 5);
INSERT INTO favorites VALUES (4635, 36, 1);
INSERT INTO favorites VALUES (4635, 19, 4);
INSERT INTO favorites VALUES (4636, 12, 1);
INSERT INTO favorites VALUES (4636, 61, 2);
INSERT INTO favorites VALUES (4637, 52, 6);
INSERT INTO favorites VALUES (4637, 5, 5);
INSERT INTO favorites VALUES (4637, 44, 2);
INSERT INTO favorites VALUES (4637, 19, 3);
INSERT INTO favorites VALUES (4637, 53, 4);
INSERT INTO favorites VALUES (4637, 3, 1);
INSERT INTO favorites VALUES (4638, 25, 1);
INSERT INTO favorites VALUES (4639, 7, 3);
INSERT INTO favorites VALUES (4639, 40, 1);
INSERT INTO favorites VALUES (4639, 40, 2);
INSERT INTO favorites VALUES (4639, 33, 4);
INSERT INTO favorites VALUES (4641, 37, 3);
INSERT INTO favorites VALUES (4641, 50, 1);
INSERT INTO favorites VALUES (4641, 92, 2);
INSERT INTO favorites VALUES (4642, 9, 1);
INSERT INTO favorites VALUES (4642, 41, 2);
INSERT INTO favorites VALUES (4643, 23, 1);
INSERT INTO favorites VALUES (4644, 17, 3);
INSERT INTO favorites VALUES (4644, 60, 4);
INSERT INTO favorites VALUES (4644, 20, 2);
INSERT INTO favorites VALUES (4644, 31, 1);
INSERT INTO favorites VALUES (4644, 61, 5);
INSERT INTO favorites VALUES (4645, 22, 3);
INSERT INTO favorites VALUES (4645, 3, 1);
INSERT INTO favorites VALUES (4645, 26, 2);
INSERT INTO favorites VALUES (4646, 26, 4);
INSERT INTO favorites VALUES (4646, 44, 1);
INSERT INTO favorites VALUES (4646, 58, 3);
INSERT INTO favorites VALUES (4646, 39, 2);
INSERT INTO favorites VALUES (4647, 36, 3);
INSERT INTO favorites VALUES (4647, 61, 1);
INSERT INTO favorites VALUES (4647, 33, 2);
INSERT INTO favorites VALUES (4648, 113, 3);
INSERT INTO favorites VALUES (4648, 34, 1);
INSERT INTO favorites VALUES (4648, 88, 2);
INSERT INTO favorites VALUES (4649, 6, 3);
INSERT INTO favorites VALUES (4649, 8, 2);
INSERT INTO favorites VALUES (4649, 28, 1);
INSERT INTO favorites VALUES (4650, 65, 4);
INSERT INTO favorites VALUES (4650, 27, 5);
INSERT INTO favorites VALUES (4650, 60, 3);
INSERT INTO favorites VALUES (4650, 17, 1);
INSERT INTO favorites VALUES (4650, 70, 2);
INSERT INTO favorites VALUES (4651, 37, 1);
INSERT INTO favorites VALUES (4651, 11, 2);
INSERT INTO favorites VALUES (4652, 65, 4);
INSERT INTO favorites VALUES (4652, 92, 1);
INSERT INTO favorites VALUES (4652, 80, 2);
INSERT INTO favorites VALUES (4652, 67, 3);
INSERT INTO favorites VALUES (4653, 82, 4);
INSERT INTO favorites VALUES (4653, 48, 5);
INSERT INTO favorites VALUES (4653, 43, 6);
INSERT INTO favorites VALUES (4653, 74, 2);
INSERT INTO favorites VALUES (4653, 63, 3);
INSERT INTO favorites VALUES (4653, 6, 1);
INSERT INTO favorites VALUES (4653, 52, 7);
INSERT INTO favorites VALUES (4654, 54, 1);
INSERT INTO favorites VALUES (4654, 13, 2);
INSERT INTO favorites VALUES (4656, 29, 1);
INSERT INTO favorites VALUES (4657, 68, 3);
INSERT INTO favorites VALUES (4657, 107, 1);
INSERT INTO favorites VALUES (4657, 14, 2);
INSERT INTO favorites VALUES (4658, 36, 1);
INSERT INTO favorites VALUES (4659, 105, 6);
INSERT INTO favorites VALUES (4659, 18, 7);
INSERT INTO favorites VALUES (4659, 55, 2);
INSERT INTO favorites VALUES (4659, 61, 4);
INSERT INTO favorites VALUES (4659, 106, 5);
INSERT INTO favorites VALUES (4659, 28, 1);
INSERT INTO favorites VALUES (4659, 36, 3);
INSERT INTO favorites VALUES (4660, 18, 3);
INSERT INTO favorites VALUES (4660, 61, 1);
INSERT INTO favorites VALUES (4660, 6, 2);
INSERT INTO favorites VALUES (4661, 9, 1);
INSERT INTO favorites VALUES (4661, 57, 2);
INSERT INTO favorites VALUES (4662, 61, 2);
INSERT INTO favorites VALUES (4662, 63, 1);
INSERT INTO favorites VALUES (4662, 26, 3);
INSERT INTO favorites VALUES (4663, 60, 1);
INSERT INTO favorites VALUES (4663, 43, 2);
INSERT INTO favorites VALUES (4664, 15, 3);
INSERT INTO favorites VALUES (4664, 54, 1);
INSERT INTO favorites VALUES (4664, 35, 2);
INSERT INTO favorites VALUES (4665, 48, 2);
INSERT INTO favorites VALUES (4665, 58, 1);
INSERT INTO favorites VALUES (4666, 78, 3);
INSERT INTO favorites VALUES (4666, 75, 2);
INSERT INTO favorites VALUES (4666, 45, 1);
INSERT INTO favorites VALUES (4667, 101, 1);
INSERT INTO favorites VALUES (4667, 82, 2);
INSERT INTO favorites VALUES (4668, 109, 3);
INSERT INTO favorites VALUES (4668, 32, 1);
INSERT INTO favorites VALUES (4668, 93, 2);
INSERT INTO favorites VALUES (4669, 4, 3);
INSERT INTO favorites VALUES (4669, 41, 1);
INSERT INTO favorites VALUES (4669, 6, 2);
INSERT INTO favorites VALUES (4669, 49, 4);
INSERT INTO favorites VALUES (4670, 55, 3);
INSERT INTO favorites VALUES (4670, 11, 2);
INSERT INTO favorites VALUES (4670, 6, 1);
INSERT INTO favorites VALUES (4671, 43, 1);
INSERT INTO favorites VALUES (4671, 66, 2);
INSERT INTO favorites VALUES (4672, 27, 3);
INSERT INTO favorites VALUES (4672, 6, 1);
INSERT INTO favorites VALUES (4672, 43, 2);
INSERT INTO favorites VALUES (4673, 77, 3);
INSERT INTO favorites VALUES (4673, 64, 1);
INSERT INTO favorites VALUES (4673, 12, 2);
INSERT INTO favorites VALUES (4675, 48, 4);
INSERT INTO favorites VALUES (4675, 60, 2);
INSERT INTO favorites VALUES (4675, 96, 1);
INSERT INTO favorites VALUES (4675, 16, 3);
INSERT INTO favorites VALUES (4676, 50, 3);
INSERT INTO favorites VALUES (4676, 95, 1);
INSERT INTO favorites VALUES (4676, 105, 2);
INSERT INTO favorites VALUES (4676, 9, 4);
INSERT INTO favorites VALUES (4677, 37, 1);
INSERT INTO favorites VALUES (4677, 1, 2);
INSERT INTO favorites VALUES (4678, 20, 4);
INSERT INTO favorites VALUES (4678, 18, 2);
INSERT INTO favorites VALUES (4678, 54, 1);
INSERT INTO favorites VALUES (4678, 8, 3);
INSERT INTO favorites VALUES (4679, 116, 3);
INSERT INTO favorites VALUES (4679, 75, 1);
INSERT INTO favorites VALUES (4679, 44, 2);
INSERT INTO favorites VALUES (4681, 75, 3);
INSERT INTO favorites VALUES (4681, 14, 2);
INSERT INTO favorites VALUES (4681, 91, 1);
INSERT INTO favorites VALUES (4681, 38, 4);
INSERT INTO favorites VALUES (4682, 16, 4);
INSERT INTO favorites VALUES (4682, 52, 5);
INSERT INTO favorites VALUES (4682, 21, 2);
INSERT INTO favorites VALUES (4682, 14, 1);
INSERT INTO favorites VALUES (4682, 71, 3);
INSERT INTO favorites VALUES (4683, 6, 1);
INSERT INTO favorites VALUES (4683, 103, 2);
INSERT INTO favorites VALUES (4685, 51, 2);
INSERT INTO favorites VALUES (4685, 44, 1);
INSERT INTO favorites VALUES (4686, 8, 2);
INSERT INTO favorites VALUES (4686, 15, 1);
INSERT INTO favorites VALUES (4687, 2, 1);
INSERT INTO favorites VALUES (4687, 76, 2);
INSERT INTO favorites VALUES (4688, 101, 4);
INSERT INTO favorites VALUES (4688, 28, 1);
INSERT INTO favorites VALUES (4688, 69, 3);
INSERT INTO favorites VALUES (4688, 41, 2);
INSERT INTO favorites VALUES (4689, 12, 3);
INSERT INTO favorites VALUES (4689, 78, 1);
INSERT INTO favorites VALUES (4689, 80, 2);
INSERT INTO favorites VALUES (4690, 42, 1);
INSERT INTO favorites VALUES (4690, 78, 2);
INSERT INTO favorites VALUES (4691, 93, 2);
INSERT INTO favorites VALUES (4691, 39, 1);
INSERT INTO favorites VALUES (4692, 113, 1);
INSERT INTO favorites VALUES (4692, 57, 2);
INSERT INTO favorites VALUES (4693, 26, 1);
INSERT INTO favorites VALUES (4694, 80, 5);
INSERT INTO favorites VALUES (4694, 67, 7);
INSERT INTO favorites VALUES (4694, 23, 6);
INSERT INTO favorites VALUES (4694, 60, 1);
INSERT INTO favorites VALUES (4694, 25, 3);
INSERT INTO favorites VALUES (4694, 88, 4);
INSERT INTO favorites VALUES (4694, 89, 2);
INSERT INTO favorites VALUES (4695, 36, 3);
INSERT INTO favorites VALUES (4695, 39, 1);
INSERT INTO favorites VALUES (4695, 82, 2);
INSERT INTO favorites VALUES (4696, 44, 1);
INSERT INTO favorites VALUES (4696, 103, 2);
INSERT INTO favorites VALUES (4697, 63, 1);
INSERT INTO favorites VALUES (4698, 21, 1);
INSERT INTO favorites VALUES (4698, 17, 2);
INSERT INTO favorites VALUES (4699, 33, 2);
INSERT INTO favorites VALUES (4699, 45, 3);
INSERT INTO favorites VALUES (4699, 16, 1);
INSERT INTO favorites VALUES (4699, 57, 5);
INSERT INTO favorites VALUES (4699, 22, 4);
INSERT INTO favorites VALUES (4700, 23, 1);
INSERT INTO favorites VALUES (4700, 63, 2);
INSERT INTO favorites VALUES (4700, 58, 3);
INSERT INTO favorites VALUES (4700, 94, 4);
INSERT INTO favorites VALUES (4700, 104, 5);
INSERT INTO favorites VALUES (4702, 4, 3);
INSERT INTO favorites VALUES (4702, 60, 4);
INSERT INTO favorites VALUES (4702, 40, 2);
INSERT INTO favorites VALUES (4702, 71, 1);
INSERT INTO favorites VALUES (4703, 33, 5);
INSERT INTO favorites VALUES (4703, 62, 2);
INSERT INTO favorites VALUES (4703, 2, 3);
INSERT INTO favorites VALUES (4703, 52, 1);
INSERT INTO favorites VALUES (4703, 29, 6);
INSERT INTO favorites VALUES (4703, 99, 4);
INSERT INTO favorites VALUES (4704, 82, 3);
INSERT INTO favorites VALUES (4704, 6, 2);
INSERT INTO favorites VALUES (4704, 32, 1);
INSERT INTO favorites VALUES (4705, 7, 3);
INSERT INTO favorites VALUES (4705, 25, 1);
INSERT INTO favorites VALUES (4705, 54, 4);
INSERT INTO favorites VALUES (4705, 35, 2);
INSERT INTO favorites VALUES (4706, 57, 1);
INSERT INTO favorites VALUES (4706, 44, 2);
INSERT INTO favorites VALUES (4707, 9, 4);
INSERT INTO favorites VALUES (4707, 71, 6);
INSERT INTO favorites VALUES (4707, 81, 2);
INSERT INTO favorites VALUES (4707, 20, 7);
INSERT INTO favorites VALUES (4707, 9, 1);
INSERT INTO favorites VALUES (4707, 89, 5);
INSERT INTO favorites VALUES (4707, 101, 3);
INSERT INTO favorites VALUES (4708, 108, 2);
INSERT INTO favorites VALUES (4708, 59, 1);
INSERT INTO favorites VALUES (4708, 37, 3);
INSERT INTO favorites VALUES (4709, 33, 5);
INSERT INTO favorites VALUES (4709, 11, 1);
INSERT INTO favorites VALUES (4709, 92, 6);
INSERT INTO favorites VALUES (4709, 86, 3);
INSERT INTO favorites VALUES (4709, 19, 2);
INSERT INTO favorites VALUES (4709, 40, 4);
INSERT INTO favorites VALUES (4710, 16, 2);
INSERT INTO favorites VALUES (4710, 39, 1);
INSERT INTO favorites VALUES (4712, 74, 2);
INSERT INTO favorites VALUES (4712, 46, 1);
INSERT INTO favorites VALUES (4713, 2, 4);
INSERT INTO favorites VALUES (4713, 77, 2);
INSERT INTO favorites VALUES (4713, 36, 3);
INSERT INTO favorites VALUES (4713, 110, 1);
INSERT INTO favorites VALUES (4714, 52, 2);
INSERT INTO favorites VALUES (4714, 28, 1);
INSERT INTO favorites VALUES (4714, 14, 3);
INSERT INTO favorites VALUES (4715, 20, 2);
INSERT INTO favorites VALUES (4715, 29, 1);
INSERT INTO favorites VALUES (4716, 72, 1);
INSERT INTO favorites VALUES (4718, 37, 3);
INSERT INTO favorites VALUES (4718, 55, 1);
INSERT INTO favorites VALUES (4718, 50, 2);
INSERT INTO favorites VALUES (4719, 58, 4);
INSERT INTO favorites VALUES (4719, 18, 1);
INSERT INTO favorites VALUES (4719, 100, 2);
INSERT INTO favorites VALUES (4719, 28, 3);
INSERT INTO favorites VALUES (4720, 17, 2);
INSERT INTO favorites VALUES (4720, 76, 1);
INSERT INTO favorites VALUES (4720, 108, 3);
INSERT INTO favorites VALUES (4720, 46, 4);
INSERT INTO favorites VALUES (4721, 12, 2);
INSERT INTO favorites VALUES (4721, 9, 1);
INSERT INTO favorites VALUES (4721, 112, 4);
INSERT INTO favorites VALUES (4721, 34, 3);
INSERT INTO favorites VALUES (4722, 39, 1);
INSERT INTO favorites VALUES (4722, 24, 2);
INSERT INTO favorites VALUES (4723, 91, 1);
INSERT INTO favorites VALUES (4725, 18, 1);
INSERT INTO favorites VALUES (4725, 50, 2);
INSERT INTO favorites VALUES (4726, 84, 3);
INSERT INTO favorites VALUES (4726, 54, 1);
INSERT INTO favorites VALUES (4726, 32, 2);
INSERT INTO favorites VALUES (4727, 46, 2);
INSERT INTO favorites VALUES (4727, 78, 1);
INSERT INTO favorites VALUES (4727, 78, 3);
INSERT INTO favorites VALUES (4728, 43, 3);
INSERT INTO favorites VALUES (4728, 57, 2);
INSERT INTO favorites VALUES (4728, 50, 1);
INSERT INTO favorites VALUES (4728, 45, 4);
INSERT INTO favorites VALUES (4729, 104, 4);
INSERT INTO favorites VALUES (4729, 1, 1);
INSERT INTO favorites VALUES (4729, 62, 2);
INSERT INTO favorites VALUES (4729, 34, 3);
INSERT INTO favorites VALUES (4730, 58, 1);
INSERT INTO favorites VALUES (4731, 28, 3);
INSERT INTO favorites VALUES (4731, 84, 1);
INSERT INTO favorites VALUES (4731, 17, 2);
INSERT INTO favorites VALUES (4732, 34, 3);
INSERT INTO favorites VALUES (4732, 36, 2);
INSERT INTO favorites VALUES (4732, 13, 1);
INSERT INTO favorites VALUES (4732, 70, 4);
INSERT INTO favorites VALUES (4733, 48, 3);
INSERT INTO favorites VALUES (4733, 10, 2);
INSERT INTO favorites VALUES (4733, 98, 1);
INSERT INTO favorites VALUES (4734, 37, 1);
INSERT INTO favorites VALUES (4735, 79, 1);
INSERT INTO favorites VALUES (4735, 64, 2);
INSERT INTO favorites VALUES (4736, 59, 1);
INSERT INTO favorites VALUES (4736, 24, 2);
INSERT INTO favorites VALUES (4737, 17, 4);
INSERT INTO favorites VALUES (4737, 11, 1);
INSERT INTO favorites VALUES (4737, 41, 2);
INSERT INTO favorites VALUES (4737, 17, 3);
INSERT INTO favorites VALUES (4738, 92, 1);
INSERT INTO favorites VALUES (4739, 61, 5);
INSERT INTO favorites VALUES (4739, 44, 3);
INSERT INTO favorites VALUES (4739, 91, 1);
INSERT INTO favorites VALUES (4739, 21, 2);
INSERT INTO favorites VALUES (4739, 17, 4);
INSERT INTO favorites VALUES (4740, 24, 5);
INSERT INTO favorites VALUES (4740, 4, 3);
INSERT INTO favorites VALUES (4740, 78, 1);
INSERT INTO favorites VALUES (4740, 53, 2);
INSERT INTO favorites VALUES (4740, 80, 4);
INSERT INTO favorites VALUES (4741, 26, 2);
INSERT INTO favorites VALUES (4741, 40, 1);
INSERT INTO favorites VALUES (4741, 39, 3);
INSERT INTO favorites VALUES (4743, 33, 1);
INSERT INTO favorites VALUES (4743, 82, 2);
INSERT INTO favorites VALUES (4744, 64, 1);
INSERT INTO favorites VALUES (4744, 18, 2);
INSERT INTO favorites VALUES (4745, 66, 3);
INSERT INTO favorites VALUES (4745, 55, 1);
INSERT INTO favorites VALUES (4745, 22, 2);
INSERT INTO favorites VALUES (4745, 114, 4);
INSERT INTO favorites VALUES (4747, 2, 1);
INSERT INTO favorites VALUES (4747, 81, 2);
INSERT INTO favorites VALUES (4748, 37, 3);
INSERT INTO favorites VALUES (4748, 55, 1);
INSERT INTO favorites VALUES (4748, 30, 2);
INSERT INTO favorites VALUES (4749, 67, 2);
INSERT INTO favorites VALUES (4749, 49, 1);
INSERT INTO favorites VALUES (4749, 82, 3);
INSERT INTO favorites VALUES (4750, 3, 1);
INSERT INTO favorites VALUES (4750, 27, 2);
INSERT INTO favorites VALUES (4751, 74, 1);
INSERT INTO favorites VALUES (4752, 30, 3);
INSERT INTO favorites VALUES (4752, 18, 2);
INSERT INTO favorites VALUES (4752, 100, 1);
INSERT INTO favorites VALUES (4752, 5, 4);
INSERT INTO favorites VALUES (4753, 22, 3);
INSERT INTO favorites VALUES (4753, 7, 2);
INSERT INTO favorites VALUES (4753, 6, 1);
INSERT INTO favorites VALUES (4754, 67, 3);
INSERT INTO favorites VALUES (4754, 79, 2);
INSERT INTO favorites VALUES (4754, 92, 1);
INSERT INTO favorites VALUES (4754, 21, 4);
INSERT INTO favorites VALUES (4755, 65, 4);
INSERT INTO favorites VALUES (4755, 45, 2);
INSERT INTO favorites VALUES (4755, 86, 3);
INSERT INTO favorites VALUES (4755, 49, 1);
INSERT INTO favorites VALUES (4756, 62, 1);
INSERT INTO favorites VALUES (4756, 52, 2);
INSERT INTO favorites VALUES (4757, 61, 2);
INSERT INTO favorites VALUES (4757, 63, 1);
INSERT INTO favorites VALUES (4758, 85, 3);
INSERT INTO favorites VALUES (4758, 71, 2);
INSERT INTO favorites VALUES (4758, 21, 1);
INSERT INTO favorites VALUES (4760, 73, 4);
INSERT INTO favorites VALUES (4760, 90, 2);
INSERT INTO favorites VALUES (4760, 54, 1);
INSERT INTO favorites VALUES (4760, 92, 3);
INSERT INTO favorites VALUES (4761, 28, 1);
INSERT INTO favorites VALUES (4761, 88, 2);
INSERT INTO favorites VALUES (4762, 92, 1);
INSERT INTO favorites VALUES (4762, 70, 2);
INSERT INTO favorites VALUES (4762, 62, 5);
INSERT INTO favorites VALUES (4762, 26, 4);
INSERT INTO favorites VALUES (4762, 64, 3);
INSERT INTO favorites VALUES (4763, 108, 4);
INSERT INTO favorites VALUES (4763, 29, 5);
INSERT INTO favorites VALUES (4763, 20, 2);
INSERT INTO favorites VALUES (4763, 109, 1);
INSERT INTO favorites VALUES (4763, 75, 3);
INSERT INTO favorites VALUES (4764, 78, 1);
INSERT INTO favorites VALUES (4764, 72, 2);
INSERT INTO favorites VALUES (4765, 14, 7);
INSERT INTO favorites VALUES (4765, 46, 4);
INSERT INTO favorites VALUES (4765, 16, 5);
INSERT INTO favorites VALUES (4765, 52, 1);
INSERT INTO favorites VALUES (4765, 89, 3);
INSERT INTO favorites VALUES (4765, 24, 2);
INSERT INTO favorites VALUES (4765, 10, 6);
INSERT INTO favorites VALUES (4766, 25, 1);
INSERT INTO favorites VALUES (4766, 27, 4);
INSERT INTO favorites VALUES (4766, 51, 3);
INSERT INTO favorites VALUES (4766, 113, 2);
INSERT INTO favorites VALUES (4767, 57, 1);
INSERT INTO favorites VALUES (4768, 81, 4);
INSERT INTO favorites VALUES (4768, 27, 1);
INSERT INTO favorites VALUES (4768, 52, 2);
INSERT INTO favorites VALUES (4768, 36, 3);
INSERT INTO favorites VALUES (4769, 3, 4);
INSERT INTO favorites VALUES (4769, 36, 2);
INSERT INTO favorites VALUES (4769, 31, 1);
INSERT INTO favorites VALUES (4769, 37, 3);
INSERT INTO favorites VALUES (4770, 60, 1);
INSERT INTO favorites VALUES (4771, 99, 1);
INSERT INTO favorites VALUES (4772, 28, 3);
INSERT INTO favorites VALUES (4772, 57, 1);
INSERT INTO favorites VALUES (4772, 25, 2);
INSERT INTO favorites VALUES (4774, 59, 3);
INSERT INTO favorites VALUES (4774, 17, 1);
INSERT INTO favorites VALUES (4774, 4, 2);
INSERT INTO favorites VALUES (4775, 72, 1);
INSERT INTO favorites VALUES (4776, 47, 6);
INSERT INTO favorites VALUES (4776, 45, 4);
INSERT INTO favorites VALUES (4776, 49, 5);
INSERT INTO favorites VALUES (4776, 41, 3);
INSERT INTO favorites VALUES (4776, 1, 1);
INSERT INTO favorites VALUES (4776, 49, 2);
INSERT INTO favorites VALUES (4778, 9, 2);
INSERT INTO favorites VALUES (4778, 67, 1);
INSERT INTO favorites VALUES (4778, 20, 3);
INSERT INTO favorites VALUES (4779, 5, 3);
INSERT INTO favorites VALUES (4779, 22, 1);
INSERT INTO favorites VALUES (4779, 6, 2);
INSERT INTO favorites VALUES (4780, 96, 6);
INSERT INTO favorites VALUES (4780, 17, 5);
INSERT INTO favorites VALUES (4780, 75, 4);
INSERT INTO favorites VALUES (4780, 15, 2);
INSERT INTO favorites VALUES (4780, 2, 3);
INSERT INTO favorites VALUES (4780, 116, 1);
INSERT INTO favorites VALUES (4782, 51, 1);
INSERT INTO favorites VALUES (4783, 70, 6);
INSERT INTO favorites VALUES (4783, 9, 7);
INSERT INTO favorites VALUES (4783, 34, 5);
INSERT INTO favorites VALUES (4783, 13, 1);
INSERT INTO favorites VALUES (4783, 77, 2);
INSERT INTO favorites VALUES (4783, 112, 3);
INSERT INTO favorites VALUES (4783, 79, 4);
INSERT INTO favorites VALUES (4784, 102, 1);
INSERT INTO favorites VALUES (4784, 77, 2);
INSERT INTO favorites VALUES (4785, 10, 1);
INSERT INTO favorites VALUES (4786, 66, 1);
INSERT INTO favorites VALUES (4787, 77, 2);
INSERT INTO favorites VALUES (4787, 94, 1);
INSERT INTO favorites VALUES (4788, 92, 2);
INSERT INTO favorites VALUES (4788, 40, 1);
INSERT INTO favorites VALUES (4789, 95, 3);
INSERT INTO favorites VALUES (4789, 1, 1);
INSERT INTO favorites VALUES (4789, 11, 2);
INSERT INTO favorites VALUES (4790, 36, 1);
INSERT INTO favorites VALUES (4790, 85, 2);
INSERT INTO favorites VALUES (4791, 42, 5);
INSERT INTO favorites VALUES (4791, 4, 3);
INSERT INTO favorites VALUES (4791, 25, 2);
INSERT INTO favorites VALUES (4791, 29, 1);
INSERT INTO favorites VALUES (4791, 76, 4);
INSERT INTO favorites VALUES (4793, 101, 1);
INSERT INTO favorites VALUES (4794, 47, 4);
INSERT INTO favorites VALUES (4794, 31, 5);
INSERT INTO favorites VALUES (4794, 31, 3);
INSERT INTO favorites VALUES (4794, 106, 1);
INSERT INTO favorites VALUES (4794, 96, 2);
INSERT INTO favorites VALUES (4795, 84, 3);
INSERT INTO favorites VALUES (4795, 111, 1);
INSERT INTO favorites VALUES (4795, 49, 2);
INSERT INTO favorites VALUES (4796, 83, 1);
INSERT INTO favorites VALUES (4799, 17, 3);
INSERT INTO favorites VALUES (4799, 109, 1);
INSERT INTO favorites VALUES (4799, 57, 2);
INSERT INTO favorites VALUES (4800, 11, 1);
INSERT INTO favorites VALUES (4800, 95, 5);
INSERT INTO favorites VALUES (4800, 55, 3);
INSERT INTO favorites VALUES (4800, 11, 4);
INSERT INTO favorites VALUES (4800, 63, 2);
INSERT INTO favorites VALUES (4801, 93, 3);
INSERT INTO favorites VALUES (4801, 15, 2);
INSERT INTO favorites VALUES (4801, 33, 1);
INSERT INTO favorites VALUES (4802, 38, 1);
INSERT INTO favorites VALUES (4803, 13, 2);
INSERT INTO favorites VALUES (4803, 14, 1);
INSERT INTO favorites VALUES (4804, 7, 1);
INSERT INTO favorites VALUES (4804, 109, 2);
INSERT INTO favorites VALUES (4805, 77, 1);
INSERT INTO favorites VALUES (4805, 115, 2);
INSERT INTO favorites VALUES (4806, 58, 1);
INSERT INTO favorites VALUES (4806, 51, 2);
INSERT INTO favorites VALUES (4807, 51, 5);
INSERT INTO favorites VALUES (4807, 59, 6);
INSERT INTO favorites VALUES (4807, 82, 7);
INSERT INTO favorites VALUES (4807, 69, 1);
INSERT INTO favorites VALUES (4807, 91, 3);
INSERT INTO favorites VALUES (4807, 19, 4);
INSERT INTO favorites VALUES (4807, 10, 2);
INSERT INTO favorites VALUES (4808, 59, 1);
INSERT INTO favorites VALUES (4809, 113, 5);
INSERT INTO favorites VALUES (4809, 35, 2);
INSERT INTO favorites VALUES (4809, 1, 1);
INSERT INTO favorites VALUES (4809, 56, 4);
INSERT INTO favorites VALUES (4809, 24, 3);
INSERT INTO favorites VALUES (4810, 67, 1);
INSERT INTO favorites VALUES (4810, 92, 2);
INSERT INTO favorites VALUES (4811, 68, 2);
INSERT INTO favorites VALUES (4811, 106, 1);
INSERT INTO favorites VALUES (4811, 7, 3);
INSERT INTO favorites VALUES (4812, 97, 5);
INSERT INTO favorites VALUES (4812, 14, 4);
INSERT INTO favorites VALUES (4812, 42, 3);
INSERT INTO favorites VALUES (4812, 14, 1);
INSERT INTO favorites VALUES (4812, 16, 2);
INSERT INTO favorites VALUES (4813, 57, 1);
INSERT INTO favorites VALUES (4814, 3, 3);
INSERT INTO favorites VALUES (4814, 112, 1);
INSERT INTO favorites VALUES (4814, 54, 2);
INSERT INTO favorites VALUES (4815, 110, 1);
INSERT INTO favorites VALUES (4815, 9, 2);
INSERT INTO favorites VALUES (4816, 44, 1);
INSERT INTO favorites VALUES (4816, 84, 2);
INSERT INTO favorites VALUES (4818, 85, 1);
INSERT INTO favorites VALUES (4819, 33, 3);
INSERT INTO favorites VALUES (4819, 7, 1);
INSERT INTO favorites VALUES (4819, 113, 2);
INSERT INTO favorites VALUES (4820, 43, 1);
INSERT INTO favorites VALUES (4821, 10, 2);
INSERT INTO favorites VALUES (4821, 45, 1);
INSERT INTO favorites VALUES (4822, 60, 1);
INSERT INTO favorites VALUES (4823, 44, 2);
INSERT INTO favorites VALUES (4823, 77, 1);
INSERT INTO favorites VALUES (4823, 53, 3);
INSERT INTO favorites VALUES (4824, 27, 4);
INSERT INTO favorites VALUES (4824, 93, 2);
INSERT INTO favorites VALUES (4824, 3, 1);
INSERT INTO favorites VALUES (4824, 86, 3);
INSERT INTO favorites VALUES (4825, 37, 1);
INSERT INTO favorites VALUES (4825, 6, 2);
INSERT INTO favorites VALUES (4826, 68, 1);
INSERT INTO favorites VALUES (4826, 39, 2);
INSERT INTO favorites VALUES (4827, 90, 2);
INSERT INTO favorites VALUES (4827, 21, 1);
INSERT INTO favorites VALUES (4827, 31, 3);
INSERT INTO favorites VALUES (4828, 20, 4);
INSERT INTO favorites VALUES (4828, 20, 5);
INSERT INTO favorites VALUES (4828, 80, 1);
INSERT INTO favorites VALUES (4828, 18, 2);
INSERT INTO favorites VALUES (4828, 79, 3);
INSERT INTO favorites VALUES (4828, 20, 6);
INSERT INTO favorites VALUES (4830, 46, 4);
INSERT INTO favorites VALUES (4830, 4, 1);
INSERT INTO favorites VALUES (4830, 71, 3);
INSERT INTO favorites VALUES (4830, 61, 2);
INSERT INTO favorites VALUES (4831, 79, 4);
INSERT INTO favorites VALUES (4831, 107, 1);
INSERT INTO favorites VALUES (4831, 12, 2);
INSERT INTO favorites VALUES (4831, 91, 3);
INSERT INTO favorites VALUES (4832, 5, 3);
INSERT INTO favorites VALUES (4832, 78, 1);
INSERT INTO favorites VALUES (4832, 7, 2);
INSERT INTO favorites VALUES (4833, 38, 1);
INSERT INTO favorites VALUES (4834, 61, 4);
INSERT INTO favorites VALUES (4834, 108, 3);
INSERT INTO favorites VALUES (4834, 21, 2);
INSERT INTO favorites VALUES (4834, 110, 1);
INSERT INTO favorites VALUES (4835, 39, 4);
INSERT INTO favorites VALUES (4835, 37, 1);
INSERT INTO favorites VALUES (4835, 93, 2);
INSERT INTO favorites VALUES (4835, 47, 3);
INSERT INTO favorites VALUES (4837, 89, 1);
INSERT INTO favorites VALUES (4837, 70, 3);
INSERT INTO favorites VALUES (4837, 79, 2);
INSERT INTO favorites VALUES (4838, 113, 3);
INSERT INTO favorites VALUES (4838, 22, 1);
INSERT INTO favorites VALUES (4838, 94, 2);
INSERT INTO favorites VALUES (4840, 88, 4);
INSERT INTO favorites VALUES (4840, 38, 1);
INSERT INTO favorites VALUES (4840, 28, 3);
INSERT INTO favorites VALUES (4840, 42, 2);
INSERT INTO favorites VALUES (4841, 2, 3);
INSERT INTO favorites VALUES (4841, 114, 1);
INSERT INTO favorites VALUES (4841, 3, 2);
INSERT INTO favorites VALUES (4841, 38, 4);
INSERT INTO favorites VALUES (4842, 4, 1);
INSERT INTO favorites VALUES (4842, 115, 2);
INSERT INTO favorites VALUES (4843, 113, 3);
INSERT INTO favorites VALUES (4843, 43, 2);
INSERT INTO favorites VALUES (4843, 91, 1);
INSERT INTO favorites VALUES (4844, 17, 6);
INSERT INTO favorites VALUES (4844, 80, 5);
INSERT INTO favorites VALUES (4844, 107, 1);
INSERT INTO favorites VALUES (4844, 103, 3);
INSERT INTO favorites VALUES (4844, 90, 4);
INSERT INTO favorites VALUES (4844, 91, 2);
INSERT INTO favorites VALUES (4845, 1, 2);
INSERT INTO favorites VALUES (4845, 27, 1);
INSERT INTO favorites VALUES (4845, 59, 3);
INSERT INTO favorites VALUES (4846, 94, 3);
INSERT INTO favorites VALUES (4846, 3, 1);
INSERT INTO favorites VALUES (4846, 3, 2);
INSERT INTO favorites VALUES (4847, 53, 2);
INSERT INTO favorites VALUES (4847, 36, 1);
INSERT INTO favorites VALUES (4848, 23, 3);
INSERT INTO favorites VALUES (4848, 23, 1);
INSERT INTO favorites VALUES (4848, 30, 2);
INSERT INTO favorites VALUES (4849, 27, 1);
INSERT INTO favorites VALUES (4849, 11, 2);
INSERT INTO favorites VALUES (4850, 57, 3);
INSERT INTO favorites VALUES (4850, 10, 1);
INSERT INTO favorites VALUES (4850, 27, 2);
INSERT INTO favorites VALUES (4851, 37, 2);
INSERT INTO favorites VALUES (4851, 107, 1);
INSERT INTO favorites VALUES (4851, 116, 3);
INSERT INTO favorites VALUES (4852, 20, 2);
INSERT INTO favorites VALUES (4852, 35, 1);
INSERT INTO favorites VALUES (4852, 13, 3);
INSERT INTO favorites VALUES (4853, 58, 1);
INSERT INTO favorites VALUES (4853, 105, 3);
INSERT INTO favorites VALUES (4853, 82, 2);
INSERT INTO favorites VALUES (4854, 32, 1);
INSERT INTO favorites VALUES (4855, 51, 5);
INSERT INTO favorites VALUES (4855, 100, 8);
INSERT INTO favorites VALUES (4855, 36, 6);
INSERT INTO favorites VALUES (4855, 29, 1);
INSERT INTO favorites VALUES (4855, 25, 3);
INSERT INTO favorites VALUES (4855, 81, 4);
INSERT INTO favorites VALUES (4855, 94, 2);
INSERT INTO favorites VALUES (4855, 106, 7);
INSERT INTO favorites VALUES (4856, 94, 5);
INSERT INTO favorites VALUES (4856, 54, 4);
INSERT INTO favorites VALUES (4856, 17, 1);
INSERT INTO favorites VALUES (4856, 3, 3);
INSERT INTO favorites VALUES (4856, 106, 2);
INSERT INTO favorites VALUES (4857, 3, 1);
INSERT INTO favorites VALUES (4857, 71, 2);
INSERT INTO favorites VALUES (4858, 5, 1);
INSERT INTO favorites VALUES (4858, 102, 2);
INSERT INTO favorites VALUES (4859, 3, 6);
INSERT INTO favorites VALUES (4859, 93, 7);
INSERT INTO favorites VALUES (4859, 7, 4);
INSERT INTO favorites VALUES (4859, 20, 1);
INSERT INTO favorites VALUES (4859, 53, 2);
INSERT INTO favorites VALUES (4859, 7, 3);
INSERT INTO favorites VALUES (4859, 102, 5);
INSERT INTO favorites VALUES (4860, 53, 1);
INSERT INTO favorites VALUES (4861, 13, 3);
INSERT INTO favorites VALUES (4861, 88, 2);
INSERT INTO favorites VALUES (4861, 95, 1);
INSERT INTO favorites VALUES (4862, 14, 1);
INSERT INTO favorites VALUES (4863, 107, 5);
INSERT INTO favorites VALUES (4863, 88, 3);
INSERT INTO favorites VALUES (4863, 116, 2);
INSERT INTO favorites VALUES (4863, 50, 1);
INSERT INTO favorites VALUES (4863, 62, 4);
INSERT INTO favorites VALUES (4864, 51, 4);
INSERT INTO favorites VALUES (4864, 2, 2);
INSERT INTO favorites VALUES (4864, 1, 1);
INSERT INTO favorites VALUES (4864, 83, 3);
INSERT INTO favorites VALUES (4866, 9, 1);
INSERT INTO favorites VALUES (4867, 10, 3);
INSERT INTO favorites VALUES (4867, 96, 1);
INSERT INTO favorites VALUES (4867, 94, 2);
INSERT INTO favorites VALUES (4868, 34, 2);
INSERT INTO favorites VALUES (4868, 53, 1);
INSERT INTO favorites VALUES (4868, 56, 3);
INSERT INTO favorites VALUES (4869, 14, 1);
INSERT INTO favorites VALUES (4870, 10, 3);
INSERT INTO favorites VALUES (4870, 7, 1);
INSERT INTO favorites VALUES (4870, 82, 2);
INSERT INTO favorites VALUES (4870, 86, 4);
INSERT INTO favorites VALUES (4871, 29, 5);
INSERT INTO favorites VALUES (4871, 46, 4);
INSERT INTO favorites VALUES (4871, 71, 3);
INSERT INTO favorites VALUES (4871, 62, 1);
INSERT INTO favorites VALUES (4871, 38, 2);
INSERT INTO favorites VALUES (4872, 2, 1);
INSERT INTO favorites VALUES (4872, 19, 2);
INSERT INTO favorites VALUES (4874, 46, 2);
INSERT INTO favorites VALUES (4874, 41, 1);
INSERT INTO favorites VALUES (4874, 28, 3);
INSERT INTO favorites VALUES (4875, 5, 7);
INSERT INTO favorites VALUES (4875, 7, 6);
INSERT INTO favorites VALUES (4875, 53, 3);
INSERT INTO favorites VALUES (4875, 1, 2);
INSERT INTO favorites VALUES (4875, 8, 5);
INSERT INTO favorites VALUES (4875, 81, 1);
INSERT INTO favorites VALUES (4875, 27, 4);
INSERT INTO favorites VALUES (4876, 26, 4);
INSERT INTO favorites VALUES (4876, 80, 1);
INSERT INTO favorites VALUES (4876, 59, 2);
INSERT INTO favorites VALUES (4876, 40, 3);
INSERT INTO favorites VALUES (4877, 9, 4);
INSERT INTO favorites VALUES (4877, 3, 5);
INSERT INTO favorites VALUES (4877, 65, 8);
INSERT INTO favorites VALUES (4877, 89, 1);
INSERT INTO favorites VALUES (4877, 83, 7);
INSERT INTO favorites VALUES (4877, 55, 2);
INSERT INTO favorites VALUES (4877, 10, 3);
INSERT INTO favorites VALUES (4877, 44, 6);
INSERT INTO favorites VALUES (4878, 10, 1);
INSERT INTO favorites VALUES (4879, 45, 3);
INSERT INTO favorites VALUES (4879, 59, 1);
INSERT INTO favorites VALUES (4879, 60, 2);
INSERT INTO favorites VALUES (4880, 23, 3);
INSERT INTO favorites VALUES (4880, 69, 2);
INSERT INTO favorites VALUES (4880, 52, 4);
INSERT INTO favorites VALUES (4880, 73, 1);
INSERT INTO favorites VALUES (4881, 9, 1);
INSERT INTO favorites VALUES (4881, 89, 3);
INSERT INTO favorites VALUES (4881, 102, 2);
INSERT INTO favorites VALUES (4882, 63, 2);
INSERT INTO favorites VALUES (4882, 53, 1);
INSERT INTO favorites VALUES (4883, 19, 1);
INSERT INTO favorites VALUES (4883, 83, 3);
INSERT INTO favorites VALUES (4883, 19, 2);
INSERT INTO favorites VALUES (4884, 39, 4);
INSERT INTO favorites VALUES (4884, 51, 6);
INSERT INTO favorites VALUES (4884, 66, 5);
INSERT INTO favorites VALUES (4884, 9, 1);
INSERT INTO favorites VALUES (4884, 13, 3);
INSERT INTO favorites VALUES (4884, 75, 2);
INSERT INTO favorites VALUES (4885, 64, 1);
INSERT INTO favorites VALUES (4885, 33, 4);
INSERT INTO favorites VALUES (4885, 14, 2);
INSERT INTO favorites VALUES (4885, 8, 3);
INSERT INTO favorites VALUES (4886, 33, 1);
INSERT INTO favorites VALUES (4886, 10, 2);
INSERT INTO favorites VALUES (4886, 41, 3);
INSERT INTO favorites VALUES (4887, 35, 2);
INSERT INTO favorites VALUES (4887, 102, 1);
INSERT INTO favorites VALUES (4888, 56, 1);
INSERT INTO favorites VALUES (4889, 68, 1);
INSERT INTO favorites VALUES (4889, 92, 2);
INSERT INTO favorites VALUES (4889, 36, 3);
INSERT INTO favorites VALUES (4890, 11, 1);
INSERT INTO favorites VALUES (4890, 75, 2);
INSERT INTO favorites VALUES (4890, 20, 4);
INSERT INTO favorites VALUES (4890, 49, 3);
INSERT INTO favorites VALUES (4892, 101, 1);
INSERT INTO favorites VALUES (4892, 79, 5);
INSERT INTO favorites VALUES (4892, 14, 4);
INSERT INTO favorites VALUES (4892, 64, 2);
INSERT INTO favorites VALUES (4892, 19, 3);
INSERT INTO favorites VALUES (4893, 112, 2);
INSERT INTO favorites VALUES (4893, 4, 1);
INSERT INTO favorites VALUES (4894, 103, 1);
INSERT INTO favorites VALUES (4894, 61, 2);
INSERT INTO favorites VALUES (4895, 74, 3);
INSERT INTO favorites VALUES (4895, 62, 1);
INSERT INTO favorites VALUES (4895, 41, 2);
INSERT INTO favorites VALUES (4896, 97, 1);
INSERT INTO favorites VALUES (4896, 34, 2);
INSERT INTO favorites VALUES (4898, 100, 2);
INSERT INTO favorites VALUES (4898, 88, 1);
INSERT INTO favorites VALUES (4898, 91, 3);
INSERT INTO favorites VALUES (4898, 21, 5);
INSERT INTO favorites VALUES (4898, 32, 4);
INSERT INTO favorites VALUES (4899, 61, 4);
INSERT INTO favorites VALUES (4899, 19, 2);
INSERT INTO favorites VALUES (4899, 111, 3);
INSERT INTO favorites VALUES (4899, 99, 1);
INSERT INTO favorites VALUES (4899, 92, 5);
INSERT INTO favorites VALUES (4900, 64, 1);
INSERT INTO favorites VALUES (4900, 10, 3);
INSERT INTO favorites VALUES (4900, 77, 2);
INSERT INTO favorites VALUES (4901, 7, 1);
INSERT INTO favorites VALUES (4901, 81, 2);
INSERT INTO favorites VALUES (4902, 25, 3);
INSERT INTO favorites VALUES (4902, 3, 2);
INSERT INTO favorites VALUES (4902, 43, 1);
INSERT INTO favorites VALUES (4903, 106, 1);
INSERT INTO favorites VALUES (4905, 93, 2);
INSERT INTO favorites VALUES (4905, 18, 1);
INSERT INTO favorites VALUES (4905, 30, 3);
INSERT INTO favorites VALUES (4906, 83, 4);
INSERT INTO favorites VALUES (4906, 42, 1);
INSERT INTO favorites VALUES (4906, 77, 2);
INSERT INTO favorites VALUES (4906, 13, 3);
INSERT INTO favorites VALUES (4907, 90, 1);
INSERT INTO favorites VALUES (4908, 36, 1);
INSERT INTO favorites VALUES (4908, 49, 2);
INSERT INTO favorites VALUES (4909, 37, 1);
INSERT INTO favorites VALUES (4910, 93, 2);
INSERT INTO favorites VALUES (4910, 40, 1);
INSERT INTO favorites VALUES (4910, 29, 3);
INSERT INTO favorites VALUES (4911, 63, 4);
INSERT INTO favorites VALUES (4911, 63, 3);
INSERT INTO favorites VALUES (4911, 66, 2);
INSERT INTO favorites VALUES (4911, 34, 1);
INSERT INTO favorites VALUES (4912, 10, 1);
INSERT INTO favorites VALUES (4913, 54, 3);
INSERT INTO favorites VALUES (4913, 31, 5);
INSERT INTO favorites VALUES (4913, 24, 1);
INSERT INTO favorites VALUES (4913, 112, 2);
INSERT INTO favorites VALUES (4913, 42, 4);
INSERT INTO favorites VALUES (4914, 78, 2);
INSERT INTO favorites VALUES (4914, 116, 1);
INSERT INTO favorites VALUES (4914, 85, 4);
INSERT INTO favorites VALUES (4914, 83, 3);
INSERT INTO favorites VALUES (4915, 26, 1);
INSERT INTO favorites VALUES (4915, 51, 2);
INSERT INTO favorites VALUES (4916, 56, 2);
INSERT INTO favorites VALUES (4916, 26, 1);
INSERT INTO favorites VALUES (4916, 22, 3);
INSERT INTO favorites VALUES (4917, 96, 3);
INSERT INTO favorites VALUES (4917, 100, 1);
INSERT INTO favorites VALUES (4917, 14, 2);
INSERT INTO favorites VALUES (4917, 19, 4);
INSERT INTO favorites VALUES (4918, 84, 1);
INSERT INTO favorites VALUES (4918, 81, 2);
INSERT INTO favorites VALUES (4919, 79, 1);
INSERT INTO favorites VALUES (4920, 75, 7);
INSERT INTO favorites VALUES (4920, 20, 6);
INSERT INTO favorites VALUES (4920, 96, 2);
INSERT INTO favorites VALUES (4920, 4, 1);
INSERT INTO favorites VALUES (4920, 55, 3);
INSERT INTO favorites VALUES (4920, 71, 4);
INSERT INTO favorites VALUES (4920, 29, 5);
INSERT INTO favorites VALUES (4921, 22, 3);
INSERT INTO favorites VALUES (4921, 45, 1);
INSERT INTO favorites VALUES (4921, 84, 2);
INSERT INTO favorites VALUES (4922, 62, 5);
INSERT INTO favorites VALUES (4922, 6, 3);
INSERT INTO favorites VALUES (4922, 37, 2);
INSERT INTO favorites VALUES (4922, 31, 1);
INSERT INTO favorites VALUES (4922, 107, 4);
INSERT INTO favorites VALUES (4923, 87, 5);
INSERT INTO favorites VALUES (4923, 63, 6);
INSERT INTO favorites VALUES (4923, 25, 1);
INSERT INTO favorites VALUES (4923, 67, 4);
INSERT INTO favorites VALUES (4923, 3, 3);
INSERT INTO favorites VALUES (4923, 31, 2);
INSERT INTO favorites VALUES (4924, 113, 4);
INSERT INTO favorites VALUES (4924, 12, 2);
INSERT INTO favorites VALUES (4924, 95, 3);
INSERT INTO favorites VALUES (4924, 39, 1);
INSERT INTO favorites VALUES (4925, 79, 3);
INSERT INTO favorites VALUES (4925, 30, 1);
INSERT INTO favorites VALUES (4925, 103, 2);
INSERT INTO favorites VALUES (4926, 70, 3);
INSERT INTO favorites VALUES (4926, 113, 1);
INSERT INTO favorites VALUES (4926, 12, 2);
INSERT INTO favorites VALUES (4926, 31, 4);
INSERT INTO favorites VALUES (4927, 78, 1);
INSERT INTO favorites VALUES (4927, 89, 2);
INSERT INTO favorites VALUES (4928, 46, 1);
INSERT INTO favorites VALUES (4928, 42, 2);
INSERT INTO favorites VALUES (4929, 3, 1);
INSERT INTO favorites VALUES (4929, 112, 2);
INSERT INTO favorites VALUES (4930, 27, 5);
INSERT INTO favorites VALUES (4930, 15, 3);
INSERT INTO favorites VALUES (4930, 64, 1);
INSERT INTO favorites VALUES (4930, 41, 2);
INSERT INTO favorites VALUES (4930, 23, 4);
INSERT INTO favorites VALUES (4931, 51, 5);
INSERT INTO favorites VALUES (4931, 31, 4);
INSERT INTO favorites VALUES (4931, 39, 2);
INSERT INTO favorites VALUES (4931, 86, 1);
INSERT INTO favorites VALUES (4931, 68, 3);
INSERT INTO favorites VALUES (4932, 6, 3);
INSERT INTO favorites VALUES (4932, 22, 1);
INSERT INTO favorites VALUES (4932, 24, 2);
INSERT INTO favorites VALUES (4933, 62, 2);
INSERT INTO favorites VALUES (4933, 31, 1);
INSERT INTO favorites VALUES (4933, 60, 3);
INSERT INTO favorites VALUES (4934, 4, 1);
INSERT INTO favorites VALUES (4934, 30, 2);
INSERT INTO favorites VALUES (4935, 61, 4);
INSERT INTO favorites VALUES (4935, 97, 1);
INSERT INTO favorites VALUES (4935, 37, 2);
INSERT INTO favorites VALUES (4935, 80, 3);
INSERT INTO favorites VALUES (4936, 55, 4);
INSERT INTO favorites VALUES (4936, 113, 5);
INSERT INTO favorites VALUES (4936, 44, 1);
INSERT INTO favorites VALUES (4936, 60, 3);
INSERT INTO favorites VALUES (4936, 77, 2);
INSERT INTO favorites VALUES (4937, 61, 1);
INSERT INTO favorites VALUES (4937, 65, 2);
INSERT INTO favorites VALUES (4938, 12, 1);
INSERT INTO favorites VALUES (4939, 50, 5);
INSERT INTO favorites VALUES (4939, 41, 6);
INSERT INTO favorites VALUES (4939, 40, 1);
INSERT INTO favorites VALUES (4939, 88, 3);
INSERT INTO favorites VALUES (4939, 20, 4);
INSERT INTO favorites VALUES (4939, 8, 2);
INSERT INTO favorites VALUES (4940, 112, 3);
INSERT INTO favorites VALUES (4940, 57, 2);
INSERT INTO favorites VALUES (4940, 35, 1);
INSERT INTO favorites VALUES (4941, 104, 1);
INSERT INTO favorites VALUES (4943, 65, 1);
INSERT INTO favorites VALUES (4943, 2, 2);
INSERT INTO favorites VALUES (4944, 51, 3);
INSERT INTO favorites VALUES (4944, 40, 4);
INSERT INTO favorites VALUES (4944, 61, 1);
INSERT INTO favorites VALUES (4944, 91, 5);
INSERT INTO favorites VALUES (4944, 56, 2);
INSERT INTO favorites VALUES (4945, 7, 3);
INSERT INTO favorites VALUES (4945, 1, 2);
INSERT INTO favorites VALUES (4945, 37, 1);
INSERT INTO favorites VALUES (4945, 91, 4);
INSERT INTO favorites VALUES (4946, 4, 3);
INSERT INTO favorites VALUES (4946, 81, 1);
INSERT INTO favorites VALUES (4946, 38, 2);
INSERT INTO favorites VALUES (4947, 69, 4);
INSERT INTO favorites VALUES (4947, 96, 5);
INSERT INTO favorites VALUES (4947, 9, 8);
INSERT INTO favorites VALUES (4947, 5, 1);
INSERT INTO favorites VALUES (4947, 100, 7);
INSERT INTO favorites VALUES (4947, 57, 2);
INSERT INTO favorites VALUES (4947, 54, 3);
INSERT INTO favorites VALUES (4947, 74, 6);
INSERT INTO favorites VALUES (4948, 33, 3);
INSERT INTO favorites VALUES (4948, 15, 1);
INSERT INTO favorites VALUES (4948, 20, 2);
INSERT INTO favorites VALUES (4949, 20, 8);
INSERT INTO favorites VALUES (4949, 96, 7);
INSERT INTO favorites VALUES (4949, 23, 5);
INSERT INTO favorites VALUES (4949, 107, 3);
INSERT INTO favorites VALUES (4949, 96, 4);
INSERT INTO favorites VALUES (4949, 16, 1);
INSERT INTO favorites VALUES (4949, 27, 2);
INSERT INTO favorites VALUES (4949, 20, 6);
INSERT INTO favorites VALUES (4950, 47, 1);
INSERT INTO favorites VALUES (4950, 19, 2);
INSERT INTO favorites VALUES (4951, 111, 2);
INSERT INTO favorites VALUES (4951, 36, 1);
INSERT INTO favorites VALUES (4952, 65, 3);
INSERT INTO favorites VALUES (4952, 80, 1);
INSERT INTO favorites VALUES (4952, 11, 2);
INSERT INTO favorites VALUES (4953, 11, 2);
INSERT INTO favorites VALUES (4953, 1, 1);
INSERT INTO favorites VALUES (4953, 34, 3);
INSERT INTO favorites VALUES (4954, 32, 1);
INSERT INTO favorites VALUES (4955, 94, 1);
INSERT INTO favorites VALUES (4955, 28, 2);
INSERT INTO favorites VALUES (4956, 17, 7);
INSERT INTO favorites VALUES (4956, 21, 8);
INSERT INTO favorites VALUES (4956, 5, 6);
INSERT INTO favorites VALUES (4956, 53, 5);
INSERT INTO favorites VALUES (4956, 10, 3);
INSERT INTO favorites VALUES (4956, 5, 4);
INSERT INTO favorites VALUES (4956, 21, 1);
INSERT INTO favorites VALUES (4956, 104, 2);
INSERT INTO favorites VALUES (4957, 104, 1);
INSERT INTO favorites VALUES (4957, 86, 2);
INSERT INTO favorites VALUES (4959, 68, 1);
INSERT INTO favorites VALUES (4959, 13, 2);
INSERT INTO favorites VALUES (4960, 44, 1);
INSERT INTO favorites VALUES (4961, 72, 1);
INSERT INTO favorites VALUES (4962, 16, 2);
INSERT INTO favorites VALUES (4962, 96, 3);
INSERT INTO favorites VALUES (4962, 40, 1);
INSERT INTO favorites VALUES (4962, 63, 5);
INSERT INTO favorites VALUES (4962, 107, 4);
INSERT INTO favorites VALUES (4963, 45, 1);
INSERT INTO favorites VALUES (4963, 44, 2);
INSERT INTO favorites VALUES (4964, 33, 3);
INSERT INTO favorites VALUES (4964, 5, 2);
INSERT INTO favorites VALUES (4964, 102, 1);
INSERT INTO favorites VALUES (4965, 1, 1);
INSERT INTO favorites VALUES (4965, 43, 2);
INSERT INTO favorites VALUES (4966, 50, 3);
INSERT INTO favorites VALUES (4966, 66, 2);
INSERT INTO favorites VALUES (4966, 6, 1);
INSERT INTO favorites VALUES (4967, 11, 1);
INSERT INTO favorites VALUES (4968, 2, 1);
INSERT INTO favorites VALUES (4969, 35, 5);
INSERT INTO favorites VALUES (4969, 13, 6);
INSERT INTO favorites VALUES (4969, 87, 7);
INSERT INTO favorites VALUES (4969, 112, 1);
INSERT INTO favorites VALUES (4969, 67, 4);
INSERT INTO favorites VALUES (4969, 44, 2);
INSERT INTO favorites VALUES (4969, 5, 3);
INSERT INTO favorites VALUES (4970, 28, 3);
INSERT INTO favorites VALUES (4970, 7, 1);
INSERT INTO favorites VALUES (4970, 9, 2);
INSERT INTO favorites VALUES (4971, 93, 1);
INSERT INTO favorites VALUES (4971, 20, 4);
INSERT INTO favorites VALUES (4971, 4, 3);
INSERT INTO favorites VALUES (4971, 26, 2);
INSERT INTO favorites VALUES (4972, 9, 4);
INSERT INTO favorites VALUES (4972, 32, 5);
INSERT INTO favorites VALUES (4972, 13, 1);
INSERT INTO favorites VALUES (4972, 58, 3);
INSERT INTO favorites VALUES (4972, 99, 2);
INSERT INTO favorites VALUES (4972, 46, 6);
INSERT INTO favorites VALUES (4973, 20, 3);
INSERT INTO favorites VALUES (4973, 87, 2);
INSERT INTO favorites VALUES (4973, 48, 1);
INSERT INTO favorites VALUES (4973, 74, 4);
INSERT INTO favorites VALUES (4974, 59, 3);
INSERT INTO favorites VALUES (4974, 74, 2);
INSERT INTO favorites VALUES (4974, 43, 1);
INSERT INTO favorites VALUES (4975, 14, 2);
INSERT INTO favorites VALUES (4975, 86, 1);
INSERT INTO favorites VALUES (4977, 13, 2);
INSERT INTO favorites VALUES (4977, 6, 1);
INSERT INTO favorites VALUES (4977, 86, 4);
INSERT INTO favorites VALUES (4977, 47, 3);
INSERT INTO favorites VALUES (4978, 71, 2);
INSERT INTO favorites VALUES (4978, 22, 1);
INSERT INTO favorites VALUES (4979, 25, 1);
INSERT INTO favorites VALUES (4979, 62, 2);
INSERT INTO favorites VALUES (4980, 58, 1);
INSERT INTO favorites VALUES (4981, 8, 2);
INSERT INTO favorites VALUES (4981, 17, 1);
INSERT INTO favorites VALUES (4982, 107, 3);
INSERT INTO favorites VALUES (4982, 105, 1);
INSERT INTO favorites VALUES (4982, 85, 2);
INSERT INTO favorites VALUES (4983, 52, 3);
INSERT INTO favorites VALUES (4983, 14, 1);
INSERT INTO favorites VALUES (4983, 22, 2);
INSERT INTO favorites VALUES (4983, 16, 4);
INSERT INTO favorites VALUES (4984, 102, 3);
INSERT INTO favorites VALUES (4984, 115, 1);
INSERT INTO favorites VALUES (4984, 84, 2);
INSERT INTO favorites VALUES (4985, 24, 1);
INSERT INTO favorites VALUES (4986, 34, 7);
INSERT INTO favorites VALUES (4986, 109, 6);
INSERT INTO favorites VALUES (4986, 23, 5);
INSERT INTO favorites VALUES (4986, 52, 3);
INSERT INTO favorites VALUES (4986, 94, 1);
INSERT INTO favorites VALUES (4986, 3, 2);
INSERT INTO favorites VALUES (4986, 18, 4);
INSERT INTO favorites VALUES (4987, 30, 5);
INSERT INTO favorites VALUES (4987, 66, 4);
INSERT INTO favorites VALUES (4987, 63, 3);
INSERT INTO favorites VALUES (4987, 31, 2);
INSERT INTO favorites VALUES (4987, 54, 1);
INSERT INTO favorites VALUES (4988, 72, 1);
INSERT INTO favorites VALUES (4988, 88, 2);
INSERT INTO favorites VALUES (4989, 48, 1);
INSERT INTO favorites VALUES (4990, 60, 8);
INSERT INTO favorites VALUES (4990, 106, 7);
INSERT INTO favorites VALUES (4990, 104, 3);
INSERT INTO favorites VALUES (4990, 99, 2);
INSERT INTO favorites VALUES (4990, 79, 4);
INSERT INTO favorites VALUES (4990, 72, 5);
INSERT INTO favorites VALUES (4990, 25, 1);
INSERT INTO favorites VALUES (4990, 68, 6);
INSERT INTO favorites VALUES (4991, 63, 1);
INSERT INTO favorites VALUES (4992, 59, 5);
INSERT INTO favorites VALUES (4992, 3, 4);
INSERT INTO favorites VALUES (4992, 69, 6);
INSERT INTO favorites VALUES (4992, 32, 1);
INSERT INTO favorites VALUES (4992, 37, 3);
INSERT INTO favorites VALUES (4992, 100, 2);
INSERT INTO favorites VALUES (4992, 87, 7);
INSERT INTO favorites VALUES (4993, 112, 3);
INSERT INTO favorites VALUES (4993, 100, 2);
INSERT INTO favorites VALUES (4993, 48, 1);
INSERT INTO favorites VALUES (4993, 69, 4);
INSERT INTO favorites VALUES (4994, 51, 3);
INSERT INTO favorites VALUES (4994, 37, 1);
INSERT INTO favorites VALUES (4994, 88, 2);
INSERT INTO favorites VALUES (4994, 4, 4);
INSERT INTO favorites VALUES (4995, 41, 6);
INSERT INTO favorites VALUES (4995, 96, 4);
INSERT INTO favorites VALUES (4995, 111, 3);
INSERT INTO favorites VALUES (4995, 9, 2);
INSERT INTO favorites VALUES (4995, 3, 1);
INSERT INTO favorites VALUES (4995, 13, 5);
INSERT INTO favorites VALUES (4996, 36, 4);
INSERT INTO favorites VALUES (4996, 76, 3);
INSERT INTO favorites VALUES (4996, 16, 2);
INSERT INTO favorites VALUES (4996, 67, 1);
INSERT INTO favorites VALUES (4997, 4, 3);
INSERT INTO favorites VALUES (4997, 8, 2);
INSERT INTO favorites VALUES (4997, 85, 1);
INSERT INTO favorites VALUES (4998, 5, 1);
INSERT INTO favorites VALUES (4998, 51, 2);
INSERT INTO favorites VALUES (4999, 114, 3);
INSERT INTO favorites VALUES (4999, 26, 1);
INSERT INTO favorites VALUES (4999, 33, 2);
INSERT INTO favorites VALUES (5000, 55, 1);





COMMIT;

PROMPT
PROMPT Informació introduïda.
PROMPT
SET ESCAPE OFF
SET FEEDBACK 6
